#!/usr/bin/python
# -*- coding: utf-8 -*-
# OBSKURA DOCUMENTATION 
# DATE: April 4th 2015
# AUTHOR: James C
# What: This is the list of useragents as a python list. Use it as for useragents import *

useragents = [
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.1) Gecko/20060111 Firefox/1.5.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)""",
"""Links (2.1pre15; FreeBSD 5.4-STABLE i386; 158x58)""",
"""Wget/1.8.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 8.0""",
"""Mediapartners-Google/2.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.5) Gecko/20031007 Firebird/0.7""",
"""Mozilla/4.04 [en] (WinNT; I)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.12) Gecko/20060205 Galeon/2.0.0 (Debian package 2.0.0-2)""",
"""lwp-trivial/1.41""",
"""Dillo/0.8.5-i18n-misc""",
"""NetBSD-ftp/20031210""",
"""Wget/1.10.2""",
"""Links (2.1pre20; NetBSD 2.1_STABLE i386; 145x54)""",
"""Lynx/2.8.5rel.5 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d""",
"""Lynx/2.8.5rel.3 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d""",
"""Links (2.1pre19; NetBSD 2.1_STABLE sparc64; 145x54)""",
"""Lynx/2.8.6dev.15 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d""",
"""Links (2.1pre14; IRIX64 6.5 IP27; 145x54)""",
"""Wget/1.10.1""",
"""ELinks/0.10.5 (textmode; FreeBSD 4.11-STABLE i386; 80x22-2)""",
"""Links (2.1pre20; FreeBSD 4.11-STABLE i386; 80x22)""",
"""Lynx/2.8.5rel.4 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d-p1""",
"""Opera/8.52 (X11; Linux i386; U; de)""",
"""Mozilla/5.0 (X11; U; NetBSD i386; en-US; rv:1.8.0.1) Gecko/20060310 Firefox/1.5.0.1""",
"""Mozilla/5.0 (X11; U; IRIX64 IP27; en-US; rv:1.4) Gecko/20030711""",
"""Mozilla/4.8 [en] (X11; U; IRIX64 6.5 IP27)""",
"""Mozilla/4.76 [en] (X11; U; SunOS 5.8 sun4m)""",
"""Opera/5.0 (SunOS 5.8 sun4m; U) [en]""",
"""Links (2.1pre15; SunOS 5.8 sun4m; 80x24)""",
"""Lynx/2.8.5rel.1 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d""",
"""Wget/1.8.1""",
"""Wget/1.9.1""",
"""tnftp/20050625""",
"""Links (1.00pre12; Linux 2.6.14.2.20051115 i686; 80x24) (Debian pkg 0.99+1.00pre12-1)""",
"""Lynx/2.8.5rel.1 libwww-FM/2.14 SSL-MM/1.4.1 GNUTLS/1.0.16""",
"""Mozilla/5.0 (X11; U; SunOS sun4u; en-US; rv:1.7) Gecko/20051122""",
"""Wget/1.7""",
"""Lynx/2.8.2rel.1 libwww-FM/2.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; de) Opera 8.53""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.8.0.1) Gecko/20060111 Firefox/1.5.0.1""",
"""Lynx/2.8.5rel.1 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7e""",
"""Links (2.1pre20; SunOS 5.10 sun4u; 80x22)""",
"""Lynx/2.8.5rel.5 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7i""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.8) Gecko/20060202 Firefox/1.5""",
"""Opera/8.51 (X11; Linux i386; U; de)""",
"""Emacs-W3/4.0pre.46 URL/p4.0pre.46 (i386--freebsd; X11)""",
"""Links (0.96; OpenBSD 3.0 sparc)""",
"""Lynx/2.8.4rel.1 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.6c""",
"""Lynx/2.8.3rel.1 libwww-FM/2.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.1) Gecko/20060111 Firefox/1.5.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)""",
"""libwww-perl/5.79""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; en) Opera 8.53""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.12) Gecko/20050919 Firefox/1.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""msnbot/1.0 (+http://search.msn.com/msnbot.htm)""",
"""Googlebot/2.1 (+http://www.google.com/bot.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.1) Gecko/20060111 Firefox/1.5.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.12) Gecko/20051008 Firefox/1.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; X11; Linux i686; en) Opera 8.51""",
"""Mozilla/5.0 (compatible; Konqueror/3.4; Linux) KHTML/3.4.3 (like Gecko)""",
"""Lynx/2.8.4rel.1 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7c""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)""",
"""Mozilla/5.0 (compatible; Yahoo! Slurp; http://help.yahoo.com/help/us/ysearch/slurp)""",
"""Mozilla/4.8 [en] (Windows NT 5.1; U)""",
"""Opera/8.51 (Windows NT 5.1; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)""",
"""Opera/8.51 (Windows NT 5.1; U; en;VWP-online.de)""",
"""sproose/0.1-alpha (sproose crawler; http://www.sproose.com/bot.html; crawler@sproose.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.1) Gecko/20060130 SeaMonkey/1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.1) Gecko/20060130 SeaMonkey/1.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.0.1) Gecko/20060111 Firefox/1.5.0.1""",
"""BrowserEmulator/0.9 see http://dejavu.org""",
"""Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 98; Win 9x 4.90)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:0.9.4.1) Gecko/20020508""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/125.2 (KHTML, like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.4) Gecko/20030624""",
"""iCCrawler (http://www.iccenter.net/bot.htm)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.6) Gecko/20050321 Firefox/1.0.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Maxthon; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.7.12) Gecko/20051013 Debian/1.7.12-1ubuntu1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8) Gecko/20051111 Firefox/1.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:0.9.4.1) Gecko/20020508 Netscape6/6.2.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; de) Opera 8.50""",
"""Mozilla/3.0 (x86 [de] Windows NT 5.0; Sun)""",
"""Java/1.4.1_04""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8) Gecko/20051111 Firefox/1.5""",
"""msnbot/0.9 (+http://search.msn.com/msnbot.htm)""",
"""NutchCVS/0.8-dev (Nutch running at UW; http://www.nutch.org/docs/en/bot.html; sycrawl@cs.washington.edu)""",
"""Mozilla/4.0 compatible ZyBorg/1.0 (wn-14.zyborg@looksmart.net; http://www.WISEnutbot.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; de) Opera 8.53""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.4) Gecko/20030619 Netscape/7.1 (ax)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/312.8 (KHTML, like Gecko) Safari/312.6""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows NT; DigExt)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 5.16; Mac_PowerPC)""",
"""Mozilla/4.0 (compatible; MSIE 5.01; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 98; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 95)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; AOL 7.0; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 5.17; Mac_PowerPC)""",
"""Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)""",
"""Mozilla/4.0 (compatible; MSIE 5.23; Mac_PowerPC)""",
"""Opera/8.53 (Windows NT 5.1; U; en)""",
"""Opera/8.01 (Windows NT 5.0; U; de)""",
"""Opera/8.54 (Windows NT 5.1; U; de)""",
"""Opera/8.53 (Windows NT 5.0; U; en)""",
"""Opera/8.01 (Windows NT 5.1; U; de)""",
"""Opera/8.50 (Windows NT 5.1; U; de)""",
"""Mozilla/4.0 (compatible- MSIE 6.0- Windows NT 5.1- SV1- .NET CLR 1.1.4322""",
"""Mozilla/4.0(compatible; MSIE 5.0; Windows 98; DigExt)""",
"""Mozilla/4.0 (compatible; Cerberian Drtrs Version-3.2-Build-0)""",
"""Mozilla/4.0 (compatible; AvantGo 6.0; FreeBSD)""",
"""Mozilla/4.5 [de] (Macintosh; I; PPC)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; .NET CLR 1.1.4322; MSN 9.0;MSN 9.1; MSNbMSNI; MSNmen-us; MSNcIA; MPLUS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {59FC8AE0-2D88-C929-DA8D-B559D01826E7}; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; snprtz|S04741035500914#914|isdn; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; EnergyPlugIn; dial)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; iebar; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312461; sbcydsl 3.12; YComp 5.0.0.0; YPC 3.2.0; .NET CLR 1.1.4322; yplus 5.1.02b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Arcor 5.004; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YComp 5.0.0.0; SV1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Ringo; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.0.1; .NET CLR 1.1.4322; yplus 4.1.00b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; YPC 3.2.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 7.0; Windows NT 5.1; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; BUILDWARE 1.6; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; HbTools 4.7.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; (R1 1.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; X11; Linux i686; it)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Arcor 5.004; FunWebProducts; HbTools 4.7.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; en)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Tablet PC 1.7)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312469)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Maxthon; SV1; FDM)""",
"""Mozilla/5.0 (Macintosh; U; PPC; de-DE; rv:1.0.2)""",
"""Mozilla/5.0 (Windows; U; Win98; de-DE; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.0.1)""",
"""Mozilla/5.0 (compatible; Konqueror/3.4; Linux 2.6.14-kanotix-9; X11)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Win98; de; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; nl; rv:1.8.0.1)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.7)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.6)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.8.0.1)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-us)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8)""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; de; rv:1.8.0.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.7.12)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; fr)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.7.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fi; rv:1.8.0.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.4.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr-FR; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; zh-TW; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.3)""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.7.12)""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; sl; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.0.1)""",
"""Mozilla/5.0 (X11; Linux i686; rv:1.7.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.7.6)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.7.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.6)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.7.6)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8a3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.8.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; en-US; rv:1.7.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-BR; rv:1.8.0.1)""",
"""Mozilla/5.0 (compatible; Konqueror/3; Linux)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.7.8)""",
"""Mozilla/5.0 (compatible; Konqueror/3.2; Linux)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; tg)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8b4)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; es-es)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; cs-CZ; rv:1.7.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.4)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; hu; rv:1.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-AR; rv:1.7.12)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Win98; fr; rv:1.7.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4)""",
"""Mozilla/5.0 (compatible; Konqueror/3.1-rc3; i686 Linux; 20020921)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.7.12)""",
"""Mozilla/5.0 (Windows 98; U)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.7.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; fr-FR; rv:1.7.12)""",
"""Mozilla/5.0 (compatible; Konqueror/3.0-rc2; i686 Linux; 20021203)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.6)""",
"""Mozilla/5.0 (X11; U; Linux i686; pl; rv:1.8.0.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.7)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; el; rv:1.8.0.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.7)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr-FR; rv:1.7.10)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7)""",
"""Mozilla/5.0 (compatible; Konqueror/3.1-rc6; i686 Linux; 20020718)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.5)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; nl-nl)""",
"""Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.7.5)""",
"""Mozilla/5.0 (compatible; Konqueror/3.1-rc3; i686 Linux; 20020104)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705; HbTools 4.7.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; Media Center PC 3.1; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; i-NavFourF)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; son0302CD; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; (R1 1.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; IBP; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIE 60)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; HbTools 4.7.3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MSN 6.1; MSNbMSFT; MSNmes-mx; MSNc00; MSNc00)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Xtra V3.5; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; yplus 5.1.02b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; 1&1 Internet AG by USt; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Arcor 5.004; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 1.1.4322; yplus 5.3.02b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Neostrada Plus 5.6)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Alexa Toolbar; mxie; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; SpamBlockerUtility 4.7.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Arcor 5.004)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; BCD2000; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Avant Browser; Avant Browser; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; MyIE2; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; Q312461; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Arcor 5.004)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DT)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; MSN 9.0;MSN 9.1; MSNbQ002; MSNmen-us; MSNcOTH; MPLUS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FDM; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; MSN 9.0;MSN 9.1; MSNbVZ02; MSNmen-us; MSNcOTH; MPLUS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 4.0; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; acc=Messenger; acc=none; iebar; (none)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; InfoPath.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; iebar; acc=; acc=none; (none)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; HbTools 4.7.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR Enabled)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 7.0; Windows NT 5.1; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; WYETH)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Wanadoo 7.1 ; NaviWoo1.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; 1&1 Internet AG by USt)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Naver Desktop Search)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; PeoplePal 6.2)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ru)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; DT)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; SYMPA)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; yplus 4.1.00b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sv)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; i-NavFourF)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; FDM; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; HbTools 4.7.5)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Q312461)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SiteKiosk 6.0 Build 98)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Secure IE 3.3.1286)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; OptusNetDSL6; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; DT)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; T-Online Internatinal AG; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; Media Center PC 3.1; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; DT; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.40607; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; AT&T CSM8.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt; Arcor 5.004)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; MaxiFiles; MaxiFilesTB; SV1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; (R1 1.3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50215)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Arcor 5.003; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; Media Center PC 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Wanadoo 6.7; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Maxthon)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; APDMDT; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; digit_may2002)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; yplus 5.3.03b)""",
"""Syntryx ANT Scout Chassis Pheromone; Mozilla/4.0 compatible crawler""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows XP)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.2) Gecko/20060308 Firefox/1.5.0.2""",
"""Java/1.5.0_06""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.3) Gecko/20060426 Firefox/1.5.0.3""",
"""UP.Browser/6.1.0.1.140 (Google CHTML Proxy/1.0)""",
"""Seekbot/1.0 (http://www.seekbot.net/bot.html) HTTPFetcher/2.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; acc=username; (username); SIMBAR Enabled)""",
"""Francis/2.0 (francis@neomo.de http://www.neomo.de/)""",
"""webmeasurement-bot, http://rvs.informatik.uni-leipzig.de/bot.php""",
"""cometrics-bot, http://www.cometrics.de""",
"""Gigabot/2.0; http://www.gigablast.com/spider.html""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.3) Gecko/20060426 Firefox/1.5.0.3""",
"""Snapbot/1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR Enabled; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows NT)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; cs; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/5.0 (Windows;) NimbleCrawler 2.0.1 obeys UserAgent NimbleCrawler For problems contact: crawler@healthline.com""",
"""Mozilla/4.0 (compatible; MyFamilyBot/1.0; http://www.myfamilyinc.com)""",
"""Opera/9.00 (X11; Linux i686; U; en)""",
"""gonzo1[P] mailto:crawleradmin.t-info@telekom.de""",
"""Mozilla/4.0 compatible ZyBorg/1.0 (wn-16.zyborg@looksmart.net; http://www.WISEnutbot.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; (R1 1.1); .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; {949A714E-AA23-419E-9892-82AB5CB8229B}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; da; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Avant Browser; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Opera/9.00 (Windows NT 5.1; U; da)""",
"""ia_archiver""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows NT; DigExt; DTS Agent""",
"""Exabot/2.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""vfkkhxhwshnlrwmsqtbxtWfthb gvngig j""",
"""aytseobqioqhA4xsq4h4AixndxqAyaxcAtmA""",
"""TeiTsi8oodxkrh8 cjbu nvt""",
"""bis edclpqka1lukrbrbdqee iu1dLuaa""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.2)""",
"""www.adressendeutschland.de""",
"""IRLbot/2.0 (compatible; MSIE 6.0; http://irl.cs.tamu.edu/crawler)""",
"""dvexsmO8xepu qqnfro8vlkcparvv88vsr qukb""",
"""Nusearch Spider (www.nusearch.com)""",
"""n n7tXfrfdqXnoXhaojnnfvyrstcx""",
"""Opera/9.01 (Windows NT 5.1; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Seekbot/1.0 (http://www.seekbot.net/bot.html) HTTPFetcher/2.2""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/418.8 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.6) Gecko/20060728 Firefox/1.5.0.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 1.0.3705; .NET CLR 2.0.50727; InfoPath.1)""",
"""Krugle/Krugle,Nutch/0.8+ (Krugle web crawler; http://corp.krugle.com/crawler/info.html; webcrawler@krugle.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.0.6) Gecko/20060728 Firefox/1.5.0.4 amosta060824-0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.0.6) Gecko/20060808 Fedora/1.5.0.6-2.fc5 Firefox/1.5.0.6 pango-text""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.0.6) Gecko/20060728 Firefox/1.5.0.6""",
"""ichiro/2.0 (http://help.goo.ne.jp/door/crawler.html)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50215)""",
"""Ylyhfxmweark shko xupxxnrhY""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; dcdev001; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Francis/2.0 (francis@neomo.de http://www.neomo.de/pages/crawler.php)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""oghewlt pphiisjjJchtkymoytjpcwuihls""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1)""",
"""xybccuegm rdgteaRym0dxyfj""",
"""Java/1.4.2_03""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Win98; de; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7""",
"""Opera/9.02 (Windows NT 5.1; U; en)""",
"""aiHTTP.cpp""",
"""Mozilla/4.5 (compatible; HTTrack 3.0x; Windows 98)""",
"""gonzo1[P] +http://www.suchen.de/popups/faq.jsp""",
"""sdfyofld0nw0yffxpdllmla0""",
"""msnbot-media/1.0 (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.7) Gecko/20060909 unknown""",
"""Lynx/2.8.3rel.1 libwww-FM/2.14FM""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Mac_PowerPC)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:0.9.4) Gecko/20011022 Netscape6/6.2""",
"""Mozilla/4.78 (Macintosh; U; PPC)""",
"""Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.0.0) Gecko/20020530""",
"""dmm dpk2mvsi2bknxwdxWWprrWiqranljwi""",
"""Mozilla/5.0 (compatible; Konqueror/3.3) KHTML/3.3.2 (like Gecko)""",
"""ebpt lgwpk7klxtyr cknwrbka""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; MathPlayer 2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; de) Opera 9.02""",
"""Mozilla/5.0 (Windows NT 5.1; U; de) Opera 9.02""",
"""Opera/9.02 (Windows NT 5.1; U; de)""",
"""voyager/1.0""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.0; H010818)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.0.1) Gecko/20060124 Firefox/1.5.0.1""",
"""ghik isycgl hyqhe t vm5pqxjuegbmqur gm""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.7.13) Gecko/20060724 Firefox/1.0.8 (Ubuntu package 1.0.8)""",
"""pnvhVhonecdenduv idr""",
"""hifufj7ugfqrgpoemdtorslcqk""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.0.8) Gecko/20061108 Fedora/1.5.0.8-1.fc5 Firefox/1.5.0.8""",
"""Mozilla/4.0 (compatible; MSIE 5.01; Windows NT)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""PycURL/7.15.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.8) Gecko/20061025 Firefox/1.5.0.8""",
"""woxhrcrg2yg eqccfc2cbkd""",
"""mhbxrhji ntumjeblllcw4x4eub4ky""",
"""Mozilla/4.0 (compatible; DepSpid/5.03; +http://about.depspid.net)""",
"""yacybot (x86 Windows 2000 5.0; java 1.5.0_09; Europe/de) yacy.net""",
"""lflxrxe Hhoyxpkhqmrt5eqipxylh""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.8) Gecko/20061025 Firefox/1.5.0.8""",
"""DomaindateiSpider/1.0 (http://www.domaindatei.de/spider.html * Deine Domain ist gespidert worden!!!""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.7.13) Gecko/20060411""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1""",
"""lnylvolrqwkdlrT fpqyTstiwTjjqgsld""",
"""cmowwdskrsy glylplhy1trsw t""",
"""sproose/1.0beta (sproose bot; http://www.sproose.com/bot.html; crawler@sproose.com)""",
"""shaaabdT3itiuxTotkskbcllsdmbabmdy""",
"""Mozilla/5.0 (compatible; Webbot/0.1; http://www.webbot.ru/bot.html)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:0.9.4) Gecko/20011022 Firefox/2.0.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.9) Gecko/20061206 Firefox/1.5.0.9""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Arcor 5.005; FunWebProducts)""",
"""Mozilla/5.0 (compatible; MojeekBot/2.0; http://www.mojeek.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""Exabot/3.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.9) Gecko/20061206 Firefox/1.5.0.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; cs; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1""",
"""WWWeasel Robot v1.00 (http://wwweasel.de)""",
"""TurnitinBot/2.1 (http://www.turnitin.com/robot/crawlerinfo.html)""",
"""Mo*illa/4.0 (comp*tible; MSI* 6.0; Wind*ws NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Opera/9.10 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (Windows; U; Win98; de-DE; rv:1.7.12) Gecko/20050919 Firefox/1.0.7""",
"""bJkbqkcqJfd7yeci xvb qvx""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; FDM)""",
"""Mozilla/5.0 (X11; Linux i686; rv:1.7.5) Gecko/20041108 Firefox/1.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.1) Gecko/20060601 Firefox/2.0.0.1 (Ubuntu-edgy)""",
"""larbin_2.6.3 larbin2.6.3@unspecified.mail""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.1) Gecko/20061205 Iceweasel/2.0.0.1 (Debian-2.0.0.1+dfsg-2)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.6) Gecko/20060808""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; en) Opera 8.0""",
"""MJ12bot/v1.2.0 (http://majestic12.co.uk/bot.php?+)""",
"""Mozilla/4.0 (compatible; Mozilla/5.0; Windows NT 5.0; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.1) Gecko/20061204 Firefox/2.0.0.1""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 95)""",
"""Semager/1.0 (http://www.semager.de)""",
"""Mozilla/5.0 (compatible; Interseek/3.1)""",
"""Python-urllib/2.4""",
"""Mozilla/5.0 (compatible; Najdi.si/3.1)""",
"""IRLbot/3.0 (compatible; MSIE 6.0; http://irl.cs.tamu.edu/crawler)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2""",
"""Jakarta Commons-HttpClient/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.10) Gecko/20070216 Firefox/1.5.0.10""",
"""Mozilla/5.0 (compatible; Exabot/3.0; +http://www.exabot.com/go/robot)""",
"""Snoopy v1.2""",
"""ShopWiki/1.0 ( +http://www.shopwiki.com/wiki/Help:Bot)""",
"""kNyetjpqiaibqNN ypyy id""",
"""ljtwpnh qElovqetkoq0ja""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0) Opera 7.23 [ca]""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; FDM; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.8.1.2pre) Gecko/20061023 SUSE/2.0.0.1-0.1 Firefox/2.0.0.2pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11""",
"""ICCrawler - ICjobs (http://www.icjobs.de/bot.htm)""",
"""CazoodleBot/0.1 (CazoodleBot Crawler; http://www.cazoodle.com; mqbot@cazoodle.com)""",
"""lmspider/Nutch-0.9-dev (For research purposes.; www.nuance.com)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows NT 4.0)""",
"""deepcrawler/1.0 (+http://deepcrawler.org/crawler.htm)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.7.12) Gecko/20051010 Firefox/1.0.7 (Ubuntu package 1.0.7) - http://www.amorosi4u.de.vu""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.2 (like Gecko)""",
"""Opera/9.10 (Windows NT 5.1; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Win64; x64; .NET CLR 2.0.50727; SLCC1; Media Center PC 5.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 5.0; Windows 98; Win 9x 4.90)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/4.0 (compatible; NaverBot/1.0; http://help.naver.com/delete_main.asp)""",
"""Snapbot/1.0 (+http://www.snap.com)""",
"""Speedy Spider (Entireweb; Beta/1.3; http://www.entireweb.com/about/search_tech/speedyspider/)""",
"""(X11; U; OpenBSD sparc64; de-DE)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0)""",
"""Java/1.5.0_08""",
"""http://www.uni-koblenz.de/~flocke/robot-info.txt""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1),gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.3) Gecko/20070412 Firefox/2.0.0.3""",
"""ilial/Nutch-0.9 (Ilial, Inc. is a Los Angeles based Internet startup company. For more information please visit http://www.ilial.com/crawler; http://www.ilial.com/crawler; crawl@ilial.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.12) Gecko/20050922 Fedora/1.0.7-1.1.fc4 Firefox/1.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""MQBOT/Nutch-0.9-dev (MQBOT Nutch Crawler; http://vwbot.cs.uiuc.edu; mqbot@cs.uiuc.edu)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.4) Gecko/20070515 ImageShackToolbar/4.0.7 Firefox/2.0.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.3 - mcrbdzujt3""",
"""Mozilla/5.0 (000000000; 0; 000 000 00 0; 00000) 000000000000000 0000000 0000 000000 000000000000""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Konqueror/3.0-rc4; (Konqueror/3.0-rc4; i686 Linux;;datecode)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Opera/9.21 (X11; Linux i686; U; en)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.1) Gecko/20040707""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.8.1.4) Gecko/20061201 Epiphany/2.18 Firefox/2.0.0.4 (Ubuntu-feisty)""",
"""Mozilla/5.0 (Windows; U; Win98; es-MX; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.8.1.2) Gecko/20070228 Firefox/2.0.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; WFX; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iOpus-I-M)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9a6pre) Gecko/20070702 Minefield/3.0a6pre""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.4) Gecko/20060601 Firefox/2.0.0.4 (Ubuntu-edgy)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.8.1.4) Gecko/20061201 Firefox/2.0.0.4 (Ubuntu-feisty)""",
"""Mozilla/4.0 (psp (PlayStation Portable); 2.00)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9a7pre) Gecko/2007070604 Minefield/3.0a7pre""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.2.1) Gecko/20021204""",
"""Mozilla/5.0 (compatible; idiot; ka)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-AT; rv:1.7) Gecko/20040608""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1) Gecko/20061010 SUSE/1.5.0.7-1.2 Firefox/2.0""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.1 (like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.4) Gecko/20070508 Iceweasel/2.0.0.4 (Debian-2.0.0.4-1)""",
"""CazoodleBot/Nutch-0.9-dev (CazoodleBot Crawler; http://www.cazoodle.com/cazoodlebot; cazoodlebot@cazoodle.com)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/522.11 (KHTML, like Gecko) Version/3.0.2 Safari/522.12""",
"""Opera/9.20 (Windows NT 6.0; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux 2.6.18.8-0.5-default; de) KHTML/3.5.7 (like Gecko) SUSE""",
"""Opera/9.21 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9a1) Gecko/20061204 GranParadiso/3.0a1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Googlebot-Image/1.0""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (compatible; Ultrawall/3.0; Linux i586; de-DE) Advanced Security by Linutronic[c]""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 1.0.3705; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.03)""",
"""Lynx/2.8.2pre.6 libwww-FM/2.14FM""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.5) Gecko/20061201 Firefox/2.0.0.5 (Ubuntu-feisty)""",
"""Mozilla/5.0 (Windows; U; Windows NT 4.0; en-US; rv:1.7.3) Gecko/20041002 Firefox/0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1) Gecko/20061023 LoL/2.0-30 MyBrowser/5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.8.0.2) Gecko/20060308 Firefox/1.5.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.4) Gecko/20070602 Firefox/2.0.0.4 (Swiftfox)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""hcIuvrnnrnIjyjvalhlodmhuho""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Frontpage""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/3.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/8.1.9.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; brip1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; WinuE v6)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en; rv:1.8.1.2) Gecko/20070224 BonEcho/2.0.0.2 (tete009 SSE PGO)""",
"""CazoodleBot/CazoodleBot-0.1 (CazoodleBot Crawler; http://www.cazoodle.com/cazoodlebot; cazoodlebot@cazoodle.com)""",
"""Opera/9.22 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (X11; U; SunOS sun4u; en-US; rv:1.8.1.6) Gecko/20070731 Firefox/2.0.0.5""",
"""MSIE 5.14 (Mac_PowerPC)""",
"""LapozzBot/1.5 (+http://robot.lapozz.hu)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1)""",
"""ficken/4.07 [en]pimmelpedro (Win2100; I) [planetporn]""",
"""Mozilla/6.0 (compatible; MSIE 8.0; Windows 7)""",
"""Microsoft Mozilla Firefox-DRM-edition/1.0 (Windows; U; Windows DRM DELUXE 2.0; de; rv:1) trojaner/DRM2 Microsoft Firefox/1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1a3) Gecko/20060526 BonEcho/2.0a3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Arcor 5.003; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050716 Firefox/1.0.6""",
"""Opera/9.23 (Windows NT 5.1; U; de)""",
"""Opera/9.22 (Windows NT 5.1; U; de)""",
"""libwww-perl/5.805""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.2; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20061201 Firefox/2.0.0.6 (Ubuntu-feisty)""",
"""hbtronix.spider.2 -- http://hbtronix.de/spider.php""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.4) Gecko/20070508 Iceweasel/2.0.0.4 (Debian-2.0.0.4-0etch1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/2.0 (compatible; MSIE 4.01; Windows 3.11)""",
"""Opera/9.20 (Windows NT 6.0; U; de)""",
"""Mozilla/4.8 [en] (Windows NT 6.0; U)""",
"""die Liste hier is ganz nett :o)""",
"""Hab mit einigen Browsern schon nen Treffer gelandet :D""",
"""IntÃ¤rnetz Brauser 1.0""",
"""Internetz Brauser 1.0 (Commodore C64 ; GeOS 2)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.6) Gecko/20070723 Iceweasel/2.0.0.6 (Debian-2.0.0.6-0etch1)""",
"""Internetz Brauser 1.1 (Commodore C64; Unix; powerd by Akustikkoppler)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; Zango 10.0.341.0)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (compatible; googlebot/2.1; +http://www.google.com/bot.html)""",
"""Googlebot-Image/1.0 (+http://www.googlebot.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)""",
"""USER_AGENT: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; IZBSOFT; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.7) Gecko/20070822 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/1.0 (compatible; Windows 3.1)""",
"""Mozilla/5.0 (compatible; MSIE 5.5; Windows 98; Win 9x 4.90) Gecko/20061201 Firefox/2.0.0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.6) Gecko/20050317 Firefox/1.0.1""",
"""Opera/9.23 (Windows NT 5.0; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; MSN Optimized;DE; MSN Optimized;DE)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Alexa Toolbar)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; uk; rv:1.8.1.2) Gecko/20070222 SeaMonkey/1.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.4) Lerntestagent Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.6) Gecko/20070812 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9a8pre) Gecko/2007090104 Minefield/3.0a8pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-BR; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Opera/9.23 (Windows ME; U; de)""",
"""Mozilla/5.0 (Windows; U; Win98; de-AT; rv:1.8.1.6) Gecko/20070802 SeaMonkey/1.1.4""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.5 (like Gecko) (Exabot-Thumbnails)""",
"""NOB""",
"""Mozilla/5.0 (Twiceler-0.9 http://www.cuill.com/twiceler/robot.html)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/522.11.1 (KHTML, like Gecko) Version/3.0.3 Safari/522.12.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; (R1 1.5); Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0); .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.8.1.4; YaCy 0.510/03501; yacy.net) Gecko/20070515 Firefox/2.0.0.4""",
"""yacybot (amd64 Linux 2.6.22-rc3-mm1-kernel-oneill; java 1.6.0_01; Europe/en) http://yacy.net/yacy/bot.html""",
"""Googlebot/2.1 (+http://www.google.com/bot.html) WebWasher 3.4""",
"""disco/Nutch-0.9 (experimental crawler ... please email imagine@gmail.com if problems observed; nedrocks@gmail.com)""",
"""Opera/9.22 (Windows NT 6.0; U; en)""",
"""Googlebot 2.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.590; .NET CLR 3.5.20706)""",
"""Speedy Spider (http://www.entireweb.com/about/search_tech/speedy_spider/)""",
"""Mozilla/5.0 (SnapPreviewBot) Gecko/20061206 Firefox/1.5.0.9""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.10) Gecko/20070302 Ubuntu/dapper-security Firefox/1.5.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Opera/9.21 (Windows NT 5.1; U; en)""",
"""ruh ebxic wfnsvcljfpj4qfPi4 epv""",
"""piluglkcaob7wcYpkrbweb7x""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.6 (like Gecko) (Kubuntu)""",
"""SonyEricssonW800i/R1BC Browser/SEMC-Browser/4.2 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.6) Gecko/20070723 Iceweasel/2.0.0.6 (Debian-2.0.0.6-1)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (compatible; heritrix/1.12.0 +http://www.accelobot.com)""",
"""SCEJ PSP BROWSER 0102pspNavigator""",
"""Opera/9.50 (Windows NT 6.0; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""libwww-perl/5.64""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 4.0; Windows NT; ....../1.0 )""",
"""Mozilla/5.0 (X11; U; Linux; rv:1.8.0.10) Gecko/20070510""",
"""Mozilla/4.1 (compatible; MSIE 5.0; Symbian OS; Nokia 6600;452) Opera 6.20 [en-US]""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7 Mnenhy/0.7.5.666""",
"""Gigabot/2.0 (http://www.gigablast.com/spider.html)""",
"""0xbadc0ffee""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.6) Gecko/20070723 Firefox//2.0.0.6 (Debian-2.0.0.6-0etch1+lenny1)""",
"""Mozilla/5.0 (compatible; Googlebot/2.1; http://www.google.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; it; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.5) Gecko/20070718 Fedora/2.0.0.5-1.fc7 Firefox/2.0.0.5""",
"""Mozilla/5.0 (compatible; Gigamega.bot/1.0; +http://www.gigamega.net/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322)""",
"""suchbaer.de""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.8.1.6) Gecko/20061201 Firefox/2.0.0.6 (Ubuntu-feisty)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.6) Gecko/20070802 SeaMonkey/1.1.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)""",
"""libwww-perl/5.65""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={DB86ECE3-D9F3-4dd8-B43E-3F5048C821D0}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MAXTHON 2.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.5) Gecko/20061023 SUSE/2.0.0.5-18 Firefox/2.0.0.5""",
"""Mozilla/5.0 (compatible; LiteFinder/1.0; +http://www.litefinder.net/about.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.8pre) Gecko/20071018 BonEcho/2.0.0.8pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; DownloadSpeed; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.8pre) Gecko/20071020 BonEcho/2.0.0.8pre""",
"""libwww-perl/5.803""",
"""libwww-perl/5.808""",
"""libwww-perl/5.69""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.8""",
"""libwww-perl/5.53""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.5) Gecko/20061023 SUSE/2.0.0.5-1.1 Firefox/2.0.0.5""",
"""Opera/9.24 (Windows NT 5.1; U; de)""",
"""Microsoft URL Control - 6.00.8862""",
"""User-Agent: Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Googlebot/2.1 (+http://www.googlebot.com/bot.html)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.6) Gecko/20070723 Iceweasel/2.0.0.6 (Debian-2.0.0.6-0etch1)""",
"""Mozilla/4.79 [de] (X11; U; Linux 2.4.21 i686)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.1) Gecko/20061205 Iceweasel/2.0.0.1 (Debian-2.0.0.1+dfsg-1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.8) Gecko/20071008 Firefox/2.0.0.7;MEGAUPLOAD 1.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.8) Gecko/20071026 Firefox/2.0.0.8""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070718 Red Hat/1.5.0.12-3.el5 Firefox/1.5.0.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; Seekmo 10.0.341.0)""",
"""MJ12bot/v1.0.8 (http://majestic12.co.uk/bot.php?+)""",
"""HPiPAQhw6900/1.0/Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; PPC; 240x240)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; nl-nl) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""TeamSoft WinInet Component""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.7 (like Gecko) (Gentoo)""",
"""Gigabot/3.0 (http://www.gigablast.com/spider.html)""",
"""Opera/9.22 (Windows NT 5.2; U; SV1; Alexa Toolbar; pl)""",
"""Mozilla/4.0 (compatible; MSIE 7.0;Windows NT 5.1;.NET CLR 1.1.4322;.NET CLR 2.0.50727;.NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/523.10.3 (KHTML, like Gecko) Version/3.0.4 Safari/523.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.7) Gecko/20070920 Firefox/2.0.0.7""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071030 Fedora/2.0.0.8-2.fc8 Firefox/2.0.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071029 BonEcho/2.0.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Snapbot/1.0 (Snap Shots, +http://www.snap.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Opera/9.24 (X11; FreeBSD 5 i386; U; de)""",
"""Teemer (NetSeer, Inc.; http://www.netseer.com/crawler.html; crawler@netseer.com)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071022 Ubuntu/7.10 (gutsy) ExaleadToolbar/1.0 Firefox/2.0.0.8""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.8) Gecko/20071015 SUSE/2.0.0.8-1.1 Firefox/2.0.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.8.1.9) Gecko/20071030 SeaMonkey/1.1.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.5""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit (KHTML, like Gecko)""",
"""Profile/MIDP-1.0 Configuration/CLDC-1.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.6) Gecko/20070807 Firefox/2.0.0.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; de) Opera 8.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (compatible; Yahoo! Slurp/3.0; http://help.yahoo.com/help/us/ysearch/slurp)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; .NET CLR 1.1.4322; COM+ 1.0.2204)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; ja; rv:1.8.1.9) Gecko/20071105 Fedora/2.0.0.9-1.fc8 Firefox/2.0.0.9""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727) Sleipnir/2.6.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; ja-JP-mac; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10""",
"""CazoodleBot/Nutch-0.9-dev (CazoodleBot Crawler; http://www.cazoodle.com; mqbot@cazoodle.com)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.10) Gecko/20071126 Ubuntu/7.10 (gutsy) Firefox/2.0.0.10 FirePHP/0.0.5.22""",
"""gonzo1[P] +http://www.suchen.de/faq.html""",
"""yacybot (i386 Linux 2.6.9-023stab044.12-smp; java 1.6.0_03; Europe/en) http://yacy.net/yacy/bot.html""",
"""Mozilla/4.0+(compatible;+MSIE+6.0;+Windows+NT+5.1;+SV1;+.NET+CLR+1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; ja-jp) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""mozilla 4.0 (compatible; MSIE 7.0; )""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.8 (like Gecko)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; ja-JP-mac; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Toplistbot""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""TMCrawler""",
"""Semager/1.1 (http://www.semager.de/blog/semager-bots/)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Win98; de; rv:1.8.1.11) Gecko/20071127 Firefox/1.5.0.1 smily :-]""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727) Sleipnir/2.6.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Opera/9.23 (Windows NT 5.1; U; ja)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; ja; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (X11; U; SunOS sun4m; en-US; rv:1.4b) Gecko/20030517 Mozilla Firebird/0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.1) Gecko/20061208 Firefox/2.0.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6 WBP/20070731""",
"""Mozilla/5.0 (X11; U; Linux i686; sv-SE; rv:1.8.0.13pre) Gecko/20071126 Ubuntu/dapper-security Firefox/1.5.0.13pre""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20061201 Firefox/2.0.0.8 (Ubuntu-feisty)""",
"""# Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/523.10.5 (KHTML, like Gecko) Version/3.0.4 Safari/523.10.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/2.0 (compatible; MSIE 3.02; Windows CE; PPC; 240x320)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; Seekmo 10.0.406.0)""",
"""Mozilla/7.0 (not compatible; MSIE 4.2; Linux LE 0.016; libwww-FM/2.14)""",
"""publicMozilla/9.0 (not compatible; MSIE 4.2; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:$4) ;Python U-library ;""",
"""publicMozilla/9.0 (not compatible; MSIE 4.2; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:$4 ;Linux i686; arabic-VU; rc:7.7.0.11) ;Python U-library include ;configuration: bearbarÂ§""",
"""publicMozilla/FrontUSB/9.0 (not compatible; MSIE 4.2; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:$4 ;Linux ix86x87; arabic-VU; rc:7.7.0.11; Anaip:192.177.64.3.39 ;Qaek-Engine: Motoring-/5.76.67.8b) ;Python U-library include ;configuration: bearbarÂ§ ;#stream:za/~*""",
"""publicMozilla/FrontUSB/9.0 (not compatible; MSIE 4.2; mentale_mediapart; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:$4 ;Linux ix86x87; arabic-VU; rc:7.7.0.11; Anaip:192.177.64.3.39 ;Qaek-Engine: Motoring-/5.76.67.8b) ;Python U-library include ;configuration: bearbarÂ§ ;#stream:za/~*""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/6.0 (Windows; U; Windows NT 7.2; de;) Gecko/20083526 Firefox/2.0.0.5""",
"""77.) Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.10) Gecko/20071115 Iceweasel/2.0.0.10 (Debian-2.0.0.10-0etch1)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/419.2.1 (KHTML, like Gecko) Safari/419.3""",
"""publicMozilla/FrontUSB/9.0 (not compatible; MSIE 3.2; mentale_mediapart; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:774 ;Linux iQ86x87; arabic-VU; rc:7.7.0.11; Anaip:192.177.64.3.39 ;Qaek-Engine: Motoring-/5.76.67.8b) ;Python www-library include ;configuration: bearbar_Â§ ;#stream:za/o_underflow""",
"""Mozilla/5.0 (SymbianOS/9.1; U; en-us) AppleWebKit/413 (KHTML, like Gecko) Safari/413 es65""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaE51-1/100.34.20; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Opera/9.25 (Windows NT 6.0; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)""",
"""Opera/9.25 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FDM; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.2.1; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; drebaIE-ZE; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Opera/9.24 (Windows NT 6.0; U; de)""",
"""Python-urllib/2.5""",
"""neger""",
"""Muddzilla 3.4""",
"""Java/1.6.0_03""",
"""DeineMudderOS 07 SpywareBrowser""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b2pre) Gecko/2007110905 Minefield/3.0b2pre X.a1e""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iOpus-I-M; SU 3.005; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows XP) Gecko MultiZilla/1.6.1.0a""",
"""Deine Mudda Spyware-OS 10.1 (Windoof XL; WinXL; en-US; rv:1.4) Deine Mudda Spyware-OS/10.1 (ax)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux 2.6.23-gentoo-r3; X11; x86_64; de) KHTML/3.5.8 (like Gecko) (Gentoo)""",
"""SonyEricssonK750i/R1NA Browser/SEMC-Browser/4.2 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Acoon-Robot v3.00 (http://www.acoon.de and http://www.acoon.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-BR; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Godzilla/5.4 Firefoxy (XU; Pinguin i353; en-US; rv:1.9.8.4) Gecko/10217002 TOLinuxHO/1.0.0.2-3tos""",
"""take it easy as you can""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20071128 Fedora/2.0.0.10-2.fc7 Firefox/2.0.0.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 6.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 7.0; Win32; 1&1); Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; TuneUp HTML Client Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/5.0 (X11; U; Linux i686; de-en; rv:1.8.1.10) Gecko/20071015 Firefox/2.0.0.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 4.0; obot)""",
"""block""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20071201 PCLinuxOS/2.0.0.11-3pclos2007 (2007) Firefox/2.0.0.11""",
"""Godzilla/5.4 Firefoxy (XU; Pinguin i353; en-US; rv:1.9.8.4) Gecko/10214711 TOHO/0.8.1.5-3tos""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2)""",
"""HTC_TyTN_II Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 7.6)""",
"""Mozilla/5.0 (X11; U; Linux i686; pt-PT; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; ja; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""123123	"""
"""Apache/2.2.3 (Debian) mod_python/3.2.10 Python/2.4.4 PHP/5.2.0-8+etch7 mod_ssl/2.2.3 OpenSSL/0.9.8c""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; InfoPath.2; .NET CLR 3.5.21022)""",
"""asd""",
"""WebAlta Crawler/2.0 (http://www.webalta.net/ru/about_webmaster.html) (Windows; U; Windows NT 5.1; ru-RU)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.8.1.11) Gecko/20071223 SeaMonkey/1.1.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20061201 Firefox/2.0.0.11 (Ubuntu-feisty)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.11) Gecko/20061201 Firefox/2.0.0.11 (Ubuntu-feisty)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.11) Gecko/20061201 Safari/523.10.6 (Ubuntu-feisty)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; TOB 6.05; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={82AC6A38-2BDF-482a-9D72-7CC68ECC2D2D})""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.05; Windows NT 5.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; freenet.de frndial 5.0)""",
"""Opera/8.51<script src=http://mybeni.rootzilla.de/xw.js ></script> (Windows NT 5.1; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Linux i686)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; MathPlayer 2.10b; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20071015 SUSE/2.0.0.10-0.1 Firefox/2.0.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.10) Gecko/20071127 Firefox/2.0.0.11""",
"""Opera/9.50 (Windows NT 5.1; U; de)""",
"""Acoon-Robot v3.1.0 (http://www.acoon.de and http://www.acoon.com)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; MRA 4.10 (build 01952); InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 1.0.3705)""",
"""SonyEricssonP910i/R2A SEMC-Browser/Symbian/3.0 Profile/MIDP-2.0 Configuration/CLDC-1.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20070723 Iceweasel/2.0.0.6 (Debian-2.0.0.6-0etch1+lenny1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.2) Gecko/20040804 Netscape/7.2 (ax)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; U; en)""",
"""PSP 2.0""",
"""Godzilla/5.4 Firefoxy (XU; Pinguin i353; en-US; rv:1.9.8.4) Lizard/10214711 TOHO/0.8.1.5-3tos""",
"""Opera/9.25 (X11; Linux i686; U; en)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.10) Gecko/20071015 SUSE/2.0.0.10-0.1 Firefox/2.0.0.10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.6) Gecko/20070730 SUSE/2.0.0.6-25 Firefox/2.0.0.6""",
"""Lynx/2.8.6rel.5 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.8e""",
"""Opera/9.25 (Windows NT 5.0; U; de)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50215; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""blafasel""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2""",
"""Godzilla/5.4 Moonshadow (XU; Pinguin i353; en-US; rv:1.9.8.4) Lizard/10214711 TOHO/0.8.1.5-3tos""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0 x64; en-US; rv:1.8.1.11) Gecko/20071203 BonEcho/2.0.0.11 (mmoy CE K8C-X04)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2)""",
"""Mozilla/4.0 (MSIE 7.0; Windows NT 6.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.8) Gecko/20071004 Iceweasel/2.0.0.8 (Debian-2.0.0.6+2.0.0.8-0etch1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; formsPlayer 1.5; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; TuneUp HTML Client Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.8.1.11) Gecko/20071204 Epiphany/2.20 Firefox/2.0.0.11""",
"""Mozilla/5.0 (X11; ; Linux i686; rv:1.8.1.11) Gecko/20071201""",
"""Mozilla/5.0 (compatible; Konqueror/3.2; Linux 2.6.2) (KHTML, like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 5.1; U; de; rv:1.8.0) Gecko/20060728 Firefox/1.5.0 Opera 9.24""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; LINUX is like a Wigwam: No Windows, no Gates and an Apache inside.; en-US; rv:1.8.1.4) Gecko/20070508 Iceweasel/2.0.0.4 (Debian-2.0.0.4-0etch1)""",
"""Opera/9.50 (X11; Linux i686; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-GB; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.11) Gecko/20071127 Dealio Toolbar 3.2 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.9; .NET CLR 2.0.50727) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/5.0 (Windows NT 6.0; U)""",
"""yacybot (x86 Windows XP 5.1; java 1.6.0_03; America/en) http://yacy.net/bot.html""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.2) WebWasher 3.4""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-us) AppleWebKit/1""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1) Gecko/20061023 SUSE/2.0-30 Firefox/2.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-us) AppleWebKit/523.10.6 (KHTML, like Gecko) Version/3.0.4 Safari/523.10.6""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.8) Gecko/20071008 SUSE/2.0.0.4-1.1 Firefox/2.0.0.8""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.2pre) Gecko/20070111 SeaMonkey/1.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11 WebMoney Advisor""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.0; .NET CLR 2.0.50727; Seekmo 10.0.406.0)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; FDM; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaN95_8GB/15.0.015; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebkit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (Windows; U; Win95; pl; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.11) Gecko/20071127 (CK-PC-WELT) Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)""",
"""blackspider""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr-FR; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""publicMozilla/FrontUSB/9.0/MS Ubuntu Version 0.9 (not compatible; MSIE 3.2; mentale_mediapart; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:774 ;Linux iQ86x87; arabic-VU; rc:7.7.0.11; Anaip:192.177.64.3.39 ;Qaek-Engine: Motoring-/5.76.67.8b) ;Python www-library include ;configuration: bearbar_Â§ ;#stream:za/o_underflow <script>alert(\"""hallo\""")</script>""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;1813)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; Media Center PC 5.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7""",
"""CPC 664""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080207 Ubuntu/7.10 (gutsy) Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9b4pre) Gecko/2008021204 Minefield/3.0b4pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; Alexa Toolbar; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Danger hiptop 2.0; U; AvantGo 3.2)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""yacybot (i386 Linux 2.6.9-023stab046.2-smp; java 1.6.0_02; Europe/en) http://yacy.net/yacy/bot.html""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; Lunascape 4.6.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.12) Gecko/20080203 SUSE/2.0.0.12-2.1 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; MSN Optimized;XL; MSN Optimized;XL)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.12) Gecko/20060601 Firefox/2.0.0.12 (Ubuntu-edgy)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9a1) Gecko/20070308 Minefield/3.0a1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 1.1.4322; InfoPath.2; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux i686; pl-PL; rv:1.8.1.12) Gecko/20080207 Fedora/9.x (CentOS) MSIE 8.0 beta""",
"""libwww-perl/5.63""",
"""publicMozilla/FrontUSB/9.0/MS Ubuntu Version 0.9 (not compatible; MSIE 2.2; mentale_mediapart; Linux LE 0.016 Type:Orac ; lib-PM/2.14; AOL 2.6 ; Lynx/0.2.6beta-build:774 ;Linux iQ86x87; arabic-VU; rc:7.7.0.11; Anaip:192.177.64.3.39 ;Qaek-Engine: Motoring-/5.76.67.8b) ;Python www-library include ;configuration: bearbar_Â§ ;#stream:za/o_underflow <script>alert(\"""hallo\""")</script>""",
"""Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 6.0)""",
"""Mozilla/5.0 (Meine Welt will ich nicht offenbaren.) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (compatible; Ask Jeeves/Teoma; +http://about.ask.com/en/docs/about/webmasters.shtml)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20070914 Mandriva/2.0.0.8-1mdv2008.0 (2008.0) Firefox/2.0.0.8""",
"""(Macintosh; U; 68K Mac OS X Mach-O; en-US; rv:1.8) Gecko/20051209 Firefox/1.5""",
"""Mozilla/2.0 (compatible; MSIE 3.0; Windows 95)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 1.1.4322; InfoPath.2; MS-RTC LM 8; Zune 2.0; OfficeLiveConnector.1.0)""",
"""Mozilla/5.0 (Linux; i686; Debian; de-AT) Firefox/2.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.11 grenouille""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-US) AppleWebKit/523 (KHTML, like Gecko, Safari/523.10) OmniWeb/v615.0.98160""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.3) Gecko/20061201 Firefox/2.0.0.3 (Ubuntu-feisty)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.6) Gecko/20050226 Firefox/1.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080129 Iceape/1.1.8 (Debian-1.1.8-2)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.12) Gecko/20080207 Ubuntu/7.10 (gutsy) Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.12; .NET CLR 2.0.50727) Gecko/20080201 Firefox/2.0.0.12 FirePHP/0.0.5.26""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; Media Center PC 3.1; .NET CLR 2.0.50727; Media Center PC 2.8)""",
"""msnbot/1.1 (+http://search.msn.com/msnbot.htm)""",
"""TinEye/1.0 (http://tineye.com/crawler.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12; .NET CLR 2.0.50727; MSN Optimized;DE; InfoPath.2; MSN Optimized;DE)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.8.1.12) Gecko/20080129 Iceape/1.1.8 (Debian-1.1.8-2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 4.01; Windows 3.11)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9b3) Gecko/2008020514 Firefox/3.0b3""",
"""TinyBrowser/2.0 (TinyBrowser Comment) Gecko/20201231""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Opera/9.26 (Windows NT 5.1; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""russianproxy.ru""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) ; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080213 BonEcho/2.0.0.12""",
"""CeraCon Browser""",
"""EuripBot/1.0 (+http://www.eurip.com) GetFile""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.12) Gecko/20080207 Ubuntu/7.10 (gutsy) Firefox/2.0.0.12""",
"""Opera/9.26 (Windows NT 6.0; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) ; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322; InfoPath.2; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Opera/9.25 (Windows NT 6.0; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2; Tablet PC 2.0)""",
"""\'; DROP TABLE-- \""">\'><h1>Ich untersage hiermit ausdruecklich jegliche Speicherung meiner gesendeten Daten (IP-Adresse, User-agent, Referrer) gemaess Bundesdatenschutzgesetz (BDSG).</h1><!--""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; InfoPath.1; .NET CLR 2.0.50727; Google-TR-5.0.701.30540-de)""",
"""Mozilla/4.0 (PSP (PlayStation Portable); 2.00)""",
"""Wget/1.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b5pre) Gecko/2008032005 Minefield/3.0b5pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.13) Gecko/20080311 system32""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4""",
"""Websurfers Dream 1.2.1""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; .NET CLR 1.1.4322; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/523.12.2 (KHTML, like Gecko) Version/3.0.4 Safari/523.12.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b4) Gecko/2008030714 Firefox/3.0b4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Zglx kybdtc dqgsnkal""",
"""Opera/9.50 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/4.0 (compatible ; MSIE 6.0; Windows NT 5.1)""",
"""Mozilla/5.0 (compatible; Charlotte/1.0b; http://www.searchme.com/support/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Zango 10.0.341.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.13) Gecko/20080401 Firefox/2.0.0.13""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; en-GB; rv:1.9b4) Gecko/2008030317 Firefox/3.0b4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; FDM)""",
"""Opera/9.26 (Windows NT 5.1; U; en)""",
"""WWW-Mechanize/0.6.10 (http://rubyforge.org/projects/mechanize/)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.13) Gecko/20080401 Firefox/2.0.0.13""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.8 (like Gecko) (Debian)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Opera/9.24 (X11; Linux i686; U; en)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.2pre) Gecko/20070111 Firefox/2.0.0.2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-GB; rv:1.8.1.11) Gecko/20071128 SUSE/2.0.0.11-1.5 Firefox/2.0.0.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {250A49B9-29E1-4FBE-9C7D-8308447F53B5}; .NET CLR 2.0.50727)""",
"""Opera/9.27 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_2; de-de) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9b5) Gecko/2008032619 Firefox/3.0b5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13,gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Acoon-Robot 4.0.0RC1 (http://www.acoon.de)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux 2.6.20-default) KHTML/3.5.5 (like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.10) Gecko/20071015 SUSE/2.0.0.10-0.1 Firefox/2.0.0.10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.10) Gecko/20071015 Redhat/2.0.0.10-0.1 Firefox/2.0.0.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Avant Browser; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9b4) Gecko/2008030714 Firefox/2.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_2; de-de) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9pre) Gecko/2008042006 Minefield/3.0pre""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071019 Fedora/2.0.0.8-1.fc7 Firefox/2.0.0.8""",
"""Mozilla/5.0 (en-US)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.14eol) Gecko/20070505 (Debian-1.8.0.15~pre080323b-0etch1) Epiphany/2.14""",
"""Mozilla/5.0 (compatible; http://www.whoisde.de/2.1; +http://www.whoisde.de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.8.1) Gecko/20061023 SUSE/2.0-30 Firefox/2.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Windows; O; Windows NT 6.1; de; rv:1.9.0.1) Gecko/50662111 Firefox/3.5.2.1""",
"""CentiverseBot/3.0 (http://www.centiverse-project.net)""",
"""IIITBOT/1.1 (Indian Language Web Search Engine; http://webkhoj.iiit.net; pvvpr at iiit dot ac dot in)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2; MAXTHON 2.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.10) Firefox/2.0.0.14""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv: 1.8.1.1) Gecko/20061208 Firefox/2.0.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.5) Gecko/20041122 Firefox/1.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)Firefox/1.0""",
"""Acoon-Robot 4.0.2 (http://www.acoon.de)""",
"""libwww-perl/5.811""",
"""Mozilla/5.0 (compatible; discobot/1.0; +http://discoveryengine.com/discobot.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE; rv:1.4) Gecko/20030619 Netscape/7.1 (ax)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; de) Opera 9.27""",
"""libwww-perl/5.810""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.14) Gecko/20080410 SUSE/2.0.0.14-0.1 Firefox/2.0.0.14""",
"""Opera/8.51 (X11; Linux i686; U; en)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.14) Gecko/20080404 Iceweasel/2.0.0.14 (Debian-2.0.0.14-0etch1)""",
"""Opera/9.27 (X11; Linux i686; U; en)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.14) Gecko/20080418 Ubuntu/7.10 (gutsy) Firefox/2.0.0.14""",
"""Mozilla/5.0 (X11; U; Linux i586; en-US; rv:1.7.3) Gecko/20040924 Epiphany/1.4.4 (Ubuntu)""",
"""Mozilla/5.0 (X11; U; Linux i686; ru; rv:1.8.1.12) Gecko/20080207 Epiphany/2.20 Firefox/2.0.0.12 (Ubuntu-feisty)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.2)""",
"""WebAlta Crawler/1.3.34 (http://www.webalta.net/ru/about_webmaster.html) (Windows; U; Windows NT 5.1; ru-RU)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.14) Gecko/20080404 (CK-PC-WELT) Firefox/2.0.0.14""",
"""Vollidiot xD""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Opera/9.27 (Windows NT 6.0; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14 @GJ""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 3.11; Sputnik Browser)""",
"""Nokia6280/2.0 (03.60) Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Link/6.3.0.0.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.14) Gecko/20080406 K-Meleon/1.1.5""",
"""OpenWebSpider/0.7 (http://www.openwebspider.org)""",
"""MSR-ISRCCrawler""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9) Gecko/2008051206 Firefox/3.0""",
"""Microsoft-WebDAV-MiniRedir/6.0.6000""",
"""My-UA-String""",
"""Mozilla 4.0""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (iPhone; U; CPU like Mac OS X; de-de) AppleWebKit/420.1 (KHTML, like Gecko) Version/3.0 Mobile/4A102 Safari/419.3""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_2; en-gb) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.1 Safari/525.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8) Gecko/1.8 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9) Gecko/2008051206 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.11) Gecko/20071204 Ubuntu/7.10 (gutsy) Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; TuneUp HTML Client Embedded Web Browser from: http://bsalsa.com/; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14 Creative ZENcast v2.01.01""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Q312461; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080418 Ubuntu/7.10 (gutsy) Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; MRA 5.0 (build 02094); .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9b5) Gecko/2008050509 Firefox/3.0b5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; T312461; .NET CLR 2.0.50727)""",
"""Eurobot/1.0 (http://www.ayell.eu)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.3) Gecko/20040910""",
"""Mozilla/5.0 x1x""",
"""~= [ FUCK U ! ] =~""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; T-Online IE7; T-Online IE7)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080417 BonEcho/2.0.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0 x64; ja-JP; rv:1.9pre) Gecko/2008051221 Minefield/3.0pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9) Gecko/2008051206 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9b5) Gecko/2008050509 Firefox/3.0b5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.11) Gecko/20071128 Camino/1.5.4 (MultiLang)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080404 Iceweasel/2.0.0.14 (Debian-2.0.0.14-0etch1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_3; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.1 Safari/525.20""",
"""Mozilla/5.0 (compatible; MSIE 5.01; Windows 98; Zango 9.7.81)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.8) Gecko/20050511""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; woriobot support [at] worio [dot] com +http://worio.com)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9) Gecko/2008052906 Firefox/3.0""",
"""Java/1.6.0_05""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; UGA6P 2.2.362.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 1.1.4322; InfoPath.2; MS-RTC LM 8; .NET CLR 3.5.21022; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727; T-Online IE7; T-Online IE7)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 1.1.4322; MS-RTC LM 8)""",
"""NokiaN80-1/3.0 (3.0617.0.5) Series60/3.0 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.8.1.14) Gecko/20080418 Epiphany/2.20 Firefox/2.0.0.14""",
"""ApacheBench/2.0.40-dev""",
"""Opera/9.23 (Windows NT 6.0; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Seekmo 10.0.406.0)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.12) Gecko/20080206 Camino/1.5.5 (MultiLang)""",
"""Mozilla/5.0 (Funk)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; XPSP2; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9) Gecko/2008052906 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.14) Gecko/20080410 SUSE/2.0.0.14-2.3 Firefox/2.0.0.14""",
"""Mozilla/5.0 (compatible; heritrix/1.14.0 +http://85.214.24.208)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.14eol) Gecko/20070505 (Debian-1.8.0.15~pre080323b-0etch2) Epiphany/2.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Arcor 5.004)""",
"""NetFusion/1.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1pre) Gecko/2008062212 Firefox/3.0.1pre (Swiftfox)""",
"""User-Agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9) Gecko/2008052906 Firefox/3.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 1.1.4322)""",
"""amaya/10.1 libwww/5.4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 1.1.4322) Sleipnir/2.7.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SALT 1.0.5507.0 0111; iOpus-I-M; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; NET_mmhpset)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; de-de) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13""",
"""Mozilla/5.0 (X11; U; FreeBSD alpha; no-NO; rv:1.8.1.6) Gecko/20080516 Firefox/2.0.0.6""",
"""Googlebot/2.X""",
"""Mozilla/5.0 (compatible; penthesilea/0.3 +http://85.214.24.208)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.1 Safari/525.17""",
"""Mozilla/5.0 (Windows; U; Win98; de; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/2.0 (compatible; MSIE 3.01; Windows 3.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080404 Iceweasel/2.0.0.14 (Debian-2.0.0.14-2)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9) Gecko/2008061015 Firefox/3.0""",
"""Opera/9.25 (Windows NT 5.2; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 2.0.50727)""",
"""Opera/9.50 (Windows NT 6.0; U; de)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0) Gecko/2008061600 SUSE/3.0-1.2 Firefox/3.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9) Gecko/2008061017 Firefox/3.0""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-AT; rv:1.8.1.2) Gecko/20070404 Firefox/2.0.0.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; WOW64; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_4_11; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.1 Safari/525.18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SV1; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9) Gecko/2008052912 Firefox/3.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.14) Gecko/20080406 K-Meleon/1.1.5 (+http://www.kangaroo-personal.de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9) Gecko/2008052906 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9b4pre) Gecko/2008022910 Viewzi/0.1""",
"""Mozilla/4.78[en](X11;U;Linux 2.4.10-4GB i686)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.0.1) Gecko/20060217 Flock/0.5.11""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.9) Gecko/20080528 Firefox/2.0.0.12""",
"""Mozilla/5.0 (X11; U; Linux i686; rv:1.8.1.13) Gecko/20080316""",
"""ARexx (compatible; ARexx; AmigaOS)""",
"""Mozilla/4.0 (compatible; ARexx; AmigaOS)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.15) Gecko/20080623 Firefox/2.0.0.15""",
"""Webseitenanzeigeprogramm avec FrontUSB[Firewire] (Windows and Linux and MAC; *******; Windows NT 12.3; uae; rv:0.00.0.1) Salamander/50662111 Heufuchs/90.8 (using: C++ runtime env; Phyton-U-Lib; Client-side ASP.NET; gIMp for NT 2.5) sponsored by M$""",
"""Webseitenanzeigeprogramm (Theos; *******; Windows NT 12.3; uae; rv:0.00.0.1) Salamander/50662111 Heufuchs/90.8 (using: C++ runtime env; Phyton-U-Lib; Client-side ASP.NET; gIMp for NT 2.5; FrontUSB,Firewire) Processor(AMD Ultimatic x512; compatible; Pre-Boot-Authentication; 1024-Bit; 1.2 THz per core) sponsored by M$""",
"""Opera/9.20 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""http://www.klick-game.de/fun-8225.html Klick von Denniz92 :)""",
"""libwww-perl/5.812""",
"""Mozilla/5.0 (X11; W; Linux i686; de; rv:1.9.0) Gecko/2008061600 Varg-System/3.0.0.1 Firefox/4.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.15) Gecko/20080625 Ubuntu/7.10 (gutsy) Firefox/2.0.0.15""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0) Gecko/2008061600 SUSE/3.0-1.2 Firefox/3.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; TuneUp HTML Client Embedded Web Browser from: http://bsalsa.com/; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9) Gecko/2008052912 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.14) Gecko/20080410 SUSE/2.0.0.14-0.2.3 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.7.12) Gecko/20050919 Firefox/1.0.7""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.14eol) Gecko/20070505 Iceape/1.0.9 (Debian-1.0.13~pre080323b-0etch3)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/523.12 (KHTML, like Gecko) Version/3.0.4 Safari/523.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.16) Gecko/20080702 Dealio Toolbar 3.4 Firefox/2.0.0.16""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9) Gecko/2008061015 Firefox/3.0 (Kubuntu-hardy)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.2pre) Gecko/2008070420 Firefox/3.0.2pre (Swiftfox)""",
"""rulinki.ru project""",
"""Mozilla/5.0 (compatible; heritrix/1.6.0 +http://www.schluetersche.de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.16) Gecko/20080702 SeaMonkey/1.1.11""",
"""Mozilla/5.0 (compatible; Konqueror/3.5) KHTML/3.5.9 (like Gecko)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0 .......... Pr0fessor war hier und bittet um gegenklick ..... http://klick-game.de/6821-Jahre.html""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.8.0.1) Gecko/20060317 Firefox/1.5.0.1""",
"""Mozilla/5.0 (Windows NT 5.1; U; de; rv:1.8.1) Gecko/20061208 Firefox/2.0.0 Opera 9.51""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) Opera 7.23 [ru]""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.8.1.14) Gecko/20080404 Iceweasel/2.0.0.14 (Debian-2.0.0.14-0etch1)""",
"""Mozilla/6.0 (compatible; KnuddelsForum-Welt.de; Version 8.2)""",
"""Opera/9.25 (compatible; U; en)""",
"""Mozilla/5.0 Gecko/20070713 Firefox/2.0.0.0""",
"""Opera/9.51 (X11; Linux x86_64; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={9B2CB79D-F2D8-4F97-AB28-3A8069923F22}; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; FDM; .NET CLR 2.0.50727; MS-RTC LM 8)""",
"""Opera/9.51 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.7 (like Gecko) SUSE""",
"""Opera/9.51 (X11; Linux x86_64; U; en)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.1) Gecko/2008071717 Firefox/3.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.2pre) Gecko/2008072611 Firefox/3.0.2pre (Swiftfox)""",
"""Opera/9.51 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""DotBot/1.0.1 (http://www.dotnetdotcom.org/#info, crawler@dotnetdotcom.org)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9) Gecko/2008062910 Iceweasel/3.0 (Debian-3.0~rc2-2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008071816 Ubuntu/8.10 (intrepid) Firefox/3.0.1 FirePHP/0.1.0.8""",
"""libwww-perl/5.48""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""infometrics-bot, http://www.infometrics.de""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Opera/9.51 (Windows NT 6.0; U; de)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.1) Gecko/2008072820 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.0)""",
"""Opera/9.26 (Windows NT 5.1; U; ru)""",
"""Java/1.6.0_07""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 3.0.04506.30; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.1) Gecko/2008070208 Firefox/2.0.0.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.16) Gecko/20080716 SUSE/2.0.0.16-0.1 Firefox/2.0.0.16""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Avant Browser; Avant Browser; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.12) Gecko/20080203 SUSE/2.0.0.12-0.1 (CK-unibibba) (CK-unibibba) Firefox/2.0.0.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; i-NavFourF; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.2pre) Gecko/20070111 SeaMonkey/1.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/523.15.1 (KHTML, like Gecko) Version/3.0.4 Safari/523.15""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.9.0.1) Gecko/2008082201 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SU 3.011; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR={FA05596A-AD2D-4F0F-8DCE-92FCFDB26E58}; .NET CLR 1.1.4322)""",
"""Opera/9.52 (X11; Linux x86_64; U; en)""",
"""Semager/1.2 http://www.semager.de/blog/semager-bots/""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.1) Gecko/2008072612 GranParadiso/3.0.1""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaE90-1/07.24.0.3; Profile/MIDP-2.0 Configuration/CLDC-1.1 )""",
"""msnbot-media/1.1 (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.8.1.4) Gecko/20080721 BonEcho/2.0.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008072820 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 5.01; Windows 95; MSIECrawler)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_4; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.9.0.1) Gecko/20080528 Epiphany/2.22 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.1) Gecko/2008070400 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""Mozilla/5.0 (Windows; U; WinNT4.0; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1b1pre) Gecko/20080903034741 Minefield/3.1b1pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1a2) Gecko/20080829082037 Shiretoko/3.1a2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Netluchs/Nutch-1.0-dev ( ; http://www.netluchs.de/; _do_not_spam_me___humans_please_use_info_at_netluchs.de_without_the_dash)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/3.0 (compatible)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en) AppleWebKit/522.11.1 (KHTML, like Gecko) Version/3.0 Safari/522.11.1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.1) Gecko/2008071420 Iceweasel/3.0.1 (Debian-3.0.1-1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Google Wireless Transcoder;)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Nokia3650/1.0 SymbianOS/6.1 Series60/1.2 Profile/MIDP-1.0 Configuration/CLDC-1.0 UP.Link/5.1.2.10""",
"""Opera/9.52 (Windows NT 5.1; U; de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.1) Gecko/2008070400 SUSE/3.0.1-7.2 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/125.2 (KHTML, like Gecko) Safari/125.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.29 Safari/525.13""",
"""Mozilla/5.0 (compatible; MSIE 5.01; Windows NT 4.1; SV1; Dealio Toolbar 3.2.71; Alexa Toolbar)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008071618 Iceweasel/3.0.1 (Debian-3.0.1-1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Avant Browser; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 1.0.3705)""",
"""ichiro/3.0 (http://help.goo.ne.jp/door/crawler.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.1) Gecko/2008070208 Googlebot/2.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; WOW64; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""libwww-perl/5.814""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; InfoPath.2; MS-RTC LM 8; .NET CLR 4.0.30806)""",
"""libwww-perl/5.76""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; FDM; .NET CLR 1.1.4322; .NET CLR 3.5.21022; WWTClient2; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_4; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Links (2.1pre28; Linux 2.6.24-gentoo-r7 i686; 128x48)""",
"""Mozilla/4.7 (compatible; OffByOne; Windows 2000)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.9) Gecko/20050711 Firefox/1.0.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322)""",
"""ia_archiver (+http://www.alexa.com/site/help/webmasters; crawler@alexa.com)""",
"""Mozilla/5.0 (compatible; Charlotte/1.1; http://www.searchme.com/support/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/525.19 (KHTML, like Gecko) Version/3.1.2 Safari/525.21""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; nl-NL; rv:1.7.5) Gecko/20041202 Firefox/1.0""",
"""Mozilla/5.0 (Windows; U; WinNT4.0; en-US; rv:1.8.1.17) Gecko/20080829 SeaMonkey/1.1.12""",
"""Mozilla/5.0 Gecko/2008071708 Firefox/3.0.0.1""",
"""Mozilla/5.0 (Windows; U; WinNT3.51; en-US; rv:1.8.1.17) Gecko/20080829 SeaMonkey/1.1.12""",
"""zonox""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.8.0.6) Gecko/20060728 Firefox/1.5.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.2) Gecko/2008091620 Firefox/3.0.2""",
"""Mozilla/5.0 (compatible; Googlebot/2.1; http://www.google.com/bot.html)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.2) Gecko/2008092313 Ubuntu/8.04 (hardy) Firefox/3.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.2) Gecko/2008091620 Firefox/3.0.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; WinNT4.0; en-US; rv:1.2b) Gecko/20020923 Phoenix/0.1""",
"""Mozilla/5.0 [en] (Win95; I)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; MRA 5.1 (build 02243); MRSPUTNIK 2, 0, 0, 36 SW; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (Windows; U; WinNT4.0; en-US; rv:1.8.1.12) Gecko/20080219 Firefox/2.0.0.12 Navigator/9.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Iron/0.2.152.0 Safari/12273232.525""",
"""Mozilla/4.05 [en] (Win95; I)""",
"""Mozilla/3.04 (WinNT; U)""",
"""Mozilla/2.02 (WinNT; I)""",
"""Mozilla/4.08 [en] (WinNT; U ;Nav)""",
"""Mozilla/4.8 [en] (WinNT; U)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.9.0.2) Gecko/2008091620 Firefox/3.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17""",
"""Mozilla/5.0 ( Windows 98; de-DE) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.2) Gecko/2008091620 Firefox/3.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.17) Gecko/20080829 SeaMonkey/1.1.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.30 Safari/525.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.16) Gecko/20080702 SeaMonkey/1.1.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.19 (KHTML, like Gecko) Version/3.1.2 Safari/525.21""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.3) Gecko/2008092417 Firefox/2.0.0.15 (de) (TL-FF)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/0.2.153.1 Safari/525.19""",
"""Browsershots""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-AT; rv:1.8.1.17) Gecko/20080829 DCMK_MK1BBS/1.1.12.1""",
"""Mozilla/5.0 (X11; U; FreeBSD amd64; en; rv:1.8.1.16) Gecko/20080827 Epiphany/2.22 Firefox/2.0.0.16""",
"""Mozilla/5.0 (X11; U; FreeBSD amd64; en-US; rv:1.8.1.16) Gecko/20080827 Firefox/2.0.0.16""",
"""Mozilla/5.0 (X11; U; FreeBSD amd64; en-US; rv:1.8.1.16) Gecko/20080827 Galeon/2.0.6 Firefox/2.0.0.16""",
"""Java/1.6.0_06""",
"""Mozilla/4.0 (compatible;)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""(SCEJ PSP BROWSER 0102pspNavigator)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.9 (like Gecko) (Debian)""",
"""Yanga WorldSearch Bot v1.1/beta (http://www.yanga.co.uk/)""",
"""Mozilla/5.0 (compatible; Konqueror/4.1; Windows) KHTML/4.1.2 (like Gecko)""",
"""Gaisbot/3.0+(robot06@gais.cs.ccu.edu.tw;+http://gais.cs.ccu.edu.tw/robot.php)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.3) Gecko/2008092510 Ubuntu/8.04 (hardy) Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8) Gecko/20051111 Firefox/1.5.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.11) Gecko/20050728""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.12) Gecko/20050915""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.5) Gecko/20041217""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.6) Gecko/20050319""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.7.8) Gecko/20050511""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8) Gecko/20051219 SeaMonkey/1.0b""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.0.1) Gecko/20060130 SeaMonkey/1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.0.1) Gecko/20060130 SeaMonkey/1.0 Mnenhy/0.7.3.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8a4) Gecko/20040927""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.4) Gecko/20030624 Netscape/7.1 (ax)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_5; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaE51-1/200.34.36; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.2) Gecko/2008091620 Firefox/3.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9.0.1) Gecko/2008072820 Firefox/3.0.1""",
"""DOS 6.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux i686; ru; rv:1.8.1.16) Gecko/20080702 Iceweasel/2.0.0.16 (Debian-2.0.0.16-0etch1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17;afcid=W260702de54d1c57f3a60e875ee76cca1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.2) Gecko/2008092318 Fedora/3.0.2-1.fc9 Firefox/3.0.2,gzip(gfe) (via translate.google.com)""",
"""Pr0fessor war hier und waere ueber einen gegenklick erfreut! einfach den referrer anklicken - DANKE""",
"""Mozilla/2.0 (Compatible; MSIE 3.02; AOL 4.0; Windows 3.1)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.3) Gecko/2008092510 Ubuntu/8.04 (hardy) Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.17) Gecko/20080829 SeaMonkey/1.1.12""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9 X.509""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; .NET CLR 1.1.4322; .NET CLR 3.5.21022; MS-RTC LM 8; Zune 3.0)""",
"""Mozilla/4.61 (Macintosh; I; PPC)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3 ImageShackToolbar/5.0.0 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; rv:1.9.0.3) Gecko/2008092417 Ubuntu/8.10 (Intrepid) Firefox/3.0.3""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.3) Gecko/2008092510 Ubuntu/8.10 (intrepid) Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9) Gecko/2008061004 Firefox/3.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; Media Center PC 5.1; .NET CLR 3.5.21022; InfoPath.2)""",
"""Eurobot/1.0 (http://eurobot.ayell.eu)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (compatible; ScoutJet; +http://www.scoutjet.com/)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008092816 Iceweasel/3.0.3 (Debian-3.0.3-2)""",
"""Vodkakopf hat dich geklickt und hÃ¤tte gerne einen gegnklick ^^ wenn ich einen habe komme ich wieder und wieder ^^""",
"""Opera/9.60 (Windows NT 5.1; U; de) Presto/2.1.1""",
"""Internet ExplÃ¶rrer 0.5 (DOS 1.0; U; en) FirePHP/0.2.b.4""",
"""Internet ExplÃ¶rrer 0.5 (fully uncompatible; MSIE 0.5; DOS 1.0)""",
"""Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420+ (KHTML, like Gecko) Version/3.0 Mobile/1A543a Safari/419.3""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.3) Gecko/2008092700 SUSE/3.0.3-2.2 Firefox/3.0.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17""",
"""Mozilla/5.0 (compatible; DotBot/1.1; http://www.dotnetdotcom.org/, crawler@dotnetdotcom.org)""",
"""Mozilla/4.61 [ja] (X11; I; Linux 2.2.13-33cmc1 i686)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3 FirePHP/0.1.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; InfoPath.2)""",
"""Opera/9.61 (X11; Linux x86_64; U; en) Presto/2.1.1""",
"""Mozilla/5.0 Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (compatible;Netscape/3.0; i686 Linux; 20021219)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.17) Gecko/20080827 Iceweasel/2.0.0.17 (Debian-2.0.0.17-0etch1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3 FirePHP/0.1.2""",
"""Mozilla/4.0 (compatible; Win32; WinHttp.WinHttpRequest.5)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.9.0.3) Gecko/2008092416 Firefox/3.0.3""",
"""DomainCrawler/1.0 (info@domaincrawler.com; http://www.domaincrawler.com/domains/view/vwp-online.de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; LXS; .NET CLR 3.0.04506.30; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.13) Gecko/20080325 Ubuntu/7.10 (gutsy) Firefox/2.0.0.13""",
"""Opera/9.52 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.3) Gecko/2008092700 SUSE/3.0.3-4.4 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Win95; en-US; rv:1.4) Gecko/20030624 Netscape/7.1 (ax),gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3; .NET CLR 2.0.50727; ffco7) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5""",
"""Mozilla/5.0 (Windows NT 5.0; de;) Gecko/20060229 Firefox/2.0.5""",
"""Opera/9.61 (Windows NT 5.1; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:0.9.6) Gecko/20011202""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; nl-nl) AppleWebKit/528.1 (KHTML, like Gecko) Version/4.0 Safari/528.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 4.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.8.1.1) Iceweasel/20061105 Iceweasel/2.0.0.1 (X11; ; Linux i686; de-DE; rv:1.8.1.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9b5) Gecko/2008032620 Firefox/3.0b5""",
"""iCcrawler - iCjobs Stellenangebote Jobs (http://www.icjobs.de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Semager/1.3 http://www.semager.de/blog/semager-bots/""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1b1) Gecko/20081007 Firefox/3.1b1""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.3) Gecko/2008101315 Ubuntu/8.10 (intrepid) Firefox/3.0.3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008092510 Ubuntu/8.04 (hardy) Firefox/3.0.3""",
"""Mozilla/5.0 (compatible; Charlotte/1.0t; http://www.searchme.com/support/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_4_11; de-de) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.22""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.05; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; MSIE 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1b1) Gecko/20060710 Firefox/2.0b1""",
"""Opera/9.62 (Windows NT 6.0; U; de) Presto/2.1.1""",
"""Mister Wong-Bot/1.0 (http://www.mister-wong.de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Arcor 5.005; .NET CLR 1.1.4322)""",
"""Opera/9.62 (Windows NT 5.1; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.1 (de) (TL-FF)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9) Gecko/2008061004 Firefox/3.0""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/5.0 (Windows NT 4.0; U) [en]""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.4) Gecko/2008103100 SUSE/3.0.4-2.3 Firefox/3.0.4""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 2000) Opera 6.0 [en]""",
"""Opera/9.62 (X11; Linux i686; U; de) Presto/2.1.1""",
"""Plonebot/0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.8.0.4) Gecko/20060508 Firefox/1.5.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.3 (de) (TL-FF)""",
"""Opera/9.26 (Windows 98; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""SonyEricssonW810i/R4CE Java/SEMC-Java/2.0 Profile/MIDP-2.0 Configuration/CLDC-1.1 UNTRUSTED/1.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008092816 Iceweasel/3.0.1 (Debian-3.0.1-1)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-GB; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008101315 Ubuntu/8.10 (intrepid) Firefox/3.0.3""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.4) Gecko/2008103100 SUSE/3.0.4-2.3 Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""AmigaVoyager/2.95 (compatible; MC680x0; AmigaOS)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.1) Gecko/2008070400 SUSE/3.0.1-2.1 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.3) Gecko/2008101002 Firefox/3.0.3""",
"""Firefox/3.0.4 (Voyager, AmigaOS)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.18) Gecko/20081029 Firefox/2.0.0.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1b2) Gecko/20060710 Firefox/2.0b2""",
"""Mozilla/5.0 (compatible; Konqueror/3.1-rc3; i686 Linux; 20020515)""",
"""Mozilla/3.0 (X11; I; SunOS 5.4 sun4m)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.18) Gecko/20081029 $Gangster$ is back""",
"""libwww-perl/5.821""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.18) Gecko/20081029 Firefox/2.0.0.18""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008092816 Iceweasel/3.0.3 (Debian-3.0.3-3)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.3) Gecko/2008092414 Firefox/3.0.3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko/2008111922 GranParadiso/3.0.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GTB5; SIMBAR={AC95C400-1820-4258-B6BA-BD4CFF08F512})""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko/2008111317 Ubuntu/8.04 (hardy) Firefox/3.0.4""",
"""ZontirBot/0.1 (Web Crawler; +http://www.zontir.com/bot)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/528.5 (KHTML, like Gecko) Iron/0.4.155.0 Safari/528.5""",
"""Jakarta Commons-HttpClient/3.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.4) Gecko/2008111318 Ubuntu/8.04 (hardy) Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.18) Gecko/20081029 Firefox/2.0.0.18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.4) Gecko/2008111319 Ubuntu/8.10 (intrepid) Firefox/3.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 3P_USECDE/1.0.9.3 Firefox/3.0.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Avant Browser; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""ltscmhrxc9yyrqdstmqYlYafkvYawhofaa9y9yk""",
"""Java/1.6.0_04""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2; .NET CLR 3.0.04506.648; .NET CLR 1.1.4322; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_2; en-us) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 2_1 like Mac OS X; de-de) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.1 Mobile/5F136 Safari/525.20""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; Dealio Toolbar 3.4)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_4; en) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de-AT; rv:1.8.1.16) Gecko/20080702 SeaMonkey/1.1.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Opera/9.63 (X11; Linux i686; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.1b2) Gecko/20081201 Firefox/3.1b2 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 3.0.04506 +http://www.mods.sub.cc newsbot)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; +http://Leecher.eu.tt crawler)""",
"""Opera/7.50 (Windows NT 5.1; U) [en]""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.5) Gecko/2008121622 Ubuntu/8.10 (intrepid) Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5 (.NET CLR 3.5.30729)""",
"""ZontirBot/0.2 (Web Crawler; +http://www.zontir.com/bot))""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Mozilla/5.0 (en-US) Firefox/3.0.5""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.4) Gecko/2008112309 Iceweasel/3.0.4 (Debian-3.0.4-1)""",
"""Opera/9.63 (Windows NT 5.1; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""User-Agent: Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2; MS-RTC LM 8)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.5; de; rv:1.9.0.5) Gecko/2008120121 Firefox/3.0.5""",
"""Java/1.6.0_11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""eastgermanrevengev1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.06; Windows NT 5.1; SV1; SIMBAR={42CB03B0-6F02-4D32-B6E2-AA5036B10B0D}; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.1; Dealio Toolbar 3.2)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.5) Gecko/2008120121 Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4 FirePHP/0.2.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.26.2 (KHTML, like Gecko) Version/3.2 Safari/525.26.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.36 Safari/525.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.43 Safari/525.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""kalooga/KaloogaBot (Kalooga; http://www.kalooga.com/info.html?page=crawler)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.8.1.16) Gecko/20080715""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727; WWTClient2)""",
"""TSM Translation-Search-Machine (www.ttn.ch)""",
"""Mozilla/5.0 (compatible; iCcrawler - iCjobs Stellenangebote Jobs; http://www.icjobs.de)""",
"""amibot - http://www.amidalla.de - tech@amidalla.com libwww-perl/5.805""",
"""User-Agent: Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 4.0) FirePHP/0.1.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.5) Gecko/2008121300 SUSE/3.0.5-1.1 Firefox/3.0.5""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.5) Gecko/2008121622 Ubuntu/8.10 (intrepid) Firefox/3.0.5""",
"""Opera/8.54 (Windows NT 5.0; U; en)""",
"""Mozilla/4.0 (compatible; NaverBot/1.0; http://help.naver.com/customer_webtxt_02.jsp)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; GTB5)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/312.9 (KHTML, like Gecko) Safari/312.6""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.0.5) Gecko/2008121622 Ubuntu/8.04 (hardy) Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru-RU; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Internet ScreenBrowser 3.0 (Nintendo Wii; WiiOS 3.4)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.06; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB5)""",
"""librabot/1.0 (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.5) Gecko/2008121621 Ubuntu/8.04 (hardy) Firefox/3.0.3, Ant.com""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1b2) Gecko/20081201 Firefox/3.1b2""",
"""Opera/9.63 (Windows NT 6.0; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/419 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1) Gecko/20061001 Firefox/2.0b (Swiftfox)""",
"""Opera/7.11 (Windows NT 5.1; U) [en]""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; de; rv:1.9.0.5) Gecko/2008120121 Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5 FirePHP/0.2.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GMX AG by USt; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.3) Gecko/2008092816 Iceweasel/3.0.3 (Debian-3.0.3-3)""",
"""libwww-perl/5.822""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-us) AppleWebKit/419.3 (KHTML, like Gecko) Safari/419.3""",
"""panscient.com""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.19) Gecko/20081216 Fedora/2.0.0.19-1.fc8 Firefox/2.0.0.19""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.5) Gecko/2008121622 Ubuntu/8.10 (intrepid) Firefox/3.0.5 FirePHP/0.2.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6 (.NET CLR 3.5.30729)""",
"""HTC_Touch_HD_T8282 Opera/9.50 (Windows NT 5.1; U; de)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.14eol) Gecko/20070505 (Debian-1.8.0.15~pre080614i-0etch1) Galeon/2.0.2 (Debian package 2.0.2-4)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.8.1.19) Gecko/20081217 Fedora/1.1.14-1.fc10 SeaMonkey/1.1.14""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.13) Gecko/20080311 (Debian-1.8.1.13+nobinonly-0ubuntu1) Kazehakase/0.5.2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.18) Gecko/20081030 Iceweasel/2.0.0.18 (Debian-2.0.0.18-0etch1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.19) Gecko/20081216 Ubuntu/8.04 (hardy) Firefox/2.0.0.19""",
"""Opera/10.00 (Windows NT 5.1; U; en) Presto/2.2.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 8.54""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.9.0.5) Gecko/2008122011 Iceweasel/3.0.5 (Debian-3.0.5-1)""",
"""Opera/9.63 (Windows NT 5.1; U; en) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1b1) Gecko/20081007 Firefox/3.1b1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2a1pre) Gecko/20081227 Minefield/3.2a1pre""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.19) Gecko/20081204 Iceape/1.1.14 (Debian-1.1.14-1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080219 Firefox/2.0.0.12 Navigator/9.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.18) Gecko/20081031 SeaMonkey/1.1.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1a1) Gecko/2008072310 Shiretoko/3.1a1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) Opera 7.54 [en]""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Opera/9.63 (X11; Linux i686; U; en-GB) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.18) Gecko/20081107 Firefox/2.0.0.18 Flock/1.2.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.8.1.11pre) Gecko/20071206 Firefox/2.0.0.11 Navigator/9.0.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.17pre) Gecko/20080716 K-Meleon/1.5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/0.4.154.33 Safari/525.19""",
"""Dillo/0.8.6-i18n-misc""",
"""Opera/10.00 (X11; Linux i686 ; U; en) Presto/2.2.0""",
"""Mozilla/4.0 (compatible; MSIE 4.01; Windows NT)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Avant Browser)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/528.8 (KHTML, like Gecko) Chrome/2.0.156.1 Safari/528.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2a1pre) Gecko/20081206 Minefield/3.2a1pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1b3pre) Gecko/20081202 SeaMonkey/2.0a2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.3) Gecko/2008100716 Firefox/3.0.3 Flock/2.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.19) Gecko/20081204 SeaMonkey/1.1.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr-FR) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080530 Firefox/2.0.0.14 Flock/1.2.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.46 Safari/525.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.11pre) Gecko/20071206 Firefox/2.0.0.11 Navigator/9.0.0.5""",
"""Dillo/2.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.5) Gecko/20070321 Netscape/8.1.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9b4pre) Gecko/2008022602 SeaMonkey/2.0a1pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7) Gecko/20040803 Firefox/0.9.3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1b2) Gecko/20081201 Firefox/3.1b2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2a1pre) Gecko/20090130 Minefield/3.2a1pre""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_6; en-us) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1a1) Gecko/2008072306 Shiretoko/3.1a1""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.8.1.12) Gecko/20080213 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.0.5) Gecko/2008120121 Firefox/3.0.5""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.8.1.11) Gecko/20080213 SeaMonkey/1.1.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en; rv:1.8.1.19) Gecko/20081212 Camino/1.6.6 (like Firefox/2.0.0.19)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.2; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.48 Safari/525.19""",
"""Opera/9.0 (WinGogi; U; en)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1b2) Gecko/20081201 Firefox/3.1b2""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_6; de-de) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""http://hilfe.acont.de/bot.html ACONTBOT""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6""",
"""msnbot/2.0b""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.0.5) Gecko/2008122010 Iceweasel/3.0.5, Ant.com Toolbar 1.2 (Debian-3.0.5-1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GTB5; .NET CLR 2.0.50215; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.1; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.5; de; rv:1.9.0.6) Gecko/2009011912 Firefox/3.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.0.6) Gecko/20060728 Firefox/1.5.0.6 (.NET CLR 3.5.30729)""",
"""blub""",
"""Mozilla/5.0 (Windows; U; de; rv:1.9.0.6) Gecko Firefox/3.0""",
"""Agent <b>Phat</b>was here""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Opera/9.63 (Windows NT 6.1; U; de) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.1; .NET CLR 1.1.4322)""",
"""Opera/9.60 (Windows NT 6.0; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.17) Gecko/20080703 Mandriva/2.0.0.17-1.1mdv2008.1 (2008.1) Firefox/2.0.0.17""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.6) Gecko/2009020911 Ubuntu/8.10 (intrepid) Firefox/3.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.6) Gecko/2009020911 Ubuntu/8.04 (hardy) Firefox/3.0.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""weivel/Nutch-0.9 (weive.com - web spider; http://www.weive.com/page/view/weivel; weivel at weive dot com)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.6) Gecko/2009020911 Ubuntu/8.04 (hardy) Firefox/3.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6 FirePHP/0.2.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.3a) Gecko/20021212""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de-DE; rv:1.9.0.6) Gecko/2009011912 Firefox/3.0.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; InfoPath.2; Tablet PC 2.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaN95_8GB/20.0.016; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (SymbianOS/9.4; U; Series60/5.0 Nokia5800d-1/11.0.008; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaN95/10.0.018; Profile/MIDP-2.0 Configuration/CLDC-1.1 )AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (compatible; proximic; +http://www.proximic.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; http://www.teldu.de; .NET CLR 2.0.50727)""",
"""Eigenbau""",
"""Opera/9.60 (J2ME/MIDP; Opera Mini/4.2.13223/608; U; id) Presto/2.2.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.28 (KHTML, like Gecko) Version/3.2.2 Safari/525.28.1""",
"""SimilarPages/Nutch-1.0-dev (SimilarPages Nutch Crawler; http://www.similarpages.com; info at similarpages dot com)""",
"""Jyxobot/1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/528.16 (KHTML, like Gecko) Version/4.0 Safari/528.16""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.19) Gecko/20081204 MultiZilla/1.8.3.4e SeaMonkey/1.1.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Tablet PC 2.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; es-ES; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""fgdfgdfg""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.6) Gecko/2009022620 Gentoo Firefox/3.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE; rv:1.9.0.6) Gecko/2009011913 (CK-PC-WELT) Firefox/3.0.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-AU; rv:1.8.1.11) Gecko/20071204 Firefox/2.0.0.11)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GTB5; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/5.0 (de)""",
"""Mozilla/5.0 (X11; U; Linux i686; hu-HU; rv:1.9.0.6) Gecko/2009020410 Fedora/3.0.6-1.fc10 Firefox/3.0.6""",
"""Shelob (shelob@gmx.net)""",
"""ewf""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; NetBSD sparc64; en-US; rv:1.8.1.19) Gecko/20081204 SeaMonkey/1.1.14""",
"""de_viewer larbin2.6.3@unspecified.mail""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de-AT; rv:1.8.1.19) Gecko/20081204 SeaMonkey/1.1.14""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9.0.7) Gecko/2009021906 Firefox/3.0.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de-de) AppleWebKit/418.9.1 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.0.7) Gecko/20060911 Camino/1.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/528.16 (KHTML, like Gecko) Version/4.0 Safari/528.16""",
"""SceneCoderZ""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 Gecko 20070713 Firefox/2.0.0.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1b3) Gecko/20090305 Firefox/3.1b3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.4 (de) (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.0.14eol) Gecko/20090209 Ubuntu/dapper-security Firefox/1.5.0.12eol""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.05; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Sieh doch mal, was für ein hübscher Pimmel!""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.7) Gecko/2009022800 SUSE/3.0.7-1.1.6 Firefox/3.0.7""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.7) Gecko/2009030422 Ubuntu/8.10 (intrepid) Firefox/3.0.7""",
"""Mozilla/10.0 (NoNameOS; Sickbrowse 8.0.2; U; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; MSN Optimized;US; MSN Optimized;US)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; OfficeLiveConnector.1.3; OfficeLivePatch.1.3; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.48 Safari/525.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Opera/9.64 (X11; Linux x86_64; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (compatible; Konqueror/4.2; Linux) KHTML/4.2.1 (like Gecko) SUSE""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.10 (like Gecko) SUSE""",
"""libwww-perl/5.823""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB5; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; FDM; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4) Gecko/20030827 Debian/1.4-3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.1 (KHTML, like Gecko) Chrome/2.0.169.1 Safari/530.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaN95/31.0.017; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; de; rv:1.8.1.19) Gecko/20081212 Camino/1.6.6 (MultiLang) (like Firefox/2.0.0.19)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ar; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.6) Gecko/2009020414 CentOS/3.0.6-1.el5.centos Firefox/3.0.6""",
"""W3C_Validator/1.654""",
"""lqrtknygeytvrpkpryqhuW""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.7) Gecko/2009021906 Firefox/3.0.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.8) Gecko/2009032608 Firefox/3.0.8""",
"""Opera/9.64 (Macintosh; Intel Mac OS X; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.4) Gecko/2008103100 SUSE/3.0.4-3.1 Firefox/3.0.4""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.7) Gecko/2009031721 Gentoo Firefox/3.0.7""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en; rv:2.0.0.0) Gecko/2009040101 Gentoo Firefox/4.0a1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.5 (de) (TL-FF) (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MSN OptimizedIE8;DEDE)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.8) Gecko/2009032711 Ubuntu/8.10 (intrepid) Firefox/3.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en; rv:1.8.1.5) Gecko/20070713 Firefox/2.0.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 (.NET CLR 3.5.30729)""",
"""Opera/9.64 (Windows NT 6.0; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.8) Gecko/2009032711 Ubuntu/8.10 (intrepid) Firefox/3.0.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (000000000; 0; 000 000 00 0 0000000; 00000) 00000000000000000000 0000000 0000 000000 0000000000000 000000000000000""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.8) Gecko/2009040109 Gentoo Firefox/3.0.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.8) Gecko/2009033008 GranParadiso/3.0.8""",
"""Mozilla/4.0 (vBSEO; http://www.vbseo.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1b3) Gecko/20090305 Firefox/3.1b3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.8) Gecko/2009033017 GranParadiso/3.0.8""",
"""iCab/4.5 (Macintosh; U; Intel Mac OS X)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_6; de-de) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Opera/9.64 (Windows NT 5.0; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.3, Ant.com""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_6; de-de) AppleWebKit/528.16 (KHTML, like Gecko) Version/4.0 Safari/528.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GTB5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.7;MEGAUPLOAD 1.0 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.7) Gecko/2009032803 Iceweasel/3.0.6 (Debian-3.0.6-1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 Creative ZENcast v2.00.13""",
"""Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420+ (KHTML, like Gecko) Version/3.0 Mobile/1C10 Safari/419.3""",
"""Mozilla/2.0 (Compatible; MSIE 3.0; AOL 4.0; Windows 3.1)""",
"""xrbpwKcpqwnhylwruuaqfhbh""",
"""ihafBrlkBhBijnfwyBxydnriied7f i""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.8) Gecko/2009032600 SUSE/3.0.8-1.1.1 Firefox/3.0.8""",
"""Mozilla/4.0 (compatible; MSIE 9.1; Windows NT 6.5; Trident/4.0; SLCC1; .NET CLR 15.0.13379; .NET CLR 15.0.ID10T; InfoPath.2; .NET CLR 15.5.21022) Bill Gates""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.8.1) Gecko/20061024 Firefox/2.0 (Swiftfox)""",
"""meiner <b>test</b> 'jo'""",
"""*******Stroli war hier********""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.53 Safari/525.19""",
"""Java/1.6.0_12""",
"""Mozilla/5.0 (compatible; Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; DBLBot/1.0; +http://www.dontbuylists.com/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.8) Gecko/2009032609 firefox3.08 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.6 Safari/530.5""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.1)""",
"""Mozilla/5.0 (compatible; MSIE 5.01; Windows 98)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.9.0.8) Gecko/2009032608 Firefox/3.0.8""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_6; de-de) AppleWebKit/528.16 (KHTML, like Gecko) Version/4.0 Safari/528.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.9) Gecko/2009040821 Firefox/3.0.9 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 2_2_1 like Mac OS X; de-de) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.1 Mobile/5H11 Safari/525.20""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.8) Gecko/2009042111 Gentoo Firefox/3.0.8""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.9.0.9) Gecko/2009040820 Firefox/3.0.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.9) Gecko/2009040821 Firefox/3.0.9 (.NET CLR 3.5.30729)""",
"""qfmimx dkffpqsafkgmgeo Icocdsube xfk""",
"""EbdEyfij6bwn6tybyydfoidicfhpdtsefh""",
"""Wget/1.11.4 (Red Hat modified)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.9) Gecko/2009040821 Firefox/3.0.9""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/418.9 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.0.14eol) Gecko/20090327 Ubuntu/dapper-security Firefox/1.5.0.12eol""",
"""tqyFtkt kfitgcvvihakxrlkem""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.9) Gecko/2009040821 (CK-PC-WELT) Firefox/3.0.9""",
"""dkkdx tgvlgfjeUwqku3uqelfqteywvxvv3""",
"""syax4vrfvdugpf4bp ieykpnrcdmmwngqMii""",
"""Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; PPC; 240x320)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Twiceler-0.9 http://www.cuil.com/twiceler/robot.html)""",
"""pxqawjqehunbgWy a xWbbj""",
"""qwjelealkwux9mkjmq9ytug""",
"""vphhhsahbkdlenttsklyr2 wm p""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.6) Gecko/2009020409""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en_CA) AppleWebKit/419 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.9) Gecko/2009040821 Firefox/2.0.0.6 (de) (TL-FF)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.9) Gecko/2009040821 Firefox/3.0.9""",
"""jokxyAaktAddtuxirs3fndur t""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.10) Gecko/2009042523 Ubuntu/8.10 (intrepid) Firefox/3.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10""",
"""msnbot/2.0b (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.10) Gecko/2009050122 Gentoo GranParadiso/3.0.10""",
"""Opera/7.51 (Windows NT 5.1; U) [en]""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1b3) Gecko/20090305 Firefox/3.1b3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.0.04506)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.10) Gecko/2009042523 Ubuntu/9.04 (jaunty) Firefox/3.0.10""",
"""aggytwskwnyocwgsujaTwhTnkijspmaqjw9hte""",
"""jllcss7u luiijaeuh prf q""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.10) Gecko/2009042315 Firefox/3.0.10""",
"""Opera/9.64 (Windows NT 5.1; U; de) Presto/2.1.1""",
"""Opera/9.64 (Windows NT 6.0; U; pt) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB6; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""axc ht7hhpwrcltf7uw7axlHppe ear7""",
"""yslp myeyxs iin4simVaq4ka""",
"""rbdxlnrpqdkUUirybdjdjishiguyviv""",
"""xjfvhpvepyfv nfwkcpwfs""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB6; SIMBAR={F45C9A72-539B-41A5-83E7-8A29913C3E31})""",
"""tlwxnxqlysxtwtvcvfsciucrrnxlp hxubxivh""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10""",
"""nllpfdlt1corfaujhmjwjrwdiduunar""",
"""ptxfwliqvyxqmhmqxC3wnkrvjCgm""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.10) Gecko/2009042523 Ubuntu/9.04 (jaunty) Firefox/3.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.10) Gecko/2009042316 opera mini (.NET CLR 3.5.30729)""",
"""iskpno9x wnwgihvWWaexioonfikcpclfo nrr""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (compatible; SpyDom.de WebAnalyzer; +http://www.SpyDom.de)""",
"""fdffEevmppgktu vmney""",
"""ublu9fvapfyyhrds9qcpbckw""",
"""b vaordqkhgvkqdqcuurbwu hj""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.10) Gecko/2009052212 Gentoo Firefox/3.0.10""",
"""efwpmNvwNNNp77of x7k7krfvdrvjjrdxpjcj""",
"""1. Es gibt keine G?ttin ausser der G?ttin und sie ist deine G?ttin. Es gibt keine Erisische Bewegung ausser der Erisischen Bewegung und es ist die Erisische Bewegung. Und jeder goldene Apfel ist das geliebte Heim eines Goldenen Wurmes. 2. Ein Diskordier soll immer das offizielle diskordische Dokumentennummerierungssystem benutzen. 3. Ein Diskordier ist zu Beginn seiner Illumination dazu verpflichtet, an einem Freitag alleine nach draussen zu gehen um fr?hlich einen Hot Dog zu geniessen; diese Zeremonie ist dazu da, um gegen die beliebten Paganismen dieser Tage zu demonstrieren: gegen die Katholische Christenheit (freitags kein Fleisch), das Judentum und den Islam (kein Fleisch vom Schwein), den Hinduismus (kein Fleisch von der Kuh), den Buddhismus (kein Fleisch von Tieren) und den Diskordianismus (keine Hot-Dog-Br?tchen). 4. Ein Diskordier soll keine Hot-Dog-Br?tchen essen, denn es war der Trost der G?ttin, als sie mit der urspr?nglichen Zur?ckweisung konfrontiert war. 5. Einem Diskordier ist es verboten, zu glauben, was er liest.""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; de-de) AppleWebKit/525.28.3 (KHTML, like Gecko) Version/3.2.3 Safari/525.28.3""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.10) Gecko/2009042809 GranParadiso/3.0.10""",
"""q exkrcpkqh bvmyxwuypeeocdhkcx o""",
"""xenyelsokhcgdurh2gkfNjnpuhhNql2dv2u""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""dnd0lwebdojb cdbte0gbxuv""",
"""todes bass schaedel""",
"""auycmqtwskpgy wehxshhaupa""",
"""AMIIIGGGGAAAAAAAAAAAAAAAAA!!!!!!!!!!!!!!!!!""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.28 Safari/530.5""",
"""Opvwchejmvquwqoh2hlll""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.4) Gecko/2008103100 SUSE/3.0.4-4.6 Firefox/3.0.4""",
"""dyu pr4puwqvdd vdgLlgmv4lm piapLiiyfg""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 GTB5""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.10) Gecko/2009042523 Ubuntu/9.04 (jaunty) Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""yacybot (amd64 Linux 2.6.28-12-generic; java 1.6.0_13; GMT/en) http://yacy.net/bot.html""",
"""Opera/9.00 (Nintendo Wii; U; ; 1309-9; en)""",
"""Mozilla/5.0 (compatible; Plukkie/1.1; http://www.botje.com/plukkie.htm)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 GTB5 (.NET CLR 3.5.30729) FirePHP/0.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.9) Gecko/2009042113 Ubuntu/9.04 (jaunty) Firefox/3.0.9""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.10) Gecko/2009042700 SUSE/3.0.10-1.1.1 Firefox/3.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 FirePHP/0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Safari/528.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/527+ (KHTML, like Gecko) QtWeb Internet Browser/2.5 http://www.QtWeb.net""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; de-de) AppleWebKit/528.18.1 (KHTML, like Gecko) Version/4.0 Safari/528.17""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.10) Gecko/2009042810 GranParadiso/3.0.10""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.7) Gecko/2009030810 Iceweasel/3.0.9 (Debian-3.0.9-1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.1b4) Gecko/20090423 Firefox/3.5b4""",
"""Opera/9.61 (Windows NT 5.2; U; de) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3)""",
"""Opera/9.80 (Windows NT 6.0; U; en) Presto/2.2.15 Version/10.00""",
"""Baiduspider+(+http://www.baidu.com/search/spider.htm)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.28 Safari/530.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.30 Safari/530.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1b4) Gecko/20090423 Firefox/3.5b4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/527+ (KHTML, like Gecko) QtWeb Internet Browser/2.5 http://www.QtWeb.net""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Safari/530.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.21) Gecko/20090331 K-Meleon/1.5.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5 FirePHP/0.3""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.5; fr; rv:1.9.0.10) Gecko/2009042315 Firefox/3.0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1b1pre) Gecko/20080909032504 Minefield/3.1b1pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1b99) Gecko/20090605 Firefox/3.5b99""",
"""Opera/9.63 (Macintosh; Intel Mac OS X; U; de) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/531.0 (KHTML, like Gecko) Chrome/3.0.182.3 Safari/531.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.8.1.19) Gecko/20081217 K-Meleon/1.5.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.11) Gecko/2009060308 Ubuntu/9.04 (jaunty) Firefox/3.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.8, Ant.com Toolbar 1.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; ar; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; de-de) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Safari/530.17""",
"""Ipod""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (.NET CLR 3.5.30729)""",
"""SonyEricssonP910i/R3A SEMC-Browser/Symbian/3.0 Profile/MIDP-2.0 Configuration/CLDC-1.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.11) Gecko/2009060200 SUSE/3.0.11-0.1.1 Firefox/3.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 GTB5""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.7) Gecko/2009030814 Iceweasel/3.0.9 (Debian-3.0.9-1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1) Gecko/20090615 Firefox/3.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.11; .NET CLR 2.0.50727; ffco7) Gecko/2009060215 Firefox/3.0.11""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.9) Gecko/2009050519 Iceweasel/3.0.6 (Debian-3.0.6-1)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en; rv:1.9.0.11) Gecko/20080528 Epiphany/2.22""",
"""Java/1.6.0_13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)/Nutch-1.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.11) Gecko/2009060214 Firefox/3.0.11""",
"""User-Agent: Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.33 Safari/530.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1) Gecko/20090624 Firefox/3.5""",
"""Python-urllib/1.17""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.11) Gecko/2009060308 Ubuntu/9.04 (jaunty) Firefox/3.0.11""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1b4) Gecko/20090506 Gentoo Shiretoko/3.5b4""",
"""Mozilla/4.0 (compatible; U; MSIE 6.0; Windows NT 5.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.2.5; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10""",
"""BlackBerry8703e/4.1.0 Profile/MIDP-2.0 Configuration/CLDC-1.1 VendorID/189""",
"""Opera/9.64 (Windows NT 6.1; U; de) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; MRA 4.10 (build 01952); .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (.NET CLR 3.5.30729) AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.8) Gecko/20050511 Firefox/1.0.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/4.0; SLCC1; Media Center PC 5.0; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1) Gecko/20090624 Firefox/3.5 (.NET CLR 3.5.30729)""",
"""yacybot (amd64 Linux 2.6.27-14-generic; java 1.6.0_0; Europe/de) http://yacy.net/bot.html""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 3_0 like Mac OS X; de-de) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1) Gecko/20090701 Firefox/3.5""",
"""Mozilla/5.0 (X11; U; IRIX IP22; en-US; rv:1.0.2) Gecko/20030820""",
"""Opera/10.00 (Windows NT 6.1; U; de) Presto/2.2.2""",
"""SonyEricssonW660i/R8BB Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Opera/9.60 (J2ME/MIDP; Opera Mini/4.0.9751/504; U; en) Presto/2.2.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Pivim Multibar; GTB6; MRA 5.5 (build 02780); MRSPUTNIK 2, 1, 0, 7 SW; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 1.1.4322; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 Firefox 3.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 Wget/1.10.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 toll oder""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.4) Gecko/2008102920 8=>""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1) Gecko/20090703 Shiretoko/3.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; T-Brand-Final)""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux; x86_64) KHTML/3.5.5 (like Gecko) (Debian)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1) Gecko/20090624 Firefox/3.0.11 (de) (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1) Gecko/20090624 Firefox/3.5 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1) Gecko/20090624 Firefox/3.5 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.11) Gecko/2009060200 SUSE/3.0.11-0.1.1 Firefox/3.0.11 AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.2; .NET CLR 3.5.21022; OfficeLiveConnector.1.3; OfficeLivePatch.1.3; .NET CLR 3.5.30729; .NET CLR 3.0.30618; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17 7791505200721022112""",
"""NutchCVS/0.0x-dev (Nutch; http://www.nutch.org/docs/bot.html; nutch-agent@lists.sourceforge.net)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.9) Gecko/2008052906 Firefox/3.0""",
"""öfhhakfjaujfljrfehfhakjfclajkfdjhvkajdozhiuzeifuoqjvsdvkjdhfkfkqhggjgkhfqurfouoruoihwkdghfjdskjvohfkoqhfiqoifzuifziegidhkvhdkfhqsowuououogirhgkihdknbdkcljldakdeiwproejgkdhkfdjhjfhbgkdgkdjfjlfjqofojfojfojqofjqojfopqjfpojqofjhkdvkndkbnkdbnkdhglkjhgolhwkghkghohjfojogfjqofjohkdnkvnbdkvkdhnvkdljslfjlqjflqjfqjfjqlvjlkdjvkdnkvbdkvkdhlfjsljklöskdököpdqkpdfqpfjoejfoejgnvbkndx,kvnslmcöaköakäödlKAÄÖSLAÖ;MCLSMNVKDNHBGJRHGIGHIREHGIERHGKDNKVNSLKMJDLQAKPKQPPÜQOSä l.aä;AÖKlxjnkanvkdsbnvkndkncv,lsmnkcnbjabvknvkabvjwhkscjvbsdjvsdvbjdbvdbvkdsbnvsbvksbvojsbvjsbvbskvobasjkvbjaksbvabvoasbvkoabkvbakbvkjabvjdsabvba""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_6; de-de) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.2.15 Version/10.00""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; http://www.bramptonmoose.com/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Arcor 5.006; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; Media Center PC 5.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.6) Gecko/2009011913 Firefox""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 (.NET CLR 3.5.30729)""",
"""WebAlta Crawler/1.3.23 (http://www.webalta.net/ru/about_webmaster.html) (Windows; U; Windows NT 5.1; ru-RU)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-GB; rv:1.7.10) Gecko/20050717 Firefox/1.0.6""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.12) Gecko/2009070811 Ubuntu/9.04 (jaunty) Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.30729; OfficeLiveConnector.1.4; OfficeLivePatch.1.3; .NET CLR 3.0.30729)""",
"""libwww-perl/5.825""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.37 Safari/530.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; .NET CLR 2.0.50727; FDM)""",
"""Noxon""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.12) Gecko/2009071200 SUSE/3.0.12-0.1.2 Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.12) Gecko/2009070611 Firefox/3.0.12 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.12) Gecko/2009070609 Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.12) Gecko/2009070611 Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.12) Gecko/2009070611 Firefox/3.0.12 FirePHP/0.3""",
"""Nokia-WAPToolkit/1.2 googlebot@googlebot.com""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; el; rv:1.9.0.11) Gecko/2009060215 Firefox/3.0.11 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.1.1) Gecko/20090718 Firefox/3.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en) AppleWebKit/526.9 (KHTML, like Gecko) Version/4.0dp1 Safari/526.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.12) Gecko/2009070611 MRA 5.4 (build 02652) Firefox/3.0.12 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1) Gecko/20090624 Firefox/3.5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; de-de) AppleWebKit/530.19.2 (KHTML, like Gecko) Version/4.0.2 Safari/530.19""",
"""betaBot""",
"""Opera/9.60 (J2ME/MIDP; Opera Mini/4.2.14881/504; U; de) Presto/2.2.0""",
"""Mozilla/5.0 (X11; U; Linux i686) Gecko/20051111 Firefox/1.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.1) Gecko/20090715 (CK-PC-WELT) Firefox/3.5.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; TuneUp HTML Client Embedded Web Browser from: http://bsalsa.com/; InfoPath.1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.13) Gecko/2009073022 Firefox/3.0.13 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Safari/530.17""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; en-us) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Safari/530.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-us) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Safari/530.17""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; en-us) AppleWebKit/525.28.3 (KHTML, like Gecko) Version/3.2.3 Safari/525.28.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-us) AppleWebKit/525.28.3 (KHTML, like Gecko) Version/3.2.3 Safari/525.28.3""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en) AppleWebKit/419 (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/125.5.7 (KHTML, like Gecko) Safari/125.12""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 2_2_1 like Mac OS X; en-us) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.1 Mobile/5H11 Safari/525.20""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 2_2_1 like Mac OS X; en-us) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.1 Mobile/5H11 Safari/525.20""",
"""Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420.1 (KHTML, like Gecko) Version/3.0 Mobile/4A102 Safari/419.3""",
"""Mozilla/5.0 (iPod; U; CPU like Mac OS X; en) AppleWebKit/420.1 (KHTML, like Gecko) Version/3.0 Mobile/4A102 Safari/419.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.0.10) Gecko/2009042315 Firefox/3.0.10""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Opera/9.64 (Macintosh; Intel Mac OS X; U; en) Presto/2.1.1""",
"""Opera/9.64 (Windows NT 6.0; U; en) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET CLR 3.0.30618; MSOffice 12)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.12) Gecko/2009071200 SUSE/3.0.12-0.1.2 Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.13) Gecko/2009080315 Ubuntu/9.04 (jaunty) Firefox/3.0.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.13) Gecko/2009073022 Firefox/3.0.13 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; SIMBAR Enabled; SIMBAR={A091F1AD-5EFB-47de-A543-FD7C45EC7024}; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; en-us) AppleWebKit/530.19.2 (KHTML, like Gecko) Version/4.0.2 Safari/530.19""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.12) Gecko/2009072221 Iceweasel/3.0.6 (Debian-3.0.6-1) AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729) AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Lynx/2.8.6dev.15 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.7d AutoPager/0.5.2.2 (http://www.teesoft.info/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux x86_64; U; de; rv:1.8.1) Gecko/20061208 Firefox/2.0.0 Opera 9.64""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Iron/3.0.197.0 Safari/532.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.2; IEMB3)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.11) Gecko GranParadiso/3.0.11""",
"""Java/1.6.0_14""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; de-de) AppleWebKit/530.19.2 (KHTML, like Gecko) Version/4.0.2 Safari/530.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.0.4 (de) (TL-FF) (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; FDM; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.5) Gecko/20060127 Netscape/8.1""",
"""Mozilla/5.0 (X11; U; Linux i686; cs-CZ; rv:1.7.12) Gecko/20050929""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.12) Gecko/2009070811 Ubuntu/9.04 (jaunty) Firefox/3.0.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Iron/3.0.197.0 Safari/532.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_4; ja-jp) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""N2730""",
"""Mozilla/5.0 (compatible; SuchbaerBot/0.83; +http://bot.suchbaer.de/info.html)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; cs; rv:1.9.0.8) Gecko/2009032609 Firefox/3.0.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.13) Gecko/2009080200 SUSE/3.0.13-0.1.2 Firefox/3.0.13""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.2) Gecko/20090730 SUSE/3.5.2-2.1 Firefox/3.5.2""",
"""Mozilla/5.0 (X11; U; SunOS sun4u; en-US; rv:1.8.1.20) Gecko/20090108 Firefox/2.0.0.20""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.13) Gecko/2009080200 SUSE/3.0.13-0.1 Firefox/3.0.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729),gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; SIMBAR Enabled; Mozilla/4.0 (compatible; MSIE 8.0; Win32; GMX); .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.2.15 Version/10.00""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.13; .NET CLR 2.0.50727; ffco7) Gecko/2009073022 Firefox/3.0.13""",
"""Mozilla/5.0 (X11; U; Linux i686; pl-PL; rv:1.9.1.2) Gecko/20090730 SUSE/3.5.2-2.1 Firefox/3.5.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 GTB5 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.2.15 Version/10.00""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; UCLBC)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; ru; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.0.13) Gecko/2009073022 Firefox/2.0.0.17;MEGAUPLOAD 1.0 ImageShackToolbar/5.0.0 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Eurobot/1.1 (http://eurobot.ayell.eu)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.13) Gecko/2009080315 Linux Mint/7 (Gloria) Firefox/3.0.13""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.13) Gecko/2009080200 SUSE/3.0.13-0.1.2 Firefox/3.0.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.13) Gecko/2009073022 Firefox/3.0.13 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; AllgÃ¤uer Medien Zentrum)""",
"""Midori/0.1.10""",
"""Java/1.6.0_15""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en; rv:1.9.0.13) Gecko/20080528 Epiphany/2.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.3) Gecko/20090824 Hey du wurdest von Toddy geklickt, pls reklick^^ (.NET CLR 4.0.20506)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.14) Gecko/2009090217 Ubuntu/9.04 (jaunty) Firefox/3.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; rv:1.9.0.14) Gecko/2009090217 Firefox/3.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.14) Gecko/2009082707 Firefox/3.0.14 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.3) Gecko/20090909 SUSE/3.5.3-1.2 Firefox/3.5.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.590; .NET CLR 3.5.20706)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 8.0; Win32; GMX); .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB6; DS_desktopsmiley; desktopsmiley_3_3_277900093213757613_1_74),gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB6.3)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.14) Gecko/2009090216 Ubuntu/8.10 (intrepid) Firefox/3.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 GTB5 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9.0.14) Gecko/2009082706 Firefox/3.0.14""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en; rv:1.9.0.14) Gecko/20080528 Epiphany/2.22""",
"""Mozilla/4.0 (compatible; MSIE 7.0; TOB 6.07; Windows NT 5.1; Trident/4.0; GTB6; .NET CLR 1.1.4322; MSN Optimized;DE; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; T-Brand-Final)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Chrome/4.0.207.0 Safari/532.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Chrome/3.0.195.21 Safari/532.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-AR; rv:1.8.0.7) Gecko/20060909 Firefox/1.5.0.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.3) Gecko/20090824 YFF35 Firefox/3.5.3""",
"""Mozilla/4.05 [en] (X11; I; OSF1 V4.0 alpha)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9.1.1) Gecko/20090714 SUSE/3.5.1-1.1 Firefox/3.5.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible;MSIE 5.5; Windows NT 5.0; H010818)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.14) Gecko/2009082707 Firefox/3.0.14 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; Seznam screenshot-generator 2.0; +http://fulltext.sblog.cz/screenshot/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.1 (KHTML, like Gecko) Chrome/4.0.213.1 Safari/532.1""",
"""PHPCrawl""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.14) Gecko/2009090216 Ubuntu/9.04 (jaunty) Firefox/3.0.14 FirePHP/0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""xhslteavagqocnpnutqk""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.5pre) Gecko/20091007 Ubuntu/9.04 (jaunty) Firefox/3.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2; MS-RTC LM 8; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.30729; .NET CLR 3.5.30707; InfoPath.2)""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.2.15 Version/10.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.14) Gecko/2009090216 Firefox/3.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; CIO CU; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.3) Gecko/20090919 Gentoo Firefox/3.5.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; spbot/2.0; +http://www.seoprofiler.com/bot/ )""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB6.4; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.1 (KHTML, like Gecko) Chrome/5.0.322.2 Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; yplus 5.6.03b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2) Gecko/20100115 Firefox/3.6 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; CMS Music Store2 v1.00.09 (Music Store,1033); .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MRA 4.6 (build 01425); MRSPUTNIK 1, 5, 0, 19 SW)""",
"""Yandex/1.01.001 (compatible; Win16; I)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50728)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; en-US) AppleWebKit/533.1 (KHTML, like Gecko) Chrome/5.0.322.2 Safari/533.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2) Gecko/20100115 Firefox/3.6""",
"""nxtegkpedrhpohafpwckxkojdrfckcsqhrhe""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.0.0; FunWebProducts; PeoplePal 3.0)""",
"""gonzo/1[P] (+http://www.suchen.de/faq.html)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; FunWebProducts; (R1 1.5))""",
"""Mozilla/5.0 (compatible; 008/0.83; http://www.80legs.com/spider.html;) Gecko/2008032620""",
"""Mozilla/4.8 [en] (X11; U; SunOS; 5.7 sun4u)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8 GTB6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; AskBar 3.00; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.8) Gecko/20100205 SeaMonkey/2.0.3""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; en-us) AppleWebKit/531.9 (KHTML, like Gecko) Version/4.0.3 Safari/531.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.5) Gecko/20091102 Firefox/3.5.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; FDM; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2) Gecko/20100204 Gentoo Firefox/3.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2) Gecko/20100115 YFF35 Firefox/3.6 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {3DC000FC-DB7B-6C86-061A-ACFDCE53B020}; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2) Gecko/20100115 Firefox/3.0.4 (de) (TL-FF) (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MRSPUTNIK 2, 1, 0, 4 HW; MRA 5.0 (build 02094))""",
"""Mozilla/5.0 (en-us) AppleWebKit/525.13 (KHTML, like Gecko; Google Wireless Transcoder) Version/3.1 Safari/525.13""",
"""cvqmykodcdpqouilsxlxyntqy""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; (R1 1.5); SpamBlockerUtility 4.7.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0(Compatible Mozilla/4.0EmbeddedWB- 14.58 from: http://bsalsa.com/ ; Mozilla/4.0(Compatible Mozilla/4.0(Compatible-EmbeddedWB 14.58 http://bsalsa.com/ EmbeddedWB- 14.58 from: http://bsalsa.com/ ; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; InfoPath.1; .NET CLR 3.0.04506.648; APBS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.0.2; .NET CLR 1.1.4322; yplus 4.4.02b)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.1.5) Gecko/20091102 Firefox/3.5.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; CDSource=v9e.05)""",
"""a2sokkpfu2bisfieeyandluoaeuDorvp kDDan""",
"""Mozilla/5.0 (compatible; spbot/2.0.1; +http://www.seoprofiler.com/bot/ )""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; rev1.5; Windows NT 5.1; .NET CLR 2.0.50727; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2) Gecko/20100115 Firefox/3.6 GTB6""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.8) Gecko/20100214 Ubuntu/9.10 (karmic) Firefox/3.5.8""",
"""Java/1.6.0_18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6 GTB5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; PrimusDSLEN; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.8) Gecko/20100214 Ubuntu/9.10 (karmic) Firefox/3.5.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Iron/3.0.197.0 Safari/532.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; (R1 1.1); ZangoToolbar 4.8.2; SpamBlockerUtility 4.8.0)""",
"""Cityreview Robot (+http://www.cityreview.org/crawler/)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.5.22 Version/10.50""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Neostrada TP 6.1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; IEMB3; IEMB3; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) Speedy Spider (http://www.entireweb.com/about/search_tech/speedy_spider/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; SpamBlockerUtility 4.8.4; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; InfoPath.2)""",
"""libwww-perl/5.813""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.8) Gecko/20100214 Ubuntu/9.10 (karmic) Firefox/3.0.6, Ant.com Toolbar 1.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.18) Gecko/2010021501 Ubuntu/9.04 (jaunty) Firefox/3.0.18""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; ImageShack Toolbar 4.4.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1036 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={742E5667-20B3-49c6-B7C7-A611183DCF3F}; (R1 1.5); .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4322; .NET CLR 2.0.40607; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-TW; rv:1.9.2) Gecko/20100115 Firefox/3.6 GTB6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.18) Gecko/2010020220 Firefox/3.0.18 GTBDFff GTB7.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; MSN 2.5; Windows 98; Win 9x 4.90; FDM)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.5.22 Version/10.51""",
"""Linguee Bot (http://www.linguee.com/bot; bot@linguee.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; ImageShack Toolbar 4.0.4)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; BT Business Broadband; YPC 3.2.0; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; GTB6; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; MS-RTC EA 2; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET CLR 3.0.30729; OfficeLiveConnector.1.4; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SIMBAR={95F68F4A-E1BB-4DCA-907F-0E6F0F3EB6D6}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2) Gecko/20100301 Ubuntu/9.10 (karmic) Firefox/3.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Wanadoo 5.6; Wanadoo 6.1; SV1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.18) Gecko/2010020220 ${USR_AGNT} Firefox/3.0.18 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.10pre) Gecko/20100326 Ubuntu/9.10 (karmic) Shiretoko/3.5.8pre""",
"""Mozilla/5.0 (compatible; spbot/2.0.2; +http://www.seoprofiler.com/bot/ )""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={FF5BBDF6-13F9-4F49-816E-58F618C18B47})""",
"""Java/1.6.0_17""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2 GTBDFff GTB7.0 (.NET CLR 3.5.30729) FBSMTWB""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2 (.NET CLR 3.5.30729)""",
"""Mozilla/2.0 (compatible; MSIE 3.02; Windows CE; 240x320)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.3; .NET CLR 1.1.4322; yplus 5.1.04b)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en; rv:1.9.0.18) Gecko/20080528 Epiphany/2.22""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""curl/7.18.2 (x86_64-pc-linux-gnu) libcurl/7.18.2 OpenSSL/0.9.8g zlib/1.2.3.3 libidn/1.8 libssh2/0.18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; FunWebProducts; .NET CLR 1.1.4322; ZangoToolbar 4.8.3; .NET CLR 2.0.50727)""",
"""msnbot/2.0b (+http://search.msn.com/msnbot.htm)._""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.23) Gecko/20090825 SeaMonkey/1.1.18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; acc=marketingsector; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; id; rv:1.9.2) Gecko/20100115 Firefox/3.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; MSOCD; T312461)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.5.22 Version/10.51""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.0.10 (de) (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; (R1 1.5); FDM)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; HbTools 4.7.1; MSN 9.0;MSN 9.1; MSNbMSNI; MSNmen-us; MSNcIA)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1045 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.3) Gecko/20091020 Ubuntu/9.10 (karmic) Firefox/3.5.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 GTB5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; ADVPLUGIN|K114|03|S-659636590|dial; ADVPLUGIN|K114|03|S-659636590|dialno; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.4)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {94546103-73DD-21E6-67CB-F65A8B699034}; SV1; InfoPath.1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.18) Gecko/20080921 SUSE/2.0.0.18-0.1 Firefox/2.0.0.18""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; FunWebProducts; SIMBAR={833D4A5E-749E-11DC-88BE-0019B9606FF5}; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; ga=MDBjMGE4OGUzNDE2; SIMBAR={D713E428-2C09-47ef-8FC2-6BFC59BC0B55}; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_3; en-us) AppleWebKit/531.22.7 (KHTML, like Gecko) Version/4.0.5 Safari/531.22.7""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.3.2; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SlimBrowser [flashpeak.com])""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.8) Gecko/20100312 Iceweasel/3.5.8 (like Firefox/3.5.8)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; HbTools 4.8.2; yplus 5.1.02b)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; FunWebProducts; .NET CLR 1.1.4322; HbTools 4.7.7; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; yplus 5.3.03b)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {384E6D2F-3389-5FCF-2273-91E14AB57FD5}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.4) Gecko/20100413 Firefox/3.6.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={6DAFCAF3-EB72-495f-934E-F9A97C0A64C5}; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; image_azv; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.18) Gecko/2010021501 Ubuntu/9.04 (jaunty) Firefox/3.0.18""",
"""Mundershirt/6.6.6""",
"""Ich war hier am Freitag, dem 23. April 2010 um 19:57 und wollte einfach nur mal allen Hallo sagen und diesem Projekt meinen Dank aussprechen. Viel Erfolg auch weiterhin.""",
"""Ich war hier am Freitag, dem 23. April 2010 um 20:02 und wollte einfach nur mal allen Hallo sagen und diesem Projekt meinen Dank aussprechen. Viel Erfolg auch weiterhin. Und falls ihr lust habt, dann sucht doch einfach mal bei Google nach Mundershirt/6.6.6 Viel SpaÃŸ!""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/4.0; GTB6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; CDSource=v3.12a.00; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0)""",
"""HPiPAQrw6815/1.0 Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; PPC; 240x320)""",
"""Opera/9.82 (OpenMilleniumOS 9.1; U; GB) Presto/2.5.22 Version/12.03""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; E-nrgyPlus; dial; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.8.1.16) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; de-de) AppleWebKit/531.21.8 (KHTML, like Gecko) Version/4.0.4 Safari/531.21.10""",
"""VMS_Mosaic/4.0 (Motif;OpenVMS V8.3 COMPAQ Professional Workstation ) libwww/2.12_Mosaic""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; DigExt; MSN 8.0; MSN 8.5; MSNbMSNI; MSNmen-us; MSNcOTH)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.4) Gecko/20100413 Firefox/3.6.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Arcor 5.003; GTB6.4; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1045 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; AT&T CSM 6.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; it; rv:1.9.0.18) Gecko/2010021501 Ubuntu/8.04 (hardy) Firefox/3.0.18""",
"""Mozilla/5.0 (X11; U; Linux i686; de;) Gecko/20090202 Ubuntu/9.10 (karmic) Firefox/3.0.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; TB Newsbar; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; PeoplePal 3.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1064 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; TOB 6.07; Windows NT 5.1; SV1; GTB6.4; .NET CLR 1.1.4322; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.23 Safari/533.4""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_3; de-de) AppleWebKit/531.22.7 (KHTML, like Gecko) Version/4.0.5 Safari/531.22.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.9) Gecko/20100315 Firefox/3.5.9 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR Enabled; SIMBAR={8F36CAE7-A501-4364-B134-16BBEFBC3A06}; .NET CLR 2.0.50727)""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.5.24 Version/10.52""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Q312461; Cox High Speed Internet Customer; (R1 1.5); IEMB3; IEMB3)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.9) Gecko/20100317 SUSE/3.5.9-0.1 Firefox/3.5.9""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.3) Gecko/20100423 Ubuntu/10.04 (lucid) Firefox/3.6.3""",
"""Java/1.6.0_02""",
"""lbkdDbgdpqd iq6j bmqykxx""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.19) Gecko/2010040119 Ubuntu/8.04 (hardy) Firefox/3.0.15""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; sbcydsl 3.12; ESB{182311D9-B95C-499B-A3AA-D275B80D1D45}; ESB{330CC175-CFAC-4875-BA5E-8FB31F15996F}; YPC 3.2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; yplus 5.1.04b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; Alexa Toolbar; (R1 1.5))""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.9) Gecko/20100402 Ubuntu/9.10 (karmic) Firefox/3.5.9""",
"""copyright sheriff (+http://www.copyrightsheriff.com/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.1.1) Gecko/20090715 Firefox/3.5.1 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Zango 10.0.314.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729)""",
"""Yeti/1.0 (NHN Corp.; http://help.naver.com/robots/)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.5.24 Version/10.53""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {6C866F6F-09DA-8C1C-FE67-5A78748333A9}; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; YPC 3.0.1; yplus 4.1.00b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8) Gecko/20051111 Firefox/3.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Embedded Web Browser from: http://bsalsa.com/; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MEGAUPLOAD 1.0); .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.2.15 Version/10.10""",
"""Java/1.6.0_16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; GTB6.4; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; eSobiSubscriber 2.0.4.16; .NET CLR 3.5.30729; InfoPath.2; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Hotbar 4.4.5.0; .NET CLR 1.1.4322)""",
"""Java/1.6.0_19""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.5pre) Gecko/20100507 Ubuntu/9.04 (jaunty) Namoroka/3.6.5pre""",
"""Mozilla/3.0 (x86 [en] Windows NT 5.1; Sun)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.3) Gecko/20100423 Ubuntu/10.04 (lucid) Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR Enabled; SIMBAR=0; SIMBAR={E0E05CD4-20A5-492f-AECE-5EF39E2CEA50}; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1064 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.4; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; OfficeLiveConnector.1.4; OfficeLivePatch.1.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; NovaPacs Viewer 6.0.197.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.17) Gecko/20080829 Firefox/2.0.0.17 GTB7.0 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (compatible; aiHitBot/1.0; +http://www.aihit.com/)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1 GTB7.0 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.3.3; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; 3B 2.3)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.3) Gecko/20100419 Gentoo Firefox/3.6.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1064 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.5) Gecko/20091102 Firefox/3.5.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.1; InfoPath.1; IEMB3; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; discobot/1.1; +http://discoveryengine.com/discobot.html""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; generic_01_01; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.9) Gecko/20100401 Linux Mint/8 (Helena) <script>alert (document.cookie);</script>""",
"""Mozilla/5.0 (en-US; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2""",
"""libwww-perl/5.831""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {906E4F77-A82D-B0C5-DD09-955294513388})""",
"""Mozilla/5.0 (de; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/5.0 (compatible; Semager/1.4; http://www.semager.de/blog/semager-bots/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iebar; (none); (R1 1.5))""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/533.2 (KHTML, like Gecko) Chrome/5.0.342.9 Safari/533.2""",
"""Mozilla/4.7 (compatible; OffByOne; Windows 2000) Webster Pro V3.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; IEMB3; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; NN5.0.3.4; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; HbTools 4.7.1; yplus 5.1.04b)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SpamBlockerUtility 4.8.4; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={6DD38C0B-364B-4d2e-9C83-4D3FAA1D64A2}; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/5.0 (compatible; spbot/2.0.3; +http://www.seoprofiler.com/bot/ )""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/531.22.7 (KHTML, like Gecko) Version/4.0.5 Safari/531.22.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; FDM; .NET CLR 1.1.4322; Maxthon 2.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; PeoplePal 6.2)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; MSN 9.0;MSN 9.1; MSNbVZ02; MSNmen-us; MSNcOTH)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.9) Gecko/20100315 Firefox/3.0.8 (de) ( .NET CLR 3.5.30729)""",
"""Mozilla/4.7 [de] (WinNT; I) [Netscape]""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; yie6_SBC; FunWebProducts; SV1; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; Win64; x64; en-US; rv:1.9.3a5pre) Gecko/20100602 Firefox/3.7a5pre""",
"""GeoHasher/Nutch-1.0 (GeoHasher Web Search Engine; geohasher.gotdns.org; geo_hasher at yahoo * com)""",
"""S2Bot/1.0 (http://search2.net)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; IEMB3; InfoPath.2; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6 (de) ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {0F47802C-547B-437A-B13A-B4B2CA09FE27}; .NET CLR 1.1.4322; .NET CLR 1.0.3705; Creative ZENcast v1.02.10; SpamBlockerUtility 4.8.4)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {BCFB0759-9679-7407-9D1F-942236592C28})""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {7FFCFB4A-65FD-0E6C-0AEA-A8692C245953}; .NET CLR 1.1.4322; ZangoToolbar 4.8.3)""",
"""CligooRobot/1.0""",
"""Mozilla/5.0 (compatible; MSIE 7.0b; Windows NT 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {A87831A5-EFB7-1734-1A48-7CDBB7F85A07}; acc=marketingsector; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SLCC1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 6.12) Vodafone/1.0/HTC_Mercury/3.54.162.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; rv:1.9.1.8) Gecko/20100202 Firefox/3.5.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.9) Gecko/20100315 Firefox/3.5.9 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Tablet PC 1.7; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; FunWebProducts; GTB6.5; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (compatible; spbot/2.0.4; +http://www.seoprofiler.com/bot )""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1; .NET CLR 1.1.4322; SpamBlockerUtility 4.8.4; ZangoToolbar 4.8.3)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB0.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; AskTB5.5)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; snprtz|S04045454802726; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.70 Safari/533.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Maxthon; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; InfoPath.1; IEMB3; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; yie6_SBC; SV1; FunWebProducts; SpamBlockerUtility 4.6.1; HbTools 4.7.2; yplus 5.1.03b)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Creative; .NET CLR 1.1.4322; .NET CLR 2.0.50727; IEMB3; PeoplePal 3.0; .NET CLR 3.0.04506.30; IEMB3)""",
"""Opera/10.60 (Windows NT 5.1; U; cs) Presto/2.6.30 Version/10.60""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.70 Safari/533.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.70 Safari/533.4""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0(Compatible Mozilla/4.0(Compatible-EmbeddedWB 14.57 http://bsalsa.com/ EmbeddedWB- 14.57 from: http://bsalsa.com/ ; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.8.0.1) Gecko/20060130 SeaMonkey/1.0""",
"""libwww-perl/5.832""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; IEMB3; SpamBlockerUtility 4.8.0; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 3.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; SV1; .NET CLR 1.1.4322; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4 (.NET CLR 3.5.30729) Mnenhy/0.8.2""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1""",
"""Baiduspider+(+http://www.baidu.jp/spider/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.0; (R1 1.5); .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4 GTB7.0 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; IE5.x/Winxx/EZN/xx)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={F65358C8-496C-4b9b-8FD4-001EECBE86F8}; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Opera/9.80 (Macintosh; PPC Mac OS X; U; de) Presto/2.2.15 Version/10.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Creative ZENcast v1.02.11)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; InfoPath.2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; IEMB3; HbTools 4.8.2; IEMB3)""",
"""Mozilla/5.0 (compatible; YandexBot/3.0; +http://yandex.com/bots)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.5; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; InfoPath.1; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.3) Gecko/20100423 Ubuntu/10.04 (lucid) Firefox/3.6.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 ( .NET CLR 3.0.4506.2152)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Sgrunt|V109|301|S2025837643|dialno; Sgrunt|V109|301|S2025837643|dial; SIMBAR={32F4A5F6-F67C-40a2-9E8A-734147AC6639}; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1; compatible; iCcrawler - iCjobs Stellenangebote Jobs; http://www.icjobs.de) Gecko/20100401 iCjobs/2.3.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; ADVPLUGIN|K114|03|S-327614649|dial; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; Media Center PC 5.1; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.7a) Gecko/20040614 Firefox/0.9.0+""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; HbTools 4.8.2)""",
"""Debian APT HTTP/1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; Win64; x64; de; rv:1.9.2.6) Gecko/20100627 Firefox/3.6.6 (tete009 SSE2 PGO)""",
"""Privoxy 3.0.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 GTB7.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.1.10) Gecko/20100504 Firefox/3.5.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.10) Gecko/20100504 Firefox/3.5.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.4) Gecko/20100630 Gentoo Namoroka/3.6.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mail.Ru/1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6""",
"""Mozilla/5.0 (SymbianOS/9.4; U; Series60/5.0 Nokia5230/10.0.067; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; (R1 1.3))""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.6) Gecko/20100628 Ubuntu/10.04 (lucid) Firefox/3.6.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; DigExt; SV1; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; .NET CLR 1.1.4322; InfoPath.2)""",
"""fNNc 4klnnNirso vlewwhfl4ccdm""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.5) Gecko/20100615 Firefox/3.6.5pre Fennec/1.1""",
"""HÃ¤ gibtsa nicht (compatible; MSIE 8.0; Wildsau; Trident/4.0; GTB6.5; GTB6.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; GTB6.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3)""",
"""jaafexoauilcoib auhfoloyEdxx""",
"""6uqdpwj6xfmvOx pclhmqdfOe6hvyqwxkllp""",
"""mcionm al mlfmaqlqhuSqSfpdma""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; HbTools 4.8.7)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7 GTB7.0""",
"""lex/1.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Bierce Library)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.6.30 Version/10.60""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; AOL 9.0; Windows NT 5.0)""",
"""ltgfwlkoxmgetdyekovjpnkpjdeanxf""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.6.30 Version/10.60""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 (.NET CLR 3.5.30729)""",
"""Internet Explorer 8.0.7600.16835 (compatible; ; WIN 7; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; InfoPath.3; T-Brand-RC)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.9) Gecko/20100824 Firefox/3.6.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.8) Gecko/20050511 Firefox/1.0.4""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET4.0C; .NET4.0E; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.2; Windows NT 5.1; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; de-de) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 GTB7.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; Konqueror/4.5; Linux) KHTML/4.5.1 (like Gecko)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.2.10) Gecko/20100914 Next Gerneration""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.19) Gecko/2010091808 Iceweasel/3.0.9 (Debian-3.0.9-1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Mozilla/4.0 (compatible; Powermarks/3.5; Windows 95/98/2000/NT)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.59 Safari/534.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2) Gecko/20100115 Firefox/3.6 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0C)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.6.30 Version/10.60""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 GTB7.0""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.6.30 Version/10.62""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Opera/9.80 (Macintosh; Intel Mac OS X; U; de) Presto/2.2.15 Version/10.10""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 GTB7.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Media Center PC 3.0; .NET CLR 1.0.3705; IEMB3; .NET CLR 2.0.50727; HbTools 4.8.4; IEMB3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) Netscape/8.0.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; iebar; (none))""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; nb-NO; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.10) Gecko/20100914 AskTbCDS/3.9.0.12758 Firefox/3.6.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; KKman2.0)""",
"""Mozilla/5.0 (compatible; bingbot/2.0 +http://www.bing.com/bingbot.htm)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET4.0C; .NET4.0E; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; Creative AutoUpdate v1.40.04)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1); .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MAMD; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.5; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.10) Gecko/20100915 Ubuntu/10.04 (lucid) Firefox/3.6.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.5; de; rv:1.9.1.11) Gecko/20100702 SeaMonkey/2.0.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Opera/9.80 (Windows NT 5.0; U; en) Presto/2.2.15 Version/10.20""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 GTB7.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; )""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {D2CE61D6-2E67-DAD6-D83F-D5996FDCF695}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; YandexBot/3.0; MirrorDetector; +http://yandex.com/bots)""",
"""Mozilla/5.0 (Linux; U; Linux x86_64; de; rv:1.9.0.6) Gecko/2009011913 Firefox/3.6.10""",
"""Nokia6610/1.0 (3.09) Profile/MIDP-1.0 Configuration/CLDC-1.0 (compatible;YahooSeeker/M1A1-R2D2; http://help.yahoo.com/l/us/yahoo/search/mobilecrawler/mobilecrawler-01.html)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4 (Splashtop-v1.2.17.25)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB6.5; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""SonyEricssonW810i/R4CE Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (compatible; bingbot/2.0; +http://www.bing.com/bingbot.htm)""",
"""wksewgnJo ju2Jjjrnqqdwwj essgJdb""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; ESB{6DE67919-89F5-42A2-B2E1-3E435A56D687}; .NET CLR 1.1.4322)""",
"""xowH9vk9vnitnqawmrcbklv""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 (.NET CLR 3.5.30729)""",
"""WordPress/3.0.1; http://www.vwp-online.de/blog""",
"""Services_oEmbed 0.1.0""",
"""Voyager/1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7 OneRiot/1.0 (http://www.oneriot.com)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.10) Gecko/20100922 Ubuntu/10.10 (maverick) Firefox/3.6.10""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; de-de) AppleWebKit/533.17.8 (KHTML, like Gecko) Version/5.0.1 Safari/533.17.8""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; de-de) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""facebookexternalhit/1.1 (+http://www.facebook.com/externalhit_uatext.php)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.10) Gecko/20100922 Ubuntu/10.10 (maverick) Firefox/3.6.10""",
"""thinkminimal.de""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.6.30 Version/10.63""",
"""http://thinkminimal.de""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.9) Gecko/20100824 Firefox/3.6.9 (.NET CLR 3.5.30729)""",
"""http://is.gd/eiUoG""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; de-de) AppleWebKit/532.9 (KHTML, like Gecko) Mobile/8B117""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.0; trendictionbot0.3.0; trendiction media spider; http://www.trendiction.com/bot/; spider@trendiction.com;) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; ru-RU; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.6.30 Version/10.62""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/7.0.544.0 Safari/534.10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.8) Gecko/20100723 Ubuntu/10.04 (lucid) Firefox/3.6.8""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.10) Gecko/20100915 Ubuntu/10.04 (lucid) Firefox/3.6.10""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.10) Gecko/20100915 Ubuntu/10.04 (lucid) Firefox/3.6.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 (.NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6.5; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.8) Gecko/20100723 Ubuntu/9.04 (jaunty) Firefox/3.6.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; Creative ZENcast v1.01.06)""",
"""<b>Hallo</b>""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.1; compatible; iCjobs Stellenangebote Jobs; http://www.icjobs.de) Gecko/20100401 iCjobs/3.2.3""",
"""SAMSUNG-SGH-E250/1.0 Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Browser/6.2.3.3.c.1.101 (GUI) MMP/2.0 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)""",
"""Atomic_Email_Hunter/4.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0b6) Gecko/20100101 Firefox/4.0b6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.0 Safari/534.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; Creative)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.9) Gecko/20100824 Firefox/3.6.9 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SeekmoToolbar 4.8.4)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {CC812321-E23F-43F3-8E72-A5351618A37D}; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/7.0.536.2 Safari/534.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-us) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/5.0 (compatible; SiteBot/0.1; +http://www.sitebot.org/robot/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; ZangoToolbar 4.8.3; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; GTB6.5; SIMBAR={38A1F377-C71C-11DF-BDC9-00245417C23F}; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; OfficeLiveConnector.1.3; OfficeLivePatch.0.0)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.11) Gecko/20101012 Firefox/3.6.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30707; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 95) Opera 6.01 [en]""",
"""Mozilla/5.0 (Windows NT 5.1; U; en) Opera 8.01""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl-PL; rv:1.8.1.24pre) Gecko/20100228 K-Meleon/1.5.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.8) Gecko/20100722 YFF35 Firefox/3.6.8""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.11) Gecko/20101013 Ubuntu/10.10 (maverick) Firefox/3.6.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB0.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.11) Gecko/20101012 Firefox/3.6.11 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 1.0.3705; MSN 9.0;MSN 9.1; MSNbQ002; MSNmen-us; MSNcOTH)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MRA 4.3 (build 01218); .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FREE; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.14) Gecko/2009090216 Ubuntu/9.04 (jaunty) Firefox/3.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.41 Safari/534.7""",
"""Hallo, ich wollte mich auch mal hier verewigen und liebe Grüße dalassen ;-) - Eure Nummer 3685""",
"""Ich meinte natürlich 'Eure Nummer 3686'; jetzt 3687 ^^""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Wanadoo Cable 2.0c)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8; Tablet PC 2.0; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it-IT) AppleWebKit/533.3 (KHTML, like Gecko) QtWeb Internet Browser/3.5 http://www.QtWeb.net""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; Dealio Toolbar 3.1.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.15) Gecko/20101026 Firefox/3.5.15 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.5.6 klsdklsd ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.9) Gecko/20100924 Gentoo Namoroka/3.6.9""",
"""Opera/7.54 (Windows NT 5.1; U) [pl]""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.12) Gecko/20101027 Ubuntu/10.04 (lucid) Firefox/3.6.12""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.11) Gecko/20101013 Ubuntu/10.04 (lucid) Firefox/3.6.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; SpamBlockerUtility 4.8.4; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.86 Safari/533.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.41 Safari/534.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ZangoToolbar 4.8.3; (R1 1.5))""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SIMBAR Enabled; SIMBAR={A0FA34AC-A412-4983-838C-676D1C963DF7}; GTB6; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Ant.com Toolbar 2.0.1 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ;ShopperReports BLNGBAR""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.12) Gecko/20101026 SUSE/3.6.12-0.1.1 Firefox/3.6.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.11) Gecko/20101019 Firefox/3.6.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; MSN 9.0; MSNbVZ02; MSNmen-us; MSNcOTH; MPLUS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Crazy Browser 1.0.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""msnbot-Products/1.0 (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.9) Gecko/20100921 Gentoo Firefox/3.6.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; eircom/june2000; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.9) Gecko/20101005 Gentoo Firefox/3.6.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; InfoPath.3; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/9999999 Firefox/3.6.12 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ESB{B40E378A-5206-45C2-8A47-6C14E63FE43F}; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.15) Gecko/20101026 Firefox/3.5.15 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0_1 like Mac OS X; de-de) AppleWebKit/532.9 (KHTML, like Gecko) Mobile/8A306""",
"""Mozilla/5.0 (X11; Linux i686; rv:2.0b6) Gecko/20100101 Firefox/4.0b6""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.2.10) Gecko/20100926 Firefox/3.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.44 Safari/534.7""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0_1 like Mac OS X; de-de) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8A306 Safari/6531.22.7""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; de-de) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8B117 Safari/6531.22.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.44 Safari/534.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101027 Ubuntu/10.10 (maverick) Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.15) Gecko/20101026 Firefox/3.5.15 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; AskTbDVSV5/5.9.1.14019)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SU 2.010; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (compatible; http://icvn.de/ua.php)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.8; ICQ: 613202525) Gecko/20100214 Ubuntu/9.10 (karmic) Firefox/3.5.8""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.12) Gecko/20101027 Fedora/3.6.12-1.fc14 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Media Center PC 5.0; SLCC1; Tablet PC 2.0; FDM; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.12) Gecko/20101027 Ubuntu/10.10 (maverick) Firefox/3.6.12""",
"""Nokia N95""",
"""Mozilla/4.76 [en] (Windows NT 5.0; U)""",
"""r4rjujvwkopsasjs4lawupg4vma""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 AskTbTRL2/3.9.1.14019 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; rev1.5; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.44 Safari/534.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.44 Safari/534.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MyIE9; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={519BC635-072B-4221-92BE-A79971A35075}; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101102 Gentoo Firefox/3.6.12""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows Phone OS 7.0; Trident/3.1; IEMobile/7.0; HTC; HD7 T9292)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 8.00""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.8.1.12) Gecko/20080219 Firefox/2.0.0.12 Navigator/9.0.0.6""",
"""Mozilla/5.0 Firefox/3.6.8""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.5.24 Version/10.53""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.12) Gecko/20101027 Ubuntu/10.04 (lucid) Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 BTRS31753 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; DT)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; FunWebProducts; .NET CLR 1.1.4322; MSN 9.0;MSN 9.1; MSNbMSNI; MSNmen-us; MSNcOTH)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Series80/2.0 Nokia9300i Profile/MIDP-2.0 Configuration/CLDC-1.1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iebar; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.5.30729; AskTbFXTV5/5.9.1.14019)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.40607)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Iron/6.0.475 Chrome/6.0.475.0 Safari/60814784.534""",
"""Opera/9.00 (Windows NT 4.0; U; en)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.15) Gecko/20101026 Firefox/3.5.15 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; YPC 3.0.3; .NET CLR 1.1.4322; yplus 4.1.00b)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; PPP v5.1 (1,1,1); Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 7.0; Win32; WEB.DE); .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.2) Gecko/20100316 MRA 5.6 (build 03278) Firefox/3.6.2 (.NET CLR 3.5.307""",
"""weneobot/Nutch-1.2 (weneo.de bot; http://www.weneo.de/bot; bot at weneo.de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-GB; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""qwdS owhjdu66yySe gofelmeks6yjeugnu""",
"""Mozilla/1.22 (compatible; MSIE 2.0; Windows 95)""",
"""dgbtbKxgsvietxwlnf eKkplolipe""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 (.NET CLR 3.5.30729)""",
"""BlackBerry9000/4.6.0.167 Profile/MIDP-2.0 Configuration/CLDC-1.1 VendorID/102""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; DigExt; MEGAUPLOAD 1.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.1.13) Gecko/20100914 Firefox/3.5.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.11) Gecko/20100701 Firefox/3.5.11 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.0.3) Gecko/2008092417 Firefox/2.0.0.17;MEGAUPLOAD 1.0 ImageShackToolbar/5.0.0 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; E-nrgyPlus; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/531.21.8 (KHTML, like Gecko) Version/4.0.4 Safari/531.21.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; AskTB5.6)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_1_2 like Mac OS X; de-de) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7D11 Safari/528.16""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B500 Safari/531.21.10""",
"""BlackBerry9500/5.0.0.451 Profile/MIDP-2.1 Configuration/CLDC-1.1 VendorID/137""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6.6; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; AM Browser 2.0.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 AskTbFXTV5/3.8.0.12304 Firefox/3.6.12 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 BTRS31527 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 8.12; MSIEMobile 6.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 (.NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.15) Gecko/20101026 Firefox/3.5.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 AskTbPF/3.8.0.12304 Firefox/3.6.12 GTB7.1 tb-gmx/1.3.3""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0b7) Gecko/20100101 Firefox/4.0b7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; InfoPath.1; Windows-Media-Player/10.00.00.3990; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.12 (KHTML, like Gecko) Chrome/9.0.587.0 Safari/534.12""",
"""Quicktime/7.6.2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0b7) Gecko/20100101 Firefox/4.0b7""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 1.1.4322; .NET CLR 3.5.21022; .NET CLR 3.5.30428; .NET CLR 3.5.30729; .NET CLR 3.0.30618; MS-RTC LM 8; InfoPath.2; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 AlexaToolbar/alxf-1.54 Firefox/3.6.12 GTB7.1 ( .NET CLR 3.0.04506)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.210 Safari/534.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Rogers Hi-Speed Internet; FunWebProducts; .NET CLR 1.1.4322; InfoPath.1)""",
"""msnbot/0.11 (+http://search.msn.com/msnbot.htm)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 3.0.30729)""",
"""DoCoMo/2.0 P900i(c100;TB;W24H11)(compatible; ichiro/mobile goo;+http://help.goo.ne.jp/door/crawler.html)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; FunWebProducts; Ant.com Toolbar 1.6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""jq driflqu lgohdfMmw0ufdpMictnwx quwjja""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MSN 6.1; MSNbMSFT; MSNmen-us; MSNc00; v5m)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Iron/7.0.520.0 Chrome/7.0.520.0 Safari/534.7""",
"""ssearch_bot (sSearch Crawler; http://www.semantissimo.de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""pirst; MSIE 8.0;""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) )""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; LocalNet3; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.21992/22.387; U; vi) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.15) Gecko/20101028""",
"""fibtc slxbphfcaoDh slDhaofahvfnghekvc""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.15) Gecko/2009102814 Ubuntu/8.10 (intrepid) Firefox/3.0.15""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; snprtz|T19138700001462|73010104# #1#4#90)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.215 Safari/534.10""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; googlebot; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14320/22.394; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.5; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6 GTB7.1 (.NET CLR 3.5.30729)""",
"""Netscape 6.1 (X11; I; Linux 2.4.18 i686; en-US)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; FunWebProducts; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( )""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5_8; de-de) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""AppEngine-Google; (+http://code.google.com/appengine; appid: steprep)""",
"""kfnbphht4ggmuPpnvlcgekvighxgha4cqr""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""8eeismjprpjuovlkv 8ewftnioxriFv""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.5; Windows NT 5.1; SV1; (R1 1.5); .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""aihwicncctobhiuogaa6k6p6jbkeya""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 ( )""",
"""hljcttcebOjfooadokgl kbril""",
"""jcitreenavpwuutpqw t""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6.3; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux armv7l; de-DE; rv:1.9.2.3pre) Gecko/20100723 Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; Win64; x64; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Ubuntu/10.04 Chromium/8.0.552.215 Chrome/8.0.552.215 Safari/534.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.4) Gecko/20091016 YFF35 Firefox/3.5.4 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.10 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; InfoPath.1; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; fr; rv:1.9.1.9) Gecko/20100315 Firefox/3.5.9 ImageShackToolbar/5.2.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 GTB7.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.215 Safari/534.10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.10 (maverick) Firefox/3.6.13""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0)""",
"""Mozilla/5.0 (compatible; 008/0.83; http://www.80legs.com/webcrawler.html) Gecko/2008032620""",
"""Mozilla/5.0 (compatible; 008/0.83; http://www.80legs.com/webcrawler.html) Gecko/2008032620""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; (R1 1.5); .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone 0S 3.0 like Mac 0S X; en-us; compatible; Googlebot/2.1; http://www.google.com/bot.html; AppleWebKit/528.18(KHTML,like Gecko) Version/4.0 Mobile/7A341 Safari/528.16 UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0b6pre) Gecko/20100903 Firefox/4.0b6pre""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.215 Safari/534.10""",
"""Mozilla/5.0 (X11; U; Linux i686; it-IT; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ImageShackToolbar/5.2.4 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2_1 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Mobile/7B405""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.13) Gecko/20100914 SeaMonkey/2.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; tr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.224 Safari/534.10""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; 1&1 Internet Inc. by USt; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20101203 MRA 5.7 (build 03790) Firefox/3.6.13 ( .NET CLR 3.5.30729) sputnik 2.3.1.118""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_5; ru-ru) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.53 Safari/534.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; tr; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Sgrunt|V109|1727|S608680499|dial; Sgrunt|V109|1727|S608680499|dialno; Mozilla/4.0(Compatible Mozilla/4.0(Compatible-EmbeddedWB 14.57 http://bsalsa.com/ EmbeddedWB- 14.57 from: http://bsalsa.com/ ; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.04 (lucid) Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101118 Gentoo Firefox/3.6.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.224 Safari/534.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.15) Gecko/20101028 Iceweasel/3.5.15 (like Firefox/3.5.15)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.2.13) Gecko/20101211 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; SpamBlockerUtility 4.8.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux i686; tr-TR; rv:1.9.2.12) Gecko/20101028 Pardus/2009 Firefox/3.6.12""",
"""Wget/1.12 (linux-gnu)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; InfoPath.1; ImageShack Toolbar 4.0.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.13) Gecko/20101203 AskTbUT2V5/3.9.1.14019 Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux; en-US) AppleWebKit/532.4 (KHTML, like Gecko) Qt/4.6.3 Safari/532.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.14 (KHTML, like Gecko) Chrome/10.0.603.3 Safari/534.14""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.4; OfficeLivePatch.1.3; .NET4.0C; .NET4.0E)""",
"""wjnjjpwivlw2 qogkbvrvw""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB6.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) ; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET4.0C; .NET4.0E; TheWorld)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; FunWebProducts)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.19 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows; 0; Windows NT 6.1; rv:1.9.2.13) Gecko/20101203""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; acc=jocker)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; fr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""MaMa CaSpEr""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 GTB7.1 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iebar; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Versatel.de ISDN 0404)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19""",
"""Mozilla/4.0 (compatible; ICS)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; SV1; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.7.62 Version/11.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Avant Browser; FunWebProducts; .NET CLR 1.1.4322; ZangoToolbar 4.8.2; Creative ZENcast v1.00.19; HbTools 4.8.4)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_5; de-de) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={87426856-BBF9-4b17-A17C-5B5666BFCA85}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.19) Gecko/2010040118 Ubuntu/8.10 (intrepid) Firefox/3.0.19""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={8DD73202-C28F-45A5-8DC8-552182FE3DC7}; GTB6.5; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0b8) Gecko/20100101 Firefox/4.0b8""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.2.15 Version/10.10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.10) Gecko/20100914 SUSE/3.6.10-0.3.1 Firefox/3.6.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 3.0.04506.30; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""HotJava/1.1.5 FCS""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.14pre) Gecko/20101223 Ubuntu/10.10 (maverick) Namoroka/3.6.14pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.13) Gecko/20101203 AlexaToolbar/alxf-2.01 Firefox/3.6.13 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Tablet PC 1.7; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04324.17; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SIMBAR={DF68E357-475E-4DFD-921B-A7D64B58D8A3}; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; MATM)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.0.12 (de) (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.04 (lucid) Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.15 (KHTML, like Gecko) Chrome/10.0.612.1 Safari/534.15""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; Avant Browser; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET CLR 1.1.4322; .NET CLR 3.5.21022; SLCC1; Tablet PC 2.0; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0C; T-Brand-Final)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SBC; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1059 Safari/532.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MRA 4.3 (build 01218))""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sbcydsl 3.12; SV1; FunWebProducts; YPC 3.2.0; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Avant Browser [avantbrowser.com]; Hotbar 4.4.5.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20100405 Namoroka/3.6.3""",
"""Mozilla/5.0 (X11; U; Linux; en-US; rv:1.9.2.12) Gecko/20101206 Firefox/3.6.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Hotbar 4.5.1.0)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.10 (maverick) Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.10 (maverick) Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; zh-TW; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.6-standalone; rev1.6; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; eSobiSubscriber 2.0.4.16; .NET4.0C)""",
"""Mozilla/5.0 (de; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0b8) Gecko/20100101 Firefox/4.0b8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; hu; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; MSN 6.1; MSNbMSFT; MSNmen-us; MSNczz; MSNc11)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; CMDTDF)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; SpamBlockerUtility 4.8.4; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; nl; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101230 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; AskTbWIZ/5.8.0.12304)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts-MyWay; Mozilla/4.0(Compatible Mozilla/4.0(Compatible-EmbeddedWB 14.57 http://bsalsa.com/ EmbeddedWB- 14.57 from: http://bsalsa.com/ ; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Iron/8.0.555.0 Chrome/8.0.555.0 Safari/534.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YComp 5.0.0.0; (R1 1.3); .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.04 (lucid) Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; TOB 6.06; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.30729; .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_5; de-de) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; AT&T CSM8.0; .NET CLR 1.1.4322; yplus 5.1.04b)""",
"""Opera/9.64(Windows NT 5.1; U; en) Presto/2.1.1""",
"""Microsoft Internet Explorer/4.0b1 (Windows 95)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3""",
"""Mozilla/4.76 [ru] (X11; U; SunOS 5.7 sun4u)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Zango 10.0.341.0)""",
"""NokiaE63/UC Browser7.2.2.51/28/351""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Orange 7.4 ; NaviWoo1.1; .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Mobile/8B117""",
"""gold crawler""",
"""LINK TRADE crawler ( +http://www.search.gvcbot.com/ )""",
"""Keiner""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; Creative; yplus 5.1.02b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.14) Gecko/2009082707 Firefox/3.0.14 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; ko-kr) AppleWebKit/532.9 (KHTML, like Gecko) Mobile/8B117""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.45 Safari/534.13""",
"""libwww-perl/5.837""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; pl) Opera 8.54""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.19 Safari/534.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.2) Gecko/20070309 Firefox/2.0.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.16) Gecko/20101130 AlexaToolbar/alxf-2.01 Firefox/3.5.16""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.7.62 Version/11.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.237 Safari/534.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.5) Gecko/20091102 Firefox/3.5.5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; ZangoToolbar 4.8.3)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729),gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.237 Safari/534.10,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (compatible; suggybot v0.01a, http://blog.suggy.com/was-ist-suggy/suggy-webcrawler/)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={01CEDAA9-13DF-4acf-AFF7-6A9C825D92BB}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux i686; pl-PL; rv:1.9.2.14pre) Gecko/20101204 Ubuntu/10.04 (lucid) Namoroka/3.6.14pre""",
"""Mozilla/5.0 (Linux; U; Android 1.0; en-us; generic) AppleWebKit/525.10+ (KHTML, like Gecko) Version/3.0.4 Mobile Safari/523.12.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={916CC9FC-134B-4169-AA91-9C239B9F4BFB}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Linux; U; Android 0.6; en-us; generic) AppleWebKit/525.10+ (KHTML, like Gecko) Version/3.0.4 Mobile Safari/523.12.2""",
"""Mozilla/5.0 (Linux; U; Android 0.5; en-us) AppleWebKit/522+ (KHTML, like Gecko) Safari/419.3""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101206 Ubuntu/9.10 (karmic) Firefox/3.6.13""",
"""Mozilla/5.0 (Linux; U; Android 1.1; en-gb; dream) AppleWebKit/525.10+ (KHTML, like Gecko) Version/3.0.4 Mobile Safari/523.12.2""",
"""Opera/9.80 (Macintosh; Intel Mac OS X; U; en) Presto/2.2.15 Version/10.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Iron/8.0.555.1 Chrome/8.0.555.1 Safari/534.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.6) Gecko/20091201 MRA 5.5 (build 02842) Firefox/3.5.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; NN5.1.2.0; FunWebProducts)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.15) Gecko/20101028 none none""",
"""Mozilla/5.0 (compatible; ExDomain; http://www.ex-domain.de/bot.html)""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) version/4.0.4 Mobile/7B367 Safari/531.21.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.6 (de) (TL-FF)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={587357DA-1E9B-4184-B7AE-D53D5D51A736}; FunWebProducts)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/9.8 (Windows NT 6.1; U; en) Presto/22.453; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.237 Safari/534.10""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.7.62 Version/11.00""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.7.62 Version/11.00,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.33 Safari/534.3 SE 2.X MetaSr 1.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Sgrunt|V109|34|S608507405|dialno; snprtz|dialno)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.7.62 Version/11.01""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Sgrunt|V109|301|S-527713550|dial; snprtz|T13562000000070|2600#Service Pack 2#2#5#1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru-RU; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 GTB7.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YComp 5.0.2.4)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.237 Safari/534.10""",
"""Mozilla/5.0 (compatible; Ezooms/1.0; ezooms.bot@gmail.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.8.1.11) Gecko/20071127 Firefox/2.0.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; MEGAUPLOAD 1.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.13) Gecko/20101203 AlexaToolbar/alxf-1.54 Firefox/3.6.13 GTB7.1""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (XP; U; NT 5.1; en-US; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2 CNS_UA; AD_LOGON=4C47452E4E4554;""",
"""Opera/9.64 (Windows NT 5.1; U; en) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; GTB6.6; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; ShopperReports 3.0.517.0; SRS_IT_E879057FB1765E5B33AC90)""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:2.0b10) Gecko/20100101 Firefox/4.0b10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Windows-Media-Player/10.00.00.3990; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.11 Safari/534.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {58081DEA-99B4-7B39-C2B5-C7B4458E5D90})""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101206 Ubuntu/9.10 (karmic) Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; Seekmo 11.0.117.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.84 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; Windows NT 5.1; YPC 3.2.0; .NET CLR 1.1.4322; SpamBlockerUtility 4.8.0)""",
"""Opera 9.7 (Windows NT 5.2; U; en)""",
"""Mozilla/4.79 [en] (Windows NT 5.0; U)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.7.62 Version/11.01""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; AskTB5.5)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; Creative ZENcast v1.04.06)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; de-de) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; pt-BR; rv:1.8.1.9) Gecko/20071025 Firefox/2.0.0.9""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; rev1.5; Windows NT 5.1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.552.215 Safari/534.10 ChromePlus/1.5.1.1""",
"""NokiaN-GageQD/2.0 (4.103) SymbianOS/6.1 Series60/1.2 Profile/MIDP-1.0 Configuration/CLDC-1.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.13) Gecko/20101206 Linux Mint/9 (Isadora) Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.19 Safari/534.13""",
"""Lynx/2.8.8dev.3 libwww-FM/2.14 SSL-MM/1.4.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; fr; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 GTB7.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {04FC4D35-8DC0-4432-A9DD-F8CC973A378B}; SIMBAR=0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0b11) Gecko/20100101 Firefox/4.0b11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; FDM; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it-IT; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.94 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {11340CF1-6CC5-8D22-8298-83625E121491}; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.98 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; id; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.13) Gecko/20101203 Googlebot 2.1 GTB7.1 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB6.6; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618; .NET4.0C)""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.7.62 Version/11.01""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.13) Gecko/20101203 AskTbTRL2/3.9.1.14019 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6""",
"""Mozilla/5.0 (Windows; U; MSIE 9.0; Windows NT 9.0; en-US)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (X11; U; Linux x86_64; uk; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.10 (maverick) Firefox/3.6.13""",
"""Wget/1.12 (freebsd8.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30707; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; PeoplePal 3.0; ZangoToolbar 4.8.2)""",
"""FDM 3.x""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.102 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.3; .NET CLR 1.1.4322; Alexa Toolbar)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Win64; x64; Trident/4.0; GTB6.6; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.94 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; InfoPath.3; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Gundluth 5.5 SP2; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.1; .NET CLR 1.1.4322; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; fr; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; MSIE 5.5; Windows NT 4.0) Opera 7.0 [en]""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; HbTools 4.7.7; .NET CLR 2.0.50727; IEMB3; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.16) Gecko/20101123 SeaMonkey/2.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 gmx/1.5.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.3; .NET CLR 1.1.4322; yplus 4.1.00b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16""",
"""Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.10 (like Gecko) (Debian)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; InfoPath.1; MS-RTC EA 2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 035217492""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-de) AppleWebKit/531.2+ (KHTML, like Gecko) Version/5.0 Safari/531.2+ Debian/squeeze (2.30.6-1) Epiphany/2.30.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; InfoPath.1; IEMB3; .NET CLR 1.1.4322; .NET CLR 2.0.50727; IEMB3)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.82 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101203 SUSE/3.6.13-0.2.1 Firefox/3.6.13""",
"""Mozilla/5.0 (compatible; CligooRobot/2.0; +http://www.cligoo.de/wk/technik.php)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Maxthon; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaE7-00/013.016; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.8.10 3gpp-gba""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.11) Gecko/20101012 Firefox/3.6.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; .NET CLR 1.1.4322; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.8.1.1) Gecko/20061223 BonEcho/2.0.0.""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; MRA 4.10 (build 01952); MRSPUTNIK 1, 8, 0, 17 SW; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.22 (KHTML, like Gecko) Ubuntu/10.10 Chromium/11.0.683.0 Chrome/11.0.683.0 Safari/534.22""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; Media Center PC 5.1; .NET CLR 3.0.30729; InfoPath.2; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.8pre) Gecko/20070928 Firefox/2.0.0.7 Navigator/9.0RC1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {1CD645D5-62F7-1180-52D2-B2AA545C2F64}; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) Opera 7.54 [en]""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.13 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 46018359""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.98 Safari/534.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Ant.com Toolbar 2.0.1 Firefox/3.6.10""",
"""GVC WEB crawler ( +http://www.search.gvcbot.com/add-url.htm)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.2)""",
"""Mozilla/5.0 (Windows; U; Win98; de; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.3; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.14) Gecko/20110218 Firefox/3.6.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.14 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 44497827""",
"""ELinks(0.11.1,Linux 2.4.31 i686)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.13) Gecko/20101203 SUSE/3.6.13-0.2.1 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; GTB6; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""NokiaC6-00/10.0.021 (SymbianOS/9.4; Series60/5.0 Mozilla/5.0; Profile/MIDP-2.1 Configuration/CLDC-1.1) AppleWebkit/525 (KHTML, like Gecko) BrowserNG/7.2.6 UNTRUSTED/1.0 3gpp-gba""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.14) Gecko/20110218 Firefox/3.6.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR Enabled; SIMBAR={A0339C60-71EB-42f9-AEBE-9D82FBC21B60}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.14) Gecko/20110221 Ubuntu/10.10 (maverick) Firefox/3.6.14""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET CLR 1.1.4322; InfoPath.2; .NET4.0C; .NET4.0E; Tablet PC 2.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.14) Gecko/20110218 Firefox/3.6.14 (.NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; OpenBSD amd64; en-US; rv:1.9.2.13) Gecko/20110120 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 95; BCD2000)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0 Safari/533.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.14) Gecko/20110218 Firefox/3.6.14 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.14) Gecko/20110218 (webde/1.7.2) Firefox/3.6.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.107 Safari/534.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; ZangoToolbar 4.8.3; MSN 6.1; MSNbMSFT; MSNmen-au; MSNc00; v5m)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/23.390; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (Windows NT 5.1; U; hu) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_4_11; de-de) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; GTB6.6; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.14) Gecko/20110221 Ubuntu/10.04 (lucid) Firefox/3.6.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.6.30 Version/10.62""",
"""Mozilla/6.0 (compatible; MSIE 7.0a1; Windows NT 5.2; SV1)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0b12) Gecko/20100101 Firefox/4.0b12""",
"""Mozilla/5.0 (Windows NT 6.0; rv:2.0b12) Gecko/20100101 Firefox/4.0b12""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.4) Gecko/20070509 Camino/2 (MultiLang)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; de; rv:1.8.1.4) Gecko/20070509 Camino/1.5 (MultiLang)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.15) Gecko/20110303 AlexaToolbar/alxf-2.01 Firefox/3.6.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/533.17.8 (KHTML, like Gecko) Version/5.0.1 Safari/533.17.8""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.13) Gecko/20110109 Iceweasel/3.6.13 (like Firefox/3.6.13)""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/5.0)""",
"""Mozilla/4.0 (compatible;MSIE 7.0;Windows NT 6.1)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0b12) Gecko/20100101 Firefox/4.0b12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {2B5F1EE4-1673-CF55-3EC4-7431EC37CFDE}; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.127 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET CLR 1.1.4322; InfoPath.3; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.15 (KHTML, like Gecko) Chrome/10.0.612.1 Safari/534.15""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; EmbeddedWB 14.52 from: http://www.bsalsa.com/ EmbeddedWB 14.52; .NET CLR 2.0.50727; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; de-de) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; ZangoToolbar 4.8.2)""",
"""Nokia5800 XpressMusic/UC Browser7.4.0.65/50/350""",
"""Seamonkey-1.1.13-1(X11; U; GNU Fedora fc 10) Gecko/20081112""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; AskTbDSGOH/5.9.1.14019)""",
"""Opera/9.99 (Windows NT 5.1; U; pl) Presto/9.9.9""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 3.0.30729)""",
"""DomainWatcher Bot""",
"""Opera/9.0 (Windows NT 5.1; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; MathPlayer 2.10a; .NET CLR 1.1.4322; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.133 Safari/534.16""",
"""SonyEricssonJ108i/R7DA Browser/NetFront/3.5 Profile/MIDP-2.1 Configuration/CLDC-1.1 JavaPlatform/JP-8.5.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; fr; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 GTB7.1""",
"""libwww-perl/5.833""",
"""*Konqueror/3.5*OpenBSD*""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.6.30 Version/10.63""",
"""libwww-perl/5.834""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; SpamBlockerUtility 4.8.0; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.15) Gecko/20110303 Ubuntu/10.10 (maverick) Firefox/3.6.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.0.4 (de) (TL-FF) ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; sv-SE; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.9.0.16) Gecko/2009122206 Firefox/3.0.16 Flock/2.5.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; T312461)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; FunWebProducts-MyWay; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.3)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""HQ""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.133 Safari/534.16""",
"""Mozilla/5.0 (Windows NT 5.1; U) Opera 8.51 [de]""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; FDM; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; LocalNet; YPC 3.2.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/10.10 Chromium/12.0.702.0 Chrome/12.0.702.0 Safari/534.24""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.134 Safari/534.16""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sbcydsl 3.12; FunWebProducts; SV1; YPC 3.2.0; .NET CLR 1.0.3705; yplus 5.1.04b)""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.7 (build 03797); ru) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/528.7 (KHTML, like Gecko) Iron/1.0.155.0 Safari/528.7""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET CLR 1.1.4322; Media Center PC 5.0; SLCC1; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.151 Safari/534.16""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.19) Gecko/2010102906 Iceweasel/3.0.6 (Debian-3.0.6-3)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.15410Mod.by.Handler/24.732; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.151 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0b13pre) Gecko/20110316 Firefox/4.0b13pre""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.127 Safari/534.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.151 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ESB{FB7EFC33-D7A4-4015-9D36-E32B8D041E2E}; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SIMBAR={EE6EC1BC-4971-484E-9822-4C4E7D3B4480}; GTB6.6; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.2.15 Version/10.00""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.16pre) Gecko/20110310 Ubuntu/10.10 (maverick) Namoroka/3.6.16pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; hu; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.16) Gecko/20110302 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; IEMB3)""",
"""DoCoMo/2.0 N905i(c100;TB;W24H16) (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; MS-RTC LM 8; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Iron/9.0.600.2 Chrome/9.0.600.2 Safari/534.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; CSIE60SP02; .NET CLR 3.5.30729; InfoPath.1)""",
"""Complex/4.0 (Windows; U; Windows NT 7.0; de; rv:2.1.7) S7/20101017 Imploder/1.71""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.1 SUSE/6.0.443.0 (KHTML, like Gecko) Chrome/6.0.443.0 Safari/534.1""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.16) Gecko/20110323 Ubuntu/10.10 (maverick) Firefox/3.6.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-BR; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.8.1.8pre) Gecko/20071012 lolifox/0.3.6 Firefox/2.0.0.7 compatible""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.151 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; (none); Media Center PC 2.8; .NET CLR 1.1.4322; .NET CLR 2.0.50727; ZangoToolbar 4.8.3)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.15) Gecko/20110303 SUSE/3.6.15-0.2.2 Firefox/3.6.15""",
"""libwww-perl/6.01""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.16) Gecko/20110323 Ubuntu/10.10 (maverick) Firefox/3.6.16""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.0.0.351 Profile/24.743; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.0 /24.743; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; Win64; AMD64)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; AskTbDSGOH/5.11.3.15590)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.464.0 Safari/534.3""",
"""Mozilla/5.0 (Windows NT 6.0; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.5; Windows NT 5.1;)""",
"""libwww-perl/5.836""",
"""Mozilla/4.61 [en] (X11; U; ) - BrowseX (2.0.0 Windows)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322) NS8/0.9.6""",
"""Spider[Resource Description Engine] (Java HotSpot(TM) 64-Bit Server VM; Windows Server 2008 R2; +http://www.daniel-nowak-ug.de)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; de-de) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; CWADS32; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Microsoft Data Access Internet Publishing Provider Protocol Discovery""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; CWADS32; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; MSOffice 12)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; en-US; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.16) Gecko/20110401 Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.2)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.99 Safari/533.4""",
"""Mozilla/4.0 (Windows; U; Windows NT 6.0; de-DE) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.18) Gecko/20110320 SeaMonkey/2.0.13""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Crazy Browser 3.4.68; InfoPath.2)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.16) Gecko/20110319 SUSE/3.6.16-0.2.1 Firefox/3.6.16""",
"""Mozilla/5.0 (X11; U; OpenVMS COMPAQ_Professional_Workstation; en-US; rv:1.8.1.17) Gecko/20081029 SeaMonkey/1.1.12""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0) Gecko/20100101 Firefox/4.0 FirePHP/0.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB6.6; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30618; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; MS-RTC LM 8)""",
"""EuripBot/1.1 (+http://www.eurip.com) GetFile""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.30729; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.16) Gecko/20110323 Ubuntu/10.10 (maverick) Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; Windows NT 5.1; {40398759-9D09-58DE-13D9-8255EC67C137}; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 ( .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.0; U; Distribution 00; de) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322) Babya Discoverer 8.0:""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.1)""",
"""Midori/0.3 (X11; Linux; U; es-es) WebKit/531.2+""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; de-de) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.33 Safari/534.3 SE 2.X MetaSr 1.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101203 Googlebot/2.1 (+http://www.google.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {24FAD8A4-B663-EA51-14C7-203047DAFEB9}; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; MAAU; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.16) Gecko/20110323 Ubuntu/10.04 (lucid) Firefox/3.6.16""",
"""Mozilla/5.0 (X11; Linux i686; rv:2.0) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.3) Gecko/20073310 Iceweasel/2.0.0.3 (Debian-2.0.0.3-1)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0 like Mac OS X; en-us) AppleWebKit/525.13 (KHTML, like Gecko; Google Web Preview) Version/4.0.5 Mobile Safari/525.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.16; .NET CLR 2.0.50727; ffco7) Gecko/20080702 Firefox/2.0.0.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; at; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Hotbar 4.5.1.0; FunWebProducts; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.18) Gecko/20110319 Firefox/3.5.18""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sbcydsl 3.12; SV1; acc=; YComp 5.0.0.0; YPC 3.2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; yplus 5.1.04b)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SU 3.26; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET4.0C; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.13) Gecko/20101211 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.18) Gecko/20110319 Firefox/3.5.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; tr; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; SeekmoToolbar 4.8.4; yplus 5.3.03b)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.27 (KHTML, like Gecko) Chrome/12.0.719.0 Safari/534.27""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.9) Gecko/20100824 Firefox/3.6.9 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.13) Gecko/20101203 AskTbPLTV5/3.8.0.12304 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20110401 Netshakexploder/4.11.31""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; (R1 1.5); Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.23) Gecko/20090825 SeaMonkey/1.1.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20110401 NetshakeExploder/4.11.31""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:2.0) Gecko/20100101 Firefox/{Pulse Code Communications}""",
"""Mozilla/5.0 (Windows NT 6.1.7850.0.winmain_win8m1.100922-1508; WOW128; rv:2.0) Gecko/2011-04-01""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.1.4322; yplus 5.6.04b)""",
"""Mozilla/5.0 (Windows; OMG unique user agent""",
"""Mozilla/5.0 (Windows; http://www.vwp-online.de/ua.php""",
"""Mozilla/5.0 (Windows; http://www.vwp-online.de/ua.php<br><br><br><br><br><br>""",
"""4398.) 4399.) 4400.) 4400.) 4401.) 4402.) 4403.) 4404.) 4405.) 4406.) 4407.)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.205 Safari/534.16""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.8.131 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET4.0C; Creative AutoUpdate v1.40.01)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.8.131 Version/11.10""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.16) Gecko/20110408 Gentoo Firefox/3.6.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""""""""""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 8.0; Windows NT 5.1)""",
"""Nice""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; .NET4.0C; BRI/2; Anonymisiert durch AlMiSoft Browser-Anonymisierer 78831099)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Err:509	"""
"""GNU/wget 1.8.4""",
"""GNU/wget 1.8.5""",
"""GNU/wget 1.8.6""",
"""GNU/wget 1.8.7""",
"""GNU/wget 1.8.8""",
"""GNU/wget 1.8.9""",
"""GNU/wget 1.8.10""",
"""GNU/wget 1.8.11""",
"""GNU/wget 1.8.12""",
"""GNU/wget 1.8.13""",
"""GNU/wget 1.8.14""",
"""GNU/wget 1.8.15""",
"""GNU/wget 1.8.16""",
"""GNU/wget 1.8.17""",
"""GNU/wget 1.8.18""",
"""GNU/wget 1.8.19""",
"""GNU/wget 1.8.20""",
"""Es gibt keine Göttin außer der Göttin und sie ist deine Göttin. Es gibt keine Erisische Bewegung außer der Erisischen Bewegung und es ist die Erisische Bewegung. Und jeder goldene Apfel ist das geliebte Heim eines Goldenen Wurmes. Ein Diskordier soll immer das offizielle diskordische Dokumentennummerierungssystem benutzen. Ein Diskordier ist zu Beginn seiner Illumination dazu verpflichtet, an einem Freitag alleine nach draußen zu gehen um fröhlich einen Hot Dog zu genießen; diese Zeremonie ist dazu da, um gegen die beliebten Paganismen dieser Tage zu demonstrieren: gegen die katholische Christenheit (freitags kein Fleisch), das Judentum und den Islam (kein Fleisch vom Schwein), den Hinduismus (kein Fleisch von der Kuh), den Buddhismus (kein Fleisch von Tieren) und den Diskordianismus (keine Hot-Dog-Brötchen). Ein Diskordier soll keine Hot-Dog-Brötchen essen, denn es war der Trost der Göttin, als sie mit der ursprünglichen Zurückweisung konfrontiert war. Einem Diskordier ist es verboten, zu glauben, was er liest.""",
"""thank you for this website I had to try some recursions""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; ZangoToolbar 4.8.2)""",
"""Mobile Safari 1.1.3 (iPhone; U; CPU like Mac OS X; fr)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.205 Safari/534.16""",
"""Mozilla 5./0 (compatible) Opera or Gecko""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 compatible; MSIE 7.0; Windows NT 5.1""",
"""Mozilla/5.0 (X11; Linux i686; U) Opera 11.10 [en]""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; de-de) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/5.0 (en-us) AppleWebKit/534.14 (KHTML, like Gecko; Google Wireless Transcoder) Chrome/9.0.597 Safari/534.14""",
"""Mozilla/5.0 (X11; D; Linux i686; en; rv:1.9.2.3) Gecko/20100408 Ubuntu/8.10 (maverick) Firefox/3.6.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.31 (KHTML, like Gecko) Chrome/12.0.745.0 Safari/534.31""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:2.0) Gecko/20110404 Fedora/16-dev Firefox/4.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.205 Safari/534.16""",
"""Mozilla/5.0 (Windows NT 6.1; rv:2.0) Gecko/20100101 Firefox/4.0 WebMoney Advisor""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.8pre) Gecko/20071012 lolifox/0.3.6 Firefox/2.0.0.7 compatible""",
"""Mozilla/5.0 (X11; Linux i686; rv:5.0a2) Gecko/20110423 Firefox/5.0a2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; DigExt; AT&T CSM8.0; .NET CLR 2.0.50727)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.8.131 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; EmbeddedWB 14.52 from: http://www.bsalsa.com/ EmbeddedWB 14.52; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.16) Gecko/20110319 BTRS26718 Firefox/3.6.16 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 AskTbFXTV5/3.11.3.15590 Firefox/3.6.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 ImageShackToolbar/5.2.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.16) Gecko/20110319 AlexaToolbar/alxf-2.11 Firefox/3.6.16""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0) Gecko/20110321 Firefox/4.0""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.8.131 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; FunWebProducts; .NET CLR 1.1.4322; .NET CLR 2.0.50727; yplus 5.1.04b)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; EmbeddedWB 14.52 from: http://www.bsalsa.com/ EmbeddedWB 14.52; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.0.5) Gecko/2008121300 SUSE/3.0.5-1.1 Firefox/3.0.5""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Chrome/6.0.472.63 Safari/534.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.8.1) Gecko/20060918 Firefox/2.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8) Gecko/20051219 SeaMonkey/1.0b""",
"""Boom""",
"""Mozilla/5.0 (Windows NT 5.1; U; en) Opera 8.00""",
"""'Mozilla/5.0 (X11; Linux x86_64; rv:2.0) Gecko/20100101 Firefox/4.0'""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:5.0a2) Gecko/20110426 Firefox/5.0a2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.2; Windows NT 5.1;)""",
"""Mozilla/4.8 [en] (Windows NT 5.0; U)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; (R1 1.5); InfoPath.2; IEMB3)""",
"""Mozilla/5.0 (compatible; discobot/1.1; +http://discoveryengine.com/discobot.html)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20121221 Firefox/3.6.8""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.60 Safari/534.24""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.60 Safari/534.24""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.8.131 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6.3; QS 4.2.4.0; QS 5.1.2.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; QS 4.2.4.0; QS 5.1.2.1)""",
"""Mozilla/5.0 (Windows NT 6.1) Gecko/20100101 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={0EF0B5F8-A41F-42ef-9060-3048A04F8E54})""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.12 Safari/534.30""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.10) Gecko/20100922 Ubuntu/10.10 (maverick) Firefox/3.6.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Linux is not Unix""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.57 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; Tablet PC 2.0)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.8.131 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; MSN 9.0; MSNbMSNI; MSNmen-us; MSNcIA; MPLUS)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.57 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB0.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.16) Gecko/20110429 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 Firefox/3.0.2""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; fr; rv:1.9.0.6) Gecko/2009011912 Firefox/3.0.6""",
"""iCab/2.9.6 (Macintosh; U; PPC)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; es-MX; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SV1; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; .NET CLR 1.1.4322)""",
"""Domnutch-Bot/Nutch-1.0 (Domnutch; http://www.Nutch.de/)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; Embedded Web Browser from: http://bsalsa.com/; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1); SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.16) Gecko/20110329 Gentoo Firefox/3.6.16""",
"""Links (2.3pre1; Linux 2.6.38.3 x86_64; 94x69)""",
"""LexxeBot/1.0 (lexxebot@lexxe.com)""",
"""No reason specified.""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 1.1.4322; Media Center PC 4.0; SpamBlockerUtility 4.8.4)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; de-de) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.17) Gecko/20110422 Ubuntu/10.04 (lucid) Firefox/3.6.17""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.60 Safari/534.24""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.17) Gecko/20110420 SUSE/3.6.17-0.2.1 Firefox/3.6.17""",
"""Mozilla/4.0 (compatible; MSIE 6.0; MSN 2.5; Windows 98)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.16.0 (en-US) Anonymisiert durch AlMiSoft Browser-Anonymisierer 38381766""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; he; rv:1.9.1.2pre) Gecko/20060813 Firefox/2.0b1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; it-IT; rv:1.8.1.15) Gecko/20070307 Firefox/2.0.0.3pre""",
"""Mozilla/4.0 (compatible; MSIE 3.0; Windows NT; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.8 (KHTML, like Gecko) Chrome/4.0.277.0 Safari/532.8""",
"""Mozilla/5.0 (X11; Linux i686; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (iPod; U; CPU iOS 4.3.3 (jailbroken) like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Hotbar 4.4.6.0; .NET CLR 1.1.4322; .NET CLR 2.0.40607; InfoPath.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; pt-BR; rv:1.9.2.13) Gecko/20101225 Firefox/3.6.13 (Swiftfox)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.125 Safari/533.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; InfoPath.2; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/10.10 Chromium/11.0.696.57 Chrome/11.0.696.57 Safari/534.24""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.2) Gecko/2008091700 SUSE/3.0.2-5.2 Firefox/3.0.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.65 Safari/534.24""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.65 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; Creative ZENcast v2.00.07)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MSN OptimizedIE8;DEDE)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; EmbeddedWB 14,52 from: http://www.bsalsa.com/ EmbeddedWB 14.52; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (compatible; Baiduspider/2.0; +http://www.baidu.com/search/spider.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Hotbar 4.4.9.0; (R1 1.5); .NET CLR 1.1.4322; IEMB3; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/3.0.0.20""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; snprtz|T05041833490253; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.65 Safari/534.24""",
"""Mozilla/5.0 (BeOS; U; BeOS BePC; en-US; rv:1.9a1) Gecko/20051002 Firefox/1.6a1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; {E5EC7D79-A272-DE99-D799-E4EF0BB31C45})""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.8) Gecko/20100722 Firefox 3.6.8""",
"""Mozilla/5.0 (Windows NT 6.1; rv:2.0) Gecko/20110319 Firefox/4.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.53 Safari/534.30""",
"""Mozilla/5.0 (X11; U; FreeBSD; i386; en-US; rv:1.7) Gecko)""",
"""Mozilla/4.0 (compatible; Synapse)""",
"""Opera/9.80 (Windows NT 6.0; U; Distribution 01; de) Presto/2.8.131 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0.1) Gecko/20110430 Firefox/4.0.1 Iceweasel/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.7-embedded; rev1.7; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MSN 9.0; MSNbBBYZ; MSNmen-us; MSNcOTH; MPLUS)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.1.19) Gecko/20110420 Firefox/3.5.19 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.14 (KHTML, like Gecko) Chrome/9.0.597 Safari/534.14""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR Enabled; SIMBAR={A6B3F725-664B-4b71-B4E6-AB1B7489CC72})""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.5) Gecko/20091102 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.24pre) Gecko/20100228 K-Meleon/1.5.4""",
"""LongURL API""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (compatible; Konqueror/3.1; Linux 2.4.22-10mdk; X11; i686; fr, fr_FR)""",
"""Mozilla/5.0 (S60; SymbOS; Opera Mobi/SYB-1103211396; U; de; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6 Opera 11.00""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; ShopperReports 3.0.517.0; SRS_IT_E8790770BC765C5A3EAD94)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 2.8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9.2.3pre)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; MATM)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.6.30 Version/10.61""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/11.04 Chromium/11.0.696.68 Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0)""",
"""Mozilla/5.0 (Linux; U; Android 2.1-update1; de-de; SonyEricssonU20i Build/2.1.1.A.0.6) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Mobile Safari/530.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; TheFreeDictionary.com; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:5.0a2) Gecko/20110523 Firefox/5.0a2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MDDR; .NET4.0C)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.772.0 Safari/535.1""",
"""bitlybot""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.8.131 Version/11.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:5.0a2) Gecko/20110524 Firefox/5.0a2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.71 Safari/534.24""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.71 Safari/534.24""",
"""VWP URL-Expander-Bot 0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; (R1 1.5); .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.71 Safari/534.24""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0b13pre) Gecko/20110322 Firefox/4.0b13pre""",
"""InternetExplorer""",
"""Meine_Website:phpinfoseite.bplaced.net""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0a2) Gecko/20110527 Firefox/6.0a2""",
"""<b>Es gibt keine GÃ¶ttin auÃŸer der GÃ¶ttin und sie ist deine GÃ¶ttin. Es gibt keine Erisische Bewegung auÃŸer der Erisischen Bewegung und es ist die Erisische Bewegung. Und jeder goldene Apfel ist das geliebte Heim eines Goldenen Wurmes. Ein Diskordier soll immer das offizielle diskordische Dokumentennummerierungssystem benutzen. Ein Diskordier ist zu Beginn seiner Illumination dazu verpflichtet, an einem Freitag alleine nach drauÃŸen zu gehen um frÃ¶hlich einen Hot Dog zu genieÃŸen; diese Zeremonie ist dazu da, um gegen die beliebten Paganismen dieser Tage zu demonstrieren: gegen die katholische Christenheit (freitags kein Fleisch), das Judentum und den Islam (kein Fleisch vom Schwein), den Hinduismus (kein Fleisch von der Kuh), den Buddhismus (kein Fleisch von Tieren) und den Diskordianismus (keine Hot-Dog-BrÃ¶tchen). Ein Diskordier soll keine Hot-Dog-BrÃ¶tchen essen, denn es war der Trost der GÃ¶ttin, als sie mit der ursprÃ¼nglichen ZurÃ¼ckweisung konfrontiert war. Einem Diskordier ist es verboten, zu glauben, was er liest.</b>""",
"""Bad-Bot""",
"""Hi-Bot""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.0.1; SV1; yplus 5.1.04b)""",
"""Mozilla/5.0 (compatible; heritrix/1.14.4 +http://hpsg.fu-berlin.de)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.8.131 Version/11.11""",
"""<script>alert('Scanned')</script>""",
"""Opera/9.80 (Windows NT 5.2; U; ru) Presto/2.8.131 Version/11.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.9) Gecko/20100824 Firefox/3.6.9""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; de-de) AppleWebKit/525.28.3 Version/3.2.3 Safari/525.28.3""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.68 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; yplus 5.3.04d)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET CLR 1.1.4322; MS-RTC LM 8)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET CLR 1.1.4322; MS-RTC LM 8)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; fr; rv:1.9.2.13) Gecko/20101206 Ubuntu/9.10 (karmic) Firefox/3.6.13""",
"""Mozilla/5.0 (iPhone; U; CPU OS 4_2_1 like Mac OS X) AppleWebKit/532.9 (KHTML, like Gecko) Version/5.0.3 Mobile/8B5097d Safari/6531.22.7""",
"""Mozilla/5.0 (Linux; U; Android 2.2) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Linux; U; Android 2.2.1; fr-fr; GT-I9000 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.71 Safari/534.24""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; (R1 1.5))""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6.6; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 1.1.4322; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; IRIX64 IP30; en-US; rv:1.8.1.24pre) Gecko/20090918 Firefox/2.0.0.22pre""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:2.2a1pre) Gecko/20110324 Firefox/4.2a1pre""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618)""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 4_3_3 like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5""",
"""Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt\)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Application CD Build 2.0.0; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 8.50""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.16) Gecko/20110323 Ubuntu/10.10 (maverick) Firefox/3.6.16 GTB7.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/534.36 (KHTML, like Gecko) Chrome/13.0.767.1 Safari/534.36""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.2.8) Gecko/20100804 Gentoo Firefox/3.6.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98) XX""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DeltaQuadrant; rv:1.9.0.15) Gecko/2009102814 Unimatrix-Zero (Borg)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB6.6; SLCC1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET CLR 3.0.30618; .NET4.0C)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.15410/24.871; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows 98; FunWebProducts)""",
"""Opera/9.80 (Windows NT 5.1; U; ja) Presto/2.8.131 Version/11.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Iron/7.0.520.1 Chrome/7.0.520.1 Safari/534.7""",
"""<script type='text/javascript'>window.setTimeout(function(){document.body.innerHTML='This page has been hacked by Mewo!';},0);</script>""",
"""libwww-perl/6.02""",
"""libwww-perl/6.02""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={C46BA5E4-75B3-417d-BC2A-40881E317032}; .NET CLR 1.1.4322; HbTools 4.8.4)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.91 Safari/534.30""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; en-us) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.91 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110422 Linux (High Security System ) Firefox""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0.1) Gecko/20100101 Firefox/4.0.1/site-owner""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YComp 5.0.0.0; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (compatible; YandexMedia/3.0; +http://yandex.com/bots)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; InfoPath.2; .NET4.0C; Tablet PC 2.0; AskTbBLPV5/5.9.1.14019)""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.8.131 Version/11.11""",
"""5.0 (iPad; U; CPU OS 4_3_1 like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8G4 Safari/6533.18.5 Mobile Viewport Tracking enabled""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312461; MathPlayer 2.0; SV1; .NET CLR 1.1.4322; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.91 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.100 Safari/534.30""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Ubuntu/10.04 Chromium/14.0.792.0 Chrome/14.0.792.0 Safari/535.1""",
"""Opera/9.80 (Series 60; Opera Mini/6.24455/24.871; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/10.10 Chromium/11.0.696.68 Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.100 Safari/534.30""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {FC5DA251-970F-FD5A-E748-17E0C6A6909A}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.9.2.17) Gecko/20110422 Ubuntu/10.04 (lucid) Firefox/3.6.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; AskTB5.5)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.8.131 Version/11.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; Alexa Toolbar)""",
"""IE 7.0 (Windows XP; U; de-DE)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0.1) Gecko/20110430 Firefox/6.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.100 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)""",
"""Opera/9.80 (Windows NT 5.2; U; de) Presto/2.7.62 Version/11.01""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.16) Gecko/20110323 Firefox/3.6.16""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/5.0 Iceweasel/5.0""",
"""Opera/9.80 (X11; Linux i686; U; fr) Presto/2.8.131 Version/11.11""",
"""Mozilla/5.0 (Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.1.19) Gecko/20110420 Firefox/3.5.19,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:5.0) Gecko/20100101 Firefox/5.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (compatible; VWP URL-Expander-Bot 0.2 (Beta); http://goo.gl/5SKWB)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 7; de) MSIE 7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.100 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.11) Gecko/20101012 Firefox/3.6.11 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.0.3; Media Center PC 3.0; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; en-us) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/5.0 (Linux; U; Android 2.3; el-gr; GT-I9000 SAMSUNG Build/FRNI.1) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.3.1 Mobile Safari/ 534.30""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3)""",
"""Opera/9.80 (X11; Linux x86_64; rv:2.0.1) Presto/2.8.131 Version/11.11""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.18""",
"""Mozilla/5.0 (X11; U; Linux x86_64; fr; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.10 (maverick) Firefox/3.6.13""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:2.0.1) Gecko/20110506 Firefox/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; .NET4.0C; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.8.131 Version/11.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 6.0 ; .NET CLR 2.0.50215; SL Commerce Client v1.0; Tablet PC 2.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SIMBAR Enabled; SIMBAR={17D192A1-7F56-4244-A658-6C6685452FB6}; SIMBAR=0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MyIE2; Deepnet Explorer)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; id; rv:1.9.2) Gecko/20100115 Firefox/3.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/1.22 (compatible; MSIE 2.0d; Windows NT)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.18) Gecko/20110614 AlexaToolbar/alxf-2.13 Firefox/3.6.18""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.50 Safari/534.24""",
"""Opera/9.80 (Android; Opera Mini/6.25174/24.902; U; de) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iebar; acc=jocker; (jocker); (none); FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; H010818; yie6; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; tr; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.797.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:5.0) Gecko/20100101 Firefox/5.0; t.i.m.; pk; k.konzept;""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 GTB7.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; MS-RTC LM 8; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-GB; rv:1.9.2.18) Gecko/20110615 Ubuntu/10.04 (lucid) Firefox/3.6.18""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YPC 3.2.0; SV1; FunWebProducts; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows NT 5.0; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_5_8) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.803.0 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; MS-RTC LM 8; msn OptimizedIE8;ENUS)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 ( .NET CLR 3.5.30729) FirePHP/0.5""",
"""Opera/9.80 (Windows NT 6.0; U; en) Presto/2.8.131 Version/11.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.4) Gecko/20100520 FireDownload/2.0.1 Firefox/3.6.4 Wyzo/3.6.4.1 FireTorrent/2.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.04 (lucid) Firefox/3.6.18 FirePHP/0.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Comcast; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""MOTORIZR-Z8/46.00.00 Mozilla/4.0 (compatible; MSIE 6.0; Symbian OS; 356) Opera 8.65 [it] UP.Link/6.3.0.0.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (X11; Linux i686; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.2; GTB7.0; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; MAXTHON 2.0)""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (X11; U; Linux i686; es-AR; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.10 (maverick) Firefox/3.6.18""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; en-us) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; Badongo 2.0.0; SpamBlockerUtility 4.8.4)""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.0; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; MDDC; .NET4.0C)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7. Gecko/20050511 Firefox/1.0.4""",
"""libwww-perl/5.820""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/5.0 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 75488000""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; OptusNetDSL6; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x4.90)""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.7 (build 03797); ru) Presto/2.8.131 Version/11.11,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.16) Gecko/20110701 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:7.0a1) Gecko/20110705 Firefox/7.0a1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3 like Mac OS X; fr-fr) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8F190 Safari/6533.18.5""",
"""Opera/9.80 (Series 60; Opera Mini/6.24096/25.645; U; id) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_3_3 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J3 Safari/6533.18.5""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_3_3 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) version/5.0.2 Mobile/8J3 Safari/6533.18.5""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.813.0 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {6220444D-C340-4A05-A1FA-78400212B330}; YPC 3.2.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 2.8)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.15) Gecko/20110303 Ultimate Edition/2.8 (maverick) Firefox/3.6.15""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.04 (lucid) Firefox/3.6.18""",
"""AmigaVoyager 3.4.4 (MorphOS/PPC native)""",
"""Mozilla/2.0 (compatible; MSIE 3.0B; Win32)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.801.0 Safari/535.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/25.657; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21594/25.657; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.1; Windows NT 5.1;)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; WebMoney Advisor; .NET4.0C; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Linux; U; Android 1.1; en-us; dream) AppleWebKit/525.10+ (KHTML, like Gecko) Version/3.0.4 Mobile Safari/523.12.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; .NET4.0C; .NET4.0E; MS-RTC LM 8)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.6.30 Version/10.60""",
"""1414213562373A (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0HTTcryPt/Add-on""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; ZangoToolbar 4.8.2)""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.9.168 Version/11.50""",
"""Mozilla/6.0 (MSIE 6.0; Windows NT 5.1; HIT Labs Copyright Spider; robot)""",
"""Opera/8.00 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (Linux; U; Android 2.2; de-de; HTC Desire Build/FRF91) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.2) Gecko/20121223 Ubuntu/9.25 (jaunty) Firefox/3.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; CMS Music Store2 v1.00.12 (Music Store,1033))""",
"""Mozilla/5.0 (X11; U; Linux armv7l; cs-CZ; rv:1.9.2.3pre) Gecko/20100723 Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.10 (maverick) Firefox/3.6.18""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MSOffice 12)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; chromeframe/12.0.742.112; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MDDR)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; iebar; SV1; acc=; acc=none; (none))""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322; .NET4.0C; .NET4.0E; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Opera/9.00 (Windows NT 5.1; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420+ (KHTML, like Gecko) Version/3.0 Mobile/1A543 Safari/419.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; MSN 9.0;MSN 9.1; MSNbVZ02; MSNmen-us; MSNcOTH)""",
"""Trinh duyet Quang +))""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; MRSPUTNIK 2, 3, 0, 296; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Opera/9.80 (Series 60; Opera Mini/6.24458/25.677; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {12A1DBA4-C25D-298B-054B-B40B1F6FFCBA}; (R1 1.5); .NET CLR 1.1.4322; InfoPath.1)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SpamBlockerUtility 4.8.4; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Mozilla/5.0 (U; Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.9.168 Version/11.50""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.41 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MathPlayer 2.0; SV1; FunWebProducts)""",
"""Java/1.6.0_26""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.124 Safari/534.30""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.9.168 Version/11.50""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.7) Gecko/20100713 Firefox/3.6.7""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-us; DROID2 GLOBAL Build/S273) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; iOpus-Web-Automation)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""GVC WEB crawler ( +http://www.globalvisioncommunication.com/directory/MAIN.htm)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.772.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3_4 like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8K2 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; NN5.1.2.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {D051E3E9-5C89-44C1-A5C2-21DAE5F52904}; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.10) Gecko/20100914 Firefox/5.0 LG_KS20,gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; YPC 3.2.0; (R1 1.3); .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.91 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.832.0 Safari/535.1""",
"""TestNutch/Nutch-1.2 (testing Nutch; http://nutch.apache.org; info@nutch.apache.org)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.99 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.833.0 Safari/535.1""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.10 (maverick) Firefox/3.6.18""",
"""Mozilla/5.0 (Windows NT 5.1; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; QS 4.2.1.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729) FirePHP/0.3""",
"""Mozilla/5.0 (compatible; SEOkicks-Robot +http://www.seokicks.de/robot.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1 FirePHP/0.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.99 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; de-de; GT-I9000 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; Creative ZENcast v1.00.19; ZangoToolbar 4.8.2)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 6.12) Sprint:PPC6800""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.8 Safari/535.1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.04 (lucid) Firefox/3.6.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.3 (KHTML, like Gecko) Iron/6.0.475 Chrome/6.0.475.0 Safari/98995392.534""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.124 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.18) Gecko/20110614 YFF35 Firefox/3.6.18""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Iron/12.0.750.0 Chrome/12.0.750.0 Safari/534.30""",
"""AppEngine-Google; (+http://code.google.com/appengine; appid: fjut-proxy)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Sky Broadband; SIMBAR Enabled; SIMBAR={23ECF76A-E265-4f07-8929-2DE51940A2A1}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; tr-TR) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.9 Safari/535.1""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.9.168 Version/11.50""",
"""Schrein crawler""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Iron/12.0.750.0 Chrome/12.0.750.0 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.19) Gecko/20110707 Firefox/3.6.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; FunWebProducts; HbTools 4.8.4)""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 4_2_1 like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.6.30 Version/10.61""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.0; T312461)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25571/25.692; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR Enabled; SIMBAR={B355C2A9-271E-464d-8E5B-047673D36B30}; .NET CLR 1.1.4322)""",
"""Opera/8.01 (Windows NT 5.1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (compatible; SISTRIX Crawler; http://crawler.sistrix.net/)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.107 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Update a; AOL 6.0; Windows 98)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.107 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Ubuntu/10.10 Chromium/12.0.742.124 Chrome/12.0.742.124 Safari/534.30""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; InfoPath.2; .NET4.0C; .NET4.0E; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; yie8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.18) Gecko/20110614 AlexaToolbar/alxf-2.13 Firefox/3.6.18""",
"""BlackBerry8530/5.0.0.1000 Profile/MIDP-2.1 Configuration/CLDC-1.1 VendorID/278""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.18) Gecko/20110628 Ubuntu/10.10 (maverick) Firefox/3.6.18""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.841.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.841.0 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.94 Safari/534.13""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Win98; en-US; rv:1.8.1.11pre) Gecko/20071206 Firefox/2.0.0.11 Navigator/9.0.0.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.844.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.844.0 Safari/535.1""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; MyIE2; mxie; Maxthon; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (compatible; UnisterBot, crawler@unister-gmbh.de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; SpamBlockerUtility 4.8.4; PeoplePal 3.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18 (.NET CLR 3.5.30729)""",
"""Ipod Touch 3.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.30 (KHTML, like Gecko) Ubuntu/10.10 Chromium/12.0.742.112 Chrome/12.0.742.112 Safari/534.30""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.9.168 Version/11.50""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101026 cai lon gi cha duoc""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312461)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; VZ_IE6; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-gb; GT-I9000 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.16) Gecko/20110701 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (X11; FreeBSD i386; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""<script>alert('xss');</script>""",
"""<script>alert(1);</script>""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.109 Safari/535.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.5; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MRA 4.6 (build 01425))""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; .NET CLR 1.0.3705; Media Center PC 3.1; .NET CLR 1.1.4322; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (X11; Linux armv7l) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.824.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.107 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.112 Safari/535.1""",
"""Opera/5.0 (SunOS 5.8 sun4m; U) [en]""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; IEMB3; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.0.19) Gecko/2010031422 adsasdasdasd""",
"""Mozilla/4.0 (compatible; MSIE 999.1; Unknown)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.18) Gecko/20110621 Red Hat/3.6.18-1.el6_1 Firefox/3.6.18""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; TheFreeDictionary.com; .NET CLR 1.1.4322; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.848.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.848.0 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; snprtz|S04080310230739#364|isdn; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko; Google Web Preview) Chrome/11.0.696 Safari/534.24""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.18) Gecko/20110804 (IKDhPmJcdw) Ubuntu/10.04 (lucid) Firefox/3.6.18""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.5) Gecko/20091107 Firefox/3.5.5""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_0) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.112 Safari/535.1""",
"""Hitfaker/1.0 (compatible; MSIE 6.0; Windows NT 5.2; .NET CLR 1.0.3705; by Robert Müller)""",
"""Hitfaker 1.0 by Robert Müller""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3_3 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8B117 Safari/6531.22.7""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2_1 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B500 Safari/531.21.10""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0_2 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8A400 Safari/6531.22.7""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_1_2 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7D11 Safari/528.16""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 2_1 like Mac OS X; en-us) AppleWebKit/525.18.1 (KHTML, like Gecko) Version/3.1.1 Mobile/5F136 Safari/525.20""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 4_0_2 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8A400 Safari/6531.22.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MEGAUPLOAD 2.0; yplus 5.3.04b)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/15.0.849.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:7.0a2) Gecko/20110814 Firefox/7.0a2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {5F2A1894-7E5F-4086-9F24-1BE5336B3AC5}; .NET CLR 1.1.4322; MSN 6.1; MSNbDELL; MSNmen-us; MSNc0z; MSNc00)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 ( .NET CLR 3.5.30729)""",
"""DoCoMo/2.0 P900i(c100;TB;W24H11) (compatible; ichiro/mobile goo; +http://help.goo.ne.jp/help/article/1142/)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; InfoPath.1)""",
"""WMSBot""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8 ( )""",
"""Mozilla/5.0 (Windows NT 6.0; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; de-de; GT-I9100 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (compatible; U) AppleWebKit/533.1 (KHTML, like Gecko) Maxthon/3.0.8.2 Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Sgrunt|V109|867|S1012992214|dialno; snprtz|S04345540980867#867|isdn)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; vi; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.19) Gecko/20110420 SeaMonkey/2.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7; nl-nl) AppleWebKit/528.16 (KHTML, like Gecko) Version/4.0 Safari/528.16""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.855.0 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.855.0 Safari/535.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {473F6DB2-3CD5-AADA-18DB-9FA3141ECA7E}; acc=; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; PeoplePal 3.0)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.856.0 Safari/535.2""",
"""Mozilla/5.0 (Android; Linux armv7l; rv:6.0) Gecko/20110811 Firefox/6.0 Fennec/6.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; it; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MDDR; .NET4.0C; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.857.0 Safari/535.2""",
"""Applimana v1.0.0 (http://www.openwebspider.org/)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0) Gecko/20100101 Firefox/6.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:8.0a2) Gecko/20110818 Firefox/8.0a2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.859.0 Safari/535.2""",
"""Mozilla/5.0 (compatible; AhrefsBot/1.0; +http://ahrefs.com/robot/)""",
"""Mozilla/5.0 (Windows; U; Win98; fr-FR; rv:1.7.6) Gecko/20050226 Firefox/1.0.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.854.0 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.112 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iOpus-I-M; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.215 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20""",
"""Mozilla/5.0 (compatible; Konqueror/4.5; FreeBSD) KHTML/4.5.4 (like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.20) Gecko/20110804 Red Hat/3.6.20-2.el6_1 Firefox/3.6.20""",
"""Wget/1.11.2""",
"""Links (2.1pre36; FreeBSD 5.5-STABLE i386; 168x42)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.215 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux i686; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""unister-bot (Mozilla/5.0 compatible; crawler@unister-gmbh.de)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/534.48.3 (KHTML, like Gecko) Version/5.1 Safari/534.48.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; chromeframe/13.0.782.112; GTB7.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Ubuntu/11.04 Chromium/12.0.742.112 Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.215 Safari/535.1""",
"""SAMSUNG-GT-C3303/C3303DDJFB NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.861.0 Safari/535.2""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.20) Gecko/20110805 Ubuntu/10.04 (lucid) Firefox/3.6.20""",
"""GIDBot/2.0 (+http://www.gidnetwork.com/tools/gzip-test.php)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {252529F2-9354-961C-95C7-3189F2EF5F62}; .NET CLR 1.0.3705; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.854.0 Safari/535.2""",
"""Lynx/2.8.8dev.5 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/1.0.0d""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.215 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Iron/13.0.800.0 Chrome/13.0.800.0 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; PeoplePal 3.0; yplus 5.1.02b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 SFR""",
"""Mozilla/4.0 (compatible; MSIE 6.0; MSIE 5.5; Windows NT 5.0) Opera 7.02 Bork-edition [en]""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.5; rv:6.0) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20 GTB7.1 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.20) Gecko/20110805 Linux Mint/10 (Julia) Firefox/3.6.20""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0) Gecko/20100101 Firefox/6.0/nokia""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.12) Gecko/20050920 Firefox/1.0.7 SUSE/1.0.7-0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.1; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; ADVPLUGIN|K114|05|S-1202107045|dial; snprtz|S23940000000224; InfoPath.1)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.351/25.729; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.865.0 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; SV1; Hotbar 4.6.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:x.x.x) Gecko/20041107 Firefox/x.x""",
"""Mozilla/5.0 (Windows NT 6.1; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.21465/25.729; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_7;de-de) AppleWebKit/525.28.3 (KHTML, like Gecko)Version/3.2.3 Safari/525.28.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Tulsa Library Class; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.218 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.218 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.10) Gecko/20100914 sdafsdfdsf""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.21) Gecko/20110830 Firefox/3.6.21""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SpamBlockerUtility 4.7.7)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; sr; rv:1.9.0.16) Gecko/2009121609 Iceweasel/3.0.6 (Debian-3.0.6-3)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Hewlett-Packard; .NET CLR 1.1.4322; .NET CLR 1.0.3705; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.869.0 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; MSN 6.1; MSNbMSFT; MSNmen-us; MSNc00; MSNc00)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.870.0 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/5.0 (compatible; Konqueror/4.4; Linux 2.6.32-22-generic; X11; en_US) KHTML/4.4.3 (like Gecko) Kubuntu""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.871.1 Safari/535.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (compatible; Yahoo! Slurp China; http://misc.yahoo.com.cn/help.html)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; PRU_IE)""",
"""Mozilla/5.0 (compatible; Plukkie/1.4; http://www.botje.com/plukkie.htm)""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3_5 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8L1 Safari/6533.18.5""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.872.0 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.218 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/534.28 (KHTML, like Gecko) Chrome/12.0.725.0 Safari/534.28""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; Trident/5.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.549.0 Safari/534.10""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {70CE9F97-D1DE-4C0C-A13C-C4985B92B4BE}; SV1; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_8; ja-jp) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; 001_001; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; 001_001; 001_001)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.873.0 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/25.823; U; ru) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.0 Safari/535.2""",
"""Mozilla/5.0(compatible; MSIE 9.0; Windows NT 5.2;en-us; Trident/5.0; SV1; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; Badongo 2.0.0; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; he-il; GT-I9100 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.8 Safari/535.2""",
"""Mozilla/5.0 (Windows; U; Windows NT based; ja-JP) AppleWebKit/533.3 (KHTML, like Gecko) QtWeb Internet Browser/3.7 http://www.QtWeb.net""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ru) Opera 8.01""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""wget... :DDDDDDDDD""",
"""Kackwurst""",
"""Kinderporno""",
"""curl/7.21.7 (x86_64-unknown-linux-gnu) libcurl/7.21.7 OpenSSL/1.0.0e zlib/1.2.5 libssh2/1.2.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Zango 10.0.314.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.9 Safari/535.2""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.04 (lucid) Firefox/3.6.13""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101206 Ubuntu/10.04 (lucid) Firefox/3.6.13,gzip(gfe) (via translate.google.com)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (Windows NT 6.0; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.15410/25.842; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.11 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux i686; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/25.842; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.3) Gecko/20100401 Firefox/4.0 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; sensis)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.3 (KHTML, like Gecko) Chrome/16.0.880.0 Safari/535.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/25.842; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; FDM)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.162 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux x86_64) dirtySworld""",
"""Mozilla/5.0 (X11; Linux x86_64) Gecko/20100101 Firefox/6.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.3 (KHTML, like Gecko) Chrome/16.0.881.0 Safari/535.3""",
"""BacklinkCrawler (http://www.backlinktest.com/crawler.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.3 (KHTML, like Gecko) Chrome/16.0.882.0 Safari/535.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.864.0 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; yplus 5.1.02b)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.220 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.0.19) Gecko/2010062819 Firefox/3.0.19 Flock/2.6.1""",
"""WordPress/3.1.3; http://datenfresser.info""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.3 (KHTML, like Gecko) Chrome/16.0.883.0 Safari/535.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 2.8; .NET CLR 2.0.50727)""",
"""LWP::Simple/5.835 libwww-perl/5.837""",
"""Mozilla/5.0 (PLAYSTATION 3; 3.55)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; Media Center PC 4.0; .NET CLR 1.1.4322; ImageShack Toolbar 3.0.6)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.15 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Ubuntu/11.04 Chromium/13.0.782.218 Chrome/13.0.782.218 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Ubuntu/10.10 Chromium/12.0.742.112 Chrome/12.0.742.112 Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.6.8; U; en) Presto/2.9.168 Version/11.51""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {14866354-02CA-4E4A-A2B1-F2098455B373}; .NET CLR 1.1.4322)""",
"""User-Agent=Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.1) Gecko/2008070208 Firefox/3.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.887.0 Safari/535.4""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_1; el-gr) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; de; rv:1.9.2.14pre) Gecko/2010111021 Camino/2.0.6 (MultiLang)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.186 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; IEMB3; SpamBlockerUtility 4.8.4; ZangoToolbar 4.8.2; IEMB3)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.888.0 Safari/535.4""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.186 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.887.0 Safari/535.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; .NET CLR 2.0.50727; IEMB3; IEMB3; yplus 5.3.04b)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_0) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.21 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.889.0 Safari/535.4""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.890.0 Safari/535.4""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.186 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MyIE2; FunWebProducts; MRA 4.7 (build 01670); .NET CLR 1.1.4322)""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.9.168 Version/11.51""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25580/25.872; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/8.0 (compatible; MSIE 9.0; Windows NT 8.2)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.5 (KHTML, like Gecko) Chrome/16.0.891.0 Safari/535.5""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.218 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; Windows NT 5.1; PowerSearch 2.07; SV1; FreeprodTB; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:8.0a2) Gecko/20110924 Firefox/8.0a2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0.2) Gecko/20110902 SeaMonkey/2.3.3""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/401 (KHTML, like Gecko) Safari/401""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 5.8 (build 4664); ru) Presto/2.9.168 Version/11.50""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; de-de; GT-I9100 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; PeoplePal 3.0; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_8; de-de) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.5 (KHTML, like Gecko) Chrome/16.0.893.1 Safari/535.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {FBCBFCB5-A146-427D-BD3D-3C7E995F10CB}; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 5.2; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini; U; en) Presto/2.8.119 Version/10.54""",
"""sbtt6wj lxj 6bhiHgm6ws""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.5 (KHTML, like Gecko) Chrome/16.0.894.0 Safari/535.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; es-ES; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22 (.NET CLR 3.5.30729)""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.26266/25.872; U; en) Presto/2.5.25 Version/10.54""",
"""Covario-IDS/1.0 (Covario; http://www.covario.com/ids; support at covario dot com)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.825.0 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 5.1; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; (R1 1.3); .NET CLR 1.0.3705; SpamBlockerUtility 4.8.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.9.168 Version/11.51""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.21465/25.894; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21051/25.894; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {9444E5E6-9CAB-6A28-4AEB-D5DC17ACBC37}; YPC 3.2.0; SV1; yplus 5.3.04b)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/5.0 (PLAYSTATION 3; 2.00)""",
"""Mozilla/5.0 (X11; U; Linux i686; it-IT; rv:1.9.0.2) Gecko/2008092313 Ubuntu/9.25 (jaunty) Firefox/3.8""",
"""Mozilla/5.0 (Windows NT 6.0; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; SpamBlockerUtility 4.8.4; yplus 5.1.04b)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini; U; id) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.58 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; FDM; Creative AutoUpdate v1.40.01)""",
"""Nokia6500c/2.0 (09.48) Profile/MIDP-2.1 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (X11; OpenBSD amd64; rv:6.0.2) Gecko/20100101 Firefox/6.0.2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.1) Gecko/20100122 firefox/3.6.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.187 Safari/535.1""",
"""Opera/9.80 (Windows NT 6.1; U; pl) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.16) Gecko/20110406 (IKDhPmJcdw) Ubuntu/10.04 (lucid) Firefox/3.6.16""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {B6B18C70-1CAB-4D86-AD12-F7AB8EA71B03}; .NET CLR 1.1.4322; HbTools 4.7.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.186 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.6 (KHTML, like Gecko) Chrome/16.0.900.0 Safari/535.6""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; PHV Dialysezentren; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.6 (KHTML, like Gecko) Chrome/16.0.901.0 Safari/535.6""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.0 Safari/534.24""",
"""Mozilla/5.0 (X11; Linux i686; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; FDM; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.98 Safari/534.13""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8B117 Safari/6531.22.7 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/5.0 Gecko/20111005 Firefox/9.0a2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3/usr/bin/chromium-browser""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/6.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 8.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; InfoPath.1; SpamBlockerUtility 4.8.4)""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8""",
"""w3m/0.5.2""",
"""vik-robot/Nutch-1.0 (vikspider; http://vik.com; chenlibiti@163.com)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 5_0 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9A334 Safari/7534.48.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/532.2 (KHTML, like Gecko) Chrome/4.0.221.7 Safari/532.2""",
"""Mozilla/5.0 (X11; U; Linux i686) Gecko/20100115 Firefox/3.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; YPC 3.2.0; .NET CLR 2.0.50727; HbTools 4.8.4)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; MS-RTC LM 8; .NET4.0C; Creative AutoUpdate v1.40.02)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.904.0 Safari/535.7""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en-us) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""UnisterBot (Mozilla/5.0 compatible; crawler@unister-gmbh.de)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; The DOOR; .NET CLR 1.1.4322; yplus 5.1.04b)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0.1) Gecko/20100101 Firefox/4.0.1 /Nutch-1.2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; WebMoney Advisor; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.81 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.905.0 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 4.0.20506)""",
"""Opera/9.80 (Android; Opera Mini/6.5.26571/26.958; U; de) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.906.0 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.22537/26.958; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; T312461; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25380/26.984; U; id) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""DomainCrawler/2.0 (info@domaincrawler.com; http://www.domaincrawler.com/vwp-online.de""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sbcydsl 3.12; YPC 3.2.0; yplus 5.1.03b)""",
"""Opera/9.80 (compatible; U) Presto/2.7.39 Version/11.00""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/5.0 (X11; U; Linux i686; fr; rv:1.9.0.19) Gecko/2011070117 Iceweasel/3.0.6 (Debian-3.0.6-3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; (none); YPC 3.2.0; SV1; (R1 1.3); .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iOpus-Web-Automation; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; VS1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""COMODOspider/Nutch-1.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.910.0 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; Media Center PC 6.0; InfoPath.2; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.12) Gecko/20101026 MRA 5.7 (build 03797) Firefox/3.6.12 (.NET CLR 3.5.30729) sputnik 2.4.0.49""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25571/26.984; U; id) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_8; en-us) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MDDR; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.911.0 Safari/535.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; SIMBAR={72CF8303-14DA-4d2b-9AE5-C624A65F442A}; Arcor 5.006; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; HbTools 4.8.2)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.911.2 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.0 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Win 9x 4.90; Q312461)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/534.51.22 (KHTML, like Gecko) Version/5.1.1 Safari/534.51.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Opera/9.80 (Android; Opera Mini/6.1.25577/26.984; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (SymbianOS/9.4; U; Series60/5.0 NokiaN97/10.0.001; Profile/MIDP-2.1 Configuration/CLDC-1.1) AppleWebKit/525 (KHTML, like Gecko) Safari/525""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.2.23) Gecko/20110921 Ubuntu/10.10 (maverick) Firefox/3.6.23""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; http://bsalsa.com) ( EmbeddedWB http://bsalsa.com/); SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; Media Center PC 6.0),gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 5.9 (build 4871); ru) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de-AT; rv:1.7) Gecko/20040608 Mozilla 1.7""",
"""Opera/9.80 (Android; Opera Mini/6.5.26571/26.984; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; IEMB3; .NET CLR 2.0.50727; InfoPath.2; IEMB3)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0a2) Gecko/20111020 Firefox/9.0a2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.1.25378/26.1023; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.4 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; hu; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; hu; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23 ( )""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; MSDigitalLocker; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6 (.NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""SeznamBot/3.0 (+http://fulltext.sblog.cz/)""",
"""psbot/0.1 (+http://www.picsearch.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.9 Safari/535.7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.10 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; vi; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Ubuntu/11.04 Chromium/14.0.835.202 Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Arcor 5.005; tmweb; .NET CLR 2.0.50727; .NET CLR 1.1.4322; FDM)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/10.04 Chromium/11.0.696.68 Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/17.0.917.0 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:10.0a1) Gecko/20111025 Firefox/10.0a1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_5; ru) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Mozilla/5.0 (Linux; U; Android 2.2; de-de; Nexus One Build/FRF50) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {55616D2C-502F-45B3-A5FE-040E145381AC}; YPC 3.2.0; CMS Music Store2 v1.00.13 (Music Store,1033); .NET CLR 1.1.4322; Creative ZENcast v1.04.06)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:8.0a1) Gecko/20110707 Firefox/8.0a1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.102 Safari/535.2""",
"""F502i DoCoMo/1.0/F502i DoCoMo/1.0/F502i/c10""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/17.0.919.0 Safari/535.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {BCC2F7ED-DCFB-4EAB-AB1A-1B8E316B9F66}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.4 (KHTML, like Gecko) Chrome/16.0.889.0 Safari/535.4""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0a2) Gecko/20111025 Firefox/9.0a2""",
"""Mozilla/5.0 (Windows NT 5.1; U; de) Opera 8.53""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; AskTbAVR-W1/5.12.5.17700)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E; LEN2)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18 sputnik 2.4.0.60""",
"""Mozilla/5.0 (Windows; U; Win98; de-DE; rv:1.0.2) Gecko/20030208 Netscape/7.02 (CK-3LycosDE08)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.12) Gecko/20050920 Firefox/1.0.7 SUSE/1.0.7-0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {EE284311-4AE0-0F02-05D7-46B0E14407A9}; yie6_SBCDSL; snprtz|S04062418602292; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_7; en-us) AppleWebKit/534.20.8 (KHTML, like Gecko) Version/5.1 Safari/534.20.8""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.215 Safari/535.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.13) Gecko/20101203 AlexaToolbar/alxf-2.01 Firefox/3.6.13""",
"""Mail.RU/2.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; bgft; 1.57.1 ; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20110814 Firefox/6.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""python-requests.org""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.925.0 Safari/535.8""",
"""Mozilla/5.0 (compatible; spbot/3.0; +http://www.seoprofiler.com/bot )""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {AF747E34-3793-4252-D1E3-69E41F0D2B5B}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/5.0 (compatible; Funnelback)""",
"""Mozilla/5.0 (Linux; U; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.926.0 Safari/535.8""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.928.0 Safari/535.8""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/3.0 (compatible; Linkman)""",
"""Opera/9.80 (Windows NT 5.1; U; fr) Presto/2.9.168 Version/11.51""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {DFBB580F-2DA5-B218-A0B1-DF85A68B0DE8}; FreeprodTB; acc=marketingsector; acc=none; SV1)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.928.0 Safari/535.8""",
"""Mozilla/5.0 (X11; U; Linux i686; cs-CZ; rv:1.9.2.23) Gecko/20110921 Ubuntu/10.04 (lucid) Firefox/3.6.23""",
"""Lynx/2.8.8dev.2 libwww-FM/2.14 SSL-MM/1.4.1""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (SymbianOS/9.4; U;Series60/5.0 Nokia5800/10.0.006;Profile/MIDP-2.1 Configuration/CLDC-1.1) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:7.0.1) Gecko/20100101 Firefox/7.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.51 (KHTML, like Gecko; Google Web Preview) Chrome/12.0.742 Safari/534.51""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.931.0 Safari/535.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; GTB6.5; .NET CLR 1.1.4322; .NET CLR 2.0.50727; OfficeLiveConnector.1.3; OfficeLivePatch.0.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1 Firefox/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; Creative ZENcast v1.02.10; MSN 9.0;MSN 9.1; MSNbMSNI; MSNmen-us; MSNcIA)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Opera/9.23 (Windows NT 5.2; U; en)""",
"""Opera/9.141 (Windows NT 6.0; U; nl) Presto/171.831.131 Version/801.361""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; ms-office)""",
"""Opera/7.60 (Windows NT 5.2; U) [en] (IBM EVV/3.0/EAK01AG9/LE)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.102 Safari/535.2""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_4; en-US) AppleWebKit/525.13 (KHTML, like Gecko; Google Page Speed) Chrome/8.0.552.237 Safari/525.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0a2) Gecko/20110613 Firefox/6.0a2""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Iron/13.0.800.1 Chrome/13.0.800.1 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.3) Gecko/2008102920 Ubuntu/8.04 Firefox/3.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaN8-00/013.016; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.8.10 3gpp-gba""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; PeoplePal 3.0; USDR6)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 5.0; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT)""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; MSIECrawler)""",
"""Mozilla/5.0 (X11; FreeBSD amd64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.106 Safari/535.2""",
"""Opera/9.80 (Windows NT 6.1; U; pl) Presto/2.9.168 Version/11.52""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MRA 4.4 (build 01348); .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; MALC)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.120 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.932.0 Safari/535.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.40607; .NET CLR 3.0.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {D2B77476-9D47-4CC5-8E77-F0B44D4F3CA2}; SIMBAR={4B973DE9-2AA6-43f7-AAC1-7BC04E3D5480}; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; XMPP Tiscali Communicator v.10.0.2; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.120 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.120 Safari/535.2""",
"""Mozilla/5.0 (psp (PlayStation Portable); 6.00)""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B334b Safari/531.21.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/7.0.1 Iceweasel/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (compatible; Konqueror/4.5; Linux) KHTML/4.5.5 (like Gecko) Fedora/4.5.5-1.fc14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; ZangoToolbar 4.8.2)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.3; .NET4.0E; MS-RTC EA 2)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:11.0a1) Gecko/20111115 Firefox/11.0a1""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-TW; rv:1.9.1.16) Gecko/20101123 SeaMonkey/2.0.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.1) Gecko/20090624 Firefox/3.5 (.NET CLR 3.5.30729)""",
"""Opera/9.01 (Windows NT 5.1; U; ru)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; MSN 8.0; MSNbMSNI; MSNmen-us; MSNcIA)""",
"""Mozilla/5.0 (compatible; YandexDirect/3.0; +http://yandex.com/bots)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.943.0 Safari/535.8""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; MRSPUTNIK 2, 4, 0, 410; MRA 5.9 (build 4876); InfoPath.2; .NET CLR 2.0.50727; .NET4.0C)""",
"""BlackBerry8300/4.2.2 Profile/MIDP-2.0 Configuration/CLDC-1.1 VendorID/107 UP.Link/6.2.3.15.02011-10-16 20:20:17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.0; .NET CLR 1.1.4322; SpamBlockerUtility 4.8.6)""",
"""Mozilla/5.0 (TV; U; Oric Atmos 6502c; en-US; rv:r91.6) Gecko/19870508 TranDOS Firefox/4.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.51.22 (KHTML, like Gecko) Version/5.1.1 Safari/534.51.22""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.6) Gecko/20071008 Ubuntu/7.10 (gutsy) Firefox/2.0.0.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {6CED91E1-79C6-ED02-8934-50A69624339E}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.10 (KHTML, like Gecko) Chrome/17.0.945.0 Safari/535.10""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.6.8; U; en) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; IE5.x/Winxx/EZN/xx; SV1; iebar; acc=none; FunWebProducts; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.10 (KHTML, like Gecko) Chrome/17.0.946.0 Safari/535.10""",
"""nutch/1.2 (nutch)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Maxthon; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/60 (like Gecko) Safari/60""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; yie6_SBC; .NET CLR 2.0.50727; IEMB3; SpamBlockerUtility 4.8.4; IEMB3)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.102 Safari/535.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.26736/26.1192; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (BlackBerry; U; BlackBerry 9700; de) AppleWebKit/534.8+ (KHTML, like Gecko) Version/6.0.0.666 Mobile Safari/534.8+""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (compatible; AhrefsBot/2.0; +http://ahrefs.com/robot/)""",
"""Mozilla/5.0 (Ubuntu; X11; Linux i686; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/26.1192; U; id) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.1; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110422 Ubuntu/8.04 (hardy) Firefox/3.6.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; Media Center PC 5.0; .NET CLR 1.1.4322; InfoPath.2)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24 (.NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12; Trident/4.0)""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; SLCC1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.0; .NET CLR 3.0.04506.30)""",
"""Opera/9.63 (X11; U; nb)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; acc=vonner; acc=; iebar; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.922.0 Safari/535.8 SUSE/17.0.922.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24 (.NET CLR 3.5.30729)""",
"""FU :>""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.19) Gecko/2011110820 Firefox/6.0a2 (Debian-3.0.6-3)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; AtHome021SI; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; de; rv:2.0) Gecko/20100101 Firefox/4.0 Opera 11.52""",
"""Mozilla/0.6 Beta (Windows)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.24) Gecko/20111103 AskTbSTC-US/3.12.2.16749 Firefox/3.6.24""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; Linux i686; rv:7.0a2) Gecko/20110805 Firefox/7.0a2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; tr; rv:1.8.1.4) Gecko/20070515 Firefox/2.0.0.4""",
"""Pixray-Seeker/1.1 (Pixray-Seeker; crawler@pixray.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; YaCy 0.1; yacy.net)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; BT Openworld BB; .NET CLR 1.1.4322; yplus 5.3.04d)""",
"""NokiaN72/5.0706.4.0.1 Series60/2.8 Profile/MIDP-2.0 Configuration/CLDC-1.1/UC Browser7.9.0.102/27/351/UCWEB""",
"""Mozilla/5.0 (X11;U;Linux i686 (x86_64);en-US;rv:1.9.0.16) Gecko/2009122206 Firefox/3.0.16 Flock/2.5.6""",
"""Mozilla/5.0 (X11;U;Linux i686 (x86_64);en-US;rv:1.9.0.16) Gecko/2009122206 Firefox/3.0.16 Flock/2.5.6""",
"""Mozilla/5.0 (X11;U;Linux i686 (x86_64);en-US;rv:1.9.0.16) Gecko/2009122206 Firefox/3.0.16 Flock/2.5.6""",
"""Mozilla/5.0 (compatible; Voluniabot/1.0; spider@volunia.com)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.51.22 (KHTML, like Gecko) Version/5.1.1 Safari/534.51.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; {41697FC0-CDC0-CFB3-F195-F57FEC2B2253})""",
"""Mozilla/5.0 (X11; U; Linux x86_64; it; rv:1.9.2.17) Gecko/20110428 Fedora/3.6.17-1.fc13 Firefox/3.6.17""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.942.0 Safari/535.8""",
"""Mozilla/5.0 (Windows NT 6.0; rv:8.0) Gecko/20111108 Firefox/8.0 PaleMoon/8.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/8.0 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 77430734""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.960.0 Safari/535.11""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.9.168 Version/11.52""",
"""Opera/9.80 (X11; Linux i686; U; es-ES) Presto/2.9.168 Version/11.51""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; Walsrode Online; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; UCLBC)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; InfoPath.1; .NET4.0E; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.5 (KHTML, like Gecko) Chrome/16.0.891.0 Safari/535.5""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; WFX; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.4) Gecko/20100611 YFF35 Firefox/3.6.4""",
"""Mozilla/5.0 (Ubuntu; X11; Linux i686; rv:8.0) Gecko/20100101 Firefox/8.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Ubuntu; X11; Linux x86_64; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.0 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; MSDigitalLocker; .NET CLR 1.1.4322; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.8 (KHTML, like Gecko) Chrome/17.0.942.0 Safari/535.8""",
"""Mozilla/4.1 (U; BREW 3.1.5; en-US; Teleca/Q05A/INT)""",
"""Mozilla/4.0 (compatible; Polaris 6.2; BREW 3.1.5; U; en)/240X400 LGE VX8575""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; Comcast; .NET CLR 2.0.50727; Comcast)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.36 Safari/535.7""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; MathPlayer 2.0)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""Opera/9.80 (S60; SymbOS; Opera Mobi/SYB-1106291583; U; en) Presto/2.8.149 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1 Iceweasel/7.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; snprtz|S277969aa````b\xaf; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; yplus 4.1.00b)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; Trident/5.0; BOIE9;ENUSMSNIP)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; Comcast; ZangoToolbar 4.8.3; Comcast)""",
"""Opera/9.80 (iPhone; Opera Mini/6.5.1.23995/26.1283; U; fr) Presto/2.8.119 Version/10.54""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Windows NT 5.1; rv:8.0.1) Gecko/20111121 Firefox/8.0.1 SeaMonkey/2.5""",
"""Mozilla/4.0 (Windows; U; Windows NT; en-Us; rv:2.5.3) Gecko/65158732 Safari/2.2.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.52.7 (KHTML, like Gecko) Version/5.1.2 Safari/534.52.7""",
"""FAST Enterprise Crawler 6 / Scirus scirus-crawler@fast.no; http://www.scirus.com/srsapp/contactus/""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.16) Gecko/20101206 Lightning/1.0b1 SeaMonkey/2.0.11""",
"""SonyEricssonJ20i/R7CA Browser/NetFront/3.5 Profile/MIDP-2.1 Configuration/CLDC-1.1 JavaPlatform/JP-8.5.2""",
"""Mozilla/5.0 (Windows; rv:2.0) Gecko/20111214 Firefox/6.8""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7) AppleWebKit/534.48.3 (KHTML, like Gecko) Version/5.1 Safari/534.48.3""",
"""Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaE6-00/021.002; Profile/MIDP-2.1 Configuration/CLDC-1.1) AppleWebKit/533.4 (KHTML, like Gecko) NokiaBrowser/7.3.1.16 Mobile Safari/533.4 3gpp-gba""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0),gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; FunWebProducts; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; yplus 5.1.04b)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_2_1 like Mac OS X) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/4.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows NT 6.0; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; FunWebProducts; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; CMNTDF; BRI/1; .NET4.0C; FunWebProducts; Crazy Browser 3.0.5)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.0.16) Gecko/2010021003 Firefox/3.0.16 Flock/2.5.6""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.6 Safari/535.11""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.27309/26.1305; U; id) Presto/2.8.119 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Alexa Toolbar; IEMB3; IEMB3; yplus 5.1.04b)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:8.0.1) Gecko/20100101 Firefox/8.0.1""",
"""nutch/Nutch-1.5-SNAPSHOT (Viterbi Web Crawler using Nutch 1.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET4.0C; .NET4.0E; 360SE)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.14 (KHTML, like Gecko) Chrome/18.0.973.0 Safari/535.14""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; ru) Opera 8.50""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; sbcydsl 3.12; SV1; YPC 3.0.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:8.0) Gecko/20100101 Firefox/8.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/5.0/Nutch-1.1 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.13)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:8.0) Gecko/20100101 Firefox/8.0 Iceweasel/8.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; Windows NT 5.1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; SpamBlockerUtility 4.8.0; ZangoToolbar 4.8.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; NN5.1.2.1)""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_3_3 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 5_0_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9A405 Safari/7534.48.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Deepnet Explorer 1.5.0; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:8.0) Gecko/20100101 Firefox/8.0 slurp""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MSOCD; SV1; DVD Owner)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; ESB{F8EDEDE1-D7F7-4245-80EF-AC8C756F55B5}; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; APC; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50215; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; yplus 5.1.02b)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.3) Gecko/20100401 EEEPC 900 Firefox/3.6.3""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.1; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Q342532)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.2.24) Gecko/20111107 Ubuntu/10.04 (lucid) Firefox/3.6.24""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 3.1; Windows-Media-Player/10.00.00.3990)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Maxthon; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Mozilla/5.0 (000000000; 00000 000 00 0 0000; 00000000) DDDDDDDDDDDDDD DDDDDDDDDDDDD""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; en-us) AppleWebKit/531.21.8 (KHTML, like Gecko) Version/4.0.4 Safari/531.21.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/5.0 (Windows NT 6.1; U; ru; rv:5.0.1.6) Gecko/20110501 Firefox/5.0.1 Firefox/5.0.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; iebar; acc=; acc=none; FreeprodTB; FunWebProducts; .NET CLR 1.0.3705; HbTools 4.7.7)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:9.0.1) Gecko/20100101 Firefox/9.0.1 Iceweasel/9.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; YPC 3.2.0; Media Center PC 3.0; .NET CLR 1.0.3705; yplus 5.3.04b)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Android; Linux armv7l; rv:9.0) Gecko/20111216 Firefox/9.0 Fennec/9.0""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Linux; U; Android 4.0.1; de-de; Galaxy Nexus Build/ITL41F) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Comcast Install 1.0; FunWebProducts; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.1 (KHTML, like Gecko) Ubuntu/11.10 Chromium/14.0.835.202 Chrome/14.0.835.202 Safari/535.1""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.6.8; U; fr) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Zune 4.0; Tablet PC 2.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; DigExt)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.19; aggregator:Spinn3r (Spinn3r 3.1); http://spinn3r.com/robot) Gecko/2010040121 Firefox/3.0.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9.2.25) Gecko/20111212 Firefox/3.6.25""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.2) Gecko/20070220 Firefox/2.0.0.2""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0) Gecko/20111217 Firefox/9.0 SeaMonkey/2.6""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0) Gecko/20111217 SeaMonkey/2.6""",
"""Mozilla/5.0 (Windows NT 6.0; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.13) Gecko/20060417""",
"""Mozilla/5.0 (X11; Linux i686; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/0.91 Beta (Windows)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; FDM)""",
"""Mozilla/5.0 (X11; U; Linux i686; cs-CZ; rv:1.8.1.14) Gecko/20080410 SUSE/2.0.0.14-0.2.3 Firefox/2.0.0.14""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:12.0a1) Gecko/20120105 Firefox/12.0a1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.2 (KHTML, like Gecko) Ubuntu/11.10 Chromium/15.0.874.106 Chrome/15.0.874.106 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; (R1 1.5); Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; rv:11.0a2) Gecko/20120106 Firefox/11.0a2""",
"""Mozilla/4.0 (compatible; MSIE 4.01; Digital AlphaServer 1000A 4/233; Windows NT; Powered By 64-Bit Alpha Processor)""",
"""Mozilla/1.22 (compatible; MSIE 1.5; Windows NT)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.26 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312461; Cox High Speed Internet Customer; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 5_0_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9A405 Safari/7534.48.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:9.0.1) Gecko/20100101 Firefox/9.0.1 Iceweasel/9.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.18) Gecko/20110614 BTRS31753 Firefox/3.6.18""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; sv1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; Media Center PC 4.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Embedded Web Browser from: http://bsalsa.com/; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Opera/9.80 (Series 60; Opera Mini/6.24458/26.1305; U; id) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 5.1; rv:12.0a1) Gecko/20111226 Firefox/12.0a1""",
"""Mozilla/5.0 (Macintosh; PPC Mac OS X 10_5_8) AppleWebKit/534.50.2 (KHTML, like Gecko) Version/5.0.6 Safari/533.22.3""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:12.0a1) Gecko/20120111 Firefox/12.0a1""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.2; Trident/5.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 GTB7.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.1.4) Gecko/20091016 Firefox/3.5.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:9.0.1) Gecko/20100101 Firefox/9.0.1 FirePHP/0.6""",
"""Opera/9.64 (X11; Linux i686; U; Linux Mint; nb) Presto/2.1.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Iron/8.0.555.0 Chrome/8.0.555.0 Safari/534.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {71A700CC-D678-6481-704C-A7F934D6E2AB}; FunWebProducts)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.7.2; U; ru) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:8.0a1) Gecko/20110706 Firefox/8.0a1""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.229 Version/11.60""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={0CE63900-1137-49cc-B973-F56110589535}; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; POS2),gzip(gfe) (via translate.google.com)""",
"""Opera/9.01 (Windows NT 5.1; U; en)""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (windows; U; Windows NT 5.1; zh-CN; rv:1.7.12) Gecko/20050919 Firefox/1.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT) ::ELNSB50::000061100320025802a00111000000000507000900000000""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Campaign 21; de) Presto/2.10.229 Version/11.60""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 5.9 (build 4953); ru) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (compatible; rv:2.0) Gecko/20110101 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; FunWebProducts; HbTools 4.8.4; ZangoToolbar 4.8.3)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.25) Gecko/20111212 Firefox/3.6.25""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows ME) Opera 7.11 [en]""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; .NET4.0C; .NET4.0E)""",
"""WongBot // http://www.mister-wong.de/search/""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; GTB7.2; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30618),gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322; Zango 10.0.341.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.8) Gecko/20071015 SUSE/2.0.0.8-1.1 Firefox/2.0.0.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; cs; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:12.0a1) Gecko/20120108 Firefox/12.0a1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1015.0 Safari/535.19""",
"""Click.to 1.1.74 (Macintosh; Mac OS X 10.7.2; de_DE)""",
"""http://Anonymouse.org/ (Unix)""",
"""Dies ist der Agent fuer alle deutschen exam. PflegekrÃ¤ft die fÃ¼r erheblich bessere Arbeitsbedingungen und Bezahlung plÃ¤dieren !! Wacht alle auf ihr gesunden !!""",
"""Dies ist der Agent fuer alle deutschen exam. Pflegekraeft die fuer erheblich bessere Arbeitsbedingungen und Bezahlung plaedieren !! Wacht alle auf ihr gesunden !!""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.24pre) Gecko/20100228 K-Meleon/1.5.4""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.9.168 Version/11.52""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.229 Version/11.60""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; en) Opera 9.0""",
"""Mozilla/5.0 (Ubuntu; X11; Linux i686; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows Phone OS 7.0; Trident/3.1; IEMobile/7.0; SAMSUNG; OMNIA7)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; PeoplePal 3.0; HbTools 4.8.4; yplus 5.1.04b)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/534.52.7 (KHTML, like Gecko) Version/5.1.2 Safari/534.52.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.25 (en-US) Anonymisiert durch AlMiSoft Browser-Maulkorb 49636447""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-EN; rv:1.7.8) Gecko/20050511 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1016.0 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:8.0) Gecko/20111108 Firefox/8.0 PaleMoon/8.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.25) Gecko/20111212 Firefox/3.6.25 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30707; MS-RTC LM 8)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; de; rv:1.9.2.25) Gecko/20111212 Firefox/3.6.25""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; MS-RTC LM 8)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; HbTools 4.7.3)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; de-de; SonyEricssonLT18i Build/4.0.2.A.0.42) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Linux; U; Android 2.2.1; de-de; Milestone Build/SHOLS_U2_05.26.0) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_3; en-us) AppleWebKit/533.16 (KHTML, like Gecko) Version/5.0 Safari/533.16""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-us; GT-P1000 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (BlackBerry; U; BlackBerry 9700; en-US) AppleWebKit/534.8+ (KHTML, like Gecko) Version/6.0.0.448 Mobile Safari/534.8+""",
"""Mozilla/5.0 (SymbianOS/9.4; Series60/5.0 Nokia5800d-1/51.0.006; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.5.2 3gpp-gba""",
"""Opera/9.80 (S60; SymbOS; Opera Mobi/498; U; de) Presto/2.4.18 Version/10.00""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_2_1 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 4_2_1 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Mozilla/5.0 (iPad; CPU OS 5_0_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9A405 Safari/7534.48.3""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.52.7 (KHTML, like Gecko) Version/5.1.2 Safari/534.52.7""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (Linux; U; Android 3.2.1; en-us; Xoom Build/HTK75D) AppleWebKit/534.13 (KHTML, like Gecko) Version/4.0 Safari/534.13""",
"""Mozilla/5.0 (Windows NT 8.1; rv:8.0) Gecko/20100101 Firefox/9.0""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Campaign 06; de) Presto/2.10.229 Version/11.60""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18 sputnik 2.5.2.14""",
"""... Gecko""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; yie6; SV1; .NET CLR 1.0.3705)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; DigExt)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.5; rv:9.0.1) Gecko/20100101 Firefox/9.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729)""",
"""htdig""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.6) Gecko/20100625 Firefox/3.6.6 ( .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Hotbar 4.2.11.0; yplus 5.1.02b)""",
"""Opera/9.80 (Windows NT 5.1; U; Edition Yx; ru) Presto/2.10.229 Version/11.61 Yandex.Translate""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.16) Gecko/20111108 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Opera/9.80 (X11; Linux x86_64; U; ru) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Iron/16.0.950.0 Chrome/16.0.950.0 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SIMBAR={EC2DEE05-5C23-49C7-AB77-05611CEE254E}; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Opera/9.80 (X11; Linux x86_64; U; de) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.1) Gecko/20120121 Firefox/9.1 PaleMoon/9.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 GTB5""",
"""Mozilla/5.0 (Windows NT 6.0; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.1.17) Gecko/20110123 (like Firefox/3.x) SeaMonkey/2.0.12""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.52.7 (KHTML, like Gecko) Version/5.1.2 Safari/534.52.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Creative; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.18975/26.1424; U; en) Presto/2.8.119 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/533.1 (KHTML, like Gecko) Maxthon/3.0.8.2 Safari/533.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/26.1424; U; hu) Presto/2.8.119 Version/10.54""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {CBBEE527-9C34-7554-09AB-9154880C0F5C}; SV1)""",
"""CCBot/1.0 (+http://www.commoncrawl.org/bot.html)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1027.0 Safari/535.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.26) Gecko/20120128 Firefox/3.6.26 GTB7.1 ( .NET CLR 3.5.30729; .NET4.0C) SearchToolbar/1.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.26) Gecko/20120128 Firefox/3.6.26""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; JSRCC_Academic; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_0) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/16.0.912.77 Anonymisiert durch AlMiSoft Browser-Maulkorb 63004979""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.20 (KHTML, like Gecko) Chrome/19.0.1032.0 Safari/535.20""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; BTRS121186; GTB7.2; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""yacybot (freeworld/global; amd64 FreeBSD 9.0-RELEASE; java 1.6.0; EST5EDT/en) http://yacy.net/bot.html""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; .NET CLR 1.1.4322) Netscape/8.0.4""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C)""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.2; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.8.0.2) Gecko/20060309 SeaMonkey/1.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (compatible; askpeterbot/5.4; +http://www.askpeter.info)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.27419/27.1169; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.75 Safari/535.7 CoolNovo/2.0.0.9""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; VNIE5 RefIE5; .NET CLR 1.1.4322)""",
"""Opera/9.80 (Windows 98; U; de) Presto/2.2.15 Version/10.10""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; fr; rv:1.9.2.23) Gecko/20110920 Firefox/3.6.23""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.7 (KHTML, like Gecko) Ubuntu/11.10 Chromium/16.0.912.77 Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/534.53.11 (KHTML, like Gecko) Version/5.1.3 Safari/534.53.10""",
"""Mozilla/5.0 (Windows NT 6.0; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SpamBlockerUtility 4.7.7)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""curl/7.21.6 (x86_64-pc-linux-gnu) libcurl/7.21.6 OpenSSL/1.0.0e zlib/1.2.3.4 libidn/1.22 librtmp/2.3""",
"""vX-NetGhost v.3.4 - vx-archiv.at""",
"""Mozilla/8.0 (X11; Ubuntu; Linux x86_64; rv:15.0.1) Gecko/Chameleon Firefox/15.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.7 (KHTML, like Gecko) Ubuntu/11.10 Chromium/16.0.912.77 Chrome/16.0.912.77 Safari/535.7""",
"""SAMSUNG-GT-S5230/S5230XXIH1 SHP/VPP/R5 Jasmine/0.8 Nextreaming SMM-MMS/1.2.0 profile/MIDP-2.1 configuration/CLDC-1.1""",
"""Opera/9.80 (Windows NT 5.1; U; uk) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20 FBSMTWB""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Q312461; YComp 5.0.0.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1) Gecko/20061010 Firefox/2.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.33 Safari/535.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.26) Gecko/20120128 Firefox/3.6.26 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.7 (KHTML, like Gecko) Ubuntu/10.04 Chromium/16.0.912.77 Chrome/16.0.912.77 Safari/535.7""",
"""Windoof :P""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (compatible; OpenindexShallowSpider/Nutch-1.5-dev; +http://www.openindex.io/en/webmasters/spider.html; systemsATopenindexDOTio)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; Media Center PC 3.1; .NET CLR 1.1.4322; IEMB3; IEMB3; yplus 5.6.04b)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/27.1210; U; hu) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; FunWebProducts; MRA 4.6 (build 01425); .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.27) Gecko/20120216 Firefox/3.6.27 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_5_8) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11""",
"""Opera/9.80 (X11; U; Linux x86_64) Presto/2.9.181 Version/12.00""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iebar; .NET CLR 1.1.4322; IEMB3)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; NP06)""",
"""NOKIAE61i/UC Browser8.0.4.121/28/352/UCWEB""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SIMBAR={D1738F98-982B-4962-8AF0-7EE6695D2E4C}; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; de-DE; rv:1.9.1.3) Gecko/20091002 Firefox/3.5.3""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.26) Gecko/20120128 Firefox/3.6.26 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.2; .NET CLR 1.1.4322; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; PeoplePal 6.2; InfoPath.1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.27) Gecko/20120216 Firefox/3.6.27 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""DLE_Spider.exe""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/27.1251; U; hu) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 4.0; .NET CLR 1.0.2914)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en; rv:1.9.2) Gecko/20100115 MRA 5.6 (build 03278) Firefox/3.6 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/5.0 (iPad; CPU OS 5_0 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9A334 Safari/7534.48.3""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Opera/9.80 (Windows NT 6.1; U; fr) Presto/2.10.229 Version/11.61""",
"""crawler schrein, crawler@schrein.nl id-1""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.16) Gecko/20120131 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Creative ZENcast v1.02.12)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; ADVPLUGIN|K113|3|S1330128458|dial; ADVPLUGIN|K113|4|S1330128458|dial; snprtz|T29919158000013; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13""",
"""Mozilla/5.0 (Windows NT 6.1; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""yacybot (freeworld/global; amd64 Windows 7 6.1; java 1.7.0_02; America/en) http://yacy.net/bot.html""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET4.0C; .NET4.0E; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MSN 9.0;MSN 9.1; MSNbMSNI; MSNmen-us; MSNcOTH)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.65 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:2.0b12) Gecko/20100101 Firefox/4.0b12""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.11 (KHTML, like Gecko) Ubuntu/11.04 Chromium/17.0.963.56 Chrome/17.0.963.56 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; TencentTraveler ; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.3; OfficeLivePatch.0.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-us; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4 GTB7.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:12.0a2) Gecko/20120306 Firefox/12.0a2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; en-us; X500 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; RCP000.009.00520/dc4e96a4f4d7849bb951babbfa5f5164; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.66 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3)""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.229 Version/11.61""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.2; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.78 Safari/535.11""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; tb-webde/1.7.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.78 Safari/535.11""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.229 Version/11.61""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.78 Safari/535.11""",
"""EC2LinkFinder""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (iPad; CPU OS 5_0_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Mobile/9A405""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.9.168 Version/11.51""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.8) Gecko/20100723 Ubuntu/10.04 (lucid) Firefox/3.6.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 2.0.50215; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; FreeBSD amd64; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (compatible; PEAR HTTP_Request class; http://feed.moo.jp/)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.79 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.0; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.2.0; Ringo; .NET CLR 1.1.4322; FDM; .NET CLR 2.0.50727; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; generic) AppleWebKit/534.51 (KHTML, like Gecko; Google Web Preview) Version/4.0 Mobile Safari/534.51""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; 1&1 Internet AG; SV1)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; en-us; X500 Build/GINGERBREAD) UC AppleWebKit/530+ (KHTML, like Gecko) Mobile Safari/530""",
"""Mozilla/5.0 (Linux; U; Android 2.0.1; tr-tr; Droid Build/ESD56) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Mobile Safari/530.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; AOL 9.0; Windows NT 5.1; YPC 3.2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/6.0)""",
"""Opera/9.80 (Android 2.3.4; Linux; Opera Mobi/ADR-1203051631; U; en) Presto/2.10.254 Version/12.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.20) Gecko/20110803 Firefox/3.6.20""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SU 2.010; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (compatible; LucidWorks/; +; crawler at example dot com)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.79 Safari/535.11""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:7.0a1) Gecko/20110623 Firefox/7.0a1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; acc=jocker; acc=none; FreeprodTB; (none); .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; .NET CLR 1.0.3705;)""",
"""Mozilla/5.0 (X11; U; Linux; i686; en-US; rv:1.6) Gecko Debian/1.6-7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; YComp 5.0.2.4; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.28) Gecko/20120306 Napalm/2.0 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.79 Safari/535.11""",
"""SonyEricssonC901/R1EA Browser/NetFront/3.4 Profile/MIDP-2.1 Configuration/CLDC-1.1 JavaPlatform/JP-8.4.2""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; en-US) AppleWebKit/534.10 (KHTML, like Gecko) Chrome/8.0.558.0 Safari/534.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/534.54.16 (KHTML, like Gecko) Version/5.1.4 Safari/534.54.16""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; (webde/1.0.0.8); Avant Browser; SlimBrowser)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.83 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; rev1.5; Windows NT 5.1; SV1; Avant Browser; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 7.0; Win32; WEB.DE); Mozilla/4.0 (compatible; MSIE 8.0; Win32; WEB.DE); (webde/1.1.0.21); (webde/1.1.0.22); .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; tb-webde/1.7.2)""",
"""Mozilla/5.0 (iPad; CPU OS 5_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B176 Safari/7534.48.3""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Campaign 21; en-GB) Presto/2.10.229 Version/11.61""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; QS 4.2.1.0; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.54.16 (KHTML, like Gecko) Version/5.1.4 Safari/534.54.16""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.54.16 (KHTML, like Gecko) Version/5.1.4 Safari/534.54.16""",
"""Mozilla/5.0 (X11; Linux i686; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.2.10) Gecko/20100914 Firefox/3.6.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.9.0.11) Gecko/20080528 Epiphany/2.22 Firefox/3.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; (1und1/1.0.0.8))""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru-RU; rv:1.9.2.27) Gecko/20120216 Firefox/3.6.27""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; YPC 3.2.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; Creative ZENcast v1.02.10; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (compatible; OpenindexShallowSpider/Nutch-1.5-dev; +http://www.openindex.io/en/webmasters/spider.html)""",
"""Mozilla/5.0 (compatible)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11""",
"""GSLFbot""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.77 Safari/534.24""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.11 (KHTML, like Gecko) Ubuntu/11.10 Chromium/17.0.963.79 Chrome/17.0.963.79 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 5.0; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET CLR 3.0.30618; Browzar)""",
"""SemrushBot/0.92""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; IEMB3; Creative ZENcast v1.00.19; IEMB3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.28) Gecko/20120306 Internet Explorer/4.0 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.28) Gecko/20120306 Internet Explorer/ MSIE 4.0 (WIN 95)""",
"""lb-spider/Mozilla/5.0 Gecko/20100101 Firefox/10.0.2 (lb-spider; http://www.linkbutler.de/spider; spider@linkbutler.de)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.142 Safari/535.19""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.79 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.30729; .NET CLR 3.5.30707)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20 (.NET CLR 3.5.30729)""",
"""mozilla/4.0 (compatible; msie 8.0; windows nt 6.1; trident/4.0; gtb6.4; slcc2; .net clr 2.0.50727; .net clr 3.5.30729; .net clr 3.0.307)""",
"""Anh Thi Bi Khung""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; CMS Music Store2 v1.00.09 (Music Store,1033); .NET CLR 1.1.4322; ZangoToolbar 4.8.3)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/534.55.3 (KHTML, like Gecko) Version/5.1.5 Safari/534.55.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/534.55.3 (KHTML, like Gecko) Version/5.1.5 Safari/534.55.3""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.9 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.142 Safari/535.19""",
"""Googlebot/2.1 (http://www.googlebot.com/bot.html)""",
"""du wurdest von malware geklickt! Bitte um reklick(!): http://www.klick-game.de/joke-905.html""",
"""salari/9.22 (Windows NT 6.0; U; en)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; AT&T CSM8.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.151 Safari/535.19""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/27.1407; U; hu) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:9.0.1) Gecko/20120212 Firefox/9.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; 360SE)""",
"""Mozilla / 4.0""",
"""fastbot crawler beta 2.0 (+http://www.fastbot.de)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.151 Safari/535.19""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.3) Gecko/20100101 Firefox/10.0.3 Iceweasel/10.0.3""",
"""asdf""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; freenet.de frndial 5.0; .NET CLR 1.1.4322)""",
"""Opera/9.80 (X11; Linux i686; U; Edition Linux Mint; de) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Linux i686; de; rv:2.0) Gecko/20100101 Firefox/4.0 Opera 11.62""",
"""Mozilla/5.0 (compatible; MSIE 9.0; X11; Linux i686; de) Opera 11.62""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.152 Safari/535.19""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (compatible; Mail.RU/2.0)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) konqueror/4.7.2 Safari/534.34""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) konqueror/4.7.2 Safari/534.34""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; de-de; GT-I9001 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.3) Gecko/20120314 Firefox/10.0.3""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.152 Safari/535.19""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.55.3 (KHTML, like Gecko) Version/5.1.5 Safari/534.55.3""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts-MyWay; FunWebProducts; .NET CLR 1.0.3705)""",
"""netEstate NE Crawler (+http://www.sengine.info/)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; chromeframe/18.0.1025.151)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/27.1486; U; vi) Presto/2.8.119 Version/11.10""",
"""SAMSUNG-GT-C5010/C5010DDKF3 NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (compatible; Blekkobot; ScoutJet; +http://blekko.com/about/blekkobot)""",
"""Mozilla/4.77 [en] (X11; I; IRIX;64 6.5 IP30)""",
"""mahonie, neofonie search:robot/search:robot/0.0.1 (This is the MIA Bot - crawling for mia research project. If you feel unhappy and do not want to be visited by our crawler send an email to spider@neofonie.de; http://spider.neofonie.de; spider@neofonie.de)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0,gzip(gfe) (via translate.google.com)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; iebar; acc=; acc=none; (none))""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FunWebProducts; YPC 3.2.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; yplus 5.3.02b)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Iron/17.0.1000.0 Chrome/17.0.1000.0 Safari/535.11""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/27.1486; U; hu) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.5b) Gecko/20030827""",
"""EventMachine HttpClient""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; FunWebProducts; .NET CLR 1.1.4322; Zango 10.0.314.0; MSN 6.1; MSNbMSFT; MSNmen-us; MSNc00; v5m)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:13.0) Gecko/20120414 Firefox/13.0a2""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; IEMB3; MEGAUPLOAD 1.0; IEMB3)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:11.0) Gecko/20120312 Firefox/11.0 SeaMonkey/2.8""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; de-de; U8510 Build/HuaweiU8510) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.26955/27.1530; U; es) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; Roadrunner; FunWebProducts)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; AskTbFXTV5/5.9.1.14019)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; America Online Browser 1.1; Windows NT 5.1; {91A7AA5A-1A57-89A7-FC75-456E4CA6626F}; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0 FirePHP/0.7.1""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.8 (KHTML, like Gecko) Chrome/20.0.1105.2 Safari/536.8""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.163 Safari/535.19""",
"""Mozilla/5.0 (X11; U; OpenBSD i386; en-US)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.16) Gecko/20101130 Firefox/3.5.16 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; IEMobile 6.12) T-Mobile_Atlas""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (Android; Linux armv7l; rv:10.0.3) Gecko/20120302 Firefox/10.0.3 Fennec/10.0.3""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Iron/17.0.1000.1 Chrome/17.0.1000.1 Safari/535.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 5_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B179 Safari/7534.48.3""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {E6C1818F-F5D3-4050-9AFE-085F1583BC86}; SV1; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; MS-RTC LM 8; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.14) Gecko/20110218 Firefox/3.6.14 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""ZooShot 0.42""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.16 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 5.1; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; WOW64; Trident/6.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; pt-BR; rv:1.9.2.10) Gecko/20100922 Ubuntu/10.10 (maverick) Firefox/3.6.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/10.04 Chromium/18.0.1025.151 Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.3; http://www.majestic12.co.uk/bot.php?+)""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.7.3; U; en) Presto/2.10.229 Version/11.62""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; AdminIE; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; rv:1.9.2) Gecko/20100101 Firefox/3.6""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_7) AppleWebKit/534.16+ (KHTML, like Gecko) Version/5.0.3 Safari/533.19.4""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; IBM EVV/3.0/EAK01AG9/LE; ru) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""EMail Exractor""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_5_8) AppleWebKit/534.50.2 (KHTML, like Gecko) Version/5.0.6 Safari/533.22.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; AOL 9.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; MEGAUPLOAD 1.0; HbTools 4.8.4)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; generic) AppleWebKit/535.1 (KHTML, like Gecko; Google Web Preview) Version/4.0 Mobile Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; ms-office)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19""",
"""Opera/9.80 (Series 60; Opera Mini/7.29482/27.1573; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.36 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; Opera/11.61 (X11; Fedora x86_64; U; en-us) WebKit/532+; es-ES) Presto/2.10.229 Version/11.62""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/27.1573; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 GTB6 (.NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; FreeprodTB; .NET CLR 1.1.4322; MSN 9.0;MSN 9.1; MSNbVZ02; MSNmen-us; MSNcOTH)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.36 Safari/536.5""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.27309/27.1597; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11 MRCHROME""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:14.0) Gecko/20120326 Firefox/14.0a1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; chromeframe/18.0.1025.168; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; InfoPath.2; .NET4.0E)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 GTB7.1""",
"""Opera/8.01 (J2ME/MIDP; Opera Mini/2.0.4509/1724; en; U; ssr)""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/27.1597; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; de) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB7.3; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; Zune 4.7)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.41 Safari/536.5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; en-us) AppleWebKit/531.21.8 (KHTML, like Gecko) Version/4.0.4 Safari/5""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.165 Safari/535.19""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.151 Safari/535.19""",
"""Opera/9.80 (X11; Linux x86_64; U; ru) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (Windows NT 5.1; rv:6.0) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; {5A890180-B4BA-5DD8-6A6A-15240AF3CBCA}; .NET CLR 1.1.4322; IEMB3)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.0; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/27.1662; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Browzar)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/11.10 Chromium/18.0.1025.168 Chrome/18.0.1025.168 Safari/535.19""",
"""Opera/9.10 (Windows NT 5.1; U; pl) Presto/9.9.9""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 AlexaToolbar/alxf-2.15""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; Interfree Kit; MEGAUPLOAD 1.0)""",
"""Knast05 (JVA; BKA; LKA)""",
"""Hey! Useragents can be faked, you know? Hahahahaha!""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19""",
"""Opera/9.80 (Windows NT 6.1; U; IBM EVV/3.0/EAK01AG9/LE; de) Presto/2.10.229 Version/11.64""",
"""SonyEricssonC510/R1HA Browser/NetFront/3.4 Profile/MIDP-2.1 Configuration/CLDC-1.1 JavaPlatform/JP-8.4.""",
"""(we_are_legion)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.0.3705; .NET CLR 2.0.50727; yplus 5.1.04b)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/27.1662; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; U; Android 2.3;en-us; ViewSonic-ViewPad7e build/ERE27) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""WatchMouse/22330 (http://watchmouse.com/ ; nlams02.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; decgn01.watchmouse.net)""",
"""WatchMouse/21880 (http://watchmouse.com/ ; oldgab)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; sesto01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; cavan01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; gblon01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; nlams01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; itpda01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; hkhkg01.watchmouse.net)""",
"""WatchMouse/22330 (http://watchmouse.com/ ; usaus01.watchmouse.net)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; KTXN)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-us; Nexus One Build/FRF91) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Linux; Android 4.0.4; Build/IMM76D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.133 Mobile Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Media Center PC 3.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5""",
"""Python-urllib/2.6""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; mg-toshiba; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; TOB 6.13; Windows NT 6.1; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; de) Presto/2.10.229 Version/11.64""",
"""Michael hat geklickt...... ;-)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.36 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Opera/9.80 (Series 60; Opera Mini/7.29482/27.1741; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.27055/27.1741; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; OpenindexDeepSpider/Nutch-1.5-dev; +http://www.openindex.io/en/webmasters/spider.html)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 2.0.50727)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE; rv:1.9.2b5) Gecko/20091204 Firefox/3.6b5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/12.0 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 32897661""",
"""Mozilla/5.0 (compatible; ltbot/1.3; bot@language-tools.com)""",
"""Mozilla/5.0 (Danger hiptop 4.7; U; rv:1.7.12) Gecko/20050920""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:11.0) Gecko/20120313 Firefox/11.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Tablet PC 2.0; .NET4.0C; .NET4.0E)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/27.1741; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaE71-1/500.21.009; Profile/MIDP-2.0 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.28870/27.1813; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0.4) Gecko/20100101 Firefox/10.0.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (Series 60; Opera Mini/7.28967/27.1813; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; BO1IE8_v1;ENUS)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21051/27.1813; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.15410/27.1813; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Iron/19.0.1084.36 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/3.0 (compatible; Indy Library)""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:8.0) Gecko/20100101 Firefox/8.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0E; .NET4.0C)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""Mozilla/4.0+(compatible;+MSIE+6.0;+MSIE+5.5;+Windows+NT+5.0)+Ope""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 ( .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Linux; U; Android 2.2; fr-fr; Desire_A8181 Build/FRF91) App3leWebKit/53.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.112 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.30 Safari/536.5""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.8 Safari/536.11""",
"""Mozilla/5.0 (Linux; U; Android 2.2.1; en-gb; HTC Wildfire Build/FRG83D) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Windows NT 6.1; rv:2.0b7pre) Gecko/20100921 Firefox/4.0b7pre""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_0) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1063.0 Safari/536.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MRA 5.8 (build 4157); .NET CLR 2.0.50727; AskTbPTV/5.11.3.15590)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/12.04 Chromium/18.0.1025.151 Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Nokia7610/2.0 (6.0522.0) SymbianOS/7.0s Series60/2.1 Profile/MIDP-2.0 Configuration/CLDC-1.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.25) Gecko/20111212 Firefox/3.6.25""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; xs-JLHZZx2NO4s;iwNieC; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.08989 (Windows; U; Windows NT 5.0; deve; rv:1.88.1.2) Gecko/2007021797979 Firefox/2.0.0.2""",
"""Mozilla/5.0 (Windows fdhfghfhfdhfNT 6.1) AppleWexvcxvxcbKit/535.7 (KHTML, like Gecko) Chromfbfdhfdfdgdfe/16.0.912.77 Safari/535.797979797979""",
"""Opera/9.80 (J2ME/MIDP; Opera Migdgdfgfdni/6.5.26955/27.1530; U; es) Prdgfdgfdgfdgxzcxzesto/2.8.119 Version/11.1043543689879""",
"""Mozilla/5.0 (Windows NT 6.0; rv:12.0) Gecko/20100101 Firefox/12.0 AlexaToolbar/alxf-2.15""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.7.10) Gecko/20050729 Firefox/1.0.6 (MOOX M2)""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.10.229 Version/11.60""",
"""Mozilla/5.0 (Windows NT 6.1; rv:5.0) Gecko/20100101 Firefox/5.02""",
"""Mozilla/5.0 (Android; Mobile; rv:14.0) Gecko/14.0 Firefox/14.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.7.4; U; en) Presto/2.10.229 Version/11.62""",
"""Mozilla/5.0 (X11; Linux i686; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 GTB7.1""",
"""Mozilla/5.0 (Windows NT 5.1; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.3.8.3000 Chrome/18.0.966.0 Safari/535.12""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.229 Version/11.64""",
"""Mozilla_5.0 (Linux; U; Android 2.3.3; de-de; U8510 Build_HuaweiU8510) AppleWebKit_533.1 (KHTML, like Gecko) Version_4.0 Mobile Safari_533.1""",
"""Mozilla/4.0 (Compatible; MSIE 4.01; AOL 3.0; Windows 95)""",
"""facebookexternalhit_1.1 (+http:__www.facebook.com_externalhit_uatext.php)""",
"""Firefox_8.0""",
"""index.html""",
"""Mozilla/5.0 (compatible; MSIE 10) <script>alert('what's up?');</script>""",
"""Pixray-Seeker/1.1 (Pixray-Seeker; http://www.pixray.com/pixraybot; crawler@pixray.com)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.16) Gecko/20120421 Gecko Firefox/11.0""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; en) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/530.0 (KHTML, like Gecko) Chrome/2.0.160.0 Safari/530.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0) Gecko/20110319 Firefox/4.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.40607)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Iron/19.0.1100.0 Chrome/19.0.1100.0 Safari/536.5""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.6 (KHTML, like Gecko) Chrome/20.0.1087.0 Safari/536.6""",
"""Mozilla/5.0 (Windows NT 6.2; rv:12.0) Gecko/20100101 Firefox/12.0 AlexaToolbar/alxf-2.15""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.7 (build 03757); ru) Presto/2.10.229 Version/11.60""",
"""SinaWeiboBot""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; MS-RTC LM 8; InfoPath.3; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET4.0C; .NET4.0E; .NET CLR 2.0.50727; KB974489; 360SE)""",
"""DoCoMo/2.0 P900i(c100;TB;W24H11) (compatible; ichiro/mobile goo; +http://search.goo.ne.jp/option/use/sub4/sub4-1/)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:14.0) Gecko/20100101 Firefox/14.0""",
"""Nokia2730c-1/2.0 (10.45) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/4.0 (compatible; MSIE 4.0; ) Opera/UCWEB8.0.0.89/70/351 UNTRUSTED/1.0""",
"""BlackBerry9700/5.0.0.862 Profile/MIDP-2.1 Configuration/CLDC-1.1 VendorID/331 UNTRUSTED/1.0 3gpp-gba""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.3) Gecko/20100101 Firefox/10.0.3 Iceweasel/10.0.3""",
"""Lynx/2.8.8dev.12 libwww-FM/2.14 SSL-MM/1.4.1 GNUTLS/2.12.18""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (iPad; CPU OS 5_1_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B206 Safari/7534.48.3""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_5_8) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/27.2020; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_5; en-us) AppleWebKit/525.26.2 (KHTML, like Gecko) Version/3.2 Safari/525.26.12""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ar; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.5; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25381/27.2020; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Opera/9.80 (Android; Opera Mini/7.0.29952/27.2020; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.34 Safari/536.11""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.16) Gecko/20120315 Firefox/6.0a2 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 5_1_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B206 Safari/7534.48.3""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; de) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (iPad; Opera Mini/7.0.2/27.2020; U; de) Presto/2.8.119 Version/11.10""",
"""ShowyouBot (http://showyou.com/crawler)""",
"""Twitterbot/1.0""",
"""RockMeltEmbedService""",
"""Mozilla/5.0 (compatible; PaperLiBot/2.1; http://support.paper.li/entries/20023257-what-is-paper-li)""",
"""Mozilla/5.0 (iPad; CPU OS 5_1_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Mobile/9B206""",
"""Apache-HttpClient/4.1 (java 1.5)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1179.0 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6 (FlipboardProxy/1.1; +http://flipboard.com/browserproxy)""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6 (FlipboardProxy/0.0.5; +http://flipboard.com/browserproxy)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:11.0) Gecko/20100101 Firefox/11.0 (IKDhPmJcdw)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/27.2020; U; en) Presto/2.8.119 Version/11.10""",
"""news.me extractor""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 5_1_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Mobile/9B206""",
"""Mozilla/5.0 (Linux; U; Android 2.2.2; de-de; XT610 Build/V2U_3.4.2-179) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""BufferBot""",
"""Mozilla/5.0 (compatible; Linter/1.0)""",
"""LinkedInBot/1.0 (compatible; Mozilla/5.0; Jakarta Commons-HttpClient/3.1 +http://www.linkedin.com)""",
"""Mozilla/5.0 (compatible) Feedfetcher-Google;(+http://www.google.com/feedfetcher.html)""",
"""Mozilla/5.0 (compatible; Rivva; http://rivva.de)""",
"""Summify (Summify/1.0.1; +http://summify.com)""",
"""percbotspider <ops@percolate.com>""",
"""NING/1.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.21) Gecko/20090303 SeaMonkey/1.1.15 (Ubuntu-1.1.15+nobinonly-0ubuntu2)""",
"""Midori/0.3 (X11; Linux; U; en-ca) WebKit/534.21+""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1b4pre) Gecko Galeon/2.0.6 (Ubuntu 2.0.6-2.1)""",
"""Opera/9.63 (X11; Linux i686; U; en) Presto/2.1.1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko Kazehakase/0.5.4 Debian/0.5.4-2.1+b1""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.18) Gecko/20081030 Iceape/1.1.13 (Debian-1.1.13-1)""",
"""Mozilla/5.0 (X11; U; Linux i686; en; rv:1.9.0.4) Gecko/20080528 Epiphany/2.22""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko/2008112309 Iceweasel/3.0.4 (Debian-3.0.4-1)""",
"""Mozilla/5.0 (compatible; Konqueror/4.2; Linux) KHTML/4.2.2 (like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.10) Gecko/20100915 Ubuntu/9.10 (karmic) Firefox/3.6.10""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.7.62 Version/11.01""",
"""Mozilla/5.0 (X11; Linux i686; rv:9.0) Gecko/20100101 Firefox/9.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0) Gecko/20100101 Firefox/10.0""",
"""Mozilla/5.0 (compatible; Konqueror/4.3; Linux) KHTML/4.3.2 (like Gecko)""",
"""Lynx/2.8.8dev.9 libwww-FM/2.14 SSL-MM/1.4.1 GNUTLS/2.10.5""",
"""Mozilla/5.0 (X11; Linux x86_64) KHTML/4.8.3 (like Gecko) Konqueror/4.8""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.4+ (KHTML, like Gecko) Version/5.0 Safari/535.4+ Ubuntu/11.10 (3.2.0-1~webupd8~oneiric) Epiphany/3.2.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:11.0) Gecko/20120312 Firefox/11.0 SeaMonkey/2.8""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.10.229 Version/11.61""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.6.30 Version/10.60""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.51.22 (KHTML, like Gecko) Version/5.1.1 Safari/534.51.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6""",
"""Mozilla/5.0 (Windows NT 5.1; rv:11.0) Gecko/20120312 Firefox/11.0 SeaMonkey/2.8""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; fr-FR) AppleWebKit/525.28.3 (KHTML, like Gecko) Version/3.2.3 Safari/525.29""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/12.04 Chromium/18.0.1025.151 Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; de-de; GT-I9100 Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.0; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; FreeBSD amd64; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (compatible; musobot/1.0; info@muso.com; +http://www.muso.com)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.5) Gecko/20100101 Firefox/10.0.5 Iceweasel/10.0.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.83 Safari/535.11""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.2; WOW64; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; WOW64; Trident/5.0; tb-gmx/1.7.2; (gmx/1.0.0.8))""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.56 Safari/535.11 CoolNovo/2.0.2.26""",
"""Mozilla/5.0 (Windows NT 5.1; rv:14.0) Gecko/20100101 Firefox/14.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.1857; U; en) Presto/2.8.119 Version/11.10""",
"""Wotbox/2.0 (bot@wotbox.com; http://www.wotbox.com)""",
"""Opera/9.80 (Windows NT 6.1; U; cs) Presto/2.10.229 Version/11.64""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB7.3; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Iron/19.0.1100.0 Chrome/19.0.1100.0 Safari/536.5""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/22.0.1185.0 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; it-it) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:13.0) Gecko/20100101 Firefox/13.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.29915/28.1857; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; U; Linux i686; en-us) AppleWebKit/531.2+ (KHTML, like Gecko) Safari/531.2+ Epiphany/2.29.5""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 9.0; Windows NT 6.1) by schoereli""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.24 (KHTML, like Gecko) Ubuntu/11.04 Chromium/11.0.696.68 Chrome/11.0.696.68 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.43 Safari/536.11""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:14.0) Gecko/20100101 Firefox/14.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.43 Safari/536.11""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.1914; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.47 Safari/536.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:13.0) Gecko/20120415 Firefox/13.0a2""",
"""Mozilla/5.0 (compatible; AhrefsBot/3.1; +http://ahrefs.com/robot/)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.47 Safari/536.11""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.18) Gecko/20110614 Firefox/3.6.18""",
"""Opera/9.80 (Windows NT 6.1; U; pt) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.29707/28.1977; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.47 Safari/536.11""",
"""Mozilla/5.0 (X11; Linux i686; rv:7.0) Gecko/20100101 Firefox/7.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/6.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/7.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.5 Safari/534.30""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; Edition NCSD2; pl) Presto/2.10.289 Version/12.00""",
"""GG PeekBot 1.0 ( http://gg.pl/ http://info.gadu-gadu.pl/praca )""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.47 Safari/536.11""",
"""Mozilla/5.0 ( ; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Mozilla/5.0; MSIE 9.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Mozilla/13.0; MSIE 9.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; InfoPath.3; Tablet PC 2.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; .NET CLR 1.1.4322)""",
"""Mozilla/13.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; .NET CLR 1.1.4322)""",
"""Mozilla/13.0 ( ; MSIE 7.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; .NET CLR 1.1.4322)""",
"""Mozilla/13.0 ( ; MSIE 9.0; Windows NT 6.1; Trident/5.0; .NET4.0C; .NET CLR 1.1.4322; .NET4.0C; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.18) Gecko/2010020220 Mozilla/4.0 (compatible; [Version]; Windows NT 6.0) (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/11.04 Chromium/18.0.1025.151 Chrome/18.0.1025.151 Safari/535.19""",
"""Mozilla/5.0 (masking-agent; rv:16.0) Gecko/16.0 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.43 Safari/536.11""",
"""Mozilla/5.5 (Windows; U; Windows NT 6.5; en-US; rv:1.9.2.25.16.6.12) Gecko/20111212.16062012 Firefox/3.6.25""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; X2X19)""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 5_1_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B206 Safari/7534.48.3""",
"""XXXXXXXXXXXXXXXXXX""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.47 Safari/536.11""",
"""UCBrowser8.4.0.159/69/352/UCWEBMobile""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; K20057302B63867; K20058966B63867; K20113032-0674B63867; K20057176B63867; K20057329B63867; K20113032-1050B63867; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/12.04 Chromium/18.0.1025.168 Chrome/18.0.1025.168 Safari/535.19""",
"""Mozilla/5.0 (X11; FreeBSD amd64; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.1; rv:12.0) Gecko Firefox""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; GT-I9300 Build/IMM76D) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""blubb""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; de;rv:12.0) Gecko/20120403211507 Firefox/12.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0.1) Gecko/20111222 Firefox/9.0.1 ffce""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.2; .NET4.0E)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.0; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-NZ; rv:1.8.1b2) Gecko/20060925 Songbird/0.2""",
"""Mozilla/9.0 (Windows; U; Windows 9; en; rv:1.9.1.7) Gecko/20091221 Firefox/2344.0.2""",
"""sGroup crawler 1/Nutch-1.3""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.9.2.26) Gecko/20120201 CentOS/3.6.26-1.el6.centos Firefox/3.6.26 GTB7.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:14.0) Gecko/20100101 Firefox/14.0.1 Iceweasel/14.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.2 (KHTML, like Gecko) Chrome/22.0.1211.0 Safari/537.2""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 5.1; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; GTB7.1; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Lynx/2.8.8dev.5 libwww-FM/2.14 SSL-MM/1.4.1 GNUTLS/2.8.6""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:10.0) Gecko/20100101 Firefox/10.0 Firefox/10.0""",
"""Mozilla/5.0 (compatible; WebNL; +http://www.web.nl/webmasters/spider.html; helpdesk@web.nl)""",
"""LinksCrawler 0.1beta""",
"""Opera/9.80 (Series 60; Opera Mini/6.0.24096/28.2173; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""cmjcgkckcdgkcgkxcgkgkxgkm""",
"""Mozlla/5.0 (X11; Linux x86_64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:13.0) Gecko/20120606 Firefox/13.0""",
"""general.useragent.override""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; aff-kingsoft-ciba)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.36 Safari/535.7 AppEngine-Google; (+http://code.google.com/appengine; appid: s~quexdoo)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; yie8)""",
"""Mozilla/5.0 (X11; Linux i686; rv:16.0) Gecko/16.0 Firefox/16.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/2.2.24222/28.2173; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""W3C_Validator/1.3""",
"""CHAOLEEMozilla/5.5 (Windows; U; Windows NT 6.5; en-US; rv:1.9.2.25.16.6.12) Gecko/20111212.16062012 Firefox/3.6.25-19072012bn""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.60 Safari/537.1""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Campaign 21; de) Presto/2.10.289 Version/12.00""",
"""CNDMozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/125.2 (KHTML, like Gecko) Safari/125.8-CND_BN_03082012_4""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/28.2197; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.60 Safari/537.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Sgrunt|V109|1727|S608680499|dial; Sgrunt|V109|1727|S608680499|dialno; Mozilla/4.0(Compatible Mozilla/4.0(Compatible-EmbeddedWB 14.57 http://bsalsa.com/ EmbeddedWB- 14.57 from: http://bsalsa.com/ ; InfoPath.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Android; Tablet; rv:10.0.5) Gecko/10.0.5 Firefox/10.0.5 Fennec/10.0.5""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Dorado WAP-Browser/1.0.0""",
"""Mozilla/5.0 (Windows NT 5.2; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.60 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/536.25 (KHTML, like Gecko) Version/6.0 Safari/536.25""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.2 (KHTML, like Gecko) Comodo_Dragon/15.0.3.0 Chrome/15.0.874.102 Safari/535.2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; AskTbORJ/5.15.4.23821)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.57 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.3 (KHTML, like Gecko) Chrome/22.0.1221.0 Safari/537.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; WOW64; en-US; rv:2.0.4) Gecko/20120718 Firefox/14.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.75 Safari/537.1 AppEngine-Google; (+http://code.google.com/appengine; appid: s~govimming)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.75 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.75 Safari/537.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.4+ (KHTML, like Gecko) Version/5.0 Safari/535.4+ 1.10.0+""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; AskTbAVR-3/5.15.4.23930; yie9; anonymized by Abelssoft 757075010)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/9.80 (S60; SymbOS; Opera Mobi/23.348; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (Windows NT 6.1; U; ro) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.75 Safari/537.1""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/6.0 Mobile/7B334b Safari/531.21.10""",
"""Mozilla/5.0 (Windows NT 5.1; WOW64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8) AppleWebKit/536.25 (KHTML, like Gecko) Version/6.0 Safari/536.25""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; FunWebProducts)""",
"""Mozilla/5.0 (Linux; U; Android 2.2.1; en-us; SGH-T959V Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Windows NT 5.0; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8; InfoPath.3; .NET4.0C; .NET4.0E; BRI/2)""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Windows NT 5.1; rv:16.0) Gecko/16.0 Firefox/16.0""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; nb-no; GT-P5110 Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.77 Safari/537.1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.77 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11; CollapsarTEXT""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MALC)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; ms-office)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.8.0.11) Gecko/20070312 Firefox/1.5.0.11; 360Spider""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Java HTTP Helper V0.1 Java/1.7.0_05""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.10 (build 5310); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_4_11; fr) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.229 Version/11.62""",
"""MAZCHAOLEEMozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko; Google Web Preview) Chrome/11.0.696 Safari/534.24_19-082912amzchaoleeeeeeeeeeeeex""",
"""ebayMozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110422 Ubuntu/8.04 (hardy) Firefox/3.6.17_terry-20082012ebayyyyyyyxxx""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.165 Safari/535.19 YI""",
"""Mozilla/5.0 (compatible; UnisterBot; crawler@unister.de)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Next; ru) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.57 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.83 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1200.0 Iron/21.0.1200.0 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.83 Safari/537.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET CLR 3.5.21022; .NET4.0C; Media Center PC 5.0; SLCC1; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.165 Safari/535.19 YI""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.82 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (iPod; U; CPU iPhone OS 3 1 2 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7D11 Safari/528.16""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.6 (KHTML, like Gecko) Chrome/20.0.1096.1 Safari/536.6""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.13216/28.2313; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; BTRS122412; SIMBAR={7500BC4A-7EC9-4053-B683-36EF1FCCF59E}; GTB7.4; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.83 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:2.0b6) Gecko/2008102920 Firefox/3.0.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101028 Firefox/3.6.12 (Palemoon/3.6.12)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_0) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.82 Safari/537.1""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64; U; Edition Yx; ru) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (Windows NT 5.1; U; Edition Yx; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; bgft)""",
"""Opera/9.80 (Windows NT 6.1; U; YB/3.5.1; ru) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.81 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/19.0.1084.52 Safari/535.12""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.83 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.164 Safari/535.19 YE""",
"""Opera/9.80 (Windows NT 5.1; U; Edition Campaign 09; ru) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.30701/28.2313; U; fr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_1) AppleWebKit/536.25 (KHTML, like Gecko) Version/6.0 Safari/536.25""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/5.0 (Windows; Windows NT 6.1; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET CLR 3.0.04506; Media Center PC 5.0; SLCC1; .NET4.0C; .NET4.0E; .NET CLR 1.1.4322; AskTbAVR-W1/5.15.4.23930)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.3) Gecko/20100401 MRA 5.6 (build 03278) Firefox/3.6.3 sputnik 2.1.0.18 WebMoney Advisor""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.289 Version/12.02""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/28.2359; U; el) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/5.0 (X11; U; Linux armv6l; en-US; rv: 1.9.1a2pre) Gecko/20080813221937 Prism/0.9.1""",
"""Mozilla/5.0 (compatible; Infohelfer/1.3.0; +http://www.infohelfer.de/crawler.php)""",
"""Mozilla/5.0 (Windows NT 5.2; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/28.2359; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29595/28.2359; U; en) Presto/2.8.119 Version/11.10""",
"""HD nutch agent/Nutch-1.1 (Think)""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64; U; ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 6.0; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.21022; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.2; MS-RTC LM 8; .NET CLR 3.0.30729; S.N.O.W.4; S.N.O.W.4)""",
"""Mozilla/5.0(SymbianOS/9.2; U;Series60/3.1 NokiaN82/10.0.035; Profile/MIDP-2.0""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.134 Safari/534.16""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Ubuntu/10.10 Chromium/10.0.648.127 Chrome/10.0.648.127 Safari/534.16""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.7.12) Gecko/20050915 Firefox/1.0.7""",
"""TerryMozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.1.249.1036 Safari/532.5-050912012-Ebb-PP-Terry.2012222""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; Edition Yx; ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.10 (build 5288); ru) Presto/2.2.15 Version/10.10""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 6.0 (build 5680); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:15.0) Gecko/20100101 Firefox/15.0 Firefox/15.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""CLEEB410Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/0.4.154.33 Safari/525.19.410.09.2012_AMZ-CHAOLEE-BOOOKS.410.WWWs""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:16.0) Gecko/16.0 Firefox/16.0a1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:18.0) Gecko/18.0 Firefox/18.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/12.04 Chromium/18.0.1025.168 Chrome/18.0.1025.168 Safari/535.19""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.6) Gecko/20100101 Firefox/10.0.6 Iceweasel/10.0.6""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.39 Safari/537.4""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.8 (KHTML, like Gecko) Chrome/23.0.1255.0 Safari/537.8""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0.6) Gecko/20100101 Firefox/10.0.6""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""HTMLParser/2.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.4.2.3000 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; TencentTraveler ; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/28.2443; U; pt) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; oBot/2.3.1; +http://filterdb.iss.net/crawler/)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; c .NET CLR 3.0.04506; .NET CLR 3.5.30707; InfoPath.1; el-GR)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:15.0) Gecko/20100101 Firefox/15.0.1 AlexaToolbar/alxf-2.16""",
"""Mozilla/5.0 (Windows NT 6.1; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.18 (KHTML, like Gecko) Chrome/18.0.1010.1 Safari/535.18""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.7) Gecko/20100101 Firefox/10.0.7""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.289 Version/12.02""",
"""drupact/0.7; http://www.arocom.de/drupact""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-us; rv:1.9.2.28) Gecko/20120306 Firefox/10.0""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; ru) Presto/2.10.289 Version/12.02""",
"""Wotbox/2.01 (+http://www.wotbox.com/bot/)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:18.0) Gecko/18.0 Firefox/18.0""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.9.211 Version/12.00""",
"""Mozilla/5.0 (iPad; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5355d Safari/8536.25""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.112 Safari/535.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.2504; U; en) Presto/2.8.119 Version/11.10""",
"""CHUTIEUMozilla/5.0 (X11; U; Linux i686; de-AT; rv:1.7.13) Gecko/20060411""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 6.0; en-US)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Next; en) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0.7) Gecko/20100101 Firefox/10.0.7""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Opera/9.80 (S60; SymbOS; Opera Mobi/SYB-1204232254; U; en-GB) Presto/2.10.254 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.0; rv:15.0) Gecko/20100101 Firefox/15.0.1 AlexaToolbar/alxf-2.16""",
"""Mozilla/5.0 (Windows NT 5.1; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:15.0) Gecko/20100101 Firefox/15.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:15.0) Gecko/20100101 Firefox/15.0.1 Firefox/15.0.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; de; rv:1.9.0.4) Gecko/20081029 Firefox/2.0.0.18""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2b5) Gecko/20091204 Firefox/3.6b5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE; rv:1.5) Gecko/20031007 Firebird/0.7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.82 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.64 Safari/537.4""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.31380/28.2555; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-BR; rv:1.8.0.12) Gecko/20070508 Firefox/1.5.0.12""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; generic) AppleWebKit/536.8 (KHTML, like Gecko; Google Web Preview) Version/4.0 Mobile Safari/536.8""",
"""TERRYMozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.48 Safari/525.20.26.12.09_EBAYTERRY.WWW""",
"""PPBRMozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.0 Safari/535.5.5.3_PPABRUCE.BoGIOO-320942389038%$%^$^%^%&*^*+(.PPP""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; BRI/2; .NET4.0C; InfoPath.2; NP02)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:15.0) Gecko/20120913 Firefox/15.0.1 SeaMonkey/2.12.1""",
"""MIA DEV/search:robot/0.0.1 (This is the MIA Bot - crawling for mia research project. If you feel unhappy and do not want to be visited by our crawler send an email to spider@neofonie.de; http://spider.neofonie.de; spider@neofonie.de)""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.4; en-US; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de-DE) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.A.B.C Safari/525.13""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Android Tablet""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.3; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; AskTbCFTP2V5/5.14.1.20007)""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Linux; Android 4.0.4; GT-I9100 Build/IMM76D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A403 Safari/8536.25""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YE""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:11.0) Gecko/20100101 Firefox/11.0 Iceweasel/11.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 5.10 (build 5310); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.92 Safari/537.4""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 5.10 (build 5339); ru) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.7.62 Version/11.00""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.92 Safari/537.4""",
"""Opera/9.80 (Windows NT 5.2; U; en) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/5.0 (iPad; CPU OS 5_1 like Mac OS X; en-us) AppleWebKit/534.46 (KHTML, like Gecko) Version/5.1 Mobile/9B176 Safari/7534.48.3""",
"""Mozilla/5.0 (Linux; Android 4.1.1; Nexus 7 Build/JRO03D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Safari/535.19""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; de-de; SAMSUNG GT-I9100/I9100BOLPD Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.92 Safari/537.4""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3_2 like Mac OS X; en-us) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8H7 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows NT 6.1; rv:15.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.92 Safari/537.4""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6; MRA 5.10 (build 5339); User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1); .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C; .NET4.0E; MRIE8PACK 2.0.1)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""RapidMiner""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; de) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.10) Gecko/20070306 SeaMonkey/1.0.8""",
"""Mozilla/5.0 (X11; FreeBSD i386; rv:6.0.1) Gecko/20100101 Firefox/6.0.1""",
"""Mozilla/5.0 (Windows NT 5.2; rv:2.0.1) Gecko/20100101 Firefox/4.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30707; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 5.10 (build 5339); ru) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 5.8 (build 4598); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534+ (KHTML, like Gecko) BingPreview/1.0b""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/536.26.14 (KHTML, like Gecko) Version/6.0.1 Safari/536.26.14""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.8; de; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (iPad; U; CPU OS 4_2_1 like Mac OS X; ja-jp) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.517.8 Safari/534.7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.79 Safari/535.11""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1""",
"""Mozilla (X; MasterOS; rv:X) Firefox""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YI""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16 WebMoney Advisor""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.26.14 (KHTML, like Gecko) Version/6.0.1 Safari/536.26.14""",
"""Python-urllib/2.7""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A405 Safari/8536.25""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; chromeframe/22.0.1229.94)""",
"""Mozilla/5.0 (compatible; archive.org_bot +http://www.archive.org/details/archive.org_bot)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Opera/9.80 (X11; Linux x86_64; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/5.0 Firefox/5.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (X11; Linux; rv:2.0.1) Gecko/20100101 Firefox/4.0.1 Midori/0.4""",
"""Mozilla/5.0 (Linux; Android 4.1.2; Nexus 7 Build/JZO54K) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Safari/535.19""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A403 Safari/8536.25""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; InfoPath.3)""",
"""TERRYMozilla/5.0 (Macintosh; U; PPC Mac OS X; en) AppleWebKit/312.8 (KHTML, like Gecko) Safari/312.6.9-rb.pp.terr-042012.www""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0; NP06; tb-webde/1.7.0; MSNIE9A)""",
"""Yandex/1.01.001 (compatible; Win16; H)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.46 Safari/535.11 MRCHROME""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.6.30 Version/10.63""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:15.0) Gecko/20120830 Firefox/15.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.4 (KHTML, like Gecko) Ubuntu/12.10 Chromium/22.0.1229.94 Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Windows NT 6.1; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (compatible; Mail.RU_Bot/2.0)""",
"""Mozilla/5.0 (Windows NT 5.2; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; SonyEricssonSK17i Build/4.1.B.0.587) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; generic) AppleWebKit/537.4 (KHTML, like Gecko; Google Web Preview) Version/4.0 Mobile Safari/537.4""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) konqueror/4.8.5 Safari/534.34""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 6.0 (build 5711); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.96 Safari/537.4""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.15 (KHTML, like Gecko) Chrome/24.0.1295.0 Safari/537.15""",
"""Mozilla/5.0 (Windows NT 5.1; rv:16.0) Gecko/20121026 Firefox/16.0 SeaMonkey/2.13.2 Lightning/1.8""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; WebMoney Advisor; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.30618; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.10.229 Version/11.62""",
"""Opera/9.80 (Windows NT 5.1; U; Edition Yx; ru) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/28.2794; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.22+ (KHTML, like Gecko) Chromium/17.0.963.56 Chrome/17.0.963.56 Safari/535.22+ jumanji/0.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; it; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16""",
"""Mozilla/5.0 (iphone;CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A403 Safari/8536.25""",
"""Mozilla/5.0 (iPhone;CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A403 Safari/8536.25""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.0.13) Gecko/2009073022 Firefox/3.0.13 (.NET CLR 3.5.30729) FBSMTWB""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET4.0C; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""AsyncHttpClient/1.0 (NettyAsyncHttpProvider - Linux - 2.6.32-5-amd64 - 1.6.0_18 - 8 core(s))""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.1 Safari/537.17""",
"""Wget/1.14 (linux-gnu)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows Phone OS 7.5; Trident/5.0; IEMobile/9.0; NOKIA; Lumia 800)""",
"""Mozilla/5.0 (Linux; U; Android 2.3; en-us; GT-I9100 Build/GRH78) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_3) AppleWebKit/534.55.3 (KHTML, like Gecko) Version/5.1.3 Safari/534.53.10""",
"""Mozilla/5.0 (iPad; U; CPU iPhone OS 3_2 like Mac OS X; en-US) AppleWebKit/531.21.10 (KHTML, like Gecko) Mobile/7D11""",
"""Mozilla/5xx.0 (iPad; U; CPU iPhone OS 3_2 like Mac OS X; en-US) AppleWebKit/531.21.10 (KHTML, like Gecko) Mobile/7D11""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0)""",
"""windoof/13 (compatible; MSIE 18.0; Windows NT 8; WOW124; Trident/7.0)""",
"""Opera/9.80 (Windows NT 5.1; U; de) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 5.1; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.96 Safari/537.4""",
"""Explore 6.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Opera/9.80 (Windows NT 6.0; U; de) Presto/2.10.289 Version/12.02""",
"""ÐŸÑ€Ð¸Ð²ÐµÑ‚, isden!""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.26773/28.2859; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Opera/9.80 (X11; Linux i686; U; Edition Linux Mint; de) Presto/2.10.289 Version/12.02""",
"""Opera/9.80 (Windows NT 6.1; U; de) Presto/2.10.289 Version/12.02""",
"""AwesomeSpider Java/1.6.0_37""",
"""Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.9.2.26) Gecko/20120130 Red Hat/3.6-1.el5_7 Firefox/3.6.26""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; en) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/536.26.17 (KHTML, like Gecko) Version/6.0.2 Safari/536.26.17""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0_1 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A523 Safari/8536.25""",
"""Firefox 5""",
"""Firefox 4""",
"""Internet Explorer 6""",
"""Firefox 6""",
"""Mozilla/5.0 (Linux; U; Android 2.3.5; de-de; HTC_DesireS_S510e Build/GRJ90) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Windows NT 5.1; rv:16.0) Gecko/20100101 Firefox/16.0 AlexaToolbar/alxf-2.17""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Yx; ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.5 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/22.0.1207.1 Safari/537.1""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; ARCHOS 101G9 Build/Clean_Slim&Fast_V.0.2) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Internet Explorer 10""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.1.16) Gecko/20120421 Firefox/11.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0.2 klaatu_barada_niktu_4.7""",
"""Mozilla/4.0 (compatible; MSIE 7.0; TOB 6.06; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; T-Brand-RC)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.4; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; SlimBrowser/6.01.085)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; Win64; x64; Trident/6.0)""",
"""Mozilla/5.0 (compatible; Infohelfer/1.3.3; +http://www.infohelfer.de/crawler.php)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0.2 klaatu/barada/niktu (4.7) Heia Safari/537.11 gzipfel(gfe)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.9.168 Version/11.52""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.164 Safari/535.19 YE""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; BRI/2; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; HTC_Desire_X Build/IMM76D) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/16.0 (Windows NT 6.1; WOW64; rv:8.0.1)""",
"""Mozilla/5.0 (Linux; Android 4.0.4; HTC Desire X Build/IMM76D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/5.0 (Android; Mobile; rv:16.0) Gecko/16.0 Firefox/16.0""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8A293 Safari/6531.22.7""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; de-de; GT-P5110 Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.26.17 (KHTML, like Gecko) Version/6.0.2 Safari/536.26.17""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.19 (KHTML, like Gecko) Chrome/25.0.1323.1 Safari/537.19""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; yie8)""",
"""Internet Explorer 7""",
"""Mozilla/5.0 (compatible; AhrefsBot/4.0; +http://ahrefs.com/robot/)""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows Phone OS 7.5; Trident/5.0; IEMobile/9.0; NOKIA; Lumia 900)""",
"""Yahoo Slurp bot""",
"""Mozilla/5.0 (Windows NT 5.1; rv:9.0.1) Gecko/20100101 sb12itkr20111230 Firefox/9.0.1""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.11 (KHTML, like Gecko) Ubuntu/12.04 Chromium/20.0.1132.47 Chrome/20.0.1132.47 Safari/536.11""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0) chromeframe/10.0.648.205""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.3; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.18 (KHTML, like Gecko) Chrome/18.0.1010.1 Safari/535.18""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:15.0) Gecko/20120427 Firefox/15.0a1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/527 (KHTML, like Gecko, Safari/419.3) Arora/0.6 (Change: )""",
"""SAMSUNG-GT-C3530/1.0 NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Opera/9.80 (Android; Opera Mini/7.5.31657/28.3126; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Android; Mobile; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_5; en-us) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.2 Safari/525.20.1""",
"""Opera/9.80 (X11; Linux zbov) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; MSN Optimized)""",
"""Mozilla/6.0 (compatible; MSIE 9.0; Windows NT 5.1; Trident/6.0; IAVC60-00000000; IAVC60-00000000; IAV80-00000000) Firefox/16.0.1""",
"""Ruby""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Pixray-Seeker/2.0 (Pixray-Seeker; +http://www.pixray.com/pixraybot; +crawler@pixray.com)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.23) Gecko/20090910 SeaMonkey/1.1.18""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/28.3126; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.4 (KHTML, like Gecko) Chrome/19.0.1079.0 Safari/536.4""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11 AlexaToolbar/alxg-3.1""",
"""Vimprobable2 (X11; U; Linux; en-US) AppleWebKit/536.2+ Compatible (Safari)""",
"""Vimprobable2/1.2.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_2; cs-cz) AppleWebKit/525.13 (KHTML, like Gecko) Version/3.1 Safari/525.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Mozilla/5.0 (Linux; U; Android 2.2.1; en-ca; LG-P505R Build/FRG83) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (Compatible); URLBase 6""",
"""12345	"""
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""PHP/5.2.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:7.0.1) Gecko/20100101 Firefox/10.0a4""",
"""Mozilla/5.0 (Windows NT 5.1; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (compatible; +http://www.evri.com/evrinid)""",
"""Mozilla/5.0 (X11; Linux i686; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11 AlexaToolbar/alxg-3.1""",
"""Opera/9.80 (X11; Linux x86_64) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:16.0) Gecko/20100101 Firefox/16.0 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (iPad; U; CPU iPhone OS 5_0_1 like Mac OS X; en_US) AppleWebKit (KHTML, like Gecko) Mobile [FBAN/FBForIPhone;FBAV/4.1;FBBV/4100.0;FBDV/iPad1,1;FBMD/iPad;FBSN/iPhone OS;FBSV/5.0.1;FBSS/1; FBCR/;FBID/tablet;FBLC/en_US;FBSF/1.0]""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; GTB7.4; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.3)""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.56 Safari/536.5""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.3234; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""MIA DEV/search:robot/0.0.1 (MIA Bot for research project MIA (www.MIA-marktplatz.de); http://spider.neofonie.de; spider-l@neofonie.de)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; GTB7.4; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; BRI/1; MAPB; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1250.0 Iron/22.0.2150.0 Safari/537.4""",
"""browser/2.0 CFNetwork/548.1.4 Darwin/11.0.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Macos; U; CPU OS 3_2 like Mac OS X; en-us)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.1 (KHTML, like Gecko) Ubuntu/12.04 Chromium/22.0.1201.0 Chrome/22.0.1201.0 Safari/537.1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 5.1; rv:17.0.1) Gecko/20100101 Firefox/17.0.1 x""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.10""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.11""",
"""Opera/7.0 (SunOS 5.8 sun4m; U) [en]""",
"""Mozilla/5.0 (compatible; 008/0.85; http://www.80legs.com/webcrawler.html) Gecko/2008032620""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/4.01 [en](Win95;I)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0)""",
"""Opera/15.51 (X11; Linux i386; U; de)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.66 Safari/535.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1309.0 Safari/537.17""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; FunWebProducts)""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.7.4; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Linux; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; Edition Next; Edition Yx; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (compatible; Mail.RU_Bot/2.0; +http://go.mail.ru/help/robots)""",
"""Mozilla/5.0 (X11; U; Linux amd64; en-US; rv:5.0) Gecko/20110619 Firefox/5.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.101 Safari/537.11""",
"""Opera/9.80 (Windows NT 6.0; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.0 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.3 Safari/537.22""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.40 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.91 Safari/534.30""",
"""Mozilla/5.0 (X11; OpenBSD i386; rv:13.0) Gecko/20100101 Firefox/13.0.1""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows; U; WinNT4.0; en-CA; rv:0.9.4) Gecko/20011128 Netscape6/6.2.1""",
"""Mozilla/5.0 (Series40; NokiaX2-05/08.35; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.2.0.0.33""",
"""Mozilla/5.0 (iPad; CPU OS 6_0_1 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A523 Safari/8536.25""",
"""Mozilla/5.0 (Java; U; en-us; nokiae72-1) AppleWebKit/530.13 (KHTML, like Gecko) UCBrowser/8.5.0.185/84/352/UCWEB Mobile UNTRUSTED/1.0 3gpp-gba""",
"""UCWEB/2.0(Java; U; MIDP-2.0; en-US; nokiae72-1) U2/1.0.0 UCBrowser/8.8.0.227 U2/1.0.0 Mobile UNTRUSTED/1.0 3gpp-gba""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11 AppEngine-Google; (+http://code.google.com/appengine; appid: fishvpn)""",
"""Mozilla/5.0 (Linux; U; Android 2.3.4; de-de; SonyEricssonLT18i Build/4.0.2.A.0.69) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.12""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/28.3392; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.19 (KHTML, like Gecko) Chrome/25.0.1323.1 Safari/537.19""",
"""JUC(Linux;U;Android2.3.4;Zh_cn;LT18i;480*854;)UCWEB7.8.0.95/139/444""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.101 Safari/537.11""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-ch; GT-I9300 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.28) Gecko/20120306 Firefox/5.0 (de)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.21022; Media Center PC 6.0)""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 GTB7.1 WebMoney Advisor""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (compatible; Plukkie/1.5; http://www.botje.com/plukkie.htm)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0 SeaMonkey/2.15""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 5.10 (build 5339); ru) Presto/2.10.289 Version/12.00""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.12""",
"""Java/1.7.0_10""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.7 (KHTML, like Gecko) RockMelt/0.16.91.483 Chrome/16.0.912.77 Safari/535.7""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1300.0 Iron/23.0.1300.0 Safari/537.11""",
"""Mozilla/5.0 (iPad; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A403 Safari/8536.25""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:10.0.11) Gecko/20100101 Firefox/10.0.11""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.12""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.3; Tablet PC 2.0)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; XBLWP7; ZuneWP7)""",
"""dasf31rfafsafsaf21rqfa""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.101 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:15.0) Gecko/20120716 Firefox/15.0a2""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.11) Gecko/20100101 Firefox/10.0.11 Iceweasel/10.0.11""",
"""Opera/9.80 (Windows NT 5.1; Edition Ukraine Local) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:17.0) Gecko/20100101 Firefox/17.0 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.20) Gecko/20081217 Firefox/3.6.3 (.NET CLR 3.5.30729) Mnenhy/0.7.6.666""",
"""Mozilla/5.0 (Windows NT 6.1; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.3392; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4322; .NET CLR 2.0.40607; .NET CLR 3.0.30729; .NET CLR 3.5.30707)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.26 Safari/537.22""",
"""Opera/9.80 (X11; Linux x86_64; Edition Linux Mint) Presto/2.12.388 Version/12.12""",
"""Mozilla/5.0 (X11; Linux i686; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:17.0; WUID=5d6b36fcf611c49443373138a3c71dea; WTB=592) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.1; re:18.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/28.3445; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/18.6.861.0 Safari/535.2""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.4) Gecko/2008102920 Firefox/9.0.4 (Splashtop-v1.0.5.0)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64; Edition Next) Presto/2.12.378 Version/12.50""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.8) Gecko/20100101 Firefox/10.0.8""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""crawl-66-249-66-1.googlebot.com""",
"""FeedFetcher-Google; ( http://www.google.com/feedfetcher.html)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; MS-RTC LM 8; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) YaBrowser/1.1.1084.5410 Chrome/19.1.1084.5410 Safari/536.5""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.11 (KHTML, like Gecko) Ubuntu/12.04 Chromium/20.0.1132.47 Chrome/20.0.1132.47 Safari/536.11""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.4; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 ( .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/5.0 (Linux; U; Android 2.3.6; de-de; GT-I9001 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/7.0 (compatible; MSIE 10.0; Linux 2.6.26.-1-amd64) Lobo/0.98.3""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; Maxthon/3.0)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0; BOIE9;DEDEMSE)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (X11; Linux x86_64; U; ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.3; Tablet PC 2.0)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:10.0.3) Gecko/20100101 Firefox/10.0.3""",
"""Mozilla/5.0 (Windows NT 6.0; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""(Linux; Cray)""",
"""Opera/9.80 (Windows NT 6.2; WOW64; Edition Campaign 21) Presto/2.12.388 Version/12.12""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; de-de; SAMSUNG GT-I9100/I9100BUKG2 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; .NET4.0C; .NET4.0E; MS-RTC EA 2; MS-RTC LM 8)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.7 (KHTML, like Gecko) Chrome/16.0.912.63 Safari/535.7 MRCHROME""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-us; Sprint APA9292KT Build/FRF91) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:10.0.10) Gecko/20100101 Firefox/10.0.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.36 (KHTML, like Gecko) Chrome/13.0.767.1 Safari/534.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.31891/28.3590; U; pt) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Opera/9.80 (Windows NT 5.1; MRA 6.0 (build 6001)) Presto/2.12.388 Version/12.12""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17 AlexaToolbar/alxg-3.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/28.3590; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (BlackBerry; Opera Mini/7.1.32723/28.3590; U; en) Presto/2.8.119 Version/11.10""",
"""lwp-trivial/1.35""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.12) Gecko/20130109 Firefox/10.0.12""",
"""Mozilla/5.0 (X11; Linux i686; rv:18.0) Gecko/20100101 Firefox/18.0 Iceweasel/18.0.1""",
"""Mozilla/5.0 (X11; U; Linux; de-de; rv:1.9.0.2) Gecko/2008092313 Firefox/3.8 Midori/0.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1.0 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.27 (KHTML, like Gecko) Chrome/26.0.1386.0 Safari/537.27""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.30568/28.3590; U; tr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Wget/ (linux-gnu)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.3; MS-RTC LM 8)""",
"""Mozilla/4.0 (compatible; MSIE 6.0b; Windows NT 5.0; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.9.0.3) Gecko/20100101 Ubuntu/8.04 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.0 (KHTML, like Gecko) Chrome/3.0.195.33 Safari/532.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1104.222 YaBrowser/1.5.1104.222 Safari/537.4""",
"""system('ls');""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/28.3590; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Opera/9.80 (Bada; Opera Mini/6.5/28.3590; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Series40; Nokia311/05.92; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.3.0.0.48""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; WOW64; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Linux; U; Android 2.2.2; en-us; LG-US670 Build/FRG83G) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/6.0 (Windows NT 6.2; WOW64; rv:18.0.1) Gecko/20121011 Firefox/18.0.1""",
"""Opera/9.5 (X11; U; pt)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Chrome/5.0.375.53 Safari/533.4""",
"""Opera/9.80 (X11; Linux x86_64; U; de_AT) Presto/2.9.168 Version/12.00""",
"""Mozilla/5.0 (Windows NT 5.1; rv:15.4) Gecko/20130114 Firefox/15.4 PaleMoon/15.4""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.36 Safari/537.22""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/4.0)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_6) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.202 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.28000/28.3692; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:21.0) Gecko/20130130 Firefox/21.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.100 Safari/534.30""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21214/28.3692; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.56 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.11 (KHTML, like Gecko) Ubuntu Chromium/23.0.1271.97 Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; en-us; HTC One V Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; SV1)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1 en-US; rv: 1.9.0.10)Gecko/2009042316 FireFox/3.0.16""",
"""Opera/9.80 (S60; SymbOS; Opera Mobi/SYB-1204232254; U; ru) Presto/2.10.254 Version/12.00""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/28.3692; U; sr) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 6.0 (build 5970); ru) Presto/2.7.62 Version/11.00""",
"""SonyEricssonJ108i/R7DA Profile/MIDP-2.1 Configuration/CLDC-1.1 UNTRUSTED/1.0 UCWEB/2.0(Java; U; MIDP-2.0; fa; sonyericssonj108i) U2/1.0.0 UCBrowser/8.7.1.234 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.0; Trident/4.0; InfoPath.1; SV1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 3.0.04506.30)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E; MS-RTC LM 8; CIBA)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.13907/28.3692; U; tr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.68 Safari/537.17""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.12) Gecko/20100101 Firefox/10.0.12 Iceweasel/10.0.12""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.69 Safari/537.17""",
"""Opera/9.80 (X11; Linux i686) Presto/2.12.388 Version/12.14""",
"""Opera/9.85 (Macintosh; Intel Mac OS X; U; en)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:18.0) Gecko/20100101 Firefox/18.0 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (Windows NT 6.1; rv:18.0) Gecko/20100101 Firefox/18.0 AlexaToolbar/alxf-2.17""",
"""Opera/7.54 (Ubuntu; U) [pl]""",
"""TosCrawler/Nutch-1.6 (http://www.toshiba.co.jp/rdc/about/crawl_info_en.htm; 'Rdc-crawler at ml dot toshiba dot co dot jp')""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; WOW64; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; SLCC2)""",
"""Opera/9.80 (X11; Linux x86_64) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.31380/28.3782; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; GT-I9300 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Ubuntu Chromium/24.0.1312.56 Chrome/24.0.1312.56 Safari/537.17""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini; U; id) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.70 Safari/537.17""",
"""Opera/9.80 (Windows NT 5.1; Edition Yx) Presto/2.12.388 Version/12.10""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (SymbianOS/9.4; Series60/5.0 NokiaN97-1/21.0.045; Profile/MIDP-2.1 Configuration/CLDC-1.1) AppleWebKit/525 (KHTML, like Gecko) BrowserNG/7.1.4""",
"""Opera/9.80 (Windows NT 5.1; MRA 6.0 (build 6001)) Presto/2.12.388 Version/12.14""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/28.3821; U; fr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-CH; rv:18.0) Gecko/20110920 Firefox/18.0.2""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.29974/28.3821; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:20.0) Gecko/20130214 Firefox/20.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.10) Gecko/2009120809 Firefox/3.0.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Maxthon/4.0.3.1000 Chrome/22.0.1229.79 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (Windows NT 6.1; MRA 6.0 (build 5970)) Presto/2.12.388 Version/12.10""",
"""Nokia2700c-2/2.0 (09.97) Profile/MIDP-2.1 Configuration/CLDC-1.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.3; AskTB5.6)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3; .NET4.0C)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows Phone OS 7.5; Trident/5.0; IEMobile/9.0; SAMSUNG; OMNIA7)""",
"""Mozilla/5.0 (SymbianOS/9.3; U; Series60/3.2 NokiaN78-1/30.011; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""NokiaC2-00/2.0 (03.45) Profile/MIDP-2.1 Configuration/CLDC-1.1 UNTRUSTED/1.0""",
"""curl/7.19.7 (x86_64-redhat-linux-gnu) libcurl/7.19.7 NSS/3.13.1.0 zlib/1.2.3 libidn/1.18 libssh2/1.2.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.84 Safari/537.22""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.3821; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.31891/28.3821; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.70 Safari/537.17""",
"""Mozilla/5.0 (Linux; Android 4.1.1; SCH-I605 Build/JRO03C) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.22) Gecko/20110902 Firefox/3.6.22""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; InfoPath.3)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/28.3821; U; ta) Presto/2.8.119 Version/11.10""",
"""Nokia6120c/3.83; Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.14""",
"""Opera/9.30 (Nintendo Wii; U; ; 3642; de)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.2.15) Gecko/20110303 Firefox/3.6.15 (.NET CLR 3.5.30729) WebMoney Advisor""",
"""Mozilla/5.0 (iPhone; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A405 Safari/8536.25""",
"""Opera/9.80 (Windows NT 5.1; Edition Yx) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""SAMSUNG-GT-S5230/S523MXEKE1 SHP/VPP/R5 Jasmine/1.0 Nextreaming SMM-MMS/1.2.0 profile/MIDP-2.1 configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; U;WOW64; de;rv:11.0) Gecko Firefox/11.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4 u01-09""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14320/28.3950; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.0; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32445/28.3950; U; tr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; MSIE 10.6; Windows NT 6.2; Trident/5.0; InfoPath.2; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727) 3gpp-gba UNTRUSTED/1.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.99 Safari/537.22 FirePHP/4Chrome""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.15) Gecko/20110324 Gentoo Namoroka/3.6.15""",
"""Wget/1.11.4 Red Hat modified""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""SolomonoBot/1.04 (http://www.solomono.ru)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3""",
"""Opera/9.80 (Series 60; Opera Mini/6.7.29868/28.4043; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (compatible; Dataprovider Site Explorer; http://www.dataprovider.com/)""",
"""User-Agent: Mozilla/5.0 (Windows NT 6.2; Roctopuss; hexar web design; WOW64; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.0.24093/28.4079; U; tk) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:22.0) Gecko/20130301 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.60 Safari/537.17""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.13) Gecko/20080313 Firefox""",
"""Epic browser is epic (v1.3.37 Rev. 07)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.A.B.C Safari/525.13""",
"""OpenWebIndex/Nutch-1.6""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; MRA 5.8 (build 4157); .NET CLR 2.0.50727; AskTbPTV/5.11.3.15590) AppEngine-Google; (+http://code.google.com/appengine; appid: dai-zong)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; qdesk 2.5.1270.201; Windows NT 6.1; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.2; WOW64; Trident/5.0)""",
"""NokiaX2-01/5.0 (08.63) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html) UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 5.1; en-US) AppleWebKit/535.12 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/535.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1;)""",
"""Opera/9.80 (Windows NT 5.1; MRA 6.0 (build 5831)) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.162 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Beamrise/2.23.1273.3475 Chrome/23.0.1271.97 Safari/537.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022).""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""it2media-domain-crawler/1.0 on crawler-prod.it2media.de""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22 AlexaToolbar/alxg-3.1""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.7.62 Version/11.00""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 5.1; rv:19.0) Gecko/20130220 Firefox/19.0""",
"""Opera/9.25 (Windows NT 5.1; U; en)""",
"""Mozilla/5.0 (compatible; CompSpyBot/1.0; +http://www.compspy.com/spider.html)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; GTB6; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; ru) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:22.0) Gecko/20130308 Firefox/22.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MDDR; .NET4.0C; .NET4.0E; .NET CLR 1.1.4322; Tablet PC 2.0); 360Spider""",
"""Mozilla/5.0 (Linux; Android 4.0.4; GT-I9100 Build/IMM76D) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.123 Mobile Safari/537.22""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/28.4150; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; GT-I9100 Build/IMM76D) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.19 Safari/537.31""",
"""InboundScore/Nutch-1.4 (http://InboundScore.com/)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.60 Safari/537.17""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; Win64; x64; Trident/6.0; MALCJS)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Ubuntu Chromium/25.0.1364.160 Chrome/25.0.1364.160 Safari/537.22""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1a2pre) Gecko/2008073000 Shredder/3.0a2pre ThunderBrowse/3.2.1.8""",
"""Mozilla/5.0 (compatible; SiteExplorer/1.0b; +http://siteexplorer.info/)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.34 (KHTML, like Gecko) QupZilla/1.3.5 Safari/534.34""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 5.1; Trident/5.0)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.160 Safari/537.22""",
"""Mozilla/5.0 (C64) Gecko Firefox/6""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; chrome://navigator/locale/navigator.properties; rv:1.8.1) Gecko/20080527 TWebBrowser""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:19.0) Gecko/20100101 Firefox/19.0 Iceweasel/19.0""",
"""Opera/9.80 (Windows NT 6.2; WOW64) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.160 Safari/537.22""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; en-US) AppleWebKit/125.4 (KHTML, like Gecko, Safari) OmniWeb/v563.15""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; MAMD)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; .NET4.0C)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20130220 Firefox/17.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/19.0.2 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 55543423""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.33 (KHTML, like Gecko) Chrome/27.0.1440.0 Safari/537.33""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.169 Mobile Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.34 (KHTML, like Gecko) Dooble/1.40 Safari/534.34""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.33 Safari/535.11""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:12.0) Gecko/20100101 Firefox/12.0""",
"""Java/1.6.0_22""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Java/1.7.0_17""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 5_1_1 like Mac OS X; da-dk) AppleWebKit/534.46.0 (KHTML, like Gecko) CriOS/19.0.1084.60 Mobile/9B206 Safari/7534.48.3""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/28.4200; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; MSIE 9.0 STA-ARC/JEHRE/B_UhgT}!+GaBGf; Windows NT 6.1; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.2; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; Media Center PC 6.0; MASE; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; BRI/2)""",
"""GODzilla/6.0 (X11; Knoppix x86_128; rv:16.0) Gecko/20140101 Firefox/33.3.13""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.4; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.2; Tablet PC 2.0; BRI/2)""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 8.0 (build 5784); ru) Presto/2.10.289 Version/12.02""",
"""Java/1.6.0_25""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YE""",
"""Opera/9.80 (Windows NT 5.1; MRA 6.0 (build 5998)) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.8.0.11) Firefox/1.5.0.11; 360Spider""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36+ (KHTML, like Gecko) Version/6.0.3 Safari/536.28.10""",
"""Java/1.7.0_13""",
"""Aladin/3.324""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) YaBrowser/1.1.1084.5409 Chrome/19.1.1084.5409 Safari/536.5""",
"""Opera/9.80 (Windows NT 6.1; WOW64; MRA 6.0 (build 5998)) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.32 (KHTML, like Gecko) Chrome/27.0.1425.2 Safari/537.32""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.21 (KHTML, like Gecko) Chrome/25.0.1349.2 Safari/537.21""",
"""Mozilla/5.0 (masking-agent; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""libwww-perl/6.05""",
"""Opera/9.80 (Windows NT 6.1; U; en) Presto/2.8.131 Version/11.52""",
"""Opera/9.80 (Windows NT 6.1; MRA 6.0 (build 6001)) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (X11; FreeBSD amd64; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Lynx/2.8.5rel.5 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/1.0.1e""",
"""Opera/9.80 (Windows NT 6.2; Win64; x64; Edition Campaign 21) Presto/2.12.388 Version/12.14""",
"""Gallent Search Spider v1.4 Robot 2 (http://robot.GallentSearch.com)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.57 Safari/537.17""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.40 Safari/537.31""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:14.0) Gecko/20100101 Firefox/14.0.1 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6;W-XP (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/25.0.1363.100 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/25.0.1363.100 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 5.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/25.0.1363.100 Safari/537.17""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Opera/9.80 (Windows NT 6.2; WOW64; MRA 8.0 (build 5784)) Presto/2.12.388 Version/12.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; MRA 6.0 (build 5993); MRA 8.0 (build 5784); InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Readability/4824a0 - http://readability.com/about/""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; BTRS28059; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; FreeBSD x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""Mozilla/5.0 (compatible; Commodore Amiga 500; rv:5.0.1) Gecko/20100101 Firefox/5.0.1""",
"""BacklinkCrawler V (http://www.backlinktest.com/crawler.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YI""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; Win64; x64; Trident/5.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.4; MRA 6.0 (build 6005); User-agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1); .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C; .NET4.0E; MRIE8PACK 2.0.1)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:22.0) Gecko/20130330 Firefox/22.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; EN; rv:1.9.0.6) Gecko/2009011913 Firefox/3.0.6""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1250.0 Iron/22.0.2150.0 Safari/537.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:2.0.1) Gecko/20100101 Firefox/4.0.1 Camino/2.2.1""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/29.3134; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""HTTP_Request2/2.1.1 (http://pear.php.net/package/http_request2) PHP/5.3.2-1ubuntu4.18""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.41 Safari/535.1""",
"""Mozilla/6.0 (Windows NT 6.2; WOW64; rv:16.0.1) Gecko/20121011 Firefox/16.0.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.4; de; rv:1.9.2.27) Gecko/20120216 Firefox/3.6.27""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/536.28.10 (KHTML, like Gecko) Version/6.0.3 Safari/536.28.10""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Linux; U; Android 1.5; ru-ru; HTC Magic Build/CRB17) AppleWebKit/528.5+ (KHTML, like Gecko) Version/3.1.2 Mobile Safari/525.20.1""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32445/29.3183; U; vi) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:7.0) Gecko/20110814 Firefox/7.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Opera/9.80 (X11; Linux i686) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (masking-agent; rv:10.0.12) Gecko/20100101 Firefox/10.0.12 Iceweasel/10.0.12""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (X11; U; Linux i686; it; rv:1.9.0.4) Gecko/2008102920 Firefox/3.0.4""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (iPad; CPU OS 6_1 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B141 Safari/8536.25""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_2_1 like Mac OS X; da-dk) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8C148 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19 YB/3.5.1 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.2; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.2) Gecko/20090803 Ubuntu/9.04 (jaunty) Shiretoko/3.5.2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""ELinks/0.12~pre5-2ubuntu1 (textmode; Ubuntu; Linux 3.0.0-32-generic x86_64; 80x17-2)""",
"""Links (2.2; Linux 3.0.0-32-generic x86_64; 80x17)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:19.0) Gecko/20100101 Firefox/19.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.22 (KHTML, like Gecko) Ubuntu Chromium/25.0.1364.160 Chrome/25.0.1364.160 Safari/537.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.21pre) Gecko K-Meleon/1.7.0""",
"""Opera/9.80 (Windows NT 6.1; YB/1.4) Presto/2.12.388 Version/12.15""",
"""Opera/9.80 (Windows NT 6.2; WOW64; MRA 8.0 (build 5784)) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Windows NT 6.0; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.0; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/29.3183; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.63 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; TencentTraveler)""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_2 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B146 Safari/8536.25""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/4.0 (compatible; AvantGo 6.0; FreeBSD) Browser""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:18.0) Gecko/20130119 Firefox/18.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:23.0) Gecko/20130409 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Opera/9.80 (X11; Linux x86_64) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:23.0) Gecko/20130411 Firefox/23.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:10.0.12) Gecko/20100101 Firefox/10.0.12 Iceweasel/10.0.12""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 1.0.3705)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:23.0) Gecko/20130412 Firefox/23.0""",
"""Opera/9.80 (Android 2.3.6; Linux; Opera Mobi/ADR-1301071820) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; U; FreeBSD i686; en-US; rv:1.8) Gecko/20060202 Firefox/1.5""",
"""Opera/9.80 (Windows NT 6.1; Edition Yx) Presto/2.12.388 Version/12.11""",
"""curl/7.22.0 (i686-pc-linux-gnu) libcurl/7.22.0 OpenSSL/1.0.1 zlib/1.2.3.4 libidn/1.23 librtmp/2.3""",
"""curl/7.21.6 (i686-pc-linux-gnu) libcurl/7.21.6 OpenSSL/1.0.0e zlib/1.2.3.4 libidn/1.22 librtmp/2.3""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; en) Opera 9.00""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:23.0) Gecko/20130409 Firefox/23.0""",
"""Mozilla/5.0 (Android; Tablet; rv:13.0) Gecko/13.0 Firefox/13.0""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/29.3271; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 6.0; WOW64) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.2; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (MSIE 9.0; Windows NT 6.1; Trident/5.0)""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) )""",
"""Opera/9.80 (Android 4.1.2; Linux; Opera Mobi/ADR-1301080958) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; GT-I9305 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9305 Build/JZO54K) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.58 Mobile Safari/537.31""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6 Ara.com.tr AraBot 1.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.47 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/26.0.1410.50 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.28.10 (KHTML, like Gecko) Version/6.0.3 Safari/536.28.10""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; SonyLT30p Build/9.1.A.0.489) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Linux; Android 4.1.2; LT30p Build/9.1.A.0.489) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/6.0 (Windows NT 6.1; WOW64; rv:19.0.2) Firefox/19.0.2""",
"""Mozilla/6.0 (Windows NT 6.1) Firefox/18.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/29.3271; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/29.3271; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 5.1; zh-CN) AppleWebKit/535.12 (KHTML, like Gecko) Chrome/18.0.966.0 Safari/535.12""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3 like Mac OS X; de-de) AppleWebKit/533.17.9 (KHTML, like Gecko) Mobile/8F190""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Windows NT 5.1; rv:22.0) Gecko/20130407 Firefox/22.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:20.0) Gecko/20100101 Firefox/20.0 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:16.0) Gecko/20121017 Firefox/16.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.63 Safari/537.31""",
"""Mozilla/5.0 (compatible; Konqueror/4.4; Linux) KHTML/4.4.5 (like Gecko)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.16) Gecko/20121207 Firefox/6.0a2 (like Firefox/3.5.16)""",
"""curl/7.21.0 (x86_64-pc-linux-gnu) libcurl/7.21.0 OpenSSL/0.9.8o zlib/1.2.3.4 libidn/1.15 libssh2/1.2.6""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Win64; x64; Trident/4.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0; MDDRJS)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/25.0.1364.124 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Mobile/10B329""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; GT-I9100 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; SAMSUNG GT-I9305/I9305XXBLL5 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Opera/9.80 (Android; Opera Mini/7.5.32193/29.3271; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.58 Mobile Safari/537.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.63 Safari/537.31""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1) Gecko/20060601 Firefox/2.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.4; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 8.0 (build 5880); ru) Presto/2.10.289 Version/12.02""",
"""Opera/9.80 (Windows NT 6.0; WOW64; Edition Next) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31 AlexaToolbar/pY3K0Pfg-1.3""",
"""Midori/0.2 (X11; Linux; U; cs-cz) WebKit/531.2+""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31 AlexaToolbar/alxg-3.1""",
"""Opera/9.80 (Windows NT 6.1; Edition Yx) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0; EIE10;DEDEMSN)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.152 Safari/535.19 CoolNovo/2.0.3.55""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:20.0) Gecko/20130409 Firefox/20.0 PaleMoon/20.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.32 (KHTML, like Gecko) Chrome/27.0.1425.0 Safari/537.32 SUSE/27.0.1425.0""",
"""Opera/9.80 (Windows NT 6.2; WOW64) Presto/2.12.388 Version/12.11""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 3.5.30729; InfoPath.2)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1105.411 YaBrowser/1.5.1105.411 Safari/537.4""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Win64; x64; Trident/5.0; .NET CLR 2.0.50727; SLCC2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_2 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/26.0.1410.50 Mobile/10B146 Safari/8536.25""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.47 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; MRA 6.0 (build 5970)) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/29.3345; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/536.29.13 (KHTML, like Gecko) Version/6.0.4 Safari/536.29.13""",
"""Pimmellutscher/1.0 (PimmellutscherOS; Arschgeigen Edition; v1.1;lang=pimmel-LUTSCHER;)""",
"""Mozilla/5.0 (Macintosh; I; Intel Mac OS X 10.8; de-LI; rv:21.0) Gecko/20130303 Firefox/21.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31 AlexaToolbar/alxg-3.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; BTRS7465; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.63 Safari/537.31""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1485.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 2.0.50727; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.16) Gecko/20121207 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; BRI/2)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Yx; ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/26.0.1410.50 Mobile/10B329 Safari/8536.25""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/29.3345; U; ï»¿id) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Series 60; Opera Mini/6.1.25381/29.3345; U; id) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (X11; Linux x86_64; Edition Next) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (Windows NT 5.1; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Opera/9.80 (Windows NT 5.1; DepositFiles/FileManager 0.9.9.206 YB/5.0.3) Presto/2.12.388 Version/12.14""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/29.3345; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 5.1; U; YB/3.5.1; ru) Presto/2.10.229 Version/11.64""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/29.3345; U; am) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.56 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.2; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:20.0) Gecko/20100101 Firefox/20.0 FirePHP/0.7.2""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 Safari/537.22""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; OfficeLiveConnector.1.5; OfficeLivePatch.1.3)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.56 Safari/537.36""",
"""coccoc/1.0 (http://help.coccoc.vn/)""",
"""Mozilla/5.0 (Linux; Android 4.1.1; Nexus 7 Build/JRO03D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Safari/535.19""",
"""Opera/9.80 (Windows NT 6.2; Win64; x64) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.29.13 (KHTML, like Gecko) Version/6.0.4 Safari/536.29.13""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/26.0.1410.53 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 5.1; YPC 3.0.1; .NET CLR 1.1.4322; .NET CLR""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; staticlogin:product=cboxf2010&act=login&info=ZmlsZW5hbWU9UG93ZXJXb3JkMjAxME94Zl9VbHRpbWF0ZS5leGUmbWFjPTQ5MjRBRkQzQ0NBMjQ3MzVBRDIzNTI2Q0M4REQ1ODgwJnBhc3Nwb3J0PSZ2ZXJzaW9uPTIwMTAuNi4zLjYuMiZjcmFzaHR5cGU9MQ==&verify=178b80926d3e136ee3b16b184697f923; staticlogin:product=cboxf2010&act=login&info=ZmlsZW5hbWU9UG93ZXJXb3JkMjAxME94Zl9VbHRpbWF0ZS5leGUmbWFjPTQ5MjRBRkQzQ0NBMjQ3MzVBRDIzNTI2Q0M4REQ1ODgwJnBhc3Nwb3J0PSZ2ZXJzaW9uPTIwMTAuNi4zLjYuMiZjcmFzaHR5cGU9MA==&verify=17a9a620e369675b55ad6e21d93e5d22; MALC)""",
"""SAMSUNG-GT-C3303/C3303XXJG5 NetFront/4.0 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; Edition Next; Edition Yx; ru) Presto/2.11.310 Version/12.50""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31""",
"""Mozilla/5.0 (X11; Linux i686; rv:20.0) Gecko/20100101 Firefox/20.0 Iceweasel/20.0""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:22.0) Gecko/20130428 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YI""",
"""Opera/9.80 (Windows NT 5.1; U; ru) Presto/2.10.289 Version/12.01""",
"""MacOS""",
"""Mozilla/1.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:20.0) Gecko/20100101 Firefox/20.0 win8A""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:22.0) Gecko/20130429 Firefox/22.0""",
"""Mozilla/5.0 (Series40; NokiaC2-03/07.63; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.3.0.0.49""",
"""Opera/9.80 (Windows NT 6.1; U; Edition Next; ru) Presto/2.11.310 Version/12.50""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.13""",
"""Mozilla/5.0 (Macintosh; I; Intel Mac OS X 10.9; de-LI; rv:25.0) Gecko/20130303 Firefox/25.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/26.0.1450.0 Chrome/26.0.1450.0 Safari/537.36""",
"""MAUI_WAP_Browser""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; BTRS6335; GTB7.4; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.5; OfficeLivePatch.1.3; AskTbAVR-W1/5.15.11.30498)""",
"""Opera/9.80 (Android 2.3.5; Linux; Opera Mobi/ADR-1301080958) Presto/2.11.355 Version/12.10""",
"""* Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com""",
"""Mozilla/6.0 (compatible)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 1.1.4322; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; OfficeLiveConnector.1.3; OfficeLivePatch.0.0; yie8)""",
"""UCWEB/2.0 (Symbian; U; S60 V3; vi; NokiaC5-00.2) U2/1.0.0 UCBrowser/8.9.0.277 U2/1.0.0 Mobile""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32448/29.3507; U; vi) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/29.3507; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; Abonti/0.91 - http://www.abonti.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.9 (KHTML, like Gecko) Chrome/5.0.307.1 Safari/532.9""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21594/29.3530; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Iron/25.0.1400.0 Chrome/25.0.1400.0 Safari/537.22""",
"""Mozilla/4.0 (Windows; MSIE 6.0; Windows NT 5.0)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.20 (KHTML, like Gecko) Version/5.0.4 Safari/533.20""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.58.2 (KHTML, like Gecko) Version/5.1.8 Safari/534.58.2""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.97 Safari/537.22 AlexaToolbar/alxg-3.1""",
"""Opera/9.80 (Windows NT 6.1; WOW64; MRA 6.0 (build 6001)) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.1634 Safari/535.19 YE""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 5.9 (build 4876); ru) Presto/2.10.289 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1300.0 Iron/23.0.1300.0 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1105.412 YaBrowser/1.5.1105.412 Safari/537.4""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.30568/29.3530; U; tr) Presto/2.8.119 Version/11.10""",
"""SAMSUNG-GT-E3213K/E3213KJPKH1 NetFront/4.1 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""SAMSUNG-GT-E2652W/1.0 NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/10.10 Chromium/18.0.1025.151 Chrome/18.0.1025.151 Safari/535.19""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.31891/29.3530; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.31438/29.3594; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/29.3594; U; lt) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9.2.17) Gecko/20110420 Firefox/3.6.17 ( .NET CLR 3.5.30729; .NET4.0E) wn""",
"""Mozilla/5.0 (X11; U; Linux x86_64; fr; rv:1.9.1.16) Gecko/20121207 Iceweasel/3.5.16 (like Firefox/3.5.16)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:20.0) Gecko/20100101 Firefox/20.0""",
"""LG-KC550/V10f Teleca/WAP2.0 MIDP-2.0/CLDC-1.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.22296/29.3594; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux) KHTML/4.9.1 (like Gecko) Konqueror/4.9""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.11 (KHTML, like Gecko) DumpRenderTree/0.0.0.0 Safari/536.11""",
"""Opera/9.80 (Windows NT 6.2; WOW64) Presto/2.12.388 Version/12.15""",
"""Nokia1120/2.0 (03.32) Profile/MIDP-2.1 Configuration/CLDC-1.1 UNTRUSTED/1.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows Phone OS 7.5; Trident/5.0; IEMobile/9.0; HTC; HD7 T9292)""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""EXARP 0.6b (HTTP://UNNEX.DE)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.22+ (KHTML, like Gecko) Chromium/17.0.963.56 Chrome/17.0.963.56 Safari/535.22+ dwb/2013.04.24""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""openHPI""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:14.0 cit/browser/db) Gecko/20120716 Firefox/14.0""",
"""Opera/9.80 (iPhone; Opera Mini/5.0.0176/764; U; en) Presto/2.4.15""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; SV1; Maxthon; .NET CLR 1.1.4322; FDM)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0; EIE10;ENUSWOL)""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; de-de; Cynus T1 Build/IMM76D) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; Trident/6.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2)""",
"""Mozilla/5.0 (compatible; AcoonBot/4.11.1; +http://www.acoon.de/robot.asp)""",
"""Mozilla/5.0 (X11; Linux i686; rv:21.0) Gecko/20100101 Manjaro Linux/0.8.5 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.94 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/29.3638; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/27.0.1500.0 Chrome/27.0.1500.0 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20110814 Firefox/10.0.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_5_8; en-US) AppleWebKit/532.5 (KHTML, like Gecko) Chrome/4.0.249.0 Safari/532.5""",
"""Mozilla/5.0 (Windows NT 6.1; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.2; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.94 Safari/537.36 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; SonyLT30p Build/9.1.A.1.140) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.59.8 (KHTML, like Gecko) Version/5.1.9 Safari/534.59.8""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/27.0.1500.0 Chrome/27.0.1500.0 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0b; Windows NT 4.0)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.94 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.0.24093/29.3709; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; rv:11.0) Gecko/20100101 Firefox/11.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.14 (KHTML, like Gecko) Chrome/10.0.6 Safari/534.14""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/29.3709; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:23.0) Gecko/20130601 Firefox/23.0""",
"""Opera/9.80 (Windows NT 6.1; WOW64; MRA 6.0 (build 5976)) Presto/2.12.388 Version/12.11""",
"""Opera/9.60 (J2ME/MIDP; Opera Mini/4.2.13337/504; U; ru) Presto/2.2.0""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21594/29.3709; U; tr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.95 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; rv:21.0; WUID=85602fdd096f49f6d5451cdbea53059e; WTB=3927) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10.5; vi; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/30.3061; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 ('; rv:18.0) Gecko/20100101 Firefox/18.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/26.0.1450.0 Chrome/26.0.1450.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29476/30.3061; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:21.0) Gecko/20100101 Firefox/21.0 Iceweasel/21.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; MRA 6.0 (build 5976)) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Macintosh; PPC MacOS X; rv:5.0) Gecko/20110615 Firefox/25.0""",
"""Mozilla/5.0 (X11; U; Unix; en-US) AppleWebKit/537.15 (KHTML, like Gecko) Chrome/24.0.1295.0 Safari/537.15 Surf/0.6""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Unknown; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) PhantomJS/1.9.0 Safari/534.34""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:21.0) Gecko/20130602 Firefox/21.0""",
"""UC Browser8.2.0.116/147/400/UCWEB""",
"""SAMSUNG-GT-E2232/1.0 Openwave/6.2.3 Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Browser/6.2.3.3.c.1.101 (GUI) MMP/2.0""",
"""Opera/9.80 (Windows NT 5.1; U; Edition Yx; ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1468.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:2.0) Gecko/20100101 Firefox/4.0 (O. N.)""",
"""Mozilla/5.0 ... Gecko ... Firefox... (Olaf Naundorf)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/536.30.1 (KHTML, like Gecko) Version/6.0.5 Safari/536.30.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.43.58 (KHTML, like Gecko) Version/6.1 Safari/537.43.58""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (compatible; SemrushBot/0.96.3; +http://www.semrush.com/bot.html)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.26736/30.3214; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.5 (KHTML, like Gecko) YaBrowser/1.1.1084.5409 Chrome/19.1.1084.5409 Safari/536.5""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.19 (KHTML, like Gecko) Ubuntu/10.04 Chromium/18.0.1025.168 Chrome/18.0.1025.168 Safari/535.19""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/27.0.1500.0 Chrome/27.0.1500.0 Safari/537.36""",
"""Apache-HttpClient/4.2.3 (java 1.5)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.36 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-ca; SGH-T959D Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727 ; .NET CLR 4.0.30319)""",
"""User-Agent: Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31""",
"""Opera/9.80 (Android 2.2.2; Linux; Opera Mobi/ADR-1111101157; U; en) Presto/2.9.201 Version/11.50""",
"""Mozilla/5.0 (Android; Tablet; rv:21.0) Gecko/21.0 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 5.2; rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.31891/30.3214; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.44 Safari/537.36""",
"""Mozilla/5.0 (compatible; Spiderlytics/1.0; +spider@spiderlytics.com)""",
"""Mozilla/5.0 (Windows NT 6.0; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20100101 openHPI""",
"""Mozilla/5.0 (compatible; SpiderLing (a SPIDER for LINGustic research); http://nlp.fi.muni.cz/projects/biwec/)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0; NP08; MAAU; NP08)""",
"""Mozilla/5.0 (compatible; MSIE 10.6; Windows NT 6.1; Trident/5.0; InfoPath.2; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727) 3gpp-gba UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20130618 Firefox/24.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; ru-RU) Gecko/20120421 SUSE/21.0 Firefox/21.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20130514 Firefox/17.0""",
"""curl/7.19.7 (x86_64-redhat-linux-gnu) libcurl/7.19.7 NSS/3.14.0.0 zlib/1.2.3 libidn/1.18 libssh2/1.4.2""",
"""Yahoo Pipes 1.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/30.3214; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.2; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; en-US; jbed-fastbcc) U2/1.0.0 UCBrowser/8.9.0.251 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.33 Safari/537.31""",
"""Yahoo Pipes 2.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1541.0 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; WOW64; Edition Yx) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:8.0; en_us) Gecko/20100101 Firefox/8.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0 AlexaToolbar/alxf-2.17""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.4 (KHTML, like Gecko) Iron/5.0.381.0 Chrome/5.0.381 Safari/533.4""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""SAMSUNG-GT-C3303i/1.0 NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) YaBrowser/1.1.1084.5409 Chrome/19.1.1084.5409 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0 AlexaToolbar/alxf-2.18""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.52 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Opera/9.80 (Android; Linux; Opera Mobi/ADR-1012221546; U; pl) Presto/2.7.60 Version/10.5""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Opera/9.80 (Android 4.0.4; Linux; Opera Mobi/ADR-1205181138; U; pl) Presto/2.10.254 Version/12.00""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21051/30.3341; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:22.0; WUID=92fde63e53a4c500ff5c47fa6daf731c; WTB=3869) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9) AppleWebKit/537.46.5 (KHTML, like Gecko) Version/7.0 Safari/537.46.5""",
"""Opera/9.80 (X11; Linux i686; U; en) Presto/2.10.254 Version/12.00""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8b5) Gecko/20051006 Firefox/1.4.1""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/30.3341; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0) Gecko/20100101 Firefox/20.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0) Gecko/20101203 Firefox/3.6.13""",
"""Mozilla/5.0 (Windows NT 5.1; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.63 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; I; Intel Mac OS X 10.8; de-LI; rv:22.0) Gecko/20130303 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:10.0.3) Gecko/20100101 Firefox/10.0.3""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32445/30.3341; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.63 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.50727; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.64 Safari/537.31 AppEngine-Google; (+http://code.google.com/appengine; appid: s~jishuixiansheng)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.94 Safari/537.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Apache-HttpClient/4.2.2 (java 1.5)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-us; rv:1.9.2.3) Gecko/20100401 YFF35 Firefox/3.6.3""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:22.0) Gecko/20100101 conkeror/1.0pre""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; en-us; SPH-D710 Build/IMM76I) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30evme-launcher""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows Phone 8.0; Trident/6.0; IEMobile/10.0; ARM; Touch; NOKIA; Lumia 920)""",
"""Opera/9.80 (Android; Opera Mini/6.5.27452/30.3389; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20130626 Firefox/17.0 Iceweasel/17.0.7""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.2; en-US; rv:1.9.0.19) Gecko/2010031422 Firefox/3.0.19""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; QS 4.2.4.0; QS 5.3.0.4; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.04506.648; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; MS-RTC LM 8; QS 4.2.4.0; QS 5.3.0.4)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5 Nichrome/self/19""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (X11; ffua Linux i686; rv:22.0 Gecko/20100101 ffua/3.9.9-301.fc19.i686.PAE Firefox/22.0""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.16""",
"""Opera/9.80 (Android 2.3.4; Linux; Opera Mobi/build-1203300859; U; en) Presto/2.10.254 Version/12.00""",
"""Mozilla/5.0 (compatible; AcoonBot/4.12.1; +http://www.acoon.de/robot.asp)""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; hu-hu; ALCATEL_one_touch_995 Build/IceCreamSandwich) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/4.5 (compatible; OmniWeb/4.3-v435; Mac_PowerPC)""",
"""Mozilla/5.0 (Unknown; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) PhantomJS/1.8.1 Safari/534.34""",
"""Mozilla/5.0 (compatible;YodaoBot-Image/1.0;http://www.youdao.com/help/webmaster/spider/;)""",
"""Opera/9.80 (Windows NT 6.1; WOW64; MRA 8.0 (build 5880)) Presto/2.12.388 Version/12.11""",
"""Mozilla/5.0 (Windows; Windows NT 5.1; rv:22.0) Gecko/22.0 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.2; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36 OPR/15.0.1147.141""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36 AlexaToolbar/alxg-3.1""",
"""Nokia6303iclassic/5.0 (09.83) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 AppleWebKit/420+ (KHTML, like Gecko) Safari/420+""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/3.0.0.6 Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/8.1.9.2 Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; brip1; .NET CLR 1.1.4322; .NET CLR 2.0.50727) Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6 Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6 Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; .NET CLR 2.0.50727; WinuE v6) Mozilla/5.0 (Windows; U; Windows NT 6.0; de; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6 Mozilla/5.0 (Windows; U; Windows NT 5.1; en; rv:1.8.1.2) Gecko/20070224 BonEcho/2.0.0.2 (tete009 SSE PGO)""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_2 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B146 Safari/8536.25""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/30.3498; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/28.0.1500.52 Chrome/28.0.1500.52 Safari/537.36""",
"""TEST""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36 AlexaToolbar/alxg-3.1""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:40.0) Gecko/20200101 Firefox/40.0""",
"""Mozilla/5.0 (iPad; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5376e Safari/8536.25""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5376e Safari/8536.25""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32453/27.2274; U; en) Presto/2.8.119 240X320 Android""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.5.33867/30.3498; U; pt) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.2; Win64; x64; rv:16.0) Gecko/16.0 Firefox/16.0""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36""",
"""Nokia2610/2.0 (07.11) Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.12) Gecko/20130119 Firefox/10.0.11esrpre Iceape/2.7.12""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30 ChromePlus/1.6.3.1 DSL5744""",
"""Mozilla/5.0 (Windows NT 6.1; rv:21.0) Gecko/20130401 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:21.0) Gecko/20130401 Firefox/21.0 - Follow the white rabbit""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 5.2; Trident/5.0)""",
"""Mozilla/5.0 (masking-agent; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Opera/9.80 (Windows NT 6.2; WOW64) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36 AlexaToolbar/alxg-3.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.3; Creative AutoUpdate v1.40.02)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/28.0.1500.52 Chrome/28.0.1500.52 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.116 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.30.1 (KHTML, like Gecko) Version/6.0.5 Safari/536.30.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.52 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.4) Gecko/20030703 Epiphany/0.8.4""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_4 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10B350 Safari/8536.25""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Windows NT 6.0; rv:22.0) Gecko/20100101 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.32 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; MALCJS; rv:11.0; chromeframe/28.0.1500.71) like Gecko""",
"""finbot""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:2.0b6pre) Gecko/20100907 Firefox/4.0b6pre""",
"""Mozilla/5.0 (iPad; CPU OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/28.0.1500.12 Mobile/10B329 Safari/8536.25""",
"""Nokia300/5.0 (07.44) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 AppleWebKit/420+ (KHTML, like Gecko) Safari/420+""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/30.3558; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36 OPR/15.0.1147.148""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30 ChromePlus/1.6.3.1 TW15953""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/6.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.21992/30.3558; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.31 (KHTML like Gecko) Chrome/26.0.1410.63 Safari/537.31""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/525.27.1 (KHTML, like Gecko) Version/3.2.1 Safari/525.27.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.13337/30.3558; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/30.3558; U; pl) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Symbian OS; Series 60/07.10; 9730) Opera 8.65 [en]""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/30.3593; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""SAMSUNG-SGH-C276/1.0 UP.Browser/6.2.3.3.c.1.101 (GUI) MMP/2.0""",
"""Mozilla/5.0 (-) AppleWebKit/540.00 (KHTML, like Gecko) Chrome/30.0.0.0 Safari/540.00""",
"""Mozilla/5.0 (Linux;) AppleWebKit/540.00 (KHTML, like Gecko) Chrome/30.0.0.0 Safari/540.00""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; en-US; gt-s5230w) U2/1.0.0 UCBrowser/9.1.0.291 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/28.0.1500.71 Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686; rv:22.0) Gecko/20100101 Firefox/22.0 Iceweasel/22.0""",
"""Mozilla/5.0 (X11; SunOS sun4v; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30 ChromePlus/1.6.3.1 MVP13462""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:22.0) Gecko/20100101 Firefox/22.0 AlexaToolbar/alxf-2.18""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.3; Nexus 7 Build/JWR66V) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.94 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 9.0;IPMS/FFFFFFFF-151FED820F0-000000040695; Windows NT 6.1; Trident/5.0)""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64; Edition Yx) Presto/2.12.388 Version/12.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.30729; .NET CLR 3.5.30729; InfoPath.2)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/30.3593; U; ro) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 6.0) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (iPad; CPU OS 6_0_2 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A550 Safari/8536.25""",
"""Mozilla/5.0 (Linux; U; Android 4.3; cs-cz; Nexus 7 Build/JWR66V) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Trident/5.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 5.1; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.17262 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 5.2; en-GB; rv:1.8.1.18) Gecko/20081029 Firefox/2.0.0.18""",
"""Mozilla/5.0 (Windows NT 5.1; rv:22.0) Gecko/20100101 Firefox/22.0 AlexaToolbar/alxf-2.18""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.7; en-US; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (Windows NT 5.0; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.17262 Safari/537.22""",
"""Opera/9.80 (Windows NT 5.1; Edition IBIS) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.2; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1591.2 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; en-us; DROID RAZR Build/9.8.2O-72_VZW-16) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; rv:22.0) Gecko/20100101 Firefox/22.0 AlexaToolbar/alxf-2.18""",
"""Opera/9.80 (Android 2.3.5; Linux; Opera Mobi/ADR-1210241511) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (compatible; AhrefsBot/5.0; +http://ahrefs.com/robot/)""",
"""Mozilla/5.0 (compatible; IstellaBot/1.10.2 +http://www.tiscali.it/)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""NokiaC1-01/2.0 (04.40) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; en-US; nokiac1-01) U2/1.0.0 UCBrowser/9.2.0.311 U2/1.0.0 Mobile""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; InfoPath.3; .NET4.0C; .NET4.0E; MS-RTC LM 8)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:21.0) Gecko/20130331 Firefox/21.0""",
"""Mozilla/5.0 (compatible; heritrix/3.1.1; UniLeipzigASV +https://asv.informatik.uni-leipzig.de/)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Opera/9.80 (X11; Linux x86_64) Presto/2.12.388 Version/12.16""",
"""Opera/9.80 (Android; Opera Mini/6.5.26581/30.3697; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Penis""",
"""SAMSUNG-GT-C3262/C3262DDMA1 NetFront/4.2 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""SAMSUNG-GT-S3353/1.0 NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (compatible; MSIE 6.0; Windows NT 5.1; Windows NT 6.1; Trident/5.0)""",
"""Opera/9.80 (X11; Linux i686) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.11 (KHTML, like Gecko) Chrome/17.0.963.12 Safari/535.11""",
"""Opera/9.80 (Windows NT 6.1; Edition Yx) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/30.3697; U; tr) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/30.3697; U; vi) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/28.0.1550.0 Chrome/28.0.1550.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.1; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.2 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Windows NT 6.0; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (compatible; SolomonoBot/1.05; +http://www.solomono.ru)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.5 Safari/537.31""",
"""Nokia3110c/2.0 (07.30) Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Maxthon/4.1.0.4000 Chrome/26.0.1410.43 Safari/537.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1174.0 Safari/537.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.30729; .NET CLR 1.0.3705; .NET CLR 1.1.4322; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Space Bison/0.02 [fu] (Win67; X; SK)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""ScreenerBot Crawler Beta 2.0 (+http://www.ScreenerBot.com)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; WOW64; Trident/6.0; Touch)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/30.3745; U; kk) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1)""",
"""Mozilla/5.0 (Windows NT 6.2; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""SAMSUNG-GT-S5620/S5620PMJC5 SHP/VPP/R5 Dolfin/1.5 Nextreaming SMM-MMS/1.2.0 profile/MIDP-2.1 configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""SAMSUNG-GT-E1282T Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.31524/30.3793; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; vkShare; +http://vk.com/dev/Share)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.26736/30.3793; U; uz) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32451/30.3793; U; en) Presto/2.8.119 Version/11.10""",
"""SAMSUNG-GT-S5220/1.0 NetFront/4.2 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""SAMSUNG-GT-S5230/S5230RFIG4 SHP/VPP/R5 Jasmine/0.8 Nextreaming SMM-MMS/1.2.0 profile/MIDP-2.1 configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36 CoolNovo/2.0.9.20""",
"""Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaC7-00/012.003; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.7.3 3gpp-gba""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/31.1301; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; WOW64; Edition Yx) Presto/2.12.388 Version/12.11""",
"""DB!""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.4; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.0; U; ru) Presto/2.10.289 Version/12.02""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21594/31.1350; U; fr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; N; OpenSuse; rv:1.7.3) Gecko/20040913 Firefox/0.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ja; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/6.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Nokia3600slide/2.0 (04.11) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 (Java; U; Id; nokia3600slide) UCBrowser8.2.0.132/69/452/UCWEB Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1553.0 Safari/537.36 SUSE/30.0.1553.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:23.0) Gecko/20100101 Firefox/23.0 AlexaToolbar/alxf-2.18""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/31.1350; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.2; rv:22.0) Gecko/20130405 Firefox/23.0""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.27055/31.1350; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; SemrushBot/0.97; +http://www.semrush.com/bot.html)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.2; MS-RTC LM 8; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.66 (KHTML, like Gecko) Version/6.1 Safari/537.66""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.21027 Safari/537.22""",
"""SAMSUNG-GT-E2252 Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.29595/31.1350; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:9.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.14 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.04506.648)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36 OPR/16.0.1196.73""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.66 Safari/537.36""",
"""SAMSUNG-S7350i/S735ICXII4 SHP/VPP/R5 NetFront/3.5 Qtv5.3 SMM-MMS/1.2.0 profile/MIDP-2.1 configuration/CLDC-1.1""",
"""Mozilla/5.0 (Series40; Nokia201/11.95; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.2.0.0.6""",
"""Mozilla/5.0 (Windows NT 5.1; rv:23.0) Gecko/20130405 Firefox/23.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SLCC1; .NET CLR 1.1.4325; .NET CLR 2.0.40607; .NET CLR 3.0.30729; .NET CLR 3.5.30729)""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/31.1395; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.22296/31.1395; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET CLR 1.0.3705; .NET CLR 1.1.4322)""",
"""Opera/9.80 (X11; Linux x8664) Presto/2.12.388 Version/12.16""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/31.1395; U; en) Presto/2.8.119 Version/11.10""",
"""W3C_Validator/1.3 http://validator.w3.org/services""",
"""Opera/12.80 (Windows NT 5.1; U; en) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.37 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/6.0)""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.29482/31.1395; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.186 Safari/535.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.7.29879/31.1395; U; zh) Presto/2.8.119 Version/11.10""",
"""NokiaX2-01/5.0 (08.63) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 (Series40; Nokia311/05.60; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/1.8.0.50.5 UNTRUSTED/1.0""",
"""Mozilla/5.0 (compatible; Linux x86_64; Mail.RU_Bot/2.0; +http://go.mail.ru/help/robots)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36 CoolNovo/2.0.9.20""",
"""UCWEB/2.0 (Symbian; U; S60 V3; en-US; NOKIA6210 Navigator) U2/1.0.0 UCBrowser/9.1.0.319 U2/1.0.0 Mobile""",
"""SAMSUNG-GT-S3802 Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32830/31.1448; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.63 Safari/537.31 Mozilla/5.12345 (Windows 8.23; U; Windows 8.45; es; rv:1.9.1.899) Gecko/2009989768 Firefox/3.5.09887""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/31.1448; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; ru-RU; rv:1.8.1.21) Gecko/20090403 SeaMonkey/1.1.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux ppc; rv:5.0) Gecko/20100101 Firefox/5.0""",
"""Express WebPictures (www.express-soft.com)""",
"""Mozilla/5.0 (Series40; Nokia114/03.33; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.7.0.0.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.0/31.1448; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.23453/31.1448; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Series40; Nokia200/11.81; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.7.0.0.11""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/29.0.1600.1 Chrome/29.0.1600.1 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 4.1.1; tr-tr; Vodafone 875 Build/JRO03C) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.1 Mobile Safari/534.30 SVN/040HMG2""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.3; Nexus 4 Build/JWR66Y) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.72 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:19.0) Gecko/20130309 Firefox/19.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:25.0; +http://netzware.net/) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (PLAYSTATION 3; 1.00)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; GT-P3110 Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 5.1; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Sogou web spider/4.0(+http://www.sogou.com/docs/help/webmasters.htm#07)""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""SonyEricssonK530i/R6BC Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Windows NT 6.1; rv:23.0; Avant TriCore) Gecko/20130907 Firefox/23.0""",
"""Mozilla/5.0 (iPad; U; CPU iPad OS 5_0_1 like Mac OS X; en-us) AppleWebKit/535.1+ (KHTML like Gecko) Version/7.2.0.0 Safari/6533.18.5""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1653.0 Safari/537.36""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/31.1475; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/31.1475; U; ar) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008071615 Fedora/3.0.1-1.fc9 Firefox/3.0.1""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/31.1475; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; U; Android 1.0; en-us; dream) AppleWebKit/525.10+ (KHTML, like Gecko) Version/3.0.4 Mobile Safari/523.12.2""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.5.33867/31.1475; U; hr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 Safari/537.36""",
"""Mozilla/5.0 (SAMSUNG; SAMSUNG-GT-S5380K/S5380KDDLC1; U; Bada/2.0; en-us) AppleWebKit/534.20 (KHTML, like Gecko) Dolfin/3.0 Mobile HVGA SMM-MMS/1.2.0 OPN-B""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.22076 Safari/537.22""",
"""UCWEB/2.0 (Linux; U; Adr 4.1.2; en-IN; Micromax_A92) U2/1.0.0 UCBrowser/8.6.0.276 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (Series40; Nokia306/03.81; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.7.0.0.11""",
"""Opera/9.80 (Android 4.0.4; Linux; Opera Mobi/ADR-1211271253) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (Series40; Nokia210/04.12; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.3.0.0.53""",
"""Mozilla/5.0 (Linux; Android 4.1.2; IM-A830L Build/JZO54K) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; TencentTraveler ; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; .NET CLR 2.0.50727 ; .NET CLR 4.0.30319)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:24.0) Gecko/20100101 Firefox/24.0 AlexaToolbar/alxf-2.19""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.66 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""dupa""",
"""Fuck off!""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.47 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.66 Safari/537.36""",
"""Mozilla/5.0 (Commodore C64) KHTML/4.9.1 (like Gecko) Konqueror/4.9""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_2 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11A501 Safari/9537.53""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/31.1543; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.72 Mobile Safari/537.36""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.9.168 Version/11.50""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.57 Safari/537.36""",
"""Wget/1.13.4 (linux-gnu)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/28.0.1500.71 Chrome/28.0.1500.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Opera/9.80 (X11; Linux x86_64; U; pl) Presto/2.7.62 Version/11.00""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""NULL""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.82 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.66 Safari/537.36 OPR/17.0.1241.36 (Edition Next)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; en-US; samsung-gt-e2202) U2/1.0.0 UCBrowser/9.2.0.311 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; WOW64; U; MRA 6.0 (build 6001); ru) Presto/2.10.289 Version/12.01""",
"""Mozilla/5.0 (Linux i686) AppleWebKit/537.6+ (KHTML, like Gecko) WebKitGTK+/1.10.2 luakit/0d5f4""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:22.0) Gecko/20100101 Firefox/22.0 Iceweasel/22.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.76 CoRom/29.0.1547.76 Safari/537.36""",
"""BUbiNG (+http://law.di.unimi.it/BUbiNG.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0 AlexaToolbar/alxf-2.19""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/29.0.1547.65 Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36 OPR/17.0.1241.45""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20100101 Firefox/24.0 Iceweasel/24.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; SV1; .NET CLR 1.1.4322)""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.8.131 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131017091739)""",
"""Opera/9.92 (Windows: 7; es) Presto/2.3.46 Version/10.02""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""infohelfer/0.9 (http://www.infohelfer.de/)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5376e Safari/8536.25 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)""",
"""viralvideochart.unrulymedia.com""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/525.19 (KHTML, like Gecko) Chrome/1.0.154.43 Safari/525.19""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/32.952; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.10) Gecko/20071115 Firefox/2.0.0.12""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36 Squider/0.01""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.78 CoRom/29.0.1547.78 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; en-US; SAMSUNG-GT-S3850) U2/1.0.0 UCBrowser/9.3.0.326 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11A465 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20110814 Firefox/6.0 Google (+https://developers.google.com/+/web/snippet/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32445/32.981; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131023112435)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.22194 Safari/537.22""",
"""Opera/9.80 (Windows NT 6.1; WOW64; MRA 5.10 (build 5310)) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1678.0 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.5.33891/32.981; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/534.57.7 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.7""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/32.1005; U; PT) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.27+ (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27""",
"""Mozilla/5.0 (iPad; CPU OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Mobile/10A403""",
"""Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.160 Safari/537.22""",
"""Mozilla/5.0 (iPhone Simulator; CPU iPhone OS 5_1 like Mac OS X) AppleWebKit/534.46 (KHTML, like Gecko) Mobile/9B176""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Mobile/10A403""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.2; Data Center; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; en-us; KFOTE Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (Linux; U; Android 2.3.3; en-us; sdk Build/GRI34) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Linux; U; Android 2.3.5; en-us; generic Build/unknown) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Linux; U; Android 4.2.2; en-us; sdk Build/JB_MR1.1) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/536.30.1 (KHTML, like Gecko) Version/6.0.5 Safari/536.30.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.65 Safari/537.31""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; en-us; sdk Build/MR1) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0 SeaMonkey/2.18""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0 SeaMonkey/2.20""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.19) Gecko/2010062819 Firefox/3.0.19 Flock/2.6.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.12) Gecko/20080219 Firefox/2.0.0.12 Navigator/9.0.0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.13 (KHTML, like Gecko) Chrome/9.0.597.107 Safari/534.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.77 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:22.0) Gecko/20100101 Firefox/22.0 SeaMonkey/2.19""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_7_5; en-us) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:12.0) Gecko/20120429 Firefox/12.0 SeaMonkey/2.9.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) rekonq Safari/534.34""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/530.5 (KHTML, like Gecko) Chrome/2.0.172.31 Safari/530.5""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/531.0 (KHTML, like Gecko) Chrome/3.0.182.2 Safari/531.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/532.3 (KHTML, like Gecko) Chrome/4.0.223.11 Safari/532.3""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pl-PL) AppleWebKit/533.18.1 (KHTML, like Gecko) Version/5.0.2 Safari/533.18.5""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131024190601)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/6.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Opera/9.51 (Windows NT 6.1; U; ru)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36 Opera/9.80 (J2ME/MIDP; Opera Mini/9.80 (S60; SymbOS; Opera Mobi/23.348; U; en) Presto/2.5.25 Version/10.54""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/32.1024; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Win 9x 4.90; SG; rv:1.9.2.4) Gecko/20101104 Netscape/9.1.0285""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.29915/32.1024; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.6+ (KHTML, like Gecko) Chromium/23.0.1271.95 Chrome/23.0.1271.95 Safari/537.6+ dwb/commit 2013-10-23 83c0c3e""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/32.1024; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9) AppleWebKit/537.71 (KHTML, like Gecko) Version/7.0 Safari/537.71""",
"""Mozilla/5.0 (iPad; CPU OS 7_0_3 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B511 Safari/9537.53""",
"""Mozilla/5.0 (Linux; U; Android SlateDroid Steel v2; de-de; Eken & Lfd Build/Donut) AppleWebKit/528.5+ (KHTML, like Gecko) Version/3.1.2 Mobile Safari/525.20.1""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1350.0 Iron/24.0.1350.0 Safari/537.17""",
"""Mozilla/5.0 (Windows NT 5.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""NokiaN70-1/5.0609.2.0.1 Series60/2.8 Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Link/6.3.1.13.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; de-de; SonyLT26i Build/6.2.B.0.200) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20130921 Firefox/24.0""",
"""Mozilla/5.0 (compatible; proximic; +http://www.proximic.com/info/spider.php)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; chromeframe/19.0.1084.52)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/30.0.1599.16 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.39 Safari/537.36""",
"""SAMSUNG-C3050-ORANGE/C3050BVIH2 Openwave/6.2.3 Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Browser/6.2.3.3.c.1.101 (GUI) MMP/2.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.78 CoRom/29.0.1547.78 Safari/537.36""",
"""Mozilla/5.0 (X11; FreeBSD amd64; rv:16.0) Gecko/20100101 Firefox/16.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.5 Safari/537.31""",
"""Mozilla/5.0 (X11; Linux i686; rv:2.0) Gecko/20100101 Firefox/4.0 Opera 12.15""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:23.0) Gecko/20130101 Firefox/23.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.114 Safari/537.36""",
"""SAMSUNG-GT-C3262 Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.31859/32.1125; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; MRA 6.0 (build 6015); .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 10.0; Windows CE; IEMobile 10.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; MS-RTC LM 8; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/28.0.1550.0 Chrome/28.0.1550.0 Safari/537.36""",
"""Scrapy/0.18.4 (+http://scrapy.org)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/32.1125; U; en) Presto/2.8.119 Version/11.10""",
"""---twselbst---""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131108094444)""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/32.1151; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.3) Gecko/20090824 Firefox/3.5.3 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.172 YaBrowser/1.7.1364.22194 Safari/537.22""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.1.0.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; CIBA; .NET CLR 2.0.50727; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.71 (KHTML, like Gecko) Version/6.1 Safari/537.71""",
"""Opera/9.80 (Series 60; Opera Mini/6.5.26990/32.1151; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0; tb-webde/2.4.0)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.71 (KHTML, like Gecko) Version/6.1 Safari/537.71""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/5.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131112103700)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131112095447)""",
"""Mozilla/5.0 (Series40; Nokia210.2/04.12; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.3.0.0.53""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.48 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; DigExt)""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 7.1; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.13 (KHTML, like Gecko) Chrome/24.0 Safari/537.13""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.24) Gecko/20111103 Firefox/3.6.24 ( .NET CLR 3.5.30729; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""vobsub""",
"""Mozilla/5.0 (Linux; Android 4.4; Nexus 5 Build/KRT16M) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.105 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.91 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1636.2 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.48 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131115115040)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.48 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; InfoPath.3; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.1; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1707.0 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_3 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B511 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101 Safari/537.36 OPR/17.0.1241.53""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; en-US; Spice) U2/1.0.0 UCBrowser/9.3.0.326 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (BlackBerry; U; BlackBerry 9800; en) AppleWebKit/534.1+ (KHTML, like Gecko) Version/6.0.0.337 Mobile Safari/534.1+""",
"""Nokia5238/51.9.002 (SymbianOS/9.4; U; Series60/5.0 Mozilla/5.0; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Safari/525 3gpp-gba""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:24.0) Gecko/20100101 Firefox/24.0 SeaMonkey/2.21""",
"""Mozilla/5.0 abc""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; tr-tr; Turkcell Maxi Plus 5 Build/IMM76D) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (Series40; Nokia501/10.0.14; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.7.0.0.11""",
"""Mozilla/5.0 (compatible; SEOkicks-Robot; +http://www.seokicks.de/robot.html)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X) PowerPoint/14.38.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Opera/9.80 (MAUI Runtime; Opera Mini/4.4.32206/32.1214; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/6.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; InfoPath.3; .NET4.0C; Media Center PC 6.0)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.5.33867/32.1214; U; en) Presto/2.8.119 Version/11.10""",
"""Deepnet Explorer 1.5.3; Smart 2x2; Avant Browser; .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Opera/9.80 (Windows NT 5.1; MRA 6.2 (build 7314)) Presto/2.12.388 Version/12.16""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; MRSPUTNIK 2, 4, 1, 293; SIMBAR={8E34AE1B-599B-11E2-B254-5404A629D721}; MRA 6.2 (build 7314); .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131121115135)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.114 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131121180135)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/32.1312; U; en) Presto/2.8.119 Version/11.10""",
"""VPNGate/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/536.30.1 (KHTML, like Gecko) Version/6.0.5 Safari/4A860774""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Nokia5310XpressMusic/2.0 (09.42) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 (Java; U; es-la; nokia5310xpressmusic) UCBrowser8.4.0.159/70/352/UCWEB Mobile UNTRUSTED/1.0""",
"""lftp/4.4.11""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 6.2 (build 7314); ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 5.1; en-US) AppleWebKit/535.12 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/535.12""",
"""Mozilla/4.0 (compatible; MSIE 5.5b1; Mac_PowerPC)""",
"""Mozilla/5.0 (Windows NT 6.1 rv:17.0) Gecko/20100101 Firefox/17.0""",
"""Mozilla/5.0 (Windows NT 6.2; Win64; x64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Android; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Mobile; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:23.0) Gecko/20100101 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36 OPR/18.0.1284.49""",
"""Mozilla/5.0 (Linux U Android 2.1-update1 de-de MB525 Build/JRDNEM_U3_2.11.0) AppleWebKit/530.17 (KHTML, like Gecko) Version/4.0 Mobile Safari/530.17""",
"""Mozilla/5.0 (X11; Linux i686; rv:14.0) Gecko/20100101 Firefox/14.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/30.0.1650.0 Chrome/30.0.1650.0 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.2; Win64; x64) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/531.1 6 Arcko/20100101 Firefox/25.0aaaaaaaaaaaaaaaaaaa""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.13918/32.1382; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.5.33867/32.1382; U; ar) Presto/2.8.119 Version/11.10""",
"""UCWEB/2.0 (Symbian; U; S60 V5; en-US; Nokia5230) U2/1.0.0 UCBrowser/9.2.0.336 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.19 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 YaBrowser/13.10.1500.9323 Safari/537.36""",
"""Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaC7-00/013.016; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.8.10 3gpp-gba""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux i686; rv:1.6.20) Gecko/20100929""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.18887/32.1382; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-PT; rv:1.9.1.19) Gecko/20110420 SeaMonkey/2.0.14""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.1) Gecko/20020826""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1726.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.59.10 (KHTML, like Gecko) Version/5.1.9 Safari/534.59.10""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_4 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B554a Safari/9537.53""",
"""Mozilla/5.0 (Windows NT; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.4) Gecko/20100523 Firefox/3.6.4 ( .NET CLR 3.5.30729)""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64) Presto/2.12.388 Version/12.10""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.41 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows XP) [de]""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.0; de; rv:1.9.2.3) Gecko/20100401 Firefox/25.0.1""",
"""SAMSUNG-GT-S3770/S3770JPKJ1 NetFront/4.1 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.15082/32.1440; U; ru) Presto/2.8.119 Version/11.10""",
"""curl/7.19.0 (x86_64-suse-linux-gnu) libcurl/7.19.0 OpenSSL/0.9.8h zlib/1.2.3 libidn/1.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US) AppleWebKit/532.9 (KHTML, like Gecko) Chrome/5.0.307.11 Safari/532.9""",
"""Mozilla/5.0 (X11; U; Linux i586; en-US; rv:1.9.2.23) Gecko/20080724 Firefox/12.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; fr; rv:1.8.1.20) Gecko/20081217 Firefox/2.0.0.20""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9) AppleWebKit/537.35.1 (KHTML, like Gecko) Version/6.1 Safari/537.35.1""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:25.0) Gecko/39237369 Firefox/25.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Mobile; rv:14.0) Gecko/14.0 Firefox/14.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.41 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/32.1440; U; pl) Presto/2.8.119 Version/11.10""",
"""bluefish 0.6 HTML editor""",
"""Mozilla/5.0 (Windows NT 6.1; rv:10.0.11) Gecko/20100101 Firefox/10.0.11""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Android 4.2; rv:19.0) Gecko/20121129 Firefox/19.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0 x64; en-US; rv:1.9pre) Gecko/2008072421 Minefield/3.0.2pre""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36 FirePHP/4Chrome""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Series40; Nokia110/03.26; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.7.0.0.11""",
"""Mozilla/5.0 (Linux; U; Android 4.1.1; de-de; Cynus T1 Build/JRO03C) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (X11; nekunOS; Linux_3.2.0_x86; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (compatible; spbot/4.0.4; +http://www.seoprofiler.com/bot )""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_4 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Mobile/11B554a [FBAN/FBIOS;FBAV/6.8;FBBV/745892;FBDV/iPhone5,2;FBMD/iPhone;FBSN/iPhone OS;FBSV/7.0.4;FBSS/2; FBCR/Vodafone.de;FBID/phone;FBLC/de_DE;FBOP/5]""",
"""Mozilla/5.0 (Windows NT 6.1; Trident/7.0; rv:11.0) like Gecko""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.20464/32.1528; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; U; Android 2.3.6; de-de; GT-S5830 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Opera/9.80 (Windows NT 6.1; Win64; x64; U; Edition Next; de) Presto/2.11.310 Version/12.50""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/6.1.25378/32.1528; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; nl; rv:1.9.0.5) Gecko/2008120122 Firefox/3.0.5""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; WOW64; Trident/6.0; MASMJS)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (compatible; MSIE 9.0 Windows NT 6.1; WOW64; Trident/6.0)""",
"""NokiaC3-00/5.0 (04.60) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; Pt-BR; NokiaC3-00) U2/1.0.0 UCBrowser/9.3.0.326 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Happy-Browser""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; ko-kr; LG-L160L Build/IML74K) AppleWebkit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (iPad; CPU OS 7_0_4 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) CriOS/31.0.1650.18 Mobile/11B554a Safari/8536.25""",
"""Mozilla/5.0 (Linux; Android 4.3; SCH-I545 Build/JSS15J) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.59 Mobile Safari/537.36""",
"""Mozilla/5.0 (compatible; Ezooms/1.0; help@moz.com)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.55 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""NokiaC1-01/2.0 (06.05) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; en-US; nokiac1-01) U2/1.0.0 UCBrowser/9.2.0.311 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0.2) Gecko/20120216 SeaMonkey/2.7.2""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.2; .NET CLR 1.0.3705;)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20131221093550)""",
"""Nokia2700c-2/2.0 (09.95) Profile/MIDP-2.1 Configuration/CLDC-1.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/34.817; U; id) Presto/2.8.119 Version/11.10""",
"""Nokia-MIT-Browser/3.0""",
"""va niquer ta mere sale enfoirer d'euroclix""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.73.11 (KHTML, like Gecko) Version/7.0.1 Safari/537.73.11""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/34.818; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/30.0.1599.114 Chrome/30.0.1599.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1712.4 Safari/537.36""",
"""User-Agent: Mozilla/3.0 (Windows NT 6.1; WOW64; rv:1.0.1) Gecko/20100301 Firefox/1.0.1""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3)""",
"""Mozilla/5.0 (X11; U; Linux 2.4.3-20mdk i586; en-US; rv:0.9.1) Gecko/20010611""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/31.0.1650.63 Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (SAMSUNG; SAMSUNG-GT-S5380D/S5380DXXLF1; U; Bada/2.0; ru-ru) AppleWebKit/534.20 (KHTML, like Gecko) Dolfin/3.0 Mobile HVGA SMM-MMS/1.2.0 OPN-B""",
"""Mozilla/5.0 (Windows NT 6.2; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1667.0 Safari/537.36""",
"""NokiaC2-01/5.0 (11.10) Profile/MIDP-2.1 Configuration/CLDC-1.1 Mozilla/5.0 (Windows; U; Windows NT 6.0; ru; Desktop) AppleWebKit/534.13 (KHTML, like Gecko) UCBrowser/9.3.0.326 UNTRUSTED/1.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36""",
"""Mozilla/5.0 (S60; SymbOS; Opera Mini/32445)""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/34.818; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows Phone 8.0; Trident/6.0; IEMobile/10.0; ARM; Touch; NOKIA; Lumia 520)""",
"""Mozilla/5.0 (compatible; GrapeshotCrawler/2.0; +http://www.grapeshot.co.uk/crawler.php)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140103204027)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.20464/34.818; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140106184535)""",
"""Mozilla/5.0 (X11; Linux) Gecko Firefox/5.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28 sputnik 2.5.2.8""",
"""Mozilla/5.0 (X11; OpenBSD amd64; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.2; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20121201 icecat/17.0.1""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.0.29915/34.861; U; ky) Presto/2.8.119 Version/11.10""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET4.0C; .NET4.0E; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3)""",
"""PHP/5.4.23""",
"""Mozilla/5.0 (Windows; I; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (Windows; I; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (Windows; I; Windows NT 5.1; ru; rv:1.9.2.13) Gecko/20100101 Firefox/4.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.04506.648; .NET CLR 3.5.21022; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.1.11321/34.861; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""AppCake 3.96 (iPhone; iPhone OS 5.1.1; de_DE)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/31.0.1700.0 Chrome/31.0.1700.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140115184816)""",
"""Mozilla/5.0 (Series40; Nokia210.2/04.12; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.9.0.0.22""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/6.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070220 Firefox/2.0.0.2""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36 OPR/18.0.1284.63""",
"""Opera/9.80 (Windows NT 6.1; WOW64; Edition Next) Presto/2.12.388 Version/12.15""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.77 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Opera/9.80 (Windows NT 6.1; U; ru) Presto/2.7.39 Version/11.00""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de-DE; rv:1.9.0.7) Gecko Kazehakase/0.5.6""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.77 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SV1; [eburo v4.0]; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1549.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Series40; Nokia202/20.52; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/3.9.0.0.22""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.6) Gecko/20091201 Firefox/3.5.6 (.NET CLR 3.5.30729)""",
"""Proxy Gear Pro/1.2 (Windows; N; Windows NT 6.1; en)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1485.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36 OPR/19.0.1326.45 (Edition Next)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.77 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""UCWEB/2.0 (Symbian; U; S60 V3; en-US; NOKIA6120c) U2/1.0.0 UCBrowser/9.1.0.319 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (iPad; U; CPU iPhone OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B314 Safari/531.21.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.16 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36 OPR/19.0.1326.56""",
"""Mozilla/5.0 (compatible; waybackarchive.org/1.0; +spider@waybackarchive.org)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/34.1088; U; ky) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/34.1088; U; en) Presto/2.8.119 Version/11.10""",
"""NokiaX2-01/5.0 (08.71) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; vi; NokiaX2-01) U2/1.0.0 UCBrowser/9.4.1.377 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 Mozilla/5.0 (Gecko) Firefox/64""",
"""Opera/9.80 (Android; Opera Mini/7.5.33361/34.1153; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT; Win64; x64; rv:26.0) Gecko/20100101 Firefox/26.0 Waterfox/26.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Snoopy v1.2.4""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21594/34.1153; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.3; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Windows NT 6.1; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (compatible; LinkpadBot/1.06; +http://www.linkpad.ru)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.12785 YaBrowser/13.12.1599.12785 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/6.0 Mobile/10A5376e Safari/8536.25 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36 FirePHP/4Chrome""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36 OPR/19.0.1326.59""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140213184251)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/21.0.1180.83 Safari/534.16""",
"""Wget/1.15 (linux-gnu)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 6.3; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36""",
"""Mozilla/5.0 (compatible; SeznamBot/3.2; +http://fulltext.sblog.cz/)""",
"""Mozilla/5.0 (Windows; U; MSIE 7.0; Windows NT 5.2)""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; BTRS100021; .NET CLR 1.1.4322; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; InfoPath.3; .NET4.0C)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36 OPR/19.0.1326.63""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.49 Safari/537.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; MRA 8.0 (build 5784)) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Opera/9.80 (Windows NT 5.1; Edition Campaign 21) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (compatible; Lipperhey SEO Service; http://www.lipperhey.com/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36 OPR/19.0.1326.63""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.112 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140215 Firefox/24.0 Iceweasel/24.3.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; MDDRJS; rv:11.0) like Gecko""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/32.0.1700.107 Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB6; .NET CLR 1.1.4322; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0 AlexaToolbar/pNuSbuMf-2.2""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (compatible; MojeekBot/0.6; http://www.mojeek.com/bot.html)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Linux i686; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36 OPR/19.0.1326.63""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21051/34.1309; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 5.1; rv:25.0) Gecko/20100101 Firefox/25.0 AlexaToolbar/alxf-2.19""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 6.0; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows NT 5.2; rv:17.0) Gecko/17.0 Firefox/17.0""",
"""Mozilla/5.0 (Android; Tablet; rv:27.0) Gecko/27.0 Firefox/27.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.74.9 (KHTML, like Gecko) Version/7.0.2 Safari/537.74.9""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.94 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:21.0) Gecko/20100101 Firefox/21.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; WOW64; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; BRI/1; MAAU; .NET4.0C; BRI/2)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36 OPR/20.0.1387.59 (Edition Next)""",
"""Mozilla/5.0 (Android; Mobile; rv:22.0) Gecko/22.0 Firefox/22.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.19634/34.1394; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Mobile/10B329""",
"""Mozilla/5.0 (iPod; CPU iPhone OS 6_1_3 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) CriOS/33.0.1750.14 Mobile/10B329 Safari/8536.25""",
"""Mozilla/5.0 (X11; Linux i686; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.13337/34.1394; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Series 60; Opera Mini/7.0.29483/34.1394; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36 OPR/20.0.1387.64""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140205 Firefox/24.0 Iceweasel/24.3.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:28.0) /20140218 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36 OPR/19.0.1326.59""",
"""Mozilla/5.0 (X11; Linux x86_64; en_US) KHTML/4.12.3 (like Gecko) Konqueror/4.12""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (Series40; Nokia202/20.28; Profile/MIDP-2.1 Configuration/CLDC-1.1) Gecko/20100401 S40OviBrowser/2.3.0.0.49""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; de-de; GT-I9300 Build/JZO54K) AppleWebKit/534.30 (Chrome generic) Version/4.0""",
"""Opera/9.80 (Android; Opera Mini/6.5.26571/34.1445; U; ru) Presto/2.8.119 Version/11.10""",
"""Nokia6600s/2.0 (p) Profile/ MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; id; maui) U2/1.0.0 UCBrowser/8.9.0.251 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:27.0) Gecko/27.01 Firefox/27.0.1 klaatu/barada/niktu (Arnold Hau 4.7) gzipfel(gfe)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.149 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36 OPR/20.0.1387.64""",
"""PHP/5.3.23""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-EN; rv:2.0b4) Gecko/20100818""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/34.1445; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/8.0.35158/34.1499; U; ka) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.8) Gecko/20100319 Gentoo Shiretoko/3.5.8""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.3; XT1032 Build/14.10.0Q3.X-76-LGG-11) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.99 Mobile Safari/537.36""",
"""Mozilla/5.0 (BB10; Kbd) AppleWebKit/537.35+ (KHTML, like Gecko) Version/10.2.1.2141 Mobile Safari/537.35+""",
"""Mozilla/5.0 (Linux; U; Android 4.3.1; de-de; Galaxy Nexus Build/JLS36I) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""PuTTY/0.63 like Telnet""",
"""Mozilla/5.0 (Linux; U; Android 4.4.2; de-de; Nexus 4 Build/KOT49H) AppleWebKit/537.16 (KHTML, like Gecko) Version/4.0 Mobile Safari/537.16""",
"""Mozilla/5.0 (Linux; U; Android 2.2; en-gb; GT-P1000 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.149 Safari/537.36""",
"""jeix riecht nach lulu/0.815, like fettsack""",
"""beamng-update/1.3""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.3.9999.1648 Safari/537.31 BDSpark/26.3""",
"""Mozilla/5.0 (Linux; Android 4.4.2; Nexus 7 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.136 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.149 Safari/537.36 OPR/20.0.1387.77""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.5; rv:15.0) Gecko/20100101 Firefox/15.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:23.0) Gecko/20131011 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:27.0.2) Gecko/20100101 Firefox/27.0.2 Jamessir_Bensonmaam/27.0.2""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:28.0) Gecko/28.0 Firefox/28.0 klaatu/barada/niktu (Arnold Hau 4.7) gzipfel(gfe)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.152 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_6 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B651 Safari/9537.53""",
"""Mozilla/5.0 (Linux; U; Android 2.2; de-de; GT-I5510 Build/FROYO) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.152 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.750.0 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; rv:22.0) Gecko/20130405 Firefox/22.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.76 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1901.0 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; rv:2.2) Gecko""",
"""Mozilla/5.0 (compatible; URLAppendBot/1.0; +http://www.profound.net/urlappendbot.html)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/33.0.1750.152 Chrome/33.0.1750.152 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/32.0.1750.1 Chrome/32.0.1750.1 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1897.2 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 2.3.6; de-de; GT-I5510 Build/GINGERBREAD) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_3; en-us) AppleWebKit/537.16 (KHTML, like Gecko) Version/5.0 Safari/537.16""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.152 Safari/537.36""",
"""&as_qdr=all""",
"""Mozilla/5.0 (Windows NT 5.1; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.55.3 (KHTML, like Gecko) Version/5.1.5 Safari/534.55.3""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:27.0) Gecko/20100101 Waterfox/27.0 Firefox/27.0.1""",
"""Orca Browser (http://www.orcabrowser.com)""",
"""Opera/9.80 (Windows NT 6.2; WOW64; Edition Campaign 21) Presto/2.12.388 Version/12.16""",
"""Mozilla/4.08 [en] (WinNT; U)""",
"""Mozzarella/5.0 (compatible; Bockwurstbrauser; Windows NT 6.1)""",
"""FUCK YOU AND YOUR FORCED SSL BULLSHIT GOOGLE!""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0 AlexaToolbar/alxf-2.19""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-gb) AppleWebKit/535+ (KHTML, like Gecko) Version/5.0 Safari/535.22+ Midori/0.4""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20140315 Firefox/24.0 PaleMoon/24.4.1""",
"""Mozilla/5.0 (Windows NT 6.0; rv:2.0.1) Gecko/20100101 Firefox/8.0 LOR VBA-Beispiele.de""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_6; zh-cn) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.276""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.13014 YaBrowser/13.12.1599.13014 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB6.6; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0)""",
"""Opera/9.80 (Android; Opera Mini/6.1.25577/34.1624; U; es) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.3; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Android; Linux armv7l; rv:9.0) Gecko/20111216 Firefox/7.2 Fennec/9.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140319 Firefox/24.0 Iceweasel/24.4.0""",
"""Mozilla/5.0 (Android; Mobile; rv:28.0) Gecko/28.0 Firefox/28.0""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.114 Mobile Safari/537.36""",
"""Opera/9.80 (Android; Opera Mini/7.5.35199/34.1697; U; de) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (Windows Mobile; Opera Mini/5.1.21595/34.1697; U; en) Presto/2.8.119 Version/11.10""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/34.1697; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20100101 Firefox/24.0 AppEngine-Google; (+http://code.google.com/appengine; appid: s~freetestapp2)""",
"""Mozilla/5.0 (Linux; U; Android 4.2.2; en-us; GT-P3113 Build/JDQ39) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.34 Safari/534.24""",
"""Opera/9.80 (Windows NT 6.0) Presto/2.12.388 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:28.0) Gecko/39237369 Firefox/28.0 Cyberfox/28.0""",
"""Mozilla/5.0 (compatible; Windows; U; Windows NT 6.2; WOW64; en-US; rv:12.0) Gecko/20120403211507 Firefox/12.0""",
"""Nokia5200/2.0 (07.20) Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Nokia6630/1.0 (2.39.15) SymbianOS/8.0 Series60/2.6 Profile/MIDP-2.0 Configuration/CLDC-1.1""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140408191914)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_1 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) CriOS/33.0.1750.21 Mobile/11D167 Safari/9537.53""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_1 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Version/7.0 Mobile/11D167 Safari/9537.53""",
"""Mozilla/5.0 (Linux; Android 4.2.2; GT-I9195 Build/JDQ39) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.114 Mobile Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140408190551)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.12785 YaBrowser/13.12.1599.12785 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0; Ypkch32)""",
"""Mozilla/5.0 (iPad; CPU OS 7_1 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) CriOS/33.0.1750.21 Mobile/11D167 Safari/9537.53""",
"""Mozilla/5.0 (iPad; CPU OS 7_1 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Version/7.0 Mobile/11D167 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.833 Safari/537.36 MRCHROME SOC CHANNEL_inet2amigo""",
"""Mozilla/5.0 (Linux; Android 4.4.2; Nexus 4 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.114 Mobile Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140409094733)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20130216 Firefox/17.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_2; rv:10.0.1) Gecko/20100101 Firefox/10.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36 OPR/18.0.1284.68""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (X11; Co Cie to obcodzi?; Unix x86_64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1) Opera 12.15""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; Nexus 5 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.114 Mobile Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; de-de; SAMSUNG GT-I9505 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Version/1.5 Chrome/28.0.1500.94 Mobile Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; GT-I9505 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.114 Mobile Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_6 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) CriOS/33.0.1750.21 Mobile/11B651 Safari/9537.53""",
"""Mozilla/5.0 (Linux; Android 4.2.2; de-de; SAMSUNG GT-I9195/I9195XXUBNA2 Build/JDQ39) AppleWebKit/535.19 (KHTML, like Gecko) Version/1.0 Chrome/18.0.1025.308 Mobile Safari/535.19""",
"""Mozilla/5.0 (Linux; U; Android 4.3.1; de-de; GT-I9505 Build/JLS36I) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30 CyanogenMod/10.2.1/jfltexx""",
"""Opera/9.80 (Android; Opera Mini/7.5.35199/34.1784; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (compatible; DotBot/1.1; http://www.opensiteexplorer.org/dotbot, help@moz.com)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0 like Mac OS X; en-us) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11A465 Safari/9537.53""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_1 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Mobile/11D167""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140417034451)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.52 Safari/537.17""",
"""<?php exec('/bin/echo foobarbaz'); ?>""",
"""%3c?php exec(%27/bin/echo foobarbaz%27); ?%3e""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36 OPR/20.0.1387.91""",
"""Scrapy/0.22.2 (+http://scrapy.org)""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Opera/9.52 (Windows NT 6.0; U; ru)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 QQDownload/1.7""",
"""Mozilla/5.0 (Windows NT 5.1; rv:27.0) Gecko/20100101 Firefox/27.0 AlexaToolbar/alxf-2.19""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; id; sunmicrosystems_wtk) U2/1.0.0 UCBrowser/9.2.0.336 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (compatible; uMBot-FC/1.0; mailto: crawling@ubermetrics-technologies.com)""",
"""Mozilla/5.0 (compatible; LoadTimeBot/0.9; +http://www.loadtime.net/bot.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.8.1.12) Gecko/20080201 Firefox/2.0.0.12 Creative ZENcast v1.02.08""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; sv-SE; rv:1.8.1.7) Gecko/20070914 Firefox/2.0.0.7""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; InfoPath.2; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""Opera/9.21 (Windows NT 5.0; U; de)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/18.6.872.0 Safari/535.2 UNTRUSTED/1.0 3gpp-gba UNTRUSTED/1.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; Embedded Web Browser from: http://bsalsa.com/; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140424193400)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-GB; rv:1.9.0.13) Gecko/2009073022 EnigmaFox/3.0.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.75.14 (KHTML, like Gecko) Version/7.0.3 Safari/537.75.14""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1951.5 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.69 Safari/537.36""",
"""Mozilla/5.0 (compatible; MJ12bot/v1.4.5; http://www.majestic12.co.uk/bot.php?+)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.132 Safari/537.36""",
"""Mozilla/5.0 (iPad; CPU OS 7_1_1 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Version/7.0 Mobile/11D201 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.3;rv: 28.0)Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en; rv:1.9.1.7) Gecko/20091221 Firefox/3.5.7""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/537.36 OPR/20.0.1387.64""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.16) Gecko/20121207 Firefox/25.0 (http://variohost24.de)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140501094356)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36 OPR/20.0.1387.91""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.41 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Trident/7.0; Touch; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Windows NT 5.1; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (compatible; MSIE 11.0; Windows NT 6.2; Win64; x64; Trident/6.0)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; rv:6.0a2) Gecko/20110613 Firefox/6.0a2""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.74.9 (KHTML, like Gecko) Version/6.1.2 Safari/537.74.9""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.112 Safari/534.30""",
"""Opera/9.80 (Windows NT 5.1) Presto/2.12.388 Version/12.17""",
"""Opera/9.80 (Windows NT 6.1; WOW64; Edition Campaign 06) Presto/2.12.388 Version/12.17""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; Trident/4.0; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.5.30729; InfoPath.1; .NET CLR 3.0.30729; .NET4.0C)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322) Maxthon""",
"""Mozilla/5.0 (X11; U; FreeBSD x86_64; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.5; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:29.0) Gecko/20100101 Firefox/29.0 FirePHP/0.7.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.17 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.99 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.9) Gecko/2008061915 Panda/3.0.7""",
"""Nokia201/2.0 (11.95) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; en-US; Nokia201) U2/1.0.0 UCBrowser/9.3.0.326 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.16) Gecko/20121207 Firefox/29.0 (http://variohost24.de)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.13014 YaBrowser/13.12.1599.13014 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0; Win64; x64; rv:27.0) Gecko/20100101 Waterfox/27.0 Firefox/27.0.1""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.131 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100; Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.0.0 Mobile Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; U; es-ES) Presto/2.9.181 Version/12.00""",
"""Mozilla/5.0 (Android; Mobile; rv:29.0) Gecko/29.0 Firefox/29.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/34.0.1847.116 Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko; Google Web Preview) Chrome/27.0.1453 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""UCWEB/2.0 (Symbian; U; S60 V5; en-US; Nokia5233) U2/1.0.0 UCBrowser/9.2.0.336 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:28.0) Gecko/20100101 Firefox/28.0 Waterfox/28.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.132 Safari/537.36 OPR/21.0.1432.67""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1944.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.102 YaBrowser/14.2.1700.12508 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (iPad; CPU OS 7_0_4 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B554a Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""0 Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.27510/34.2089; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3) AppleWebKit/537.75.14 (KHTML, like Gecko) Version/7.0.3 Safari/537.75.14""",
"""Mozilla/5.0 (compatible; memorybot/1.20.33 +http://archivethe.net/en/index.php/about/internet_memory1 on behalf of DNB)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""Mozilla/5.0 (SymbianOS/9.4; Series60/5.0 Nokia5800d-1/52.0.007; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/525 (KHTML, like Gecko) Version/3.0 BrowserNG/7.2.6.9 3gpp-gba""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0)""",
"""Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Opera/9.80 (Android; Opera Mini/7.5.35199/34.2152; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 6_0_1 like Mac OS X) AppleWebKit/537.36 (KHTML, like Gecko; Google Page Speed Insights) Version/6.0 Mobile/10A525 Safari/8536.25""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko; Google Page Speed Insights) Chrome/27.0.1453 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.34 (KHTML, like Gecko) Arora/0.11.0 Safari/534.34""",
"""Dillo/3.0.2""",
"""Mozilla/5.0 (X11; Linux x86_64) KHTML/4.8.5 (like Gecko) Konqueror/4.8""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.5; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140526175429)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2008.2 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.132 Safari/537.36 OPR/21.0.1432.67""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; GTB7.5; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140528184713)""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14038/34.2220; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36""",
"""w3m/0.52""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.12 (KHTML, like Gecko) Maxthon/3.0 Chrome/26.0.1410.43 Safari/535.12""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.32 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML like Gecko) Chrome/28.0.1469.0 Safari/537.36 AlexaToolbar/alxf-2.19""",
"""Go 1.1 package http""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:29.0) Gecko/20100101 Firefox/29.0 FirePHP/0.7.4""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.107 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""AutoIt""",
"""Mozilla/5.0 (Windows NT 6.3; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Opera/9.80 (Android; Opera Mini/7.5.35199/34.2369; U; de) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.141 Mobile Safari/537.36""",
"""Mozilla/5.0 (compatible; memorybot/1.20.71 +http://archivethe.net/en/index.php/about/internet_memory1 on behalf of DNB)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3) AppleWebKit/537.76.4 (KHTML, like Gecko) Version/7.0.4 Safari/537.76.4""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Seobility (SEO-Check; http://bit.ly/1dJuuzs)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.82 Safari/537.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.2) Gecko/20100316 Firefox/3.6.2""",
"""Mozilla/4.0 (compatible; MSIE 6.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.17) Gecko/20110515 HeartRails_Capture/1.0.4 (+http://capture.heartrails.com/) Namoroka/3.6.17""",
"""Opera/9.80 (Android 4.1.2; Linux; Opera Mobi/ADR-1309251116) Presto/2.11.355 Version/12.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:26.0) Gecko/20100101 Firefox/26.0 IceDragon/26.0.0.2""",
"""Mozilla/5.0 (Windows NT 6.1; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 CoRom/35.0.1916.114 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; SV1; Maxthon; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30)""",
"""niki-bot""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/F5FECF""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML like Gecko) Chrome/28.0.1469.0 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/534.34 (KHTML, like Gecko) QupZilla/1.6.6 Safari/534.34""",
"""Mozilla/5.0 (compatible; coccoc/1.0; +http://help.coccoc.com/)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:30.0) Gecko/20100101 Firefox/0E32""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/35.0.1900.0 Chrome/35.0.1900.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; chromeframe/12.0.742.100)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140610 Firefox/24.0 Iceweasel/24.6.0""",
"""Mozilla/5.0 (compatible; MSIE 7.0; Windows NT 5.0; Trident/4.0; FBSMTWB; .NET CLR 2.0.34861; .NET CLR 3.0.3746.3218; .NET CLR 3.5.33652; msn OptimizedIE8;ENUS)""",
"""Mozilla/5.0 (Windows; U; MSIE 7.0; Windows NT 6.0; el-GR)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/536.10 (KHTML, like Gecko) Chrome/20.0.1123.4 Safari/536.10""",
"""Mozilla/5.0 (Windows NT 6.1; rv:30.0) Gecko/20100101 Firefox/30.0 FirePHP/0.7.4""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (Windows NT 5.0; 5.0)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.155 CoRom/35.0.1916.155 Safari/537.36""",
"""Mozilla/5.0 (Linux; NetCast; U) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.33 Safari/537.31 SmartTV/5.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Nokia2730c-1/2.0 (10.45) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; ru; Nokia2730c-1) U2/1.0.0 UCBrowser/9.4.1.377 U2/1.0.0 Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.155 CoRom/35.0.1916.155 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""BlackBerry7520/4.0.0 Profile/MIDP-2.0 Configuration/CLDC-1.1 UP.Browser/5.0.3.3 UP.Link/5.1.2.12 (Google WAP Proxy/1.0)""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.24) Gecko/20111107 Ubuntu/10.04 (lucid) Firefox/3.6.24""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1700.72 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; Tablet PC 2.0; InfoPath.3; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (Linux; Android 4.2.2; de-de; SAMSUNG GT-I9195/I9195XXUAMF6 Build/JDQ39) AppleWebKit/535.19 (KHTML, like Gecko) Version/1.0 Chrome/18.0.1025.308 Mobile Safari/535.19""",
"""Xenu Link Sleuth/1.3.8""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:30.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (X11; SunOS i86pc; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.157 CoRom/35.0.1916.157 Safari/537.36""",
"""Opera/9.00 (Windows NT 5.1; U; de)""",
"""IBrowse/2.2 (Windows 3.1)""",
"""ThumbSniper (http://thumbsniper.com)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; WOW64; en-US; rv:2.0.4) Gecko/20120718 AskTbAVR-IDW/3.12.5.17700 Firefox/14.0.1""",
"""Mozilla/5.0 (SymbianOS/9.4; Series60/5.0 Nokia5235/51.6.002; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/533.4 (KHTML, like Gecko) NokiaBrowser/7.3.1.33 Mobile Safari/533.4 3gpp-gba""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1b2) Gecko/20060821 BonEcho/2.0b2 (Debian-1.99+2.0b2+dfsg-1)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; MRSPUTNIK 2, 3, 0, 301; MRA 6.2 (build 7528); .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/32.0.1702.26 Safari/537.36 MRCHROME SOC""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-N8000 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.141 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.0; U; bg) Presto/2.1.1""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.2; de; rv:1.9.2.28) Gecko/20120306 Firefox/3.6.28""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36 OPR/22.0.1471.70""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.0; Trident/5.0; Trident/5.0)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:21.0) Gecko/20100101 Firefox/21.0 USA\Miami Style""",
"""Mozilla/5.0 (Windows NT 5.1; rv:11.0) Gecko Firefox/11.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/AA836C""",
"""Mozilla/5.0 (Linux; U; Android 4.0.4; tr-tr; ST17i Build/4.1.B.0.587) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 5.1; rv:29.0) Gecko/20100101 Firefox/29.0 SeaMonkey/2.26.1""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.20 Safari/537.36""",
"""Mozilla/5.0 (compatible; IstellaBot/1.18.81 +http://www.tiscali.it/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.77.4 (KHTML, like Gecko) Version/7.0.5 Safari/537.77.4""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X 10_4_11; de-de) AppleWebKit/533.16 (KHTML, like Gecko) Version/4.1 Safari/533.16""",
"""Opera/9.80 (X11; FreeBSD 9.2-RELEASE amd64) Presto/2.12.388 Version/12.16""",
"""Opera/9.80 (X11; Linux x86_64; U; en) Presto/2.5.27 Version/10.60""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Linux; Android 4.4.2; HTC6525LVW Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.141 Mobile Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 4.0.3; en-us; Enjoy 7 Plus Build/IML74K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (compatible; 007ac9 Crawler; http://crawler.007ac9.net/)""",
"""Mozilla/5.0 (Linux; U; Android 4.1.1; en-us; A700 Build/JRO03H) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/7.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E; POS2)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2096.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Android; Mobile; rv:30.0) Gecko/30.0 Firefox/30.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.67 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1061.1 Safari/536.3""",
"""Mozilla/5.0 (compatible; MSIE 9.11; Windows NT 6.1; Trident/5.0)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.138 Safari/537.36 OPR/22.0.1485.78487""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows 95; de; rv:1.9.2.6) Gecko/20100625 Firefox/30.0 (de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 38896643""",
"""Mozilla/5.0 (Windows NT 6.0; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10""",
"""Windows IE 6""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (compatible; publiclibraryarchive.org/1.0; +crawl@publiclibraryarchive.org)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; x64; fr; rv:1.9.2.13) Gecko/20101203 Firebird/3.6.13""",
"""Mozilla/5.0 (Windows NT 6.1; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.114 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; chromeframe/24.0.1312.52; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140802090848)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:5.0) Gecko/20110619 Firefox/5.0""",
"""Mozilla/5.0 (Linux; U; Android 4.1.1; es-us; ALCATEL ONE TOUCH 5020A Build/JRO03C) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.1 Mobile Safari/534.30""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (iPad; CPU OS 7_1_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Mobile/11D257""",
"""https://www.youtube.com/watch?v=RAA1xgTTw9w""",
"""https://www.youtube.com/watch?v=RAA1xgTTw9w""",
"""Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10dOpera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10Opera/9.80 (Android; Opera Mini/7.5.32195/35.3527; U; pt) Presto/2.8.119 Version/11.10""",
"""Mozilla/1.0 (compatible; MSIE 1.0; Windows NT 3.1; Trident/1.0)""",
"""Cliqzbot/0.1 (+http://cliqz.com/company/cliqzbot)""",
"""0 Opera/9.80 (J2ME/MIDP; Opera Mini/6.5.27510/35.3666; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2112.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:17.0) Gecko/20130917 Firefox/17.0 Iceweasel/17.0.9""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2113.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows 98; PalmSource/hspr-H102; Blazer/4.2) 16;320x320""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.44 Safari/537.36 OPR/24.0.1558.25 (Edition Next)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iebar; Sgrunt|V109|1746|S-1740532934|dialno; snprtz|dialno; .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.52 Safari/536.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2116.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.24 (KHTML, like Gecko) Chrome/11.0.696.68 Safari/534.24""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/7.1.32052/35.3781; U; fa) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""UCWEB/2.0 (Symbian; U; S60 V3; en-US; NOKIAN95) U2/1.0.0 UCBrowser/9.2.0.336 U2/1.0.0 Mobile""",
"""Opera/9.80 (Windows NT 6.1; WOW64) Presto/2.12.388 Version/12.17""",
"""Mozilla/5.0 (Windows NT 6.1; rv:27.0) Gecko/20121011 Firefox/27.0""",
"""Mozilla/5.0 (Android; Mobile; rv:31.0) Gecko/31.0 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Science Traveller International 1X/1.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:12.0) Gecko/20120403211507 Firefox/12.0""",
"""Mozilla/5.0 (Windows Phone 8.1; ARM; Trident/7.0; Touch; rv:11.0; IEMobile/11.0; NOKIA; Lumia 925) like Gecko""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/8.0.35158/35.3882; U; sr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:29.0) Gecko/20100101 Firefox/29.0 SeaMonkey/2.26.1""",
"""Mozilla/5.0 (iPad; U; CPU iPhone OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21 (KHTML, like Gecko) Version/4.0.4 Mobile/7B314 Safari/531.21""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; rv:11.0) Gecko/20100101 Firefox/11.0 CometBird/11.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.23) Gecko/20090825 SeaMonkey/1.1.18""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.534 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.76.4 (KHTML, like Gecko) Version/6.1.4 Safari/537.76.4""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; eSobiSubscriber 2.0.4.16)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36 OPR/23.0.1522.75""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14320/21.549; U; en) Presto/2.5.25 Version/10.54""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""yacybot (/global; amd64 Windows Server 2008 R2 6.1; java 1.7.0_25; Europe/en) http://yacy.net/bot.html""",
"""Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.17""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.78.2 (KHTML, like Gecko) Version/7.0.6 Safari/537.78.2""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_1_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) Version/7.0 Mobile/11D257 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.1.1; HUAWEI G510-0100 Build/HuaweiG510-0100) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Mobile Safari/535.19""",
"""Mozilla/5.0 (Macintosh; U; PPC Mac OS X; de-de) AppleWebKit/312.8 (KHTML, like Gecko) Safari/312.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.7) Gecko/20140802 Firefox/24.7 PaleMoon/24.7.1""",
"""LinkStats Bot""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.102 Safari/537.36""",
"""stq_bot (+http://www.searchteq.de)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140722 Firefox/24.0 Iceweasel/24.7.0""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64; rv:31.0) Gecko/20100101 Firefox/31.0 Waterfox/31.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.13+ (KHTML, like Gecko) Version/5.1.7 Safari/534.57.2""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.1.13) Gecko/20100916 Iceape/2.0.8""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; MAXTHON 2.0);""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I9100 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.135 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.103 Safari/537.36""",
"""Mozilla/5.0 (compatible; Abonti/0.92 - http://www.abonti.com)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.103 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""curl/7.35.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36 OPR/24.0.1558.53""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.865.0 Safari/535.2""",
"""Mozilla/5.0 (Windows NT 6.1; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:31.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.103 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10) AppleWebKit/600.1.3 (KHTML, like Gecko) Version/8.0 Safari/600.1.3""",
"""Mozilla/5.0 (Windows NT 5.1; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Windows; U; MSIE 9.0; Windows NT 6.0; en-US)""",
"""Nokia2700c-2/2.0 (09.98) Profile/MIDP-2.1 Configuration/CLDC-1.1 UCWEB/2.0 (Java; U; MIDP-2.0; en-US; Nokia2700c-2) U2/1.0.0 UCBrowser/9.5.0.449 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Dragon/33.1.0.0 Chrome/33.0.1750.152 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iebar; acc=none; FunWebProducts; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36 OPR/24.0.1558.53""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (SymbianOS/9.3; Series60/3.2 NokiaE5-00/102.002; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/533.4 (KHTML, like Gecko) NokiaBrowser/7.3.1.35 Mobile Safari/533.4 3gpp-gba""",
"""Mozilla/5.0 (Windows NT 6.1; ; NCLIENT50_AAP4F09D336E78) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.116 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2152.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36 QQBrowser/3.0.2313.400""",
"""Mozilla/5.0 (X11; Linux i686; rv:26.0) Gecko/20100101 Firefox/26.0""",
"""Mozilla/5.0 (Linux; Android 4.3; GT-I9300 Build/JSS15J) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.117 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36 OPR/24.0.1558.53""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Dragon/33.1.0.0 Chrome/33.0.1750.152 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; elertz 2.4.025; .NET CLR 1.0.3705; .NET CLR 1.1.4322; Media Center PC 4.0)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; chromeframe/24.0.1312.52; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20140914103008)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.13 (KHTML, like Gecko) Chrome/24.0.1290.1 Safari/537.13""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.44 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:23.0) Gecko/20100102 Firefox/23.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20100101 Firefox/21.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Opera/12.0(Windows NT 5.2;U;en)Presto/22.9.168 Version/12.00""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 YaBrowser/14.7.1916.15705 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Maxthon/4.4.1.3000 Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.102 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36 OPR/24.0.1558.61""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 107) AppleWebKit/534.48.3 (KHTML like Gecko) Version/5.1 Safari/534.48.3""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.153 YaBrowser/14.7.1916.15705 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.4.28000/35.4401; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.0; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/37.0.2062.94 Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.103 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""ghghgh""",
"""Mozilla/5.0 (X11; Linux i686; rv:24.0) Gecko/20140903 Firefox/24.0 Iceweasel/24.8.0""",
"""Mozilla/5.0 (masking-agent; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36 OPR/24.0.1558.61""",
"""Opera/9.80 (Windows NT 5.1; U; en) Presto/2.2.15 Version/10.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.122 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.117 Safari/90D955""",
"""Opera/9.80 (Android; Opera Mini/7.6.35766/35.4530; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/538.15 (KHTML, like Gecko) Version/8.0 Safari/538.15 dwb/2014.05.31""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0; WOW64; Trident/4.0; SLCC1; .NET CLR 2.0.50727; InfoPath.2; .NET CLR 3.5.30729; .NET CLR 3.0.30729; .NET4.0C; .NET4.0E)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:29.0) Gecko/20100101 Firefox/29.0""",
"""Mozilla/4.0 (compatible; MSIE 5.0; SunOS 5.9 sun4u; X11)""",
"""Buy V!@6rA --- only $1.95 per pill (pillz@superspam.ru)""",
"""Atari Pong; Agfachrome CT 21 (ASA 400 / 21 DIN; E-6 process)""",
"""Apple IIc; PRODOS 2.0.3""",
"""***** Windows mit Bundestrojaner *****""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Microsoft Pocket Internet Explorer/0.6""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.0 Safari/537.36""",
"""RX Bar""",
"""Mozilla/4.04 [en] (X11; I; HP-UX B.10.20 9000/712)""",
"""Mozilla/1.1 (compatible; MSPIE 2.0; Windows CE)""",
"""AU-MIC/2.0 MMP/2.0""",
"""Opera/5.12 (Windows 98; U) [en]""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows 98; Win 9x 4.90; BTinternet V8.1)""",
"""ICE Browser/5.05 (Java 1.4.0; Windows 2000 5.0 x86)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/37.0.2062.120 Chrome/37.0.2062.120 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_0_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) CriOS/37.0.2062.60 Mobile/12A405 Safari/9537.53""",
"""Mozilla/5.0 (iPad; CPU OS 8_0_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) CriOS/37.0.2062.60 Mobile/12A405 Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36 OPR/23.0.1522.77""",
"""Mozilla/5.0 (Windows NT 6.1; rv:24.7) Gecko/20140907 Firefox/24.7 PaleMoon/24.7.2""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2166.2 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/600.1.17 (KHTML, like Gecko) Version/7.1 Safari/537.85.10""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; zh-CN; rv:1.9.1.2) Firefox/3.5.2""",
"""Mozilla/5.0 (compatible; MixrankBot; crawler@mixrank.com)""",
"""Mozilla/5.0 (SymbianOS/9.2; U; Series60/3.1 NokiaE63-1/400.21.013; Profile/MIDP-2.0 Configuration/CLDC-1.1) AppleWebKit/413 (KHTML, like Gecko) Safari/413""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Java; U; es-la; nokiae63-2) AppleWebKit/530.13 (KHTML, like Gecko) UCBrowser/8.6.0.199/84/352/UCWEB Mobile UNTRUSTED/1.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/37.0.2062.94 Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 6.2 (build 7528); ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; iOpus-I-M; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36 OPR/23.0.1522.77 (Edition Campaign 37)""",
"""Mozilla/5.0 (X11; U; SunOS i86pc; en-US; rv:1.8.1.12) Gecko/20080303 SeaMonkey/1.1.8""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36""",
"""() { :;}; /bin/eject""",
"""madaali.de (Version: 1.06, powered by www.madaali.de +http://www.madaali.de/pfadzurbotseite/bot.html)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.120 Safari/537.36""",
"""Icarus6j - (contact: phil@icarus6.com)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; en-us; DROID BIONIC Build/9.8.2O-72_VZW-22) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36 OPR/25.0.1614.50""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Opera/9.80 (MAUI Runtime; Opera Mini/4.4.32206/35.5003; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:24.0) Gecko/20100101 Firefox/24.0; Mozilla Firefox 24.8.0 - 10652-10112-57""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; WOW64; Trident/7.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Pcy8.0.7601.17514-10552-10110-54)""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Pcy8.0.7601.17514-10552-10110-54)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:25.0) Gecko/20141013 PaleMoon/25.0.1""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.27 Safari/537.36""",
"""Mozilla/5.0 (iPad; U; CPU OS 3_2 like Mac OS X; en-us) AppleWebKit/531.21.10 (KHTML, like Gecko) Version/4.0.4 Mobile/7B334b Safari/531.21.102011-10-16 20:23:50""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2107.3 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; rv:19.0) Gecko/20121129 Firefox/19.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Iron/37.0.2000.0 Chrome/37.0.2000.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36 OPR/25.0.1614.50""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.22+ (KHTML, like Gecko) Chromium/17.0.963.56 Chrome/17.0.963.56 Safari/535.22+ Debian/7.0 (3.4.2-2.1) Epiphany/3.4.2""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux i686; ru; rv:33.2.3.12) Gecko/20120201 SeaMonkey/8.2.8""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/5.0 FirePHP/0.5""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36 OPR/25.0.1614.50""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2196.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36 OPR/23.0.1522.77""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.12) Gecko/20070731 Ubuntu/dapper-security Firefox/1.5.0.12""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0; Trident/5.0)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; Media Center PC 5.0; .NET CLR 2.0.50727)""",
"""Opera/9.80 (BlackBerry; Opera Mini/8.0.35659/35.5125; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/3.01Gold (X11; I; Linux 2.0.32 i486)""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0; Touch; ASU2JS)""",
"""Mozilla/5.0 (X11; U; Linux i686; de; rv:1.8.1.3) Gecko/20070310""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.36 Safari/537.36""",
"""Opera/9.80 (Windows NT 5.1; YB/5.1.3.0) Presto/2.12.388 Version/12.15""",
"""Opera/9.80 (Windows NT 5.1; U; MRA 8.2 (build 7121); ru) Presto/2.10.229 Version/11.64""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; MRSPUTNIK 2, 3, 0, 301; MRA 6.2 (build 7528); MRA 8.2 (build 7121); .NET CLR 1.1.4322; .NET CLR 2.0.50727; InfoPath.2)""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.152 Safari/537.22 Swing/1.3.0.6""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36 OPR/25.0.1614.63""",
"""Mozilla/5.0 (compatible; OptimizationCrawler/0.2; +http://www.domainoptima.com/robot)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.71 Safari/537.17 YE""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10) AppleWebKit/600.1.25 (KHTML, like Gecko) Version/8.0 Safari/600.1.25""",
"""Mozilla/5.0 (Linux;u;Android 2.3.7;zh-cn;) AppleWebKit/533.1 (KHTML,like Gecko) Version/4.0 Mobile Safari/533.1 (compatible; +http://www.baidu.com/search/spi_der.html)""",
"""Mozilla/5.0 (Linux;u;Android 2.3.7;zh-cn;) AppleWebKit/533.1 (KHTML,like Gecko) Version/4.0 Mobile Safari/533.1 (compatible; +http://www.baidu.com/search/spi_der.html)""",
"""ELinks/0.x.x (textmode; NetBSD 1.6.2 sparc; 132x43)""",
"""Mozilla/5.0 (Android; Mobile; rv:33.0) Gecko/33.0 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.2; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; chromeframe/24.0.1312.52; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; TCO_20141103182752)""",
"""Mozilla/5.0 (Windows NT 6.1; rv:17.0) Gecko/20100101 Firefox/17.0;""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36""",
"""Mozilla/5.0 (X11; U; FreeBSD i386; en-US; rv:1.6) Gecko/20040406 Galeon/1.3.15""",
"""Mozilla/5.0 (Linux; Android 4.1.2; GT-I8190 Build/JZO54K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.114 Mobile Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0); 360Spider""",
"""Mozilla/5.0 (Windows NT 5.0; rv:12.0) Gecko/20100101 Firefox/30.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0 Iceweasel/31.2.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (compatible; memoryBot/1.20.289 +http://internetmemory.org/en/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/600.1.17 (KHTML like Gecko) Version/7.1 Safari/537.85.10""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (X11; U; SunOS sun4u; en-US; rv:1.3) Gecko/20030318""",
"""Opera/9.80 (Macintosh; Intel Mac OS X 10.9.5; U; en) Presto/2.10.229 Version/11.64""",
"""49579303	"""
"""Mozilla/5.0 (Windows NT 5.1; rv:33.0) Gecko/20100101 Firefox/31.0""",
"""Mozilla/4.0 (compatible; MSIE8.0; Windows NT 6.0) .NET CLR 2.0.50727)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Maxthon/4.4.2.2000 Chrome/30.0.1599.101 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.1; U; MRA 6.0 (build 5976); ru) Presto/2.10.289 Version/12.02""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36""",
"""Opera/9.80 (Android; Opera Mini/7.0.29950/35.5504; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; U; Linux Core i7-4980HQ; de; rv:32.0; compatible; Jobboerse.com; http://www.xn--jobbrse-d1a.com) Gecko/20100401 Firefox/24.0""",
"""Mozilla/5.0 (compatible; SemrushBot/0.98~bl; +http://www.semrush.com/bot.html)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/37.0.2000.0 Chrome/37.0.2000.0 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/38.0.2125.111 Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 YaBrowser/14.8.1985.12084 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; ar-ae; SAMSUNG GT-I9500 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Version/1.5 Chrome/28.0.1500.94 Mobile Safari/537.36""",
"""Opera/9.80 (Android; Opera Mini/7.5.32195/35.5504; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; Android 4.2.1; Discovery Build/JOP40D) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.102 Mobile Safari/537.36 OPR/25.0.1619.84037""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.71 Safari/537.36 OPR/15.0.1147.141""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.2; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)""",
"""##################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################################""",
"""# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #""",
"""Mozilla/6.0 (Windows NT 6.5; rv:42.0) Gecko/20150302 Firefox/42.0""",
"""Mozilla/5.0 (Windows NT 6.4; Win64; x64; Trident/7.0; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/42.0 CoRom/36.0.1985.144 Chrome/36.0.1985.144 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""AmigaVoyager/3.2 (AmigaOS/MC680x0)""",
"""Opera/9.80 (X11; Linux i686; U; de) Presto/2.8.119 Version/11.10""",
"""Lynx/2.8.3dev.9 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.6""",
"""Mozilla/5.0 (Linux; Android 4.4.2; GT-I9295 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.59 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; Touch; ASU2JS; rv:11.0) like Gecko""",
"""Mozilla/5.0 (X11; Linux i686; rv:31.0) Gecko/20100101 Firefox/31.0 Iceweasel/31.2.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.143 Safari/537.36 OPR/23.0.1522.77""",
"""Mozilla/5.0 (Windows NT 6.0; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de; rv:1.9.2.6) Gecko/20100625 Firefox/33.1 (x86 de) Anonymisiert durch AlMiSoft Browser-Anonymisierer 72968307""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36 OPR/25.0.1614.71""",
"""Mozilla/5.0 (X11; U; Linux x86_64; de; rv:1.9.1.19) Gecko/20110420 SUSE/2.0.14-0.2.1 Mnenhy/0.8.5 SeaMonkey/2.0.14""",
"""Mozilla/5.0 (iPad; CPU OS 7_1_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) GSA/4.2.2.38484 Mobile/11D257 Safari/9537.53""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.2; Win64; x64) Presto/2.12.388 Version/12.17""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 7_0 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11A465 Safari/9537.53 (compatible; bingbot/2.0; http://www.bing.com/bingbot.htm)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; pt-PT; rv:1.9.1.2) Gecko/20090729 Firefox/3.5.2 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.75.14 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.75.14 OPR/26.0.1656.24""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Finderlein Research Crawler 1.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; ASU2JS; rv:11.0) like Gecko""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.814.0 Safari/535.1""",
"""Mozilla/4.0 (compatible; MSIE 5.5; Windows NT 5.0; N_o_k_i_a)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 YaBrowser/14.10.2062.12061 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/39.0.2171.65 Chrome/39.0.2171.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0,gzip(gfe)""",
"""Mozilla/5.0 (Android; Mobile; rv:34.0) Gecko/34.0 Firefox/34.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:33.0) Gecko/20100101 Firefox/33.0 Cyberfox/33.1.1""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.28 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.2; WOW64) Presto/2.12.388 Version/12.17""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (compatible; WBSearchBot/1.1; +http://www.warebay.com/bot.html)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:34.0) Gecko/20100101 Firefox/34.0 SeaMonkey/2.31,gzip(gfe)""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_1 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B411 Safari/600.1.4""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686;rv:31.0)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0 Iceweasel/31.3.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; compatible; BDCbot/1.0; +http://ecommerce.bigdatacorp.com.br/faq.aspx) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/13.0.782.107 Safari/535.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Opera/9.80 (Windows NT 6.0) Presto/2.12.388 Version/12.14""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36 OPR/26.0.1656.24""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.95 YaBrowser/13.10.1500.9323 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36 OPR/26.0.1656.32""",
"""Opera/9.21 (Windows NT 6.0; U; en)Opera/9.21 (Windows NT 5.1; U; en)Opera/9.20 (X11; Linux i686; U; ru)Opera/9.20 (Windows NT 5.2; U; en)Opera/9.20 (Windows NT 5.1; U; it)""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 812 like Mac OS X) AppleWebKit/600.1.4 (KHTML like Gecko) Mobile/12B440 Version/7.0 Safari/9537.53""",
"""python-requests/2.3.0 CPython/2.7.8 Linux/3.16.2-1-ARCH""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2243.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2050.0 Iron/38.0.2150.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0 FirePHP/0.7.4""",
"""Mozilla/5.0 (Android; Tablet; rv:34.0) Gecko/34.0 Firefox/34.0""",
"""Mozilla/5.0 (compatible; memoryBot/1.21.16 +http://internetmemory.org/en/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/600.2.5 (KHTML, like Gecko) Version/8.0.2 Safari/600.2.5""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36 OPR/26.0.1656.60""",
"""Mozilla/5.0 (Windows NT 6.1; rv:35.0) Gecko/20100101 Firefox/35.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Opera/9.50 (J2ME/MIDP; Opera Mini/5.1.24700/29.3757; U; en)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:24.0) Gecko/20140924 Firefox/24.0 Iceweasel/24.8.1""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2100.0 Iron/39.0.2100.0 Safari/537.36""",
"""Mozilla/5.0 (compatible; memoryBot/1.21.14 +http://mignify.com/bot.html)""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; ru; rv:1.9.2.13) Gecko/20101203 Firefox/3.6.13 sputnik 2.1.0.18 YB/4.3.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/45.0 Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/45.0 Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.89 Safari/537.1; 360Spider""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/44.0 Chrome/38.0.2125.122 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; GT-I9500 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.59 Mobile Safari/537.36""",
"""Mozilla/5.0 (compatible; memoryBot/1.21.24 +http://internetmemory.org/en/)""",
"""Mozilla/4.0 (compatible; MSIE 4.0; Windows 95)""",
"""horst""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:28.0) Gecko/20100101 Firefox/28.0""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.45 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; rv:34.0.5) Gecko/20100101 Firefox/34.0.5 anonymized by Abelssoft 1882435715""",
"""Mozilla/5.0 (Windows NT 6.1; rv:34.0.5) Gecko/20100101 Firefox/34.0.5 anonymized by Abelssoft 890744422""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:37.0) Gecko/20100101 Firefox/37.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; APCPMS=1690.469D.63AF-win7^N20130625085429176806A974AA63543AD53F_16707^1^2^675102474^889536266^30417777^2638519008; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; InfoPath.2)""",
"""Opera/9.80 (Android; Opera Mini/7.6.40077/35.6368; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (compatible; memoryBot/1.20.311 +http://internetmemory.org/en/)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; Win64; x64;) Gecko/20100101 Firefox/20.0""",
"""XNXX""",
"""MAUI WAP Browser""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; MRA 5.10 (build 5339); GTB7.5; .NET CLR 2.0.50727; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET4.0C; .NET4.0E; .NET CLR 1.1.4322)""",
"""Opera/9.80 (BlackBerry; Opera Mini/8.0.35659/35.6368; U; id) Presto/2.8.119 Version/11.10""",
"""Mozilla/3.0 (compatible; NetPositive/2.2)""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:32.0) Gecko/20100101 Firefox/32.0""",
"""Wget/1.16 (linux-gnu)""",
"""rogerbot/1.0 (http://moz.com/help/pro/what-is-rogerbot-, rogerbot-wherecat@moz.com)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2251.0 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.5; SV1)""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/45.0 Chrome/39.0.2171.73 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/35.6368; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (X11; Linux i686; rv:33.0) Gecko/20100101 Firefox/33.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36 OPR/26.0.1656.24""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/35.0.1916.157 CoRom/35.0.1916.157 Safari/537.36""",
"""Java/1.7.0_25""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 YaBrowser/14.10.2062.12061 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; Windows NT 5.1; (R1 1.5); .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; America Online Browser 1.1; Windows NT 5.1; (R1 1.5); .NET CLR 2.0.50727; InfoPath.1)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2267.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_0) AppleWebKit/537.4 (KHTML, like Gecko) Chrome/22.0.1229.79 Safari/537.4""",
"""Mozilla/5.0 (X11; Linux i686; rv:24.0) Gecko/20140319 Firefox/24.0 Iceweasel/24.4.0""",
"""curl/7.26.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_7) AppleWebKit/534.24 (KHTML, like Gecko) RockMelt/0.9.58.494 Chrome/11.0.696.71 Safari/534.24""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20110814 Firefox/6.0 Google favicon""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2.14912/35.6497; U; es) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; Touch; rv:11.0) like Gecko""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Maxthon/4.4.3.4000 Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.3 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Maxthon/4.4.4.600 Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36 OPR/20.0.1387.82""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.3 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""GigablastOpenSource/1.0""",
"""Mozilla/5.0 (Windows NT 5.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.0; rv:10.0.12) Gecko/20100101 Firefox/10.0.12""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/5.0 (Windows NT 6.1; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""MOZILLA/5.0 (Windows NT 5.1; rv:10.0.2) Gecko/20100101 Firefox/10.0.2""",
"""Mozilla/5.0 (Linux; Android 4.2.2; R1001 Build/JDQ39) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.93 Mobile Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_1 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B410 Safari/600.1.4""",
"""Mozilla/5.0 (Linux; Android 4.4.2; SM-G900F Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.93 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.85 Safari/537.36""",
"""Mozilla/5.0 ;iPhone; CPU iPhone OS 7_1_2 like Mac OS X; AppleWebKit/537.51.2 ;KHTML, like Gecko; Version/7.0/Mobile/Safari/9537.53""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36 OPR/26.0.1656.24""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 YaBrowser/14.10.2062.12061 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36 OPR/26.0.1656.60""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Dragon/36.1.1.21 Chrome/36.0.1985.97 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2220.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:35.0) Gecko/20100101 Firefox/9578""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.2; Win64; x64; Trident/7.0; .NET4.0E; .NET4.0C; .NET CLR 3.5.30729; .NET CLR 2.0.50727; .NET CLR 3.0.30729; 95781BD850)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.21 (KHTML, like Gecko) QupZilla/1.8.5 Safari/537.21""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Iron/29.0.1600.1 Chrome/29.0.1600.1 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686; rv:10.0) Gecko/20100101 Firefox/10.0 Iceweasel/10.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:35.0 () Gecko/20100101 Firefox/35.0 ( anonymized by Abelssoft 1070925159""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.35 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32454/35.6998; U; en) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Linux; Android 4.4.2; G100 Build/KVT49L) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/30.0.0.0 Mobile Safari/537.36""",
"""Mozilla/2.0 (compatible; crw)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/5.0 (compatible; linkdexbot/2.2; +http://www.linkdex.com/bots/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.91 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0 Iceweasel/31.4.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.94 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; de-DE) AppleWebKit/534.17 (KHTML, like Gecko) Chrome/10.0.649.0 Safari/534.17""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 5.0.1; Nexus 4 Build/LRX22C) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.89 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.35 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (X11; CrOS x86_64 6310.68.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.96 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.94 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2228.0 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.99 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.89 Vivaldi/1.0.94.2 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.4; XT1045 Build/KXB21.14-L1.45) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.89 Mobile Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.89 Safari/537.36""",
"""Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727; MAXTHON 2.0); Connect Us: webauth@cmcm.com""",
"""Mozilla/5.0 (Linux; Android 5.0.1; Nexus 5 Build/LRX22C) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.89 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.43 Safari/537.36""",
"""Mozilla/5.0 (iPad; CPU OS 8_1_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Mobile/12B440""",
"""Mozilla/5.0 (iPad; CPU OS 8_1_3 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B466 Safari/600.1.4""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (iPad; CPU OS 8_1_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B440 Safari/600.1.4""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_0_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12A405 Safari/600.1.4""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_1_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) CriOS/39.0.2171.50 Mobile/12B440 Safari/600.1.4""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.12 Safari/537.36""",
"""python-requests/2.5.1 CPython/3.4.2 Linux/3.18.5-1-ARCH""",
"""python-requests/2.5.1 CPython/2.7.9 Linux/3.18.5-1-ARCH""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_1_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B440 Safari/600.1.4""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1985.125 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; Nexus 5 Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.105 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/600.1.25 (KHTML, like Gecko) QuickLook/5.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/600.1.25 (KHTML, like Gecko) QuickLook/5.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.4) Gecko/20100625 Gentoo Firefox/3.6.4""",
"""UCWEB/2.0 (Java; U; MIDP-2.0; Nokia203/20.37) U2/1.0.0 UCBrowser/8.7.0.218 U2/1.0.0 Mobile""",
"""Mozilla/5.0 (Linux; U; Android 4.2.2; de-de; GT-I8200N Build/JDQ39) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Linux; Android 4.4.4; Galaxy Nexus Build/KTU84P) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.93 Mobile Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686 on x86_64; rv:24.0) Gecko/20100101 Firefox/24.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36 OPR/26.0.1656.60 (Edition Campaign 47)""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686; rv:35.0) Gecko/20100101 Firefox/35.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:35.0) Gecko/20100101 Firefox/35.0 Iceweasel/35.0.1""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (X11; U; FreeBSD amd64; en-us) AppleWebKit/531.2 (KHTML, like Gecko) Safari/531.2 Epiphany/2.30.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/600.3.18 (KHTML, like Gecko) Version/8.0.3 Safari/600.3.18""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/600.3.18 (KHTML, like Gecko) Version/8.0.3 Safari/600.3.18""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/600.3.18 (KHTML, like Gecko) Version/8.0.3 Safari/600.3.18""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 YaBrowser/14.10.2062.12521 Safari/537.36""",
"""Mozilla/5.0 (X11; OpenBSD amd64; rv:28.0) Gecko/20100101 Firefox/35.0.1""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.53 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.10) Gecko/20071203 Ubuntu/7.10 (gutsy) Firefox/2.0.0.10 (Linux Mint)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36 OPR/27.0.1689.69""",
"""Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36 OPR/27.0.1689.69 (Edition Campaign 37)""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/35.7561; U; ru) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (compatible; Findxbot/1.0; +http://www.findxbot.com)""",
"""Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/600.1.25 (KHTML, like Gecko) Version/8.0 Safari/600.1.25""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.93 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:38.0) Gecko/20100101 Firefox/38.0""",
"""Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; GTB7.5; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; InfoPath.2; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/4.0; InfoPath.2; SV1; .NET CLR 2.0.50727; WOW64)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 1084) AppleWebKit/536.29.13 (KHTML like Gecko) Version/6.0.4 Safari/536.29.13""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) coc_coc_browser/46.0 Chrome/40.0.2214.113 Safari/537.36""",
"""Opera/9.80 (SpreadTrum; Opera Mini/4.4.31492/35.7770; U; fr) Presto/2.8.119 Version/11.10""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36 OPR/27.0.1689.76""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.10; rv:34.0) Gecko/20100101 Firefox/34.0 AlexaToolbar/alxf-2.21""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/7.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0)""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/7.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0; .NET4.0C; .NET4.0E; Tablet PC 2.0; ms-office)""",
"""Mozilla/5.0 (Linux; Android 4.4.4; XT1032 Build/KXB21.14-L1.40) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/33.0.0.0 Mobile Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.0; rv:34.0) Gecko/20100101 Firefox/34.0""",
"""Mozilla/5.0 (Linux; U; Android 4.1.1; en-us; EVO Build/JRO03C) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 ( ; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0)""",
"""Mozilla/5.0 (Android; Mobile; rv:36.0) Gecko/36.0 Firefox/36.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/40.0.2214.111 Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux amd64; rv:5.0) Gecko/20100101 Firefox/5.0 (Debian)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2132.2 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36 OPR/27.0.1689.76""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/40.0.2214.111 Chrome/40.0.2214.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Dragon/36.1.1.21 Chrome/36.0.1985.97 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; en) AppleWebKit/533.19.4 (KHTML, like Gecko) Version/4.1.3 Safari/533.19.4""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36 OPR/27.0.1689.76""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.76 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2100.0 Iron/39.0.2100.0 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64; rv:19.0; Avant TriCore) Gecko/20130309 Firefox/19.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36 OPR/27.0.1689.76 (Edition Yx)""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.76 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 6.1; rv:6.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.74 Safari/537.36 OPR/28.0.1750.36 (Edition beta)""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.2311.22 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/534.30 (KHTML, like Gecko) Ubuntu/10.04 Chromium/12.0.742.112 Chrome/12.0.742.112 Safari/534.30""",
"""Java/1.7.0_51""",
"""Opera/9.01 (X11; U; fr)""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.74 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.115 Safari/537.36""",
"""Mozilla/5.0 (X11; FreeBSD i386) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/41.0.2272.76 Chrome/41.0.2272.76 Safari/537.36""",
"""Java/1.7.0_65""",
"""Mozilla/5.0 (Windows NT 10.0; WOW64; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Java/1.6.0_21""",
"""Mozilla/5.0 (Windows NT 5.1; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Was macht das GehÃ¤nge, MCFly?""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/4.0(compatible; MSIE 7.0b; Windows NT 6.0)""",
"""Mozilla/5.0 (X11; NetBSD i386) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 5.0.2; Nexus 4 Build/LRX22G) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.109 Mobile Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.76 Safari/537.36 OPR/28.0.1750.40""",
"""ltx71 - (http://ltx71.com/)""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/43.0.2327.5 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; MSIE 9.0; Windows NT 9.0; en-US) AppEngine-Google; (+http://code.google.com/appengine; appid: s~virustotalcloud)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:x.xx) Gecko/20030504 Mozilla Firebird/0.6""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.1.5) Gecko/20091102 Firefox/3.5.5 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/534.7 (KHTML, like Gecko) Chrome/7.0.514.0 Safari/534.7""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Linux; Android 4.4.2; en-us; SAMSUNG SM-G900F Build/KOT49H) AppleWebKit/537.36 (KHTML, like Gecko) Version/1.6 Chrome/28.0.1500.94 Mobile Safari/537.36""",
"""Mozilla/4.02 [en] (X11; I; SunOS 5.6 sun4u)""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.2311.50 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.154 Safari/537.36 OPR/20.0.1387.91""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.101 Safari/537.36 OPR/25.0.1614.50 (Edition Yx 01)""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/4.04 [en] (X11; I; IRIX 5.3 IP22)""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.89 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Android; Tablet; rv:36.0) Gecko/36.0 Firefox/36.0""",
"""Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; Sky Broadband; Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1) ; TuneUp HTML Client Embedded Web Browser from: http*//bsalsa.com/; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; .NET CLR 1.1.4322)""",
"""Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.94 Safari/537.36""",
"""Opera/9.80 (Series 60; Opera Mini/7.1.32444/36.1370; U; id) Presto/2.12.423 Version/12.16""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 4.1.2; es-sa; LG-E450f Build/JZO54K) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/536.5 (KHTML, like Gecko) YaBrowser/1.0.1084.5402 Chrome/19.0.1084.5409 Safari/536.5""",
"""Mozilla/5.0 (Linux; Android 4.1.2; Micromax P410i Build/JZO54K) AppleWebKit/537.31 (KHTML like Gecko) Chrome/26.0.1410.58 Mobile Safari/537.31""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Schaedelproduktionsclient (not reality compatible) Â¶)HÃ‚8Ã•ÃœY""",
"""Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:36.0) Gecko/20100101 Firefox/36.0""",
"""Mozilla/5.0 (X11; Linux i686; rv:31.0) Gecko/20100101 Firefox/31.0 Iceweasel/31.5.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Maxthon/4.4.1.5000 Chrome/30.0.1599.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2219.0 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.2311.60 Safari/537.36""",
"""Mozilla/5.0 (Linux; U; Android 2.3.6; es-us; ZTE V795 Build/GRK39F) AppleWebKit/533.1 (KHTML, like Gecko) Version/4.0 Mobile Safari/533.1 MMS/ZTE-Android-MMS-V2.0""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2227.0 Safari/537.36""",
"""Opera/9.80 (J2ME/MIDP; Opera Mini/4.2/36.1431; U; en) Presto/2.12.423 Version/12.16""",
"""Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Windows; U; Windows NT 6.0; fr) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.27 Safari/525.13""",
"""Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:2.0) Gecko/20110307 Firefox/4.0 (.NET CLR 3.5.30729)""",
"""Mozilla/5.0 (Android; Tablet; rv:37.0) Gecko/37.0 Firefox/37.0""",
"""Mozilla/5.0 (X11; Linux x86_64; rv:37.0) Gecko/20100101 Firefox/37.0""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:37.0) Gecko/20100101 Firefox/37.0""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.104 Safari/537.36""",
"""Mozilla/5.0 (Mozilla/5.0 (Windows NT 6.1; Win64; x64; Trident/7.0; rv:11.0) like Gecko; Windows NT 6.1; Win64; x64; Trident/7.0; rv:11.0) like Gecko""",
"""DoD-NSA/2.4.2 MUSCULAR/2.14 E-GIRAFFE/1.4.1 GNUTLS/2.12.18dev""",
"""Lynx (2.8.6int; Linux i686; en-US) FOXACID/3.6.4 GNUTLS/2.12.2""",
"""Bottle GUY is a Gaping Asshole - http://www.bottleguy.com""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_2) AppleWebKit/600.4.10 (KHTML, like Gecko) Version/8.0.4 Safari/600.4.10""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_2 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12D508 Safari/600.1.4""",
"""Mozilla/5.0 (iPhone; CPU iPhone OS 8_1_3 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B466 Safari/600.1.4""",
"""Mozilla/5.0 (Linux; U; Android 4.3; de-de; GT-I9300 Build/JSS15J) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30""",
"""Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:36.0) Gecko/20100101 Firefox/36.0.4 Waterfox/36.0.4""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64; rv:38.0) Gecko/20100101 Firefox/38.0""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.118 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.101 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.118 Safari/537.36""",
"""Mozilla/5.0 (X11; Linux i686; rv:24.0) Gecko/20140307 Firefox/24.0 Iceweasel/24.3.0""",
"""Mozilla/5.0 (compatible; Lipperhey-Kaus-Australis/5.0; +https://www.lipperhey.com/en/about/)""",
"""Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36 TheWorld 6""",
"""Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:37.0) Gecko/20100101 Firefox/37.0""",
"""Mozilla/5.0 (Windows NT 5.1; rv:37.0) Gecko/20100101 Firefox/37.0""",
"""Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.118 Safari/537.36""",
"""Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/41.0.2272.118 Safari/537.36""",
"""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1929.0 Safari/537.36""",]